/*************************************************************************

Include file : unifacparma.h

Purpose: Unifac parameters (replace file read)

Include dependencies:  Included in Unidriver.c

Notes: Type A compounds + H2O at 25 C
       (Data of Lyman, Reehl, Rosenblatt, 1990)

       NMOL and NFUNC need to match DIMMOL and DIMFUN in unidriver.c

       Parameters inputted as in the original fortran input file, therefore
       a transpose is needed in the unidriver C program for matrices A and NU
       in order to pass them properly into the Fortran unifac routine.

       Orders of the functional groups:
         Groups                 Subgroups
         C                      CH3
         C                      CH2
         C                      CH1
         C                      C
         OH                     OH
         H2O                    H2O
         Carbonyls              CH3CO
         Aldehyde               HCO
         Carboxylic Acid        COOH

revision History:  1. Developed by Betty Pun, AER, December, 1999 
	              under CARB funding
		   2. Changed from original 5 Type A SOA + butandioic acid 
                      to 6 anthropogenic and biogenic SOA for MADRID 1.5
		      July 2005

**************************************************************************/

                                                                               

#ifndef UNIPARM_H
#define UNIPARM_H

/* no. of molecules */  	
int NMOL = 6;

/* no. of functional groups */
int NFUNC = 8;	

/* Z = 10 is a fixed parameter in Unifac */
double Z = 10.0;

/* original file input has temperature, 
but temperature is in main input file now */

/* group volume parameters */
/* dimension of RG is the same as NFUNC */
double RG[DIMFUN] = {0.9011, 0.6744, 0.4469, 0.2195, 0.92, 1.6724, 0.998, 1.3013};

/* group surface area parameters */
/* dimension of QG is the same as NFUNC */
double QG[DIMFUN] = {0.8480, 0.5400, 0.2280, 0.0000, 1.40, 1.4880, 0.948, 1.2240};

/* no. of groups in each molecule*/
int NU[DIMMOL][DIMFUN] = { 
  {2, 2, 2, 1, 0, 0, 0, 2}, /* BiA2D */
  {2, 1, 2, 1, 0, 1, 0, 1}, /* BiA1D */
  {2, 2, 2, 1, 0, 1, 1, 0}, /* BiA0D */
  {0, 0, 0, 0, 0, 0, 2, 0}, /* Glyoxal */
  {0, 0, 0, 0, 0, 1, 1, 0}, /* Methyl Glyoxal */
  {0, 0, 0, 0, 1, 0, 0, 0}};
  
/* no. of groups in each molecule*/
double A[DIMFUN][DIMFUN] = {
{0.0,      0.0    ,  0.0    ,  0.0    ,  1318.00,  476.400,  677.000,  663.500},
{0.0,      0.0    ,  0.0    ,  0.0    ,  1318.00,  476.400,  677.000,  663.500},
{0.0,      0.0    ,  0.0    ,  0.0    ,  1318.00,  476.400,  677.000,  663.500},
{0.0,      0.0    ,  0.0    ,  0.0    ,  1318.00,  476.400,  677.000,  663.500},
{300.000,  300.000,  300.000,  300.000,  0.0    ,  -195.40,  -116.00,  -14.090},
{26.7600,  26.7600,  26.7600,  26.7600,  472.500,  0.0    ,  -37.360,  669.400},
{505.700,  505.700,  505.700,  505.700,  480.800,  128.000,  0.0    ,  497.50},
{315.300,  315.300,  315.300,  315.300,  -66.170,  -297.80,  -165.50,  0.0}
};

#endif

/********************END unifacparam.h**********************************/


