C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      temp = M(10, 9) * x(9)
      x(10) = ( x(10) - temp ) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      x(12) = x(12) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      temp = M(14, 7) * x(7)
      temp = temp + M(14, 8) * x(8)
      x(14) = ( x(14) - temp ) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      x(16) = x(16) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      x(19) = x(19) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      temp = M(23, 22) * x(22)
      x(23) = ( x(23) - temp ) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      x(26) = x(26) / M(26, 26)

      temp = M(27, 25) * x(25)
      temp = temp + M(27, 26) * x(26)
      x(27) = ( x(27) - temp ) / M(27, 27)

      temp = M(28, 25) * x(25)
      temp = temp + M(28, 26) * x(26)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 25) * x(25)
      temp = temp + M(29, 26) * x(26)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(30, 25) * x(25)
      temp = temp + M(30, 26) * x(26)
      x(30) = ( x(30) - temp ) / M(30, 30)

      x(31) = x(31) / M(31, 31)

      x(32) = x(32) / M(32, 32)

      x(33) = x(33) / M(33, 33)

      temp = M(34, 22) * x(22)
      temp = temp + M(34, 33) * x(33)
      x(34) = ( x(34) - temp ) / M(34, 34)

      x(35) = x(35) / M(35, 35)

      x(36) = x(36) / M(36, 36)

      x(37) = x(37) / M(37, 37)

      temp = M(38, 7) * x(7)
      temp = temp + M(38, 8) * x(8)
      temp = temp + M(38, 14) * x(14)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(39, 14) * x(14)
      temp = temp + M(39, 38) * x(38)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 8) * x(8)
      temp = temp + M(40, 39) * x(39)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 38) * x(38)
      x(41) = ( x(41) - temp ) / M(41, 41)

      x(42) = x(42) / M(42, 42)

      temp = M(43, 42) * x(42)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 14) * x(14)
      temp = temp + M(44, 20) * x(20)
      temp = temp + M(44, 37) * x(37)
      temp = temp + M(44, 41) * x(41)
      temp = temp + M(44, 42) * x(42)
      temp = temp + M(44, 43) * x(43)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 8) * x(8)
      temp = temp + M(45, 20) * x(20)
      temp = temp + M(45, 35) * x(35)
      temp = temp + M(45, 36) * x(36)
      temp = temp + M(45, 37) * x(37)
      temp = temp + M(45, 42) * x(42)
      temp = temp + M(45, 43) * x(43)
      temp = temp + M(45, 44) * x(44)
      x(45) = ( x(45) - temp ) / M(45, 45)

      x(46) = x(46) / M(46, 46)

      temp = M(47, 38) * x(38)
      temp = temp + M(47, 41) * x(41)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 4) * x(4)
      temp = temp + M(48, 20) * x(20)
      temp = temp + M(48, 31) * x(31)
      temp = temp + M(48, 33) * x(33)
      temp = temp + M(48, 35) * x(35)
      temp = temp + M(48, 36) * x(36)
      temp = temp + M(48, 37) * x(37)
      temp = temp + M(48, 39) * x(39)
      temp = temp + M(48, 41) * x(41)
      temp = temp + M(48, 42) * x(42)
      temp = temp + M(48, 43) * x(43)
      temp = temp + M(48, 44) * x(44)
      temp = temp + M(48, 45) * x(45)
      x(48) = ( x(48) - temp ) / M(48, 48)

      x(49) = x(49) / M(49, 49)

      temp = M(50, 15) * x(15)
      temp = temp + M(50, 38) * x(38)
      temp = temp + M(50, 41) * x(41)
      temp = temp + M(50, 43) * x(43)
      temp = temp + M(50, 44) * x(44)
      temp = temp + M(50, 45) * x(45)
      temp = temp + M(50, 48) * x(48)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 33) * x(33)
      temp = temp + M(51, 35) * x(35)
      temp = temp + M(51, 36) * x(36)
      temp = temp + M(51, 37) * x(37)
      temp = temp + M(51, 39) * x(39)
      temp = temp + M(51, 40) * x(40)
      temp = temp + M(51, 41) * x(41)
      temp = temp + M(51, 42) * x(42)
      temp = temp + M(51, 43) * x(43)
      temp = temp + M(51, 48) * x(48)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 11) * x(11)
      temp = temp + M(52, 35) * x(35)
      temp = temp + M(52, 36) * x(36)
      temp = temp + M(52, 38) * x(38)
      temp = temp + M(52, 41) * x(41)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 7) * x(7)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 8) * x(8)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 6) * x(6)
      temp = temp + M(55, 20) * x(20)
      temp = temp + M(55, 35) * x(35)
      temp = temp + M(55, 37) * x(37)
      temp = temp + M(55, 42) * x(42)
      temp = temp + M(55, 45) * x(45)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 5) * x(5)
      temp = temp + M(56, 23) * x(23)
      temp = temp + M(56, 32) * x(32)
      temp = temp + M(56, 48) * x(48)
      temp = temp + M(56, 49) * x(49)
      temp = temp + M(56, 55) * x(55)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 4) * x(4)
      temp = temp + M(57, 13) * x(13)
      temp = temp + M(57, 22) * x(22)
      temp = temp + M(57, 23) * x(23)
      temp = temp + M(57, 33) * x(33)
      temp = temp + M(57, 35) * x(35)
      temp = temp + M(57, 36) * x(36)
      temp = temp + M(57, 37) * x(37)
      temp = temp + M(57, 39) * x(39)
      temp = temp + M(57, 41) * x(41)
      temp = temp + M(57, 42) * x(42)
      temp = temp + M(57, 43) * x(43)
      temp = temp + M(57, 44) * x(44)
      temp = temp + M(57, 45) * x(45)
      temp = temp + M(57, 55) * x(55)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 3) * x(3)
      temp = temp + M(58, 4) * x(4)
      temp = temp + M(58, 5) * x(5)
      temp = temp + M(58, 6) * x(6)
      temp = temp + M(58, 7) * x(7)
      temp = temp + M(58, 8) * x(8)
      temp = temp + M(58, 9) * x(9)
      temp = temp + M(58, 13) * x(13)
      temp = temp + M(58, 18) * x(18)
      temp = temp + M(58, 19) * x(19)
      temp = temp + M(58, 21) * x(21)
      temp = temp + M(58, 23) * x(23)
      temp = temp + M(58, 24) * x(24)
      temp = temp + M(58, 31) * x(31)
      temp = temp + M(58, 32) * x(32)
      temp = temp + M(58, 33) * x(33)
      temp = temp + M(58, 34) * x(34)
      temp = temp + M(58, 35) * x(35)
      temp = temp + M(58, 36) * x(36)
      temp = temp + M(58, 37) * x(37)
      temp = temp + M(58, 38) * x(38)
      temp = temp + M(58, 39) * x(39)
      temp = temp + M(58, 40) * x(40)
      temp = temp + M(58, 41) * x(41)
      temp = temp + M(58, 42) * x(42)
      temp = temp + M(58, 43) * x(43)
      temp = temp + M(58, 44) * x(44)
      temp = temp + M(58, 45) * x(45)
      temp = temp + M(58, 48) * x(48)
      temp = temp + M(58, 49) * x(49)
      temp = temp + M(58, 50) * x(50)
      temp = temp + M(58, 51) * x(51)
      temp = temp + M(58, 55) * x(55)
      temp = temp + M(58, 56) * x(56)
      temp = temp + M(58, 57) * x(57)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 15) * x(15)
      temp = temp + M(59, 19) * x(19)
      temp = temp + M(59, 33) * x(33)
      temp = temp + M(59, 35) * x(35)
      temp = temp + M(59, 36) * x(36)
      temp = temp + M(59, 37) * x(37)
      temp = temp + M(59, 38) * x(38)
      temp = temp + M(59, 41) * x(41)
      temp = temp + M(59, 42) * x(42)
      temp = temp + M(59, 43) * x(43)
      temp = temp + M(59, 48) * x(48)
      temp = temp + M(59, 50) * x(50)
      temp = temp + M(59, 55) * x(55)
      temp = temp + M(59, 57) * x(57)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 3) * x(3)
      temp = temp + M(60, 21) * x(21)
      temp = temp + M(60, 33) * x(33)
      temp = temp + M(60, 35) * x(35)
      temp = temp + M(60, 36) * x(36)
      temp = temp + M(60, 37) * x(37)
      temp = temp + M(60, 42) * x(42)
      temp = temp + M(60, 48) * x(48)
      temp = temp + M(60, 55) * x(55)
      temp = temp + M(60, 57) * x(57)
      temp = temp + M(60, 58) * x(58)
      temp = temp + M(60, 59) * x(59)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 4) * x(4)
      temp = temp + M(61, 6) * x(6)
      temp = temp + M(61, 18) * x(18)
      temp = temp + M(61, 20) * x(20)
      temp = temp + M(61, 31) * x(31)
      temp = temp + M(61, 35) * x(35)
      temp = temp + M(61, 36) * x(36)
      temp = temp + M(61, 43) * x(43)
      temp = temp + M(61, 44) * x(44)
      temp = temp + M(61, 45) * x(45)
      temp = temp + M(61, 55) * x(55)
      temp = temp + M(61, 56) * x(56)
      temp = temp + M(61, 57) * x(57)
      temp = temp + M(61, 58) * x(58)
      temp = temp + M(61, 59) * x(59)
      temp = temp + M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 33) * x(33)
      temp = temp + M(62, 35) * x(35)
      temp = temp + M(62, 36) * x(36)
      temp = temp + M(62, 37) * x(37)
      temp = temp + M(62, 39) * x(39)
      temp = temp + M(62, 41) * x(41)
      temp = temp + M(62, 42) * x(42)
      temp = temp + M(62, 43) * x(43)
      temp = temp + M(62, 58) * x(58)
      temp = temp + M(62, 59) * x(59)
      temp = temp + M(62, 60) * x(60)
      temp = temp + M(62, 61) * x(61)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 18) * x(18)
      temp = temp + M(63, 37) * x(37)
      temp = temp + M(63, 42) * x(42)
      temp = temp + M(63, 43) * x(43)
      temp = temp + M(63, 48) * x(48)
      temp = temp + M(63, 55) * x(55)
      temp = temp + M(63, 58) * x(58)
      temp = temp + M(63, 59) * x(59)
      temp = temp + M(63, 60) * x(60)
      temp = temp + M(63, 61) * x(61)
      temp = temp + M(63, 62) * x(62)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 12) * x(12)
      temp = temp + M(64, 32) * x(32)
      temp = temp + M(64, 39) * x(39)
      temp = temp + M(64, 40) * x(40)
      temp = temp + M(64, 41) * x(41)
      temp = temp + M(64, 43) * x(43)
      temp = temp + M(64, 56) * x(56)
      temp = temp + M(64, 57) * x(57)
      temp = temp + M(64, 58) * x(58)
      temp = temp + M(64, 59) * x(59)
      temp = temp + M(64, 60) * x(60)
      temp = temp + M(64, 61) * x(61)
      temp = temp + M(64, 62) * x(62)
      temp = temp + M(64, 63) * x(63)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 14) * x(14)
      temp = temp + M(65, 22) * x(22)
      temp = temp + M(65, 24) * x(24)
      temp = temp + M(65, 42) * x(42)
      temp = temp + M(65, 55) * x(55)
      temp = temp + M(65, 56) * x(56)
      temp = temp + M(65, 57) * x(57)
      temp = temp + M(65, 58) * x(58)
      temp = temp + M(65, 59) * x(59)
      temp = temp + M(65, 60) * x(60)
      temp = temp + M(65, 61) * x(61)
      temp = temp + M(65, 62) * x(62)
      temp = temp + M(65, 63) * x(63)
      temp = temp + M(65, 64) * x(64)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(66, 12) * x(12)
      temp = temp + M(66, 14) * x(14)
      temp = temp + M(66, 15) * x(15)
      temp = temp + M(66, 18) * x(18)
      temp = temp + M(66, 19) * x(19)
      temp = temp + M(66, 20) * x(20)
      temp = temp + M(66, 22) * x(22)
      temp = temp + M(66, 24) * x(24)
      temp = temp + M(66, 33) * x(33)
      temp = temp + M(66, 35) * x(35)
      temp = temp + M(66, 36) * x(36)
      temp = temp + M(66, 37) * x(37)
      temp = temp + M(66, 41) * x(41)
      temp = temp + M(66, 42) * x(42)
      temp = temp + M(66, 44) * x(44)
      temp = temp + M(66, 45) * x(45)
      temp = temp + M(66, 50) * x(50)
      temp = temp + M(66, 55) * x(55)
      temp = temp + M(66, 56) * x(56)
      temp = temp + M(66, 57) * x(57)
      temp = temp + M(66, 58) * x(58)
      temp = temp + M(66, 59) * x(59)
      temp = temp + M(66, 60) * x(60)
      temp = temp + M(66, 61) * x(61)
      temp = temp + M(66, 62) * x(62)
      temp = temp + M(66, 63) * x(63)
      temp = temp + M(66, 64) * x(64)
      temp = temp + M(66, 65) * x(65)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(67, 3) * x(3)
      temp = temp + M(67, 4) * x(4)
      temp = temp + M(67, 6) * x(6)
      temp = temp + M(67, 7) * x(7)
      temp = temp + M(67, 8) * x(8)
      temp = temp + M(67, 9) * x(9)
      temp = temp + M(67, 13) * x(13)
      temp = temp + M(67, 14) * x(14)
      temp = temp + M(67, 19) * x(19)
      temp = temp + M(67, 20) * x(20)
      temp = temp + M(67, 21) * x(21)
      temp = temp + M(67, 22) * x(22)
      temp = temp + M(67, 23) * x(23)
      temp = temp + M(67, 31) * x(31)
      temp = temp + M(67, 33) * x(33)
      temp = temp + M(67, 34) * x(34)
      temp = temp + M(67, 35) * x(35)
      temp = temp + M(67, 36) * x(36)
      temp = temp + M(67, 37) * x(37)
      temp = temp + M(67, 38) * x(38)
      temp = temp + M(67, 39) * x(39)
      temp = temp + M(67, 40) * x(40)
      temp = temp + M(67, 41) * x(41)
      temp = temp + M(67, 42) * x(42)
      temp = temp + M(67, 43) * x(43)
      temp = temp + M(67, 44) * x(44)
      temp = temp + M(67, 45) * x(45)
      temp = temp + M(67, 48) * x(48)
      temp = temp + M(67, 51) * x(51)
      temp = temp + M(67, 55) * x(55)
      temp = temp + M(67, 56) * x(56)
      temp = temp + M(67, 57) * x(57)
      temp = temp + M(67, 58) * x(58)
      temp = temp + M(67, 59) * x(59)
      temp = temp + M(67, 60) * x(60)
      temp = temp + M(67, 61) * x(61)
      temp = temp + M(67, 62) * x(62)
      temp = temp + M(67, 63) * x(63)
      temp = temp + M(67, 64) * x(64)
      temp = temp + M(67, 65) * x(65)
      temp = temp + M(67, 66) * x(66)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(68, 4) * x(4)
      temp = temp + M(68, 6) * x(6)
      temp = temp + M(68, 7) * x(7)
      temp = temp + M(68, 8) * x(8)
      temp = temp + M(68, 20) * x(20)
      temp = temp + M(68, 23) * x(23)
      temp = temp + M(68, 31) * x(31)
      temp = temp + M(68, 33) * x(33)
      temp = temp + M(68, 35) * x(35)
      temp = temp + M(68, 36) * x(36)
      temp = temp + M(68, 37) * x(37)
      temp = temp + M(68, 38) * x(38)
      temp = temp + M(68, 39) * x(39)
      temp = temp + M(68, 40) * x(40)
      temp = temp + M(68, 41) * x(41)
      temp = temp + M(68, 42) * x(42)
      temp = temp + M(68, 43) * x(43)
      temp = temp + M(68, 45) * x(45)
      temp = temp + M(68, 55) * x(55)
      temp = temp + M(68, 56) * x(56)
      temp = temp + M(68, 57) * x(57)
      temp = temp + M(68, 58) * x(58)
      temp = temp + M(68, 59) * x(59)
      temp = temp + M(68, 60) * x(60)
      temp = temp + M(68, 61) * x(61)
      temp = temp + M(68, 62) * x(62)
      temp = temp + M(68, 63) * x(63)
      temp = temp + M(68, 64) * x(64)
      temp = temp + M(68, 65) * x(65)
      temp = temp + M(68, 66) * x(66)
      temp = temp + M(68, 67) * x(67)
      x(68) = ( x(68) - temp ) / M(68, 68)


C     Backward substitution.

      temp = M(67, 68) * x(68)
      x(67) = x(67) - temp

      temp = M(66, 67) * x(67)
      temp = temp + M(66, 68) * x(68)
      x(66) = x(66) - temp

      temp = M(65, 66) * x(66)
      temp = temp + M(65, 67) * x(67)
      temp = temp + M(65, 68) * x(68)
      x(65) = x(65) - temp

      temp = M(64, 65) * x(65)
      temp = temp + M(64, 66) * x(66)
      temp = temp + M(64, 67) * x(67)
      temp = temp + M(64, 68) * x(68)
      x(64) = x(64) - temp

      temp = M(63, 64) * x(64)
      temp = temp + M(63, 65) * x(65)
      temp = temp + M(63, 66) * x(66)
      temp = temp + M(63, 67) * x(67)
      temp = temp + M(63, 68) * x(68)
      x(63) = x(63) - temp

      temp = M(62, 63) * x(63)
      temp = temp + M(62, 64) * x(64)
      temp = temp + M(62, 65) * x(65)
      temp = temp + M(62, 66) * x(66)
      temp = temp + M(62, 67) * x(67)
      temp = temp + M(62, 68) * x(68)
      x(62) = x(62) - temp

      temp = M(61, 62) * x(62)
      temp = temp + M(61, 63) * x(63)
      temp = temp + M(61, 64) * x(64)
      temp = temp + M(61, 65) * x(65)
      temp = temp + M(61, 66) * x(66)
      temp = temp + M(61, 67) * x(67)
      temp = temp + M(61, 68) * x(68)
      x(61) = x(61) - temp

      temp = M(60, 61) * x(61)
      temp = temp + M(60, 62) * x(62)
      temp = temp + M(60, 63) * x(63)
      temp = temp + M(60, 64) * x(64)
      temp = temp + M(60, 65) * x(65)
      temp = temp + M(60, 66) * x(66)
      temp = temp + M(60, 67) * x(67)
      temp = temp + M(60, 68) * x(68)
      x(60) = x(60) - temp

      temp = M(59, 60) * x(60)
      temp = temp + M(59, 61) * x(61)
      temp = temp + M(59, 62) * x(62)
      temp = temp + M(59, 63) * x(63)
      temp = temp + M(59, 64) * x(64)
      temp = temp + M(59, 65) * x(65)
      temp = temp + M(59, 66) * x(66)
      temp = temp + M(59, 67) * x(67)
      temp = temp + M(59, 68) * x(68)
      x(59) = x(59) - temp

      temp = M(58, 59) * x(59)
      temp = temp + M(58, 60) * x(60)
      temp = temp + M(58, 61) * x(61)
      temp = temp + M(58, 62) * x(62)
      temp = temp + M(58, 63) * x(63)
      temp = temp + M(58, 64) * x(64)
      temp = temp + M(58, 65) * x(65)
      temp = temp + M(58, 66) * x(66)
      temp = temp + M(58, 67) * x(67)
      temp = temp + M(58, 68) * x(68)
      x(58) = x(58) - temp

      temp = M(57, 58) * x(58)
      temp = temp + M(57, 59) * x(59)
      temp = temp + M(57, 60) * x(60)
      temp = temp + M(57, 61) * x(61)
      temp = temp + M(57, 62) * x(62)
      temp = temp + M(57, 63) * x(63)
      temp = temp + M(57, 64) * x(64)
      temp = temp + M(57, 65) * x(65)
      temp = temp + M(57, 66) * x(66)
      temp = temp + M(57, 67) * x(67)
      temp = temp + M(57, 68) * x(68)
      x(57) = x(57) - temp

      temp = M(56, 57) * x(57)
      temp = temp + M(56, 58) * x(58)
      temp = temp + M(56, 59) * x(59)
      temp = temp + M(56, 60) * x(60)
      temp = temp + M(56, 61) * x(61)
      temp = temp + M(56, 62) * x(62)
      temp = temp + M(56, 63) * x(63)
      temp = temp + M(56, 64) * x(64)
      temp = temp + M(56, 65) * x(65)
      temp = temp + M(56, 66) * x(66)
      temp = temp + M(56, 67) * x(67)
      temp = temp + M(56, 68) * x(68)
      x(56) = x(56) - temp

      temp = M(55, 58) * x(58)
      temp = temp + M(55, 59) * x(59)
      temp = temp + M(55, 60) * x(60)
      temp = temp + M(55, 62) * x(62)
      temp = temp + M(55, 65) * x(65)
      temp = temp + M(55, 66) * x(66)
      temp = temp + M(55, 67) * x(67)
      temp = temp + M(55, 68) * x(68)
      x(55) = x(55) - temp

      temp = M(54, 56) * x(56)
      temp = temp + M(54, 58) * x(58)
      temp = temp + M(54, 59) * x(59)
      temp = temp + M(54, 64) * x(64)
      temp = temp + M(54, 65) * x(65)
      temp = temp + M(54, 67) * x(67)
      x(54) = x(54) - temp

      temp = M(53, 56) * x(56)
      temp = temp + M(53, 58) * x(58)
      temp = temp + M(53, 59) * x(59)
      temp = temp + M(53, 64) * x(64)
      temp = temp + M(53, 65) * x(65)
      temp = temp + M(53, 67) * x(67)
      x(53) = x(53) - temp

      temp = M(52, 53) * x(53)
      temp = temp + M(52, 54) * x(54)
      temp = temp + M(52, 58) * x(58)
      temp = temp + M(52, 59) * x(59)
      temp = temp + M(52, 60) * x(60)
      temp = temp + M(52, 62) * x(62)
      temp = temp + M(52, 65) * x(65)
      temp = temp + M(52, 66) * x(66)
      temp = temp + M(52, 67) * x(67)
      x(52) = x(52) - temp

      temp = M(51, 55) * x(55)
      temp = temp + M(51, 57) * x(57)
      temp = temp + M(51, 58) * x(58)
      temp = temp + M(51, 59) * x(59)
      temp = temp + M(51, 60) * x(60)
      temp = temp + M(51, 61) * x(61)
      temp = temp + M(51, 62) * x(62)
      temp = temp + M(51, 65) * x(65)
      temp = temp + M(51, 66) * x(66)
      temp = temp + M(51, 67) * x(67)
      temp = temp + M(51, 68) * x(68)
      x(51) = x(51) - temp

      temp = M(50, 55) * x(55)
      temp = temp + M(50, 57) * x(57)
      temp = temp + M(50, 58) * x(58)
      temp = temp + M(50, 59) * x(59)
      temp = temp + M(50, 60) * x(60)
      temp = temp + M(50, 61) * x(61)
      temp = temp + M(50, 62) * x(62)
      temp = temp + M(50, 65) * x(65)
      temp = temp + M(50, 66) * x(66)
      temp = temp + M(50, 67) * x(67)
      temp = temp + M(50, 68) * x(68)
      x(50) = x(50) - temp

      temp = M(49, 56) * x(56)
      temp = temp + M(49, 58) * x(58)
      temp = temp + M(49, 63) * x(63)
      temp = temp + M(49, 64) * x(64)
      temp = temp + M(49, 67) * x(67)
      temp = temp + M(49, 68) * x(68)
      x(49) = x(49) - temp

      temp = M(48, 55) * x(55)
      temp = temp + M(48, 58) * x(58)
      temp = temp + M(48, 59) * x(59)
      temp = temp + M(48, 60) * x(60)
      temp = temp + M(48, 62) * x(62)
      temp = temp + M(48, 65) * x(65)
      temp = temp + M(48, 66) * x(66)
      temp = temp + M(48, 67) * x(67)
      temp = temp + M(48, 68) * x(68)
      x(48) = x(48) - temp

      temp = M(47, 53) * x(53)
      temp = temp + M(47, 54) * x(54)
      temp = temp + M(47, 58) * x(58)
      temp = temp + M(47, 59) * x(59)
      temp = temp + M(47, 65) * x(65)
      temp = temp + M(47, 66) * x(66)
      temp = temp + M(47, 67) * x(67)
      x(47) = x(47) - temp

      temp = M(46, 53) * x(53)
      temp = temp + M(46, 54) * x(54)
      temp = temp + M(46, 56) * x(56)
      temp = temp + M(46, 64) * x(64)
      temp = temp + M(46, 67) * x(67)
      x(46) = x(46) - temp

      temp = M(45, 55) * x(55)
      temp = temp + M(45, 58) * x(58)
      temp = temp + M(45, 59) * x(59)
      temp = temp + M(45, 60) * x(60)
      temp = temp + M(45, 62) * x(62)
      temp = temp + M(45, 65) * x(65)
      temp = temp + M(45, 66) * x(66)
      temp = temp + M(45, 67) * x(67)
      x(45) = x(45) - temp

      temp = M(44, 45) * x(45)
      temp = temp + M(44, 55) * x(55)
      temp = temp + M(44, 58) * x(58)
      temp = temp + M(44, 59) * x(59)
      temp = temp + M(44, 60) * x(60)
      temp = temp + M(44, 62) * x(62)
      temp = temp + M(44, 65) * x(65)
      temp = temp + M(44, 66) * x(66)
      temp = temp + M(44, 67) * x(67)
      x(44) = x(44) - temp

      temp = M(43, 58) * x(58)
      temp = temp + M(43, 59) * x(59)
      temp = temp + M(43, 60) * x(60)
      temp = temp + M(43, 62) * x(62)
      temp = temp + M(43, 66) * x(66)
      x(43) = x(43) - temp

      temp = M(42, 58) * x(58)
      temp = temp + M(42, 59) * x(59)
      temp = temp + M(42, 60) * x(60)
      temp = temp + M(42, 62) * x(62)
      temp = temp + M(42, 66) * x(66)
      x(42) = x(42) - temp

      temp = M(41, 58) * x(58)
      temp = temp + M(41, 59) * x(59)
      temp = temp + M(41, 65) * x(65)
      temp = temp + M(41, 66) * x(66)
      temp = temp + M(41, 67) * x(67)
      x(41) = x(41) - temp

      temp = M(40, 41) * x(41)
      temp = temp + M(40, 43) * x(43)
      temp = temp + M(40, 58) * x(58)
      temp = temp + M(40, 59) * x(59)
      temp = temp + M(40, 62) * x(62)
      temp = temp + M(40, 65) * x(65)
      temp = temp + M(40, 67) * x(67)
      x(40) = x(40) - temp

      temp = M(39, 41) * x(41)
      temp = temp + M(39, 58) * x(58)
      temp = temp + M(39, 59) * x(59)
      temp = temp + M(39, 62) * x(62)
      temp = temp + M(39, 65) * x(65)
      temp = temp + M(39, 67) * x(67)
      x(39) = x(39) - temp

      temp = M(38, 41) * x(41)
      temp = temp + M(38, 58) * x(58)
      temp = temp + M(38, 59) * x(59)
      temp = temp + M(38, 65) * x(65)
      temp = temp + M(38, 67) * x(67)
      x(38) = x(38) - temp

      temp = M(37, 58) * x(58)
      temp = temp + M(37, 59) * x(59)
      temp = temp + M(37, 60) * x(60)
      temp = temp + M(37, 62) * x(62)
      x(37) = x(37) - temp

      temp = M(36, 58) * x(58)
      temp = temp + M(36, 59) * x(59)
      temp = temp + M(36, 60) * x(60)
      temp = temp + M(36, 62) * x(62)
      x(36) = x(36) - temp

      temp = M(35, 58) * x(58)
      temp = temp + M(35, 59) * x(59)
      temp = temp + M(35, 60) * x(60)
      temp = temp + M(35, 62) * x(62)
      x(35) = x(35) - temp

      temp = M(34, 57) * x(57)
      temp = temp + M(34, 58) * x(58)
      temp = temp + M(34, 59) * x(59)
      temp = temp + M(34, 60) * x(60)
      temp = temp + M(34, 62) * x(62)
      temp = temp + M(34, 65) * x(65)
      temp = temp + M(34, 67) * x(67)
      x(34) = x(34) - temp

      temp = M(33, 58) * x(58)
      temp = temp + M(33, 59) * x(59)
      temp = temp + M(33, 60) * x(60)
      temp = temp + M(33, 62) * x(62)
      x(33) = x(33) - temp

      temp = M(32, 58) * x(58)
      temp = temp + M(32, 63) * x(63)
      temp = temp + M(32, 64) * x(64)
      temp = temp + M(32, 67) * x(67)
      x(32) = x(32) - temp

      temp = M(31, 55) * x(55)
      temp = temp + M(31, 58) * x(58)
      temp = temp + M(31, 67) * x(67)
      temp = temp + M(31, 68) * x(68)
      x(31) = x(31) - temp

      temp = M(30, 58) * x(58)
      temp = temp + M(30, 59) * x(59)
      temp = temp + M(30, 62) * x(62)
      x(30) = x(30) - temp

      temp = M(29, 58) * x(58)
      temp = temp + M(29, 59) * x(59)
      temp = temp + M(29, 62) * x(62)
      x(29) = x(29) - temp

      temp = M(28, 58) * x(58)
      temp = temp + M(28, 59) * x(59)
      temp = temp + M(28, 62) * x(62)
      x(28) = x(28) - temp

      temp = M(27, 58) * x(58)
      temp = temp + M(27, 59) * x(59)
      temp = temp + M(27, 62) * x(62)
      x(27) = x(27) - temp

      temp = M(26, 58) * x(58)
      temp = temp + M(26, 59) * x(59)
      temp = temp + M(26, 62) * x(62)
      x(26) = x(26) - temp

      temp = M(25, 58) * x(58)
      temp = temp + M(25, 59) * x(59)
      temp = temp + M(25, 62) * x(62)
      x(25) = x(25) - temp

      temp = M(24, 58) * x(58)
      temp = temp + M(24, 65) * x(65)
      temp = temp + M(24, 66) * x(66)
      x(24) = x(24) - temp

      temp = M(23, 56) * x(56)
      temp = temp + M(23, 57) * x(57)
      temp = temp + M(23, 58) * x(58)
      temp = temp + M(23, 65) * x(65)
      temp = temp + M(23, 67) * x(67)
      x(23) = x(23) - temp

      temp = M(22, 57) * x(57)
      temp = temp + M(22, 65) * x(65)
      temp = temp + M(22, 67) * x(67)
      x(22) = x(22) - temp

      temp = M(21, 58) * x(58)
      temp = temp + M(21, 60) * x(60)
      temp = temp + M(21, 67) * x(67)
      x(21) = x(21) - temp

      temp = M(20, 45) * x(45)
      temp = temp + M(20, 58) * x(58)
      temp = temp + M(20, 66) * x(66)
      x(20) = x(20) - temp

      temp = M(19, 58) * x(58)
      temp = temp + M(19, 66) * x(66)
      temp = temp + M(19, 67) * x(67)
      x(19) = x(19) - temp

      temp = M(18, 58) * x(58)
      temp = temp + M(18, 63) * x(63)
      temp = temp + M(18, 66) * x(66)
      x(18) = x(18) - temp

      temp = M(17, 42) * x(42)
      temp = temp + M(17, 58) * x(58)
      x(17) = x(17) - temp

      temp = M(16, 42) * x(42)
      temp = temp + M(16, 58) * x(58)
      x(16) = x(16) - temp

      temp = M(15, 59) * x(59)
      temp = temp + M(15, 66) * x(66)
      x(15) = x(15) - temp

      temp = M(14, 58) * x(58)
      temp = temp + M(14, 65) * x(65)
      x(14) = x(14) - temp

      temp = M(13, 56) * x(56)
      temp = temp + M(13, 58) * x(58)
      x(13) = x(13) - temp

      temp = M(12, 64) * x(64)
      temp = temp + M(12, 66) * x(66)
      x(12) = x(12) - temp

      temp = M(11, 58) * x(58)
      x(11) = x(11) - temp

      temp = M(10, 58) * x(58)
      x(10) = x(10) - temp

      temp = M(9, 58) * x(58)
      x(9) = x(9) - temp

      temp = M(8, 58) * x(58)
      x(8) = x(8) - temp

      temp = M(7, 58) * x(58)
      x(7) = x(7) - temp

      temp = M(6, 58) * x(58)
      x(6) = x(6) - temp

      temp = M(5, 58) * x(58)
      x(5) = x(5) - temp

      temp = M(4, 58) * x(58)
      x(4) = x(4) - temp

      temp = M(3, 62) * x(62)
      x(3) = x(3) - temp


      END
