C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine dratedc(ns,nr,rk,y,dw)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the derivative of reaction  rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_AEC            
C     Species: _ciCB05_AEC         
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     DW: derivative of reaction rates wrt Y.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns
      double precision rk(nr),y(ns),dw(nr,ns)
 
 
 
      dw(  1, 66) =  rk(  1)
      dw(  2, 60) =  rk(  2)
      dw(  3, 62) =  rk(  3) * Y( 65)
      dw(  3, 65) =  rk(  3) * Y( 62)
      dw(  4, 60) =  rk(  4) * Y( 66)
      dw(  4, 66) =  rk(  4) * Y( 60)
      dw(  5, 60) =  rk(  5) * Y( 66)
      dw(  5, 66) =  rk(  5) * Y( 60)
      dw(  6, 60) =  rk(  6) * Y( 65)
      dw(  6, 65) =  rk(  6) * Y( 60)
      dw(  7, 66) =  rk(  7) * Y( 62)
      dw(  7, 62) =  rk(  7) * Y( 66)
      dw(  8, 62) =  rk(  8)
      dw(  9, 62) =  rk(  9)
      dw( 10,  3) =  rk( 10)
      dw( 11,  3) =  rk( 11)
      dw( 12, 62) =  rk( 12) * Y( 58)
      dw( 12, 58) =  rk( 12) * Y( 62)
      dw( 13, 62) =  rk( 13) * Y( 67)
      dw( 13, 67) =  rk( 13) * Y( 62)
      dw( 14, 59) =  rk( 14)
      dw( 15, 59) =  rk( 15)
      dw( 16, 59) =  rk( 16) * Y( 65)
      dw( 16, 65) =  rk( 16) * Y( 59)
      dw( 17, 59) =  rk( 17) * Y( 66)
      dw( 17, 66) =  rk( 17) * Y( 59)
      dw( 18, 59) =  rk( 18) * Y( 66)
      dw( 18, 66) =  rk( 18) * Y( 59)
      dw( 19, 15) =  rk( 19)
      dw( 20, 15) =  rk( 20)
      dw( 21, 65) =  rk( 21) * Y( 65)
      dw( 21, 65) =  rk( 21) * Y( 65)
      dw( 22, 65) =  rk( 22) * Y( 66)
      dw( 22, 66) =  rk( 22) * Y( 65)
      dw( 23, 58) =  rk( 23) * Y( 65)
      dw( 23, 65) =  rk( 23) * Y( 58)
      dw( 24, 24) =  rk( 24)
      dw( 25, 58) =  rk( 25) * Y( 24)
      dw( 25, 24) =  rk( 25) * Y( 58)
      dw( 26, 24) =  rk( 26) * Y( 24)
      dw( 26, 24) =  rk( 26) * Y( 24)
      dw( 27, 66) =  rk( 27) * Y( 58)
      dw( 27, 58) =  rk( 27) * Y( 66)
      dw( 28, 58) =  rk( 28) * Y( 50)
      dw( 28, 50) =  rk( 28) * Y( 58)
      dw( 29, 67) =  rk( 29) * Y( 65)
      dw( 29, 65) =  rk( 29) * Y( 67)
      dw( 30, 67) =  rk( 30) * Y( 66)
      dw( 30, 66) =  rk( 30) * Y( 67)
      dw( 31, 19) =  rk( 31)
      dw( 32, 58) =  rk( 32) * Y( 19)
      dw( 32, 19) =  rk( 32) * Y( 58)
      dw( 33, 67) =  rk( 33) * Y( 67)
      dw( 33, 67) =  rk( 33) * Y( 67)
      dw( 34, 67) =  rk( 34) * Y( 67)
      dw( 34, 67) =  rk( 34) * Y( 67)
      dw( 35, 21) =  rk( 35)
      dw( 36, 58) =  rk( 36) * Y( 21)
      dw( 36, 21) =  rk( 36) * Y( 58)
      dw( 37,  3) =  rk( 37)
      dw( 38, 58) =  rk( 38)
      dw( 39, 58) =  rk( 39) * Y( 60)
      dw( 39, 60) =  rk( 39) * Y( 58)
      dw( 40, 58) =  rk( 40) * Y( 58)
      dw( 40, 58) =  rk( 40) * Y( 58)
      dw( 41, 58) =  rk( 41) * Y( 58)
      dw( 41, 58) =  rk( 41) * Y( 58)
      dw( 42, 58) =  rk( 42) * Y( 67)
      dw( 42, 67) =  rk( 42) * Y( 58)
      dw( 43, 67) =  rk( 43) * Y( 60)
      dw( 43, 60) =  rk( 43) * Y( 67)
      dw( 44, 21) =  rk( 44) * Y( 60)
      dw( 44, 60) =  rk( 44) * Y( 21)
      dw( 45, 59) =  rk( 45) * Y( 60)
      dw( 45, 60) =  rk( 45) * Y( 59)
      dw( 46, 59) =  rk( 46) * Y( 58)
      dw( 46, 58) =  rk( 46) * Y( 59)
      dw( 47, 59) =  rk( 47) * Y( 67)
      dw( 47, 67) =  rk( 47) * Y( 59)
      dw( 48, 59) =  rk( 48) * Y( 62)
      dw( 48, 62) =  rk( 48) * Y( 59)
      dw( 49, 59) =  rk( 49) * Y( 59)
      dw( 49, 59) =  rk( 49) * Y( 59)
      dw( 50, 19) =  rk( 50)
      dw( 51, 50) =  rk( 51)
      dw( 52, 15) =  rk( 52)
      dw( 53, 68) =  rk( 53) * Y( 65)
      dw( 53, 65) =  rk( 53) * Y( 68)
      dw( 54, 55) =  rk( 54) * Y( 65)
      dw( 54, 65) =  rk( 54) * Y( 55)
      dw( 55, 68) =  rk( 55) * Y( 67)
      dw( 55, 67) =  rk( 55) * Y( 68)
      dw( 56, 55) =  rk( 56) * Y( 67)
      dw( 56, 67) =  rk( 56) * Y( 55)
      dw( 57, 68) =  rk( 57) * Y( 68)
      dw( 57, 68) =  rk( 57) * Y( 68)
      dw( 58, 55) =  rk( 58) * Y( 55)
      dw( 58, 55) =  rk( 58) * Y( 55)
      dw( 59, 68) =  rk( 59) * Y( 55)
      dw( 59, 55) =  rk( 59) * Y( 68)
      dw( 60, 44) =  rk( 60) * Y( 58)
      dw( 60, 58) =  rk( 60) * Y( 44)
      dw( 61, 44) =  rk( 61)
      dw( 62, 31) =  rk( 62) * Y( 58)
      dw( 62, 58) =  rk( 62) * Y( 31)
      dw( 63, 31) =  rk( 63)
      dw( 64, 58) =  rk( 64) * Y( 51)
      dw( 64, 51) =  rk( 64) * Y( 58)
      dw( 65, 58) =  rk( 65) * Y(  5)
      dw( 65,  5) =  rk( 65) * Y( 58)
      dw( 66, 56) =  rk( 66) * Y( 65)
      dw( 66, 65) =  rk( 66) * Y( 56)
      dw( 67, 56) =  rk( 67) * Y( 67)
      dw( 67, 67) =  rk( 67) * Y( 56)
      dw( 68, 56) =  rk( 68) * Y( 56)
      dw( 68, 56) =  rk( 68) * Y( 56)
      dw( 69, 23) =  rk( 69) * Y( 58)
      dw( 69, 58) =  rk( 69) * Y( 23)
      dw( 70, 23) =  rk( 70)
      dw( 71, 13) =  rk( 71) * Y( 58)
      dw( 71, 58) =  rk( 71) * Y( 13)
      dw( 72, 57) =  rk( 72) * Y( 58)
      dw( 72, 58) =  rk( 72) * Y( 57)
      dw( 73, 57) =  rk( 73)
      dw( 74, 57) =  rk( 74)
      dw( 75, 57) =  rk( 75) * Y( 60)
      dw( 75, 60) =  rk( 75) * Y( 57)
      dw( 76, 57) =  rk( 76) * Y( 59)
      dw( 76, 59) =  rk( 76) * Y( 57)
      dw( 77, 57) =  rk( 77) * Y( 67)
      dw( 77, 67) =  rk( 77) * Y( 57)
      dw( 78, 22) =  rk( 78)
      dw( 79, 22) =  rk( 79) * Y( 65)
      dw( 79, 65) =  rk( 79) * Y( 22)
      dw( 80, 22) =  rk( 80) * Y( 67)
      dw( 80, 67) =  rk( 80) * Y( 22)
      dw( 81, 34) =  rk( 81) * Y( 58)
      dw( 81, 58) =  rk( 81) * Y( 34)
      dw( 82, 61) =  rk( 82) * Y( 60)
      dw( 82, 60) =  rk( 82) * Y( 61)
      dw( 83, 61) =  rk( 83) * Y( 58)
      dw( 83, 58) =  rk( 83) * Y( 61)
      dw( 84, 61) =  rk( 84) * Y( 59)
      dw( 84, 59) =  rk( 84) * Y( 61)
      dw( 85, 61) =  rk( 85)
      dw( 86, 64) =  rk( 86) * Y( 65)
      dw( 86, 65) =  rk( 86) * Y( 64)
      dw( 87, 64) =  rk( 87) * Y( 66)
      dw( 87, 66) =  rk( 87) * Y( 64)
      dw( 88, 12) =  rk( 88)
      dw( 89, 12) =  rk( 89)
      dw( 90, 64) =  rk( 90) * Y( 67)
      dw( 90, 67) =  rk( 90) * Y( 64)
      dw( 91, 64) =  rk( 91) * Y( 56)
      dw( 91, 56) =  rk( 91) * Y( 64)
      dw( 92, 64) =  rk( 92) * Y( 68)
      dw( 92, 68) =  rk( 92) * Y( 64)
      dw( 93, 64) =  rk( 93) * Y( 64)
      dw( 93, 64) =  rk( 93) * Y( 64)
      dw( 94, 32) =  rk( 94) * Y( 58)
      dw( 94, 58) =  rk( 94) * Y( 32)
      dw( 95, 32) =  rk( 95)
      dw( 96, 49) =  rk( 96) * Y( 58)
      dw( 96, 58) =  rk( 96) * Y( 49)
      dw( 97, 48) =  rk( 97) * Y( 60)
      dw( 97, 60) =  rk( 97) * Y( 48)
      dw( 98, 48) =  rk( 98) * Y( 58)
      dw( 98, 58) =  rk( 98) * Y( 48)
      dw( 99, 48) =  rk( 99) * Y( 59)
      dw( 99, 59) =  rk( 99) * Y( 48)
      dw(100, 48) =  rk(100)
      dw(101, 63) =  rk(101) * Y( 65)
      dw(101, 65) =  rk(101) * Y( 63)
      dw(102, 63) =  rk(102) * Y( 66)
      dw(102, 66) =  rk(102) * Y( 63)
      dw(103, 18) =  rk(103)
      dw(104, 18) =  rk(104)
      dw(105, 18) =  rk(105) * Y( 58)
      dw(105, 58) =  rk(105) * Y( 18)
      dw(106, 63) =  rk(106) * Y( 67)
      dw(106, 67) =  rk(106) * Y( 63)
      dw(107, 64) =  rk(107) * Y( 56)
      dw(107, 56) =  rk(107) * Y( 64)
      dw(108, 64) =  rk(108) * Y( 68)
      dw(108, 68) =  rk(108) * Y( 64)
      dw(109, 63) =  rk(109) * Y( 63)
      dw(109, 63) =  rk(109) * Y( 63)
      dw(110, 63) =  rk(110) * Y( 64)
      dw(110, 64) =  rk(110) * Y( 63)
      dw(111, 45) =  rk(111) * Y( 58)
      dw(111, 58) =  rk(111) * Y( 45)
      dw(112, 20) =  rk(112)
      dw(113, 20) =  rk(113)
      dw(114, 20) =  rk(114) * Y( 66)
      dw(114, 66) =  rk(114) * Y( 20)
      dw(115, 60) =  rk(115) * Y( 35)
      dw(115, 35) =  rk(115) * Y( 60)
      dw(116, 58) =  rk(116) * Y( 35)
      dw(116, 35) =  rk(116) * Y( 58)
      dw(117, 62) =  rk(117) * Y( 35)
      dw(117, 35) =  rk(117) * Y( 62)
      dw(118, 59) =  rk(118) * Y( 35)
      dw(118, 35) =  rk(118) * Y( 59)
      dw(119, 60) =  rk(119) * Y( 33)
      dw(119, 33) =  rk(119) * Y( 60)
      dw(120, 58) =  rk(120) * Y( 33)
      dw(120, 33) =  rk(120) * Y( 58)
      dw(121, 62) =  rk(121) * Y( 33)
      dw(121, 33) =  rk(121) * Y( 62)
      dw(122, 59) =  rk(122) * Y( 33)
      dw(122, 33) =  rk(122) * Y( 59)
      dw(123, 36) =  rk(123) * Y( 60)
      dw(123, 60) =  rk(123) * Y( 36)
      dw(124, 36) =  rk(124) * Y( 58)
      dw(124, 58) =  rk(124) * Y( 36)
      dw(125, 36) =  rk(125) * Y( 62)
      dw(125, 62) =  rk(125) * Y( 36)
      dw(126, 36) =  rk(126) * Y( 59)
      dw(126, 59) =  rk(126) * Y( 36)
      dw(127,  7) =  rk(127) * Y( 58)
      dw(127, 58) =  rk(127) * Y(  7)
      dw(128, 14) =  rk(128) * Y( 65)
      dw(128, 65) =  rk(128) * Y( 14)
      dw(129, 14) =  rk(129)
      dw(130, 58) =  rk(130) * Y( 38)
      dw(130, 38) =  rk(130) * Y( 58)
      dw(131, 38) =  rk(131) * Y( 59)
      dw(131, 59) =  rk(131) * Y( 38)
      dw(132, 41) =  rk(132) * Y( 66)
      dw(132, 66) =  rk(132) * Y( 41)
      dw(133, 41) =  rk(133) * Y( 67)
      dw(133, 67) =  rk(133) * Y( 41)
      dw(134, 39) =  rk(134)
      dw(135, 39) =  rk(135) * Y( 58)
      dw(135, 58) =  rk(135) * Y( 39)
      dw(136, 39) =  rk(136) * Y( 62)
      dw(136, 62) =  rk(136) * Y( 39)
      dw(137, 58) =  rk(137) * Y(  8)
      dw(137,  8) =  rk(137) * Y( 58)
      dw(138, 58) =  rk(138) * Y( 40)
      dw(138, 40) =  rk(138) * Y( 58)
      dw(139, 40) =  rk(139)
      dw(140, 60) =  rk(140) * Y( 42)
      dw(140, 42) =  rk(140) * Y( 60)
      dw(141, 58) =  rk(141) * Y( 42)
      dw(141, 42) =  rk(141) * Y( 58)
      dw(142, 62) =  rk(142) * Y( 42)
      dw(142, 42) =  rk(142) * Y( 62)
      dw(143, 59) =  rk(143) * Y( 42)
      dw(143, 42) =  rk(143) * Y( 59)
      dw(144, 58) =  rk(144) * Y( 43)
      dw(144, 43) =  rk(144) * Y( 58)
      dw(145, 62) =  rk(145) * Y( 43)
      dw(145, 43) =  rk(145) * Y( 62)
      dw(146, 59) =  rk(146) * Y( 43)
      dw(146, 43) =  rk(146) * Y( 59)
      dw(147, 43) =  rk(147)
      dw(148, 37) =  rk(148) * Y( 60)
      dw(148, 60) =  rk(148) * Y( 37)
      dw(149, 37) =  rk(149) * Y( 58)
      dw(149, 58) =  rk(149) * Y( 37)
      dw(150, 37) =  rk(150) * Y( 62)
      dw(150, 62) =  rk(150) * Y( 37)
      dw(151, 37) =  rk(151) * Y( 59)
      dw(151, 59) =  rk(151) * Y( 37)
      dw(152,  9) =  rk(152) * Y( 58)
      dw(152, 58) =  rk(152) * Y(  9)
      dw(153, 58) =  rk(153) * Y(  4)
      dw(153,  4) =  rk(153) * Y( 58)
      dw(154, 58) =  rk(154) * Y(  6)
      dw(154,  6) =  rk(154) * Y( 58)
      dw(155, 66) =  rk(155) * Y( 42)
      dw(155, 42) =  rk(155) * Y( 66)
      dw(156, 67) =  rk(156)
      dw(157, 66) =  rk(157)
      dw(158, 59) =  rk(158)
      dw(159, 15) =  rk(159)
      dw(160, 11) =  rk(160) * Y( 58)
      dw(160, 58) =  rk(160) * Y( 11)
      dw(161, 25) =  rk(161) * Y( 58)
      dw(161, 58) =  rk(161) * Y( 25)
      dw(162, 25) =  rk(162) * Y( 62)
      dw(162, 62) =  rk(162) * Y( 25)
      dw(163, 25) =  rk(163) * Y( 59)
      dw(163, 59) =  rk(163) * Y( 25)
      dw(164, 26) =  rk(164) * Y( 58)
      dw(164, 58) =  rk(164) * Y( 26)
      dw(165, 26) =  rk(165) * Y( 62)
      dw(165, 62) =  rk(165) * Y( 26)
      dw(166, 26) =  rk(166) * Y( 59)
      dw(166, 59) =  rk(166) * Y( 26)
      dw(167, 53) =  rk(167) * Y( 67)
      dw(167, 67) =  rk(167) * Y( 53)
      dw(168, 53) =  rk(168) * Y( 56)
      dw(168, 56) =  rk(168) * Y( 53)
      dw(169, 53) =  rk(169) * Y( 64)
      dw(169, 64) =  rk(169) * Y( 53)
      dw(170, 53) =  rk(170) * Y( 65)
      dw(170, 65) =  rk(170) * Y( 53)
      dw(171, 53) =  rk(171) * Y( 59)
      dw(171, 59) =  rk(171) * Y( 53)
      dw(172, 53) =  rk(172)
      dw(173, 54) =  rk(173)
      dw(174, 54) =  rk(174) * Y( 67)
      dw(174, 67) =  rk(174) * Y( 54)
      dw(175, 54) =  rk(175) * Y( 56)
      dw(175, 56) =  rk(175) * Y( 54)
      dw(176, 54) =  rk(176) * Y( 64)
      dw(176, 64) =  rk(176) * Y( 54)
      dw(177, 54) =  rk(177) * Y( 65)
      dw(177, 65) =  rk(177) * Y( 54)
      dw(178, 54) =  rk(178) * Y( 59)
      dw(178, 59) =  rk(178) * Y( 54)
 
      RETURN
      END
 
