C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine kinetic(Ns,Nbin_aer,nr,IHETER,ICLD,rk,temp,xlw,
     $     Press,azi,att,lwctmp,granulo,WetDiam,dsf_aero,ispeclost,
     $     Wmol,LWCmin,option_photolysis)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the kinetic rates for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM_AEC            
C     Species: _ciRACM_AEC         
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     NR: reaction number.
C     TEMP: temperature ([K]).
C     XLW: water massic fraction.
C     PRESS: pressure ([Pa]).
C     AZI: zenithal angle ([degree]).
C     ATT: attenuation variable.
C     lwctmp: Liquid Water Content ([g.m-3])
C     WetDiam: Bins wet Diameter ([mu m])
C     granulo: Particles number in each bin.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     RK: kinetic rates.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer Ns,Nbin_aer,nr
 
      double precision rk238,rk239,rk240,rk241
      double precision rk(nr),temp,xlw,Press
      double precision Effko,Rapk,facteur,SumM,azi,att
      double precision YlH2O
      double precision lwctmp
      double precision WetDiam(Nbin_aer)
      double precision granulo(Nbin_aer)
      double precision dsf_aero(Nbin_aer)
      integer ICLD,IHETER
      integer ispeclost(4)
      double precision Wmol(Ns),LWCmin
      integer option_photolysis
 
C     Compute third body.
C     Conversion = Avogadro*1d-6/Perfect gas constant.
C     PRESS in Pascal, SUMM in molecules/cm3, TEMP in Kelvin
 
      SumM = Press * 7.243D16 / temp
 
C     Number of water molecules computed from the massic fraction
C     (absolute humidity)
 
      YlH2O = 29.d0*SumM*xlw/(18.d0+11.d0*xlw)
 
C     For the zenithal angle at tropics
 
      azi=abs(azi)
 
C
      if(option_photolysis.eq.2) then
       rk(  1)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  1)=-0.1302720567168795D-07
       rk(  1)=-0.7822279432831311D-06+(azi- 0.00D+00) * rk(  1)
       rk(  1)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  1)
       rk(  1)= 0.9310260000000001D-02+(azi- 0.00D+00) * rk(  1)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  1)= 0.3771617015067078D-08
       rk(  1)=-0.1173044113433769D-05+(azi- 0.10D+02) * rk(  1)
       rk(  1)=-0.1955272056716901D-04+(azi- 0.10D+02) * rk(  1)
       rk(  1)= 0.9219010000000000D-02+(azi- 0.10D+02) * rk(  1)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  1)=-0.5859262388581815D-08
       rk(  1)=-0.1059895602981758D-05+(azi- 0.20D+02) * rk(  1)
       rk(  1)=-0.4188211773132428D-04+(azi- 0.20D+02) * rk(  1)
       rk(  1)= 0.8909950000000000D-02+(azi- 0.20D+02) * rk(  1)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  1)=-0.7024567460738029D-08
       rk(  1)=-0.1235673474639213D-05+(azi- 0.30D+02) * rk(  1)
       rk(  1)=-0.6483780850753392D-04+(azi- 0.30D+02) * rk(  1)
       rk(  1)= 0.8379279999999999D-02+(azi- 0.30D+02) * rk(  1)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  1)=-0.9202467768466835D-08
       rk(  1)=-0.1446410498461367D-05+(azi- 0.40D+02) * rk(  1)
       rk(  1)=-0.9165864823853972D-04+(azi- 0.40D+02) * rk(  1)
       rk(  1)= 0.7600310000000000D-02+(azi- 0.40D+02) * rk(  1)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  1)=-0.1612556146540100D-07
       rk(  1)=-0.1722484531515342D-05+(azi- 0.50D+02) * rk(  1)
       rk(  1)=-0.1233475985383066D-03+(azi- 0.50D+02) * rk(  1)
       rk(  1)= 0.6529880000000000D-02+(azi- 0.50D+02) * rk(  1)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  1)= 0.3226471363007382D-07
       rk(  1)=-0.2206251375477548D-05+(azi- 0.60D+02) * rk(  1)
       rk(  1)=-0.1626349576082332D-03+(azi- 0.60D+02) * rk(  1)
       rk(  1)= 0.5108030000000000D-02+(azi- 0.60D+02) * rk(  1)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  1)= 0.2027078243961372D-06
       rk(  1)=-0.1238309966574737D-05+(azi- 0.70D+02) * rk(  1)
       rk(  1)=-0.1970805710287543D-03+(azi- 0.70D+02) * rk(  1)
       rk(  1)= 0.3293320000000000D-02+(azi- 0.70D+02) * rk(  1)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  1)=-0.7448311471194499D-07
       rk(  1)= 0.3626677818932555D-05+(azi- 0.78D+02) * rk(  1)
       rk(  1)=-0.1779736282099126D-03+(azi- 0.78D+02) * rk(  1)
       rk(  1)= 0.1741210000000000D-02+(azi- 0.78D+02) * rk(  1)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  1)= 0.2490309929270573D-05
       rk(  1)= 0.1839083065842406D-05+(azi- 0.86D+02) * rk(  1)
       rk(  1)=-0.1342475411316713D-03+(azi- 0.86D+02) * rk(  1)
       rk(  1)= 0.5113930000000000D-03+(azi- 0.86D+02) * rk(  1)
      elseif(azi.ge.90.D0)then
       rk(  1)= 0.1632080000000000D-03
      endif
      if(att.lt.0.99999) rk(  1) = rk(  1) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  2)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  2)=-0.8776629099833464D-10
       rk(  2)=-0.1165033709001661D-07+(azi- 0.00D+00) * rk(  2)
       rk(  2)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  2)
       rk(  2)= 0.3523480000000000D-04+(azi- 0.00D+00) * rk(  2)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  2)= 0.1474988729949909D-09
       rk(  2)=-0.1428332581996665D-07+(azi- 0.10D+02) * rk(  2)
       rk(  2)=-0.2593366290998327D-06+(azi- 0.10D+02) * rk(  2)
       rk(  2)= 0.3398200000000000D-04+(azi- 0.10D+02) * rk(  2)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  2)= 0.1300707990183827D-09
       rk(  2)=-0.9858359630116941D-08+(azi- 0.20D+02) * rk(  2)
       rk(  2)=-0.5007534836006686D-06+(azi- 0.20D+02) * rk(  2)
       rk(  2)= 0.3010780000000000D-04+(azi- 0.20D+02) * rk(  2)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  2)= 0.1988179309314732D-09
       rk(  2)=-0.5956235659565481D-08+(azi- 0.30D+02) * rk(  2)
       rk(  2)=-0.6588994364974921D-06+(azi- 0.30D+02) * rk(  2)
       rk(  2)= 0.2424450000000000D-04+(azi- 0.30D+02) * rk(  2)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  2)= 0.2219574772557277D-09
       rk(  2)= 0.8302268378835231D-11+(azi- 0.40D+02) * rk(  2)
       rk(  2)=-0.7183787704093613D-06+(azi- 0.40D+02) * rk(  2)
       rk(  2)= 0.1725870000000000D-04+(azi- 0.40D+02) * rk(  2)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  2)= 0.1913521600455895D-09
       rk(  2)= 0.6667026586050136D-08+(azi- 0.50D+02) * rk(  2)
       rk(  2)=-0.6516254818650674D-06+(azi- 0.50D+02) * rk(  2)
       rk(  2)= 0.1029770000000000D-04+(azi- 0.50D+02) * rk(  2)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  2)= 0.1602388256152816D-10
       rk(  2)= 0.1240759138741867D-07+(azi- 0.60D+02) * rk(  2)
       rk(  2)=-0.4608793021303539D-06+(azi- 0.60D+02) * rk(  2)
       rk(  2)= 0.4639500000000000D-05+(azi- 0.60D+02) * rk(  2)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  2)=-0.3089359890783960D-09
       rk(  2)= 0.1288830786428400D-07+(azi- 0.70D+02) * rk(  2)
       rk(  2)=-0.2079203096133002D-06+(azi- 0.70D+02) * rk(  2)
       rk(  2)= 0.1287490000000000D-05+(azi- 0.70D+02) * rk(  2)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  2)=-0.2034952628632162D-09
       rk(  2)= 0.5473844126395715D-08+(azi- 0.78D+02) * rk(  2)
       rk(  2)=-0.6102309368797090D-07+(azi- 0.78D+02) * rk(  2)
       rk(  2)= 0.2908040000000000D-06+(azi- 0.78D+02) * rk(  2)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  2)= 0.1623544916128788D-09
       rk(  2)= 0.5899578175158973D-09+(azi- 0.86D+02) * rk(  2)
       rk(  2)=-0.1251267813581064D-07+(azi- 0.86D+02) * rk(  2)
       rk(  2)= 0.4875570000000000D-07+(azi- 0.86D+02) * rk(  2)
      elseif(azi.ge.90.D0)then
       rk(  2)= 0.1853500000000000D-07
      endif
      if(att.lt.0.99999) rk(  2) = rk(  2) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  3)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  3)=-0.5928286648807996D-09
       rk(  3)=-0.3096171335119280D-07+(azi- 0.00D+00) * rk(  3)
       rk(  3)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  3)
       rk(  3)= 0.4927580000000000D-03+(azi- 0.00D+00) * rk(  3)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  3)= 0.1444859946426876D-09
       rk(  3)=-0.4874657329761677D-07+(azi- 0.10D+02) * rk(  3)
       rk(  3)=-0.7970828664880956D-06+(azi- 0.10D+02) * rk(  3)
       rk(  3)= 0.4890690000000000D-03+(azi- 0.10D+02) * rk(  3)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  3)=-0.5511531369012520D-10
       rk(  3)=-0.4441199345833616D-07+(azi- 0.20D+02) * rk(  3)
       rk(  3)=-0.1728668534047625D-05+(azi- 0.20D+02) * rk(  3)
       rk(  3)= 0.4763680000000000D-03+(azi- 0.20D+02) * rk(  3)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  3)=-0.3000247398821449D-09
       rk(  3)=-0.4606545286904014D-07+(azi- 0.30D+02) * rk(  3)
       rk(  3)=-0.2633442997321385D-05+(azi- 0.30D+02) * rk(  3)
       rk(  3)= 0.4545850000000000D-03+(azi- 0.30D+02) * rk(  3)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  3)=-0.2397857267812366D-09
       rk(  3)=-0.5506619506550444D-07+(azi- 0.40D+02) * rk(  3)
       rk(  3)=-0.3644759476666826D-05+(azi- 0.40D+02) * rk(  3)
       rk(  3)= 0.4233440000000000D-03+(azi- 0.40D+02) * rk(  3)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  3)=-0.1844832352993067D-08
       rk(  3)=-0.6225976686893995D-07+(azi- 0.50D+02) * rk(  3)
       rk(  3)=-0.4818019096011278D-05+(azi- 0.50D+02) * rk(  3)
       rk(  3)= 0.3811500000000000D-03+(azi- 0.50D+02) * rk(  3)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  3)= 0.1101151387530619D-09
       rk(  3)=-0.1176047374587370D-06+(azi- 0.60D+02) * rk(  3)
       rk(  3)=-0.6616664139287950D-05+(azi- 0.60D+02) * rk(  3)
       rk(  3)= 0.3248990000000000D-03+(azi- 0.60D+02) * rk(  3)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  3)=-0.1557211541866474D-07
       rk(  3)=-0.1143012832961418D-06+(azi- 0.70D+02) * rk(  3)
       rk(  3)=-0.8935724346837023D-05+(azi- 0.70D+02) * rk(  3)
       rk(  3)= 0.2470820000000000D-03+(azi- 0.70D+02) * rk(  3)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  3)= 0.4048472604232427D-07
       rk(  3)=-0.4880320533439059D-06+(azi- 0.78D+02) * rk(  3)
       rk(  3)=-0.1375439103995816D-04+(azi- 0.78D+02) * rk(  3)
       rk(  3)= 0.1603080000000000D-03+(azi- 0.78D+02) * rk(  3)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  3)= 0.2066880316654862D-06
       rk(  3)= 0.4836013716715513D-06+(azi- 0.86D+02) * rk(  3)
       rk(  3)=-0.1378983649333310D-04+(azi- 0.86D+02) * rk(  3)
       rk(  3)= 0.3976700000000000D-04+(azi- 0.86D+02) * rk(  3)
      elseif(azi.ge.90.D0)then
       rk(  3)= 0.5573310000000000D-05
      endif
      if(att.lt.0.99999) rk(  3) = rk(  3) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  4)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  4)=-0.2887225450832658D-08
       rk(  4)=-0.1810277454916759D-06+(azi- 0.00D+00) * rk(  4)
       rk(  4)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  4)
       rk(  4)= 0.2046710000000000D-02+(azi- 0.00D+00) * rk(  4)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  4)= 0.8216763524985595D-09
       rk(  4)=-0.2676445090166556D-06+(azi- 0.10D+02) * rk(  4)
       rk(  4)=-0.4486722545083316D-05+(azi- 0.10D+02) * rk(  4)
       rk(  4)= 0.2025720000000000D-02+(azi- 0.10D+02) * rk(  4)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  4)=-0.1309479959161308D-08
       rk(  4)=-0.2429942184416991D-06+(azi- 0.20D+02) * rk(  4)
       rk(  4)=-0.9593109819666860D-05+(azi- 0.20D+02) * rk(  4)
       rk(  4)= 0.1954910000000000D-02+(azi- 0.20D+02) * rk(  4)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  4)=-0.1523756515853649D-08
       rk(  4)=-0.2822786172165394D-06+(azi- 0.30D+02) * rk(  4)
       rk(  4)=-0.1484583817624924D-04+(azi- 0.30D+02) * rk(  4)
       rk(  4)= 0.1833370000000000D-02+(azi- 0.30D+02) * rk(  4)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  4)=-0.1745493977424016D-08
       rk(  4)=-0.3279913126921461D-06+(azi- 0.40D+02) * rk(  4)
       rk(  4)=-0.2094853747533609D-04+(azi- 0.40D+02) * rk(  4)
       rk(  4)= 0.1655160000000000D-02+(azi- 0.40D+02) * rk(  4)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  4)=-0.2754267574450560D-08
       rk(  4)=-0.3803561320148624D-06+(azi- 0.50D+02) * rk(  4)
       rk(  4)=-0.2803201192240625D-04+(azi- 0.50D+02) * rk(  4)
       rk(  4)= 0.1411130000000000D-02+(azi- 0.50D+02) * rk(  4)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  4)= 0.1037656427523324D-07
       rk(  4)=-0.4629841592484096D-06+(azi- 0.60D+02) * rk(  4)
       rk(  4)=-0.3646541483503878D-04+(azi- 0.60D+02) * rk(  4)
       rk(  4)= 0.1090020000000000D-02+(azi- 0.60D+02) * rk(  4)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  4)= 0.4335158727139456D-07
       rk(  4)=-0.1516872309913989D-06+(azi- 0.70D+02) * rk(  4)
       rk(  4)=-0.4261212873743828D-04+(azi- 0.70D+02) * rk(  4)
       rk(  4)= 0.6894440000000000D-03+(azi- 0.70D+02) * rk(  4)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  4)=-0.2976581610911796D-07
       rk(  4)= 0.8887508635220705D-06+(azi- 0.78D+02) * rk(  4)
       rk(  4)=-0.3671561967719464D-04+(azi- 0.78D+02) * rk(  4)
       rk(  4)= 0.3610350000000000D-03+(azi- 0.78D+02) * rk(  4)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  4)= 0.5586598403857848D-06
       rk(  4)= 0.1743712769036732D-06+(azi- 0.86D+02) * rk(  4)
       rk(  4)=-0.2821064255377481D-04+(azi- 0.86D+02) * rk(  4)
       rk(  4)= 0.1089500000000000D-03+(azi- 0.86D+02) * rk(  4)
      elseif(azi.ge.90.D0)then
       rk(  4)= 0.3465160000000000D-04
      endif
      if(att.lt.0.99999) rk(  4) = rk(  4) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  5)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  5)=-0.1532025548735494D-11
       rk(  5)=-0.1605297445126457D-09+(azi- 0.00D+00) * rk(  5)
       rk(  5)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  5)
       rk(  5)= 0.7475310000000001D-06+(azi- 0.00D+00) * rk(  5)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  5)= 0.1499076646206637D-11
       rk(  5)=-0.2064905109747105D-09+(azi- 0.10D+02) * rk(  5)
       rk(  5)=-0.3670202554873561D-08+(azi- 0.10D+02) * rk(  5)
       rk(  5)= 0.7299460000000000D-06+(azi- 0.10D+02) * rk(  5)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  5)= 0.8827189639089728D-12
       rk(  5)=-0.1615182115885116D-09+(azi- 0.20D+02) * rk(  5)
       rk(  5)=-0.7350289780505779D-08+(azi- 0.20D+02) * rk(  5)
       rk(  5)= 0.6740940000000000D-06+(azi- 0.20D+02) * rk(  5)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  5)= 0.1742047498157359D-11
       rk(  5)=-0.1350366426712420D-09+(azi- 0.30D+02) * rk(  5)
       rk(  5)=-0.1031583832310330D-07+(azi- 0.30D+02) * rk(  5)
       rk(  5)= 0.5853220000000000D-06+(azi- 0.30D+02) * rk(  5)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  5)= 0.2513091043461601D-11
       rk(  5)=-0.8277521772651622D-10+(azi- 0.40D+02) * rk(  5)
       rk(  5)=-0.1249395692708094D-07+(azi- 0.40D+02) * rk(  5)
       rk(  5)= 0.4704020000000000D-06+(azi- 0.40D+02) * rk(  5)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  5)= 0.3194588327996089D-11
       rk(  5)=-0.7382486422669833D-11+(azi- 0.50D+02) * rk(  5)
       rk(  5)=-0.1339553396857280D-07+(azi- 0.50D+02) * rk(  5)
       rk(  5)= 0.3396980000000000D-06+(azi- 0.50D+02) * rk(  5)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  5)= 0.5281855644545232D-11
       rk(  5)= 0.8845516341719630D-10+(azi- 0.60D+02) * rk(  5)
       rk(  5)=-0.1258480719862726D-07+(azi- 0.60D+02) * rk(  5)
       rk(  5)= 0.2081990000000000D-06+(azi- 0.60D+02) * rk(  5)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  5)=-0.2756160173816243D-12
       rk(  5)= 0.2469108327538047D-09+(azi- 0.70D+02) * rk(  5)
       rk(  5)=-0.9231147236917937D-08+(azi- 0.70D+02) * rk(  5)
       rk(  5)= 0.9647830000000000D-07+(azi- 0.70D+02) * rk(  5)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  5)=-0.5270116382809120D-11
       rk(  5)= 0.2402960483368575D-09+(azi- 0.78D+02) * rk(  5)
       rk(  5)=-0.5333492188194333D-08+(azi- 0.78D+02) * rk(  5)
       rk(  5)= 0.3829030000000000D-07+(azi- 0.78D+02) * rk(  5)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  5)= 0.3312732748114380D-10
       rk(  5)= 0.1138132551494386D-09+(azi- 0.86D+02) * rk(  5)
       rk(  5)=-0.2500617760290411D-08+(azi- 0.86D+02) * rk(  5)
       rk(  5)= 0.8303010000000000D-08+(azi- 0.86D+02) * rk(  5)
      elseif(azi.ge.90.D0)then
       rk(  5)= 0.2241700000000000D-08
      endif
      if(att.lt.0.99999) rk(  5) = rk(  5) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  6)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  6)=-0.1022637521258300D-10
       rk(  6)=-0.1047636247874169D-08+(azi- 0.00D+00) * rk(  6)
       rk(  6)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  6)
       rk(  6)= 0.5038360000000000D-05+(azi- 0.00D+00) * rk(  6)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  6)= 0.9289125637748400D-11
       rk(  6)=-0.1354427504251659D-08+(azi- 0.10D+02) * rk(  6)
       rk(  6)=-0.2402063752125827D-07+(azi- 0.10D+02) * rk(  6)
       rk(  6)= 0.4923370000000000D-05+(azi- 0.10D+02) * rk(  6)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  6)= 0.4979872661590682D-11
       rk(  6)=-0.1075753735119207D-08+(azi- 0.20D+02) * rk(  6)
       rk(  6)=-0.4832244991496692D-07+(azi- 0.20D+02) * rk(  6)
       rk(  6)= 0.4557010000000000D-05+(azi- 0.20D+02) * rk(  6)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  6)= 0.1055138371588688D-10
       rk(  6)=-0.9263575552714849D-09+(azi- 0.30D+02) * rk(  6)
       rk(  6)=-0.6834356281887375D-07+(azi- 0.30D+02) * rk(  6)
       rk(  6)= 0.3971190000000000D-05+(azi- 0.30D+02) * rk(  6)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  6)= 0.1620459247486068D-10
       rk(  6)=-0.6098160437948834D-09+(azi- 0.40D+02) * rk(  6)
       rk(  6)=-0.8370529880953754D-07+(azi- 0.40D+02) * rk(  6)
       rk(  6)= 0.3205670000000000D-05+(azi- 0.40D+02) * rk(  6)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  6)= 0.2215024638467897D-10
       rk(  6)=-0.1236782695490497D-09+(azi- 0.50D+02) * rk(  6)
       rk(  6)=-0.9104024194297703D-07+(azi- 0.50D+02) * rk(  6)
       rk(  6)= 0.2323840000000000D-05+(azi- 0.50D+02) * rk(  6)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  6)= 0.3999042198642357D-10
       rk(  6)= 0.5408291219911870D-09+(azi- 0.60D+02) * rk(  6)
       rk(  6)=-0.8686873341855619D-07+(azi- 0.60D+02) * rk(  6)
       rk(  6)= 0.1423220000000000D-05+(azi- 0.60D+02) * rk(  6)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  6)=-0.2067341717000215D-11
       rk(  6)= 0.1740541781586012D-08+(azi- 0.70D+02) * rk(  6)
       rk(  6)=-0.6405502438280072D-07+(azi- 0.70D+02) * rk(  6)
       rk(  6)= 0.6486060000000000D-06+(azi- 0.70D+02) * rk(  6)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  6)=-0.2916729149837185D-10
       rk(  6)= 0.1690925580378854D-08+(azi- 0.78D+02) * rk(  6)
       rk(  6)=-0.3660328548710213D-07+(azi- 0.78D+02) * rk(  6)
       rk(  6)= 0.2465020000000000D-06+(azi- 0.78D+02) * rk(  6)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  6)= 0.1504439894534147D-09
       rk(  6)= 0.9909105844077646D-09+(azi- 0.86D+02) * rk(  6)
       rk(  6)=-0.1514859616880918D-07+(azi- 0.86D+02) * rk(  6)
       rk(  6)= 0.4696130000000000D-07+(azi- 0.86D+02) * rk(  6)
      elseif(azi.ge.90.D0)then
       rk(  6)= 0.1184990000000000D-07
      endif
      if(att.lt.0.99999) rk(  6) = rk(  6) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  7)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  7)=-0.3691161034363460D-07
       rk(  7)=-0.1177883896563626D-05+(azi- 0.00D+00) * rk(  7)
       rk(  7)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  7)
       rk(  7)= 0.2656490000000000D-01+(azi- 0.00D+00) * rk(  7)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  7)= 0.1703483103089462D-07
       rk(  7)=-0.2285232206872663D-05+(azi- 0.10D+02) * rk(  7)
       rk(  7)=-0.3463116103436289D-04+(azi- 0.10D+02) * rk(  7)
       rk(  7)= 0.2641020000000000D-01+(azi- 0.10D+02) * rk(  7)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  7)=-0.1532771377994130D-07
       rk(  7)=-0.1774187275945825D-05+(azi- 0.20D+02) * rk(  7)
       rk(  7)=-0.7522535586254776D-04+(azi- 0.20D+02) * rk(  7)
       rk(  7)= 0.2585240000000000D-01+(azi- 0.20D+02) * rk(  7)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  7)=-0.1372397591112858D-07
       rk(  7)=-0.2234018689344064D-05+(azi- 0.30D+02) * rk(  7)
       rk(  7)=-0.1153074155154466D-03+(azi- 0.30D+02) * rk(  7)
       rk(  7)= 0.2490740000000000D-01+(azi- 0.30D+02) * rk(  7)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  7)=-0.2747638257554304D-07
       rk(  7)=-0.2645737966677932D-05+(azi- 0.40D+02) * rk(  7)
       rk(  7)=-0.1641049820756665D-03+(azi- 0.40D+02) * rk(  7)
       rk(  7)= 0.2351720000000000D-01+(azi- 0.40D+02) * rk(  7)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  7)=-0.1322704937867030D-06
       rk(  7)=-0.3470029443944237D-05+(azi- 0.50D+02) * rk(  7)
       rk(  7)=-0.2252626561818883D-03+(azi- 0.50D+02) * rk(  7)
       rk(  7)= 0.2158410000000000D-01+(azi- 0.50D+02) * rk(  7)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  7)=-0.2304164227760796D-07
       rk(  7)=-0.7438144257545598D-05+(azi- 0.60D+02) * rk(  7)
       rk(  7)=-0.3343443931967845D-03+(azi- 0.60D+02) * rk(  7)
       rk(  7)= 0.1885220000000000D-01+(azi- 0.60D+02) * rk(  7)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  7)=-0.1151055949407016D-05
       rk(  7)=-0.8129393525872428D-05+(azi- 0.70D+02) * rk(  7)
       rk(  7)=-0.4900197710309764D-03+(azi- 0.70D+02) * rk(  7)
       rk(  7)= 0.1474190000000000D-01+(azi- 0.70D+02) * rk(  7)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  7)= 0.3051007034753431D-05
       rk(  7)=-0.3575473631163908D-04+(azi- 0.78D+02) * rk(  7)
       rk(  7)=-0.8410928097310894D-03+(azi- 0.78D+02) * rk(  7)
       rk(  7)= 0.9712119999999999D-02+(azi- 0.78D+02) * rk(  7)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  7)= 0.1099207874719760D-04
       rk(  7)= 0.3746943252241897D-04+(azi- 0.86D+02) * rk(  7)
       rk(  7)=-0.8273752400447254D-03+(azi- 0.86D+02) * rk(  7)
       rk(  7)= 0.2257190000000000D-02+(azi- 0.86D+02) * rk(  7)
      elseif(azi.ge.90.D0)then
       rk(  7)= 0.2506930000000000D-03
      endif
      if(att.lt.0.99999) rk(  7) = rk(  7) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  8)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  8)=-0.1926445199576598D-06
       rk(  8)=-0.1114355480042343D-04+(azi- 0.00D+00) * rk(  8)
       rk(  8)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  8)
       rk(  8)= 0.2129960000000000D+00+(azi- 0.00D+00) * rk(  8)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  8)=-0.3806644012699938D-07
       rk(  8)=-0.1692289039915322D-04+(azi- 0.10D+02) * rk(  8)
       rk(  8)=-0.2806644519957665D-03+(azi- 0.10D+02) * rk(  8)
       rk(  8)= 0.2116890000000000D+00+(azi- 0.10D+02) * rk(  8)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  8)= 0.3591028046562922D-07
       rk(  8)=-0.1806488360296321D-04+(azi- 0.20D+02) * rk(  8)
       rk(  8)=-0.6305421920169308D-03+(azi- 0.20D+02) * rk(  8)
       rk(  8)= 0.2071520000000000D+00+(azi- 0.20D+02) * rk(  8)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  8)=-0.2185746817355116D-06
       rk(  8)=-0.1698757518899435D-04+(azi- 0.30D+02) * rk(  8)
       rk(  8)=-0.9810667799365058D-03+(azi- 0.30D+02) * rk(  8)
       rk(  8)= 0.1990760000000000D+00+(azi- 0.30D+02) * rk(  8)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  8)=-0.2006115535235656D-06
       rk(  8)=-0.2354481564105959D-04+(azi- 0.40D+02) * rk(  8)
       rk(  8)=-0.1386390688237046D-02+(azi- 0.40D+02) * rk(  8)
       rk(  8)= 0.1873480000000000D+00+(azi- 0.40D+02) * rk(  8)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  8)=-0.1055979104170267D-05
       rk(  8)=-0.2956316224676618D-04+(azi- 0.50D+02) * rk(  8)
       rk(  8)=-0.1917470467115309D-02+(azi- 0.50D+02) * rk(  8)
       rk(  8)= 0.1709290000000000D+00+(azi- 0.50D+02) * rk(  8)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  8)=-0.3204720297952934D-06
       rk(  8)=-0.6124253537187832D-04+(azi- 0.60D+02) * rk(  8)
       rk(  8)=-0.2825527443301723D-02+(azi- 0.60D+02) * rk(  8)
       rk(  8)= 0.1477420000000000D+00+(azi- 0.60D+02) * rk(  8)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  8)=-0.6785572971821502D-05
       rk(  8)=-0.7085669626571978D-04+(azi- 0.70D+02) * rk(  8)
       rk(  8)=-0.4146519759677725D-02+(azi- 0.70D+02) * rk(  8)
       rk(  8)= 0.1130420000000000D+00+(azi- 0.70D+02) * rk(  8)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  8)= 0.2349184361304102D-04
       rk(  8)=-0.2337104475894081D-03+(azi- 0.78D+02) * rk(  8)
       rk(  8)=-0.6583056910518970D-02+(azi- 0.78D+02) * rk(  8)
       rk(  8)= 0.7186080000000000D-01+(azi- 0.78D+02) * rk(  8)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  8)= 0.6606749385962285D-04
       rk(  8)= 0.3300937991232988D-03+(azi- 0.86D+02) * rk(  8)
       rk(  8)=-0.5811990098247399D-02+(azi- 0.86D+02) * rk(  8)
       rk(  8)= 0.1626670000000000D-01+(azi- 0.86D+02) * rk(  8)
      elseif(azi.ge.90.D0)then
       rk(  8)= 0.2528560000000000D-02
      endif
      if(att.lt.0.99999) rk(  8) = rk(  8) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk(  9)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk(  9)=-0.1441479345432039D-10
       rk(  9)=-0.1242452065456794D-08+(azi- 0.00D+00) * rk(  9)
       rk(  9)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk(  9)
       rk(  9)= 0.8394580000000000D-05+(azi- 0.00D+00) * rk(  9)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk(  9)= 0.8244380362960478D-11
       rk(  9)=-0.1674895869086405D-08+(azi- 0.10D+02) * rk(  9)
       rk(  9)=-0.2917347934543199D-07+(azi- 0.10D+02) * rk(  9)
       rk(  9)= 0.8255920000000000D-05+(azi- 0.10D+02) * rk(  9)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk(  9)= 0.1172720024787734D-12
       rk(  9)=-0.1427564458197592D-08+(azi- 0.20D+02) * rk(  9)
       rk(  9)=-0.6019808261827194D-07+(azi- 0.20D+02) * rk(  9)
       rk(  9)= 0.7804940000000000D-05+(azi- 0.20D+02) * rk(  9)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk(  9)= 0.4506531627127201D-11
       rk(  9)=-0.1424046298123240D-08+(azi- 0.30D+02) * rk(  9)
       rk(  9)=-0.8871419018148013D-07+(azi- 0.30D+02) * rk(  9)
       rk(  9)= 0.7060320000000000D-05+(azi- 0.30D+02) * rk(  9)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk(  9)= 0.1086660148900755D-10
       rk(  9)=-0.1288850349309390D-08+(azi- 0.40D+02) * rk(  9)
       rk(  9)=-0.1158431566558070D-06+(azi- 0.40D+02) * rk(  9)
       rk(  9)= 0.6035280000000000D-05+(azi- 0.40D+02) * rk(  9)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk(  9)= 0.1803706241686108D-10
       rk(  9)=-0.9628523046392104D-09+(azi- 0.50D+02) * rk(  9)
       rk(  9)=-0.1383601831952927D-06+(azi- 0.50D+02) * rk(  9)
       rk(  9)= 0.4758830000000000D-05+(azi- 0.50D+02) * rk(  9)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk(  9)= 0.7329514884355585D-10
       rk(  9)=-0.4217404321336693D-09+(azi- 0.60D+02) * rk(  9)
       rk(  9)=-0.1522061105630206D-06+(azi- 0.60D+02) * rk(  9)
       rk(  9)= 0.3296980000000000D-05+(azi- 0.60D+02) * rk(  9)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk(  9)= 0.6172011386267615D-10
       rk(  9)= 0.1777114033174383D-08+(azi- 0.70D+02) * rk(  9)
       rk(  9)=-0.1386523745526241D-06+(azi- 0.70D+02) * rk(  9)
       rk(  9)= 0.1806040000000000D-05+(azi- 0.70D+02) * rk(  9)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk(  9)=-0.8279704635596216D-10
       rk(  9)= 0.3258396765877763D-08+(azi- 0.78D+02) * rk(  9)
       rk(  9)=-0.9836828816022045D-07+(azi- 0.78D+02) * rk(  9)
       rk(  9)= 0.8421570000000000D-06+(azi- 0.78D+02) * rk(  9)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk(  9)= 0.1082517324572734D-08
       rk(  9)= 0.1271267653334671D-08+(azi- 0.86D+02) * rk(  9)
       rk(  9)=-0.6213097280649386D-07+(azi- 0.86D+02) * rk(  9)
       rk(  9)= 0.2213560000000000D-06+(azi- 0.86D+02) * rk(  9)
      elseif(azi.ge.90.D0)then
       rk(  9)= 0.6245350000000000D-07
      endif
      if(att.lt.0.99999) rk(  9) = rk(  9) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 10)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 10)=-0.7261045436751545D-10
       rk( 10)=-0.5576895456324842D-08+(azi- 0.00D+00) * rk( 10)
       rk( 10)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 10)
       rk( 10)= 0.4669460000000000D-04+(azi- 0.00D+00) * rk( 10)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 10)= 0.2853136310254372D-10
       rk( 10)=-0.7755209087350302D-08+(azi- 0.10D+02) * rk( 10)
       rk( 10)=-0.1333210454367515D-06+(azi- 0.10D+02) * rk( 10)
       rk( 10)= 0.4606430000000000D-04+(azi- 0.10D+02) * rk( 10)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 10)=-0.1901499804265726D-10
       rk( 10)=-0.6899268194273995D-08+(azi- 0.20D+02) * rk( 10)
       rk( 10)=-0.2798658182529944D-06+(azi- 0.20D+02) * rk( 10)
       rk( 10)= 0.4398410000000000D-04+(azi- 0.20D+02) * rk( 10)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 10)=-0.9471370931908783D-11
       rk( 10)=-0.7469718135553710D-08+(azi- 0.30D+02) * rk( 10)
       rk( 10)=-0.4235556815512711D-06+(azi- 0.30D+02) * rk( 10)
       rk( 10)= 0.4047650000000000D-04+(azi- 0.30D+02) * rk( 10)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 10)= 0.1440048177028887D-10
       rk( 10)=-0.7753859263510966D-08+(azi- 0.40D+02) * rk( 10)
       rk( 10)=-0.5757914555419174D-06+(azi- 0.40D+02) * rk( 10)
       rk( 10)= 0.3548450000000000D-04+(azi- 0.40D+02) * rk( 10)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 10)= 0.3856944385081257D-10
       rk( 10)=-0.7321844810402538D-08+(azi- 0.50D+02) * rk( 10)
       rk( 10)=-0.7265484962810543D-06+(azi- 0.50D+02) * rk( 10)
       rk( 10)= 0.2896560000000000D-04+(azi- 0.50D+02) * rk( 10)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 10)= 0.4136217428262900D-09
       rk( 10)=-0.6164761494878585D-08+(azi- 0.60D+02) * rk( 10)
       rk( 10)=-0.8614145593338596D-06+(azi- 0.60D+02) * rk( 10)
       rk( 10)= 0.2100650000000000D-04+(azi- 0.60D+02) * rk( 10)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 10)= 0.5376701572532502D-09
       rk( 10)= 0.6243890789914774D-08+(azi- 0.70D+02) * rk( 10)
       rk( 10)=-0.8606232663835604D-06+(azi- 0.70D+02) * rk( 10)
       rk( 10)= 0.1218950000000000D-04+(azi- 0.70D+02) * rk( 10)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 10)=-0.5508273899935273D-09
       rk( 10)= 0.1914797456399955D-07+(azi- 0.78D+02) * rk( 10)
       rk( 10)=-0.6574883435524898D-06+(azi- 0.78D+02) * rk( 10)
       rk( 10)= 0.5979410000000000D-05+(azi- 0.78D+02) * rk( 10)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 10)= 0.8530305661922505D-08
       rk( 10)= 0.5928117204100688D-08+(azi- 0.86D+02) * rk( 10)
       rk( 10)=-0.4568796094072541D-06+(azi- 0.86D+02) * rk( 10)
       rk( 10)= 0.1662950000000000D-05+(azi- 0.86D+02) * rk( 10)
      elseif(azi.ge.90.D0)then
       rk( 10)= 0.4762210000000000D-06
      endif
      if(att.lt.0.99999) rk( 10) = rk( 10) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 11)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 11)=-0.5816837387219519D-10
       rk( 11)=-0.5184316261278087D-08+(azi- 0.00D+00) * rk( 11)
       rk( 11)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 11)
       rk( 11)= 0.3220560000000000D-04+(azi- 0.00D+00) * rk( 11)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 11)= 0.3450512161659949D-10
       rk( 11)=-0.6929367477443941D-08+(azi- 0.10D+02) * rk( 11)
       rk( 11)=-0.1211368373872203D-06+(azi- 0.10D+02) * rk( 11)
       rk( 11)= 0.3162900000000000D-04+(azi- 0.10D+02) * rk( 11)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 11)= 0.3647887405787883D-11
       rk( 11)=-0.5894213828945960D-08+(azi- 0.20D+02) * rk( 11)
       rk( 11)=-0.2493726504511192D-06+(azi- 0.20D+02) * rk( 11)
       rk( 11)= 0.2975920000000000D-04+(azi- 0.20D+02) * rk( 11)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 11)= 0.2530332876025029D-10
       rk( 11)=-0.5784777206772343D-08+(azi- 0.30D+02) * rk( 11)
       rk( 11)=-0.3661625608083018D-06+(azi- 0.30D+02) * rk( 11)
       rk( 11)= 0.2667970000000000D-04+(azi- 0.30D+02) * rk( 11)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 11)= 0.6013879755321277D-10
       rk( 11)=-0.5025677343964861D-08+(azi- 0.40D+02) * rk( 11)
       rk( 11)=-0.4742671063156733D-06+(azi- 0.40D+02) * rk( 11)
       rk( 11)= 0.2246490000000000D-04+(azi- 0.40D+02) * rk( 11)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 11)= 0.1004414810269593D-09
       rk( 11)=-0.3221513417368319D-08+(azi- 0.50D+02) * rk( 11)
       rk( 11)=-0.5567390139290089D-06+(azi- 0.50D+02) * rk( 11)
       rk( 11)= 0.1727980000000000D-04+(azi- 0.50D+02) * rk( 11)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 11)= 0.3107352783389442D-09
       rk( 11)=-0.2082689865616575D-09+(azi- 0.60D+02) * rk( 11)
       rk( 11)=-0.5910368379682989D-06+(azi- 0.60D+02) * rk( 11)
       rk( 11)= 0.1149070000000000D-04+(azi- 0.60D+02) * rk( 11)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 11)= 0.1345128013872392D-09
       rk( 11)= 0.9113789363612173D-08+(azi- 0.70D+02) * rk( 11)
       rk( 11)=-0.5019816341977565D-06+(azi- 0.70D+02) * rk( 11)
       rk( 11)= 0.5870240000000000D-05+(azi- 0.70D+02) * rk( 11)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 11)=-0.1960445509611151D-09
       rk( 11)= 0.1234209659691269D-07+(azi- 0.78D+02) * rk( 11)
       rk( 11)=-0.3303345465135304D-06+(azi- 0.78D+02) * rk( 11)
       rk( 11)= 0.2506540000000000D-05+(azi- 0.78D+02) * rk( 11)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 11)= 0.2279277828298341D-08
       rk( 11)= 0.7637027373778166D-08+(azi- 0.86D+02) * rk( 11)
       rk( 11)=-0.1705015547476783D-06+(azi- 0.86D+02) * rk( 11)
       rk( 11)= 0.5533830000000000D-06+(azi- 0.86D+02) * rk( 11)
      elseif(azi.ge.90.D0)then
       rk( 11)= 0.1394430000000000D-06
      endif
      if(att.lt.0.99999) rk( 11) = rk( 11) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 12)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 12)=-0.1292568102250478D-10
       rk( 12)=-0.1349143189774952D-08+(azi- 0.00D+00) * rk( 12)
       rk( 12)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 12)
       rk( 12)= 0.6105070000000000D-05+(azi- 0.00D+00) * rk( 12)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 12)= 0.1221704306751377D-10
       rk( 12)=-0.1736913620450095D-08+(azi- 0.10D+02) * rk( 12)
       rk( 12)=-0.3086056810225046D-07+(azi- 0.10D+02) * rk( 12)
       rk( 12)= 0.5957230000000000D-05+(azi- 0.10D+02) * rk( 12)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 12)= 0.7227508752451222D-11
       rk( 12)=-0.1370402328424685D-08+(azi- 0.20D+02) * rk( 12)
       rk( 12)=-0.6193372759099823D-07+(azi- 0.20D+02) * rk( 12)
       rk( 12)= 0.5487150000000000D-05+(azi- 0.20D+02) * rk( 12)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 12)= 0.1521292192268060D-10
       rk( 12)=-0.1153577065851153D-08+(azi- 0.30D+02) * rk( 12)
       rk( 12)=-0.8717352153375648D-07+(azi- 0.30D+02) * rk( 12)
       rk( 12)= 0.4738000000000000D-05+(azi- 0.30D+02) * rk( 12)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 12)= 0.2301080355683006D-10
       rk( 12)=-0.6971894081707449D-09+(azi- 0.40D+02) * rk( 12)
       rk( 12)=-0.1056811862739754D-06+(azi- 0.40D+02) * rk( 12)
       rk( 12)= 0.3766120000000000D-05+(azi- 0.40D+02) * rk( 12)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 12)= 0.3106386384999131D-10
       rk( 12)=-0.6865301465823343D-11+(azi- 0.50D+02) * rk( 12)
       rk( 12)=-0.1127217333703412D-06+(azi- 0.50D+02) * rk( 12)
       rk( 12)= 0.2662600000000000D-05+(azi- 0.50D+02) * rk( 12)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 12)= 0.4531874104319860D-10
       rk( 12)= 0.9250506140339690D-09+(azi- 0.60D+02) * rk( 12)
       rk( 12)=-0.1035398802446585D-06+(azi- 0.60D+02) * rk( 12)
       rk( 12)= 0.1565760000000000D-05+(azi- 0.60D+02) * rk( 12)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 12)=-0.1303761111962380D-10
       rk( 12)= 0.2284612845330880D-08+(azi- 0.70D+02) * rk( 12)
       rk( 12)=-0.7144324565100488D-07+(azi- 0.70D+02) * rk( 12)
       rk( 12)= 0.6681850000000000D-06+(azi- 0.70D+02) * rk( 12)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 12)=-0.4077238229824927D-10
       rk( 12)= 0.1971710178462450D-08+(azi- 0.78D+02) * rk( 12)
       rk( 12)=-0.3739266146067857D-07+(azi- 0.78D+02) * rk( 12)
       rk( 12)= 0.2361790000000000D-06+(azi- 0.78D+02) * rk( 12)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 12)= 0.1193377495821847D-09
       rk( 12)= 0.9931730033112436D-09+(azi- 0.86D+02) * rk( 12)
       rk( 12)=-0.1367359600643481D-07+(azi- 0.86D+02) * rk( 12)
       rk( 12)= 0.4235170000000000D-07+(azi- 0.86D+02) * rk( 12)
      elseif(azi.ge.90.D0)then
       rk( 12)= 0.1118570000000000D-07
      endif
      if(att.lt.0.99999) rk( 12) = rk( 12) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 13)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 13)=-0.9639086891432908D-11
       rk( 13)=-0.8144091310856724D-09+(azi- 0.00D+00) * rk( 13)
       rk( 13)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 13)
       rk( 13)= 0.5704620000000000D-05+(azi- 0.00D+00) * rk( 13)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 13)= 0.5287260674299008D-11
       rk( 13)=-0.1103581737828659D-08+(azi- 0.10D+02) * rk( 13)
       rk( 13)=-0.1917990868914332D-07+(azi- 0.10D+02) * rk( 13)
       rk( 13)= 0.5613540000000000D-05+(azi- 0.10D+02) * rk( 13)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 13)=-0.2699558057629897D-12
       rk( 13)=-0.9449639175996891D-09+(azi- 0.20D+02) * rk( 13)
       rk( 13)=-0.3966536524342679D-07+(azi- 0.20D+02) * rk( 13)
       rk( 13)= 0.5316670000000000D-05+(azi- 0.20D+02) * rk( 13)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 13)= 0.2382562548753546D-11
       rk( 13)=-0.9530625917725825D-09+(azi- 0.30D+02) * rk( 13)
       rk( 13)=-0.5864563033714949D-07+(azi- 0.30D+02) * rk( 13)
       rk( 13)= 0.4825250000000000D-05+(azi- 0.30D+02) * rk( 13)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 13)= 0.6319705610747424D-11
       rk( 13)=-0.8815857153099513D-09+(azi- 0.40D+02) * rk( 13)
       rk( 13)=-0.7699211340797505D-07+(azi- 0.40D+02) * rk( 13)
       rk( 13)= 0.4145870000000000D-05+(azi- 0.40D+02) * rk( 13)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 13)= 0.1056861500825653D-10
       rk( 13)=-0.6919945469875881D-09+(azi- 0.50D+02) * rk( 13)
       rk( 13)=-0.9272791603094997D-07+(azi- 0.50D+02) * rk( 13)
       rk( 13)= 0.3294110000000000D-05+(azi- 0.50D+02) * rk( 13)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 13)= 0.4850583435620618D-10
       rk( 13)=-0.3749360967397995D-09+(azi- 0.60D+02) * rk( 13)
       rk( 13)=-0.1033972224682254D-06+(azi- 0.60D+02) * rk( 13)
       rk( 13)= 0.2308200000000000D-05+(azi- 0.60D+02) * rk( 13)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 13)= 0.4863918163365898D-10
       rk( 13)= 0.1080238933948239D-08+(azi- 0.70D+02) * rk( 13)
       rk( 13)=-0.9634419409614782D-07+(azi- 0.70D+02) * rk( 13)
       rk( 13)= 0.1285240000000000D-05+(azi- 0.70D+02) * rk( 13)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 13)=-0.6023611040521017D-10
       rk( 13)= 0.2247579293157748D-08+(azi- 0.78D+02) * rk( 13)
       rk( 13)=-0.6972164827933041D-07+(azi- 0.78D+02) * rk( 13)
       rk( 13)= 0.6085250000000000D-06+(azi- 0.78D+02) * rk( 13)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 13)= 0.8106335758155240D-09
       rk( 13)= 0.8019126434123756D-09+(azi- 0.86D+02) * rk( 13)
       rk( 13)=-0.4532571278666100D-07+(azi- 0.86D+02) * rk( 13)
       rk( 13)= 0.1637560000000000D-06+(azi- 0.86D+02) * rk( 13)
      elseif(azi.ge.90.D0)then
       rk( 13)= 0.4716430000000000D-07
      endif
      if(att.lt.0.99999) rk( 13) = rk( 13) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 14)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 14)=-0.9639086891432908D-11
       rk( 14)=-0.8144091310856724D-09+(azi- 0.00D+00) * rk( 14)
       rk( 14)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 14)
       rk( 14)= 0.5704620000000000D-05+(azi- 0.00D+00) * rk( 14)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 14)= 0.5287260674299008D-11
       rk( 14)=-0.1103581737828659D-08+(azi- 0.10D+02) * rk( 14)
       rk( 14)=-0.1917990868914332D-07+(azi- 0.10D+02) * rk( 14)
       rk( 14)= 0.5613540000000000D-05+(azi- 0.10D+02) * rk( 14)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 14)=-0.2699558057629897D-12
       rk( 14)=-0.9449639175996891D-09+(azi- 0.20D+02) * rk( 14)
       rk( 14)=-0.3966536524342679D-07+(azi- 0.20D+02) * rk( 14)
       rk( 14)= 0.5316670000000000D-05+(azi- 0.20D+02) * rk( 14)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 14)= 0.2382562548753546D-11
       rk( 14)=-0.9530625917725825D-09+(azi- 0.30D+02) * rk( 14)
       rk( 14)=-0.5864563033714949D-07+(azi- 0.30D+02) * rk( 14)
       rk( 14)= 0.4825250000000000D-05+(azi- 0.30D+02) * rk( 14)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 14)= 0.6319705610747424D-11
       rk( 14)=-0.8815857153099513D-09+(azi- 0.40D+02) * rk( 14)
       rk( 14)=-0.7699211340797505D-07+(azi- 0.40D+02) * rk( 14)
       rk( 14)= 0.4145870000000000D-05+(azi- 0.40D+02) * rk( 14)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 14)= 0.1056861500825653D-10
       rk( 14)=-0.6919945469875881D-09+(azi- 0.50D+02) * rk( 14)
       rk( 14)=-0.9272791603094997D-07+(azi- 0.50D+02) * rk( 14)
       rk( 14)= 0.3294110000000000D-05+(azi- 0.50D+02) * rk( 14)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 14)= 0.4850583435620618D-10
       rk( 14)=-0.3749360967397995D-09+(azi- 0.60D+02) * rk( 14)
       rk( 14)=-0.1033972224682254D-06+(azi- 0.60D+02) * rk( 14)
       rk( 14)= 0.2308200000000000D-05+(azi- 0.60D+02) * rk( 14)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 14)= 0.4863918163365898D-10
       rk( 14)= 0.1080238933948239D-08+(azi- 0.70D+02) * rk( 14)
       rk( 14)=-0.9634419409614782D-07+(azi- 0.70D+02) * rk( 14)
       rk( 14)= 0.1285240000000000D-05+(azi- 0.70D+02) * rk( 14)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 14)=-0.6023611040521017D-10
       rk( 14)= 0.2247579293157748D-08+(azi- 0.78D+02) * rk( 14)
       rk( 14)=-0.6972164827933041D-07+(azi- 0.78D+02) * rk( 14)
       rk( 14)= 0.6085250000000000D-06+(azi- 0.78D+02) * rk( 14)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 14)= 0.8106335758155240D-09
       rk( 14)= 0.8019126434123756D-09+(azi- 0.86D+02) * rk( 14)
       rk( 14)=-0.4532571278666100D-07+(azi- 0.86D+02) * rk( 14)
       rk( 14)= 0.1637560000000000D-06+(azi- 0.86D+02) * rk( 14)
      elseif(azi.ge.90.D0)then
       rk( 14)= 0.4716430000000000D-07
      endif
      if(att.lt.0.99999) rk( 14) = rk( 14) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 15)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 15)=-0.3832057510941250D-11
       rk( 15)=-0.3311794248905845D-09+(azi- 0.00D+00) * rk( 15)
       rk( 15)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 15)
       rk( 15)= 0.2224430000000000D-05+(azi- 0.00D+00) * rk( 15)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 15)= 0.2216172532822996D-11
       rk( 15)=-0.4461411502188222D-09+(azi- 0.10D+02) * rk( 15)
       rk( 15)=-0.7773205751094067D-08+(azi- 0.10D+02) * rk( 15)
       rk( 15)= 0.2187480000000000D-05+(azi- 0.10D+02) * rk( 15)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 15)= 0.5736737964910470D-13
       rk( 15)=-0.3796559742341328D-09+(azi- 0.20D+02) * rk( 15)
       rk( 15)=-0.1603117699562361D-07+(azi- 0.20D+02) * rk( 15)
       rk( 15)= 0.2067350000000000D-05+(azi- 0.20D+02) * rk( 15)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 15)= 0.1254357948581281D-11
       rk( 15)=-0.3779349528446593D-09+(azi- 0.30D+02) * rk( 15)
       rk( 15)=-0.2360708626641151D-07+(azi- 0.30D+02) * rk( 15)
       rk( 15)= 0.1869130000000000D-05+(azi- 0.30D+02) * rk( 15)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 15)= 0.2935200826025157D-11
       rk( 15)=-0.3403042143872213D-09+(azi- 0.40D+02) * rk( 15)
       rk( 15)=-0.3078947793873033D-07+(azi- 0.40D+02) * rk( 15)
       rk( 15)= 0.1596520000000000D-05+(azi- 0.40D+02) * rk( 15)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 15)= 0.4861838747321660D-11
       rk( 15)=-0.2522481896064666D-09+(azi- 0.50D+02) * rk( 15)
       rk( 15)=-0.3671500197866716D-07+(azi- 0.50D+02) * rk( 15)
       rk( 15)= 0.1257530000000000D-05+(azi- 0.50D+02) * rk( 15)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 15)= 0.1939344418469089D-10
       rk( 15)=-0.1063930271868565D-09+(azi- 0.60D+02) * rk( 15)
       rk( 15)=-0.4030141414660034D-07+(azi- 0.60D+02) * rk( 15)
       rk( 15)= 0.8700170000000000D-06+(azi- 0.60D+02) * rk( 15)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 15)= 0.1609506325143636D-10
       rk( 15)= 0.4754102983540026D-09+(azi- 0.70D+02) * rk( 15)
       rk( 15)=-0.3661124143492962D-07+(azi- 0.70D+02) * rk( 15)
       rk( 15)= 0.4757570000000000D-06+(azi- 0.70D+02) * rk( 15)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 15)=-0.2188667990824655D-10
       rk( 15)= 0.8616918163893223D-09+(azi- 0.78D+02) * rk( 15)
       rk( 15)=-0.2591442451698979D-07+(azi- 0.78D+02) * rk( 15)
       rk( 15)= 0.2215340000000000D-06+(azi- 0.78D+02) * rk( 15)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 15)= 0.2841313751779476D-09
       rk( 15)= 0.3364114985863228D-09+(azi- 0.86D+02) * rk( 15)
       rk( 15)=-0.1632959799716430D-07+(azi- 0.86D+02) * rk( 15)
       rk( 15)= 0.5816090000000000D-07+(azi- 0.86D+02) * rk( 15)
      elseif(azi.ge.90.D0)then
       rk( 15)= 0.1640950000000000D-07
      endif
      if(att.lt.0.99999) rk( 15) = rk( 15) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 16)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 16)=-0.2139600241835154D-11
       rk( 16)=-0.2151039975816482D-09+(azi- 0.00D+00) * rk( 16)
       rk( 16)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 16)
       rk( 16)= 0.1065630000000000D-05+(azi- 0.00D+00) * rk( 16)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 16)= 0.1813800725505395D-11
       rk( 16)=-0.2792920048367028D-09+(azi- 0.10D+02) * rk( 16)
       rk( 16)=-0.4943960024183510D-08+(azi- 0.10D+02) * rk( 16)
       rk( 16)= 0.1041980000000000D-05+(azi- 0.10D+02) * rk( 16)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 16)= 0.9033973398136872D-12
       rk( 16)=-0.2248779830715415D-09+(azi- 0.20D+02) * rk( 16)
       rk( 16)=-0.9985659903265952D-08+(azi- 0.20D+02) * rk( 16)
       rk( 16)= 0.9664250000000000D-06+(azi- 0.20D+02) * rk( 16)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 16)= 0.2075609915239675D-11
       rk( 16)=-0.1977760628771301D-09+(azi- 0.30D+02) * rk( 16)
       rk( 16)=-0.1421220036275265D-07+(azi- 0.30D+02) * rk( 16)
       rk( 16)= 0.8449840000000000D-06+(azi- 0.30D+02) * rk( 16)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 16)= 0.3345162999227387D-11
       rk( 16)=-0.1355077654199368D-09+(azi- 0.40D+02) * rk( 16)
       rk( 16)=-0.1754503864572331D-07+(azi- 0.40D+02) * rk( 16)
       rk( 16)= 0.6851600000000000D-06+(azi- 0.40D+02) * rk( 16)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 16)= 0.4733738087850787D-11
       rk( 16)=-0.3515287544311602D-10+(azi- 0.50D+02) * rk( 16)
       rk( 16)=-0.1925164505435384D-07+(azi- 0.50D+02) * rk( 16)
       rk( 16)= 0.4995040000000001D-06+(azi- 0.50D+02) * rk( 16)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 16)= 0.8639884649373739D-11
       rk( 16)= 0.1068592671923679D-09+(azi- 0.60D+02) * rk( 16)
       rk( 16)=-0.1853458113686135D-07+(azi- 0.60D+02) * rk( 16)
       rk( 16)= 0.3082060000000000D-06+(azi- 0.60D+02) * rk( 16)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 16)=-0.6489929990328960D-13
       rk( 16)= 0.3660558066739771D-09+(azi- 0.70D+02) * rk( 16)
       rk( 16)=-0.1380543039819970D-07+(azi- 0.70D+02) * rk( 16)
       rk( 16)= 0.1421860000000000D-06+(azi- 0.70D+02) * rk( 16)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 16)=-0.7060744231510420D-11
       rk( 16)= 0.3644982234767217D-09+(azi- 0.78D+02) * rk( 16)
       rk( 16)=-0.7960998156995803D-08+(azi- 0.78D+02) * rk( 16)
       rk( 16)= 0.5513690000000000D-07+(azi- 0.78D+02) * rk( 16)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 16)= 0.4009097038418610D-10
       rk( 16)= 0.1950403619196245D-09+(azi- 0.86D+02) * rk( 16)
       rk( 16)=-0.3484689473825034D-08+(azi- 0.86D+02) * rk( 16)
       rk( 16)= 0.1116170000000000D-07+(azi- 0.86D+02) * rk( 16)
      elseif(azi.ge.90.D0)then
       rk( 16)= 0.2909410000000000D-08
      endif
      if(att.lt.0.99999) rk( 16) = rk( 16) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 17)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 17)=-0.9030422964083292D-10
       rk( 17)=-0.4134957703591604D-08+(azi- 0.00D+00) * rk( 17)
       rk( 17)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 17)
       rk( 17)= 0.6803410000000000D-04+(azi- 0.00D+00) * rk( 17)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 17)= 0.2671268892247792D-10
       rk( 17)=-0.6844084592816590D-08+(azi- 0.10D+02) * rk( 17)
       rk( 17)=-0.1097904229640819D-06+(azi- 0.10D+02) * rk( 17)
       rk( 17)= 0.6753030000000001D-04+(azi- 0.10D+02) * rk( 17)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 17)=-0.4184652604907341D-10
       rk( 17)=-0.6042703925142254D-08+(azi- 0.20D+02) * rk( 17)
       rk( 17)=-0.2386583081436703D-06+(azi- 0.20D+02) * rk( 17)
       rk( 17)= 0.6577470000000001D-04+(azi- 0.20D+02) * rk( 17)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 17)=-0.5902658472617875D-10
       rk( 17)=-0.7298099706614438D-08+(azi- 0.30D+02) * rk( 17)
       rk( 17)=-0.3720663444612372D-06+(azi- 0.30D+02) * rk( 17)
       rk( 17)= 0.6274200000000000D-04+(azi- 0.30D+02) * rk( 17)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 17)=-0.1000471350462274D-09
       rk( 17)=-0.9068897248399807D-08+(azi- 0.40D+02) * rk( 17)
       rk( 17)=-0.5357363140113795D-06+(azi- 0.40D+02) * rk( 17)
       rk( 17)= 0.5823250000000000D-04+(azi- 0.40D+02) * rk( 17)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 17)=-0.2435848750889136D-09
       rk( 17)=-0.1207031129978639D-07+(azi- 0.50D+02) * rk( 17)
       rk( 17)=-0.7471283994932436D-06+(azi- 0.50D+02) * rk( 17)
       rk( 17)= 0.5186820000000000D-04+(azi- 0.50D+02) * rk( 17)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 17)=-0.1549133645980719D-09
       rk( 17)=-0.1937785755245502D-07+(azi- 0.60D+02) * rk( 17)
       rk( 17)=-0.1061610088015645D-05+(azi- 0.60D+02) * rk( 17)
       rk( 17)= 0.4294630000000000D-04+(azi- 0.60D+02) * rk( 17)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 17)= 0.8239190057396064D-09
       rk( 17)=-0.2402525849039654D-07+(azi- 0.70D+02) * rk( 17)
       rk( 17)=-0.1495641248444140D-05+(azi- 0.70D+02) * rk( 17)
       rk( 17)= 0.3023750000000000D-04+(azi- 0.70D+02) * rk( 17)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 17)= 0.2660899281401846D-08
       rk( 17)=-0.4251202352642601D-08+(azi- 0.78D+02) * rk( 17)
       rk( 17)=-0.1721852935188562D-05+(azi- 0.78D+02) * rk( 17)
       rk( 17)= 0.1715660000000000D-04+(azi- 0.78D+02) * rk( 17)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 17)= 0.1671034307484227D-07
       rk( 17)= 0.5961038040101525D-07+(azi- 0.86D+02) * rk( 17)
       rk( 17)=-0.1278979510801201D-05+(azi- 0.86D+02) * rk( 17)
       rk( 17)= 0.4472080000000000D-05+(azi- 0.86D+02) * rk( 17)
      elseif(azi.ge.90.D0)then
       rk( 17)= 0.1379390000000000D-05
      endif
      if(att.lt.0.99999) rk( 17) = rk( 17) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 18)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 18)=-0.4649884923986661D-10
       rk( 18)=-0.3874011507601327D-08+(azi- 0.00D+00) * rk( 18)
       rk( 18)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 18)
       rk( 18)= 0.2781010000000000D-04+(azi- 0.00D+00) * rk( 18)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 18)= 0.2349654771959593D-10
       rk( 18)=-0.5268976984797324D-08+(azi- 0.10D+02) * rk( 18)
       rk( 18)=-0.9142988492398653D-07+(azi- 0.10D+02) * rk( 18)
       rk( 18)= 0.2737620000000000D-04+(azi- 0.10D+02) * rk( 18)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 18)=-0.4087341638514381D-11
       rk( 18)=-0.4564080553209450D-08+(azi- 0.20D+02) * rk( 18)
       rk( 18)=-0.1897604603040542D-06+(azi- 0.20D+02) * rk( 18)
       rk( 18)= 0.2595850000000000D-04+(azi- 0.20D+02) * rk( 18)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 18)= 0.8252818834462809D-11
       rk( 18)=-0.4686700802364868D-08+(azi- 0.30D+02) * rk( 18)
       rk( 18)=-0.2822682738597972D-06+(azi- 0.30D+02) * rk( 18)
       rk( 18)= 0.2360040000000000D-04+(azi- 0.30D+02) * rk( 18)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 18)= 0.2837606630064309D-10
       rk( 18)=-0.4439116237330931D-08+(azi- 0.40D+02) * rk( 18)
       rk( 18)=-0.3735264442567557D-06+(azi- 0.40D+02) * rk( 18)
       rk( 18)= 0.2031730000000000D-04+(azi- 0.40D+02) * rk( 18)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 18)= 0.5284291596294313D-10
       rk( 18)=-0.3587834248311492D-08+(azi- 0.50D+02) * rk( 18)
       rk( 18)=-0.4537959491131808D-06+(azi- 0.50D+02) * rk( 18)
       rk( 18)= 0.1616650000000000D-04+(azi- 0.50D+02) * rk( 18)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 18)= 0.2535522698476368D-09
       rk( 18)=-0.2002546769424257D-08+(azi- 0.60D+02) * rk( 18)
       rk( 18)=-0.5096997592905323D-06+(azi- 0.60D+02) * rk( 18)
       rk( 18)= 0.1132260000000000D-04+(azi- 0.60D+02) * rk( 18)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 18)= 0.2218412986972147D-09
       rk( 18)= 0.5604021326005695D-08+(azi- 0.70D+02) * rk( 18)
       rk( 18)=-0.4736850137246926D-06+(azi- 0.70D+02) * rk( 18)
       rk( 18)= 0.6278900000000000D-05+(azi- 0.70D+02) * rk( 18)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 18)=-0.2840497156097208D-09
       rk( 18)= 0.1092821249473546D-07+(azi- 0.78D+02) * rk( 18)
       rk( 18)=-0.3414271431588446D-06+(azi- 0.78D+02) * rk( 18)
       rk( 18)= 0.2961660000000000D-05+(azi- 0.78D+02) * rk( 18)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 18)= 0.3921356959984837D-08
       rk( 18)= 0.4111019320102161D-08+(azi- 0.86D+02) * rk( 18)
       rk( 18)=-0.2211132886398726D-06+(azi- 0.86D+02) * rk( 18)
       rk( 18)= 0.7842150000000000D-06+(azi- 0.86D+02) * rk( 18)
      elseif(azi.ge.90.D0)then
       rk( 18)= 0.2165050000000000D-06
      endif
      if(att.lt.0.99999) rk( 18) = rk( 18) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 19)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 19)=-0.1826021023809213D-09
       rk( 19)=-0.1228397897619082D-07+(azi- 0.00D+00) * rk( 19)
       rk( 19)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 19)
       rk( 19)= 0.1204770000000000D-03+(azi- 0.00D+00) * rk( 19)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 19)= 0.7680630714277358D-10
       rk( 19)=-0.1776204204761847D-07+(azi- 0.10D+02) * rk( 19)
       rk( 19)=-0.3004602102380929D-06+(azi- 0.10D+02) * rk( 19)
       rk( 19)= 0.1190660000000000D-03+(azi- 0.10D+02) * rk( 19)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 19)=-0.4662312619017368D-10
       rk( 19)=-0.1545785283333527D-07+(azi- 0.20D+02) * rk( 19)
       rk( 19)=-0.6326591590476302D-06+(azi- 0.20D+02) * rk( 19)
       rk( 19)= 0.1143620000000000D-03+(azi- 0.20D+02) * rk( 19)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 19)=-0.3391380238206294D-10
       rk( 19)=-0.1685654661904045D-07+(azi- 0.30D+02) * rk( 19)
       rk( 19)=-0.9558031535713878D-06+(azi- 0.30D+02) * rk( 19)
       rk( 19)= 0.1064430000000000D-03+(azi- 0.30D+02) * rk( 19)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 19)=-0.3482166428159112D-10
       rk( 19)=-0.1787396069050238D-07+(azi- 0.40D+02) * rk( 19)
       rk( 19)=-0.1303108226666818D-05+(azi- 0.40D+02) * rk( 19)
       rk( 19)= 0.9516540000000000D-04+(azi- 0.40D+02) * rk( 19)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 19)=-0.9419954049165213D-10
       rk( 19)=-0.1891861061895016D-07+(azi- 0.50D+02) * rk( 19)
       rk( 19)=-0.1671033939761339D-05+(azi- 0.50D+02) * rk( 19)
       rk( 19)= 0.8031210000000001D-04+(azi- 0.50D+02) * rk( 19)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 19)= 0.4307198262473663D-09
       rk( 19)=-0.2174459683369613D-07+(azi- 0.60D+02) * rk( 19)
       rk( 19)=-0.2077666014287802D-05+(azi- 0.60D+02) * rk( 19)
       rk( 19)= 0.6161569999999999D-04+(azi- 0.60D+02) * rk( 19)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 19)= 0.1932828429018806D-08
       rk( 19)=-0.8823002046250573D-08+(azi- 0.70D+02) * rk( 19)
       rk( 19)=-0.2383342003087316D-05+(azi- 0.70D+02) * rk( 19)
       rk( 19)= 0.3909530000000000D-04+(azi- 0.70D+02) * rk( 19)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 19)= 0.7078805396671869D-10
       rk( 19)= 0.3756488025025498D-07+(azi- 0.78D+02) * rk( 19)
       rk( 19)=-0.2153406977455823D-05+(azi- 0.78D+02) * rk( 19)
       rk( 19)= 0.2045350000000000D-04+(azi- 0.78D+02) * rk( 19)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 19)= 0.2551390080685143D-07
       rk( 19)= 0.3926379354523939D-07+(azi- 0.86D+02) * rk( 19)
       rk( 19)=-0.1538777587090784D-05+(azi- 0.86D+02) * rk( 19)
       rk( 19)= 0.5666640000000000D-05+(azi- 0.86D+02) * rk( 19)
      elseif(azi.ge.90.D0)then
       rk( 19)= 0.1772640000000000D-05
      endif
      if(att.lt.0.99999) rk( 19) = rk( 19) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 20)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 20)=-0.8584948998100693D-09
       rk( 20)=-0.6414505100189953D-07+(azi- 0.00D+00) * rk( 20)
       rk( 20)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 20)
       rk( 20)= 0.5609260000000000D-03+(azi- 0.00D+00) * rk( 20)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 20)= 0.3254846994303392D-09
       rk( 20)=-0.8989989799620162D-07+(azi- 0.10D+02) * rk( 20)
       rk( 20)=-0.1540449489981011D-05+(azi- 0.10D+02) * rk( 20)
       rk( 20)= 0.5536530000000000D-03+(azi- 0.10D+02) * rk( 20)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 20)=-0.2454438979115351D-09
       rk( 20)=-0.8013535701329145D-07+(azi- 0.20D+02) * rk( 20)
       rk( 20)=-0.3240802040075941D-05+(azi- 0.20D+02) * rk( 20)
       rk( 20)= 0.5295840000000000D-03+(azi- 0.20D+02) * rk( 20)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 20)=-0.1557091077839579D-09
       rk( 20)=-0.8749867395063711D-07+(azi- 0.30D+02) * rk( 20)
       rk( 20)=-0.4917142349715225D-05+(azi- 0.30D+02) * rk( 20)
       rk( 20)= 0.4889170000000000D-03+(azi- 0.30D+02) * rk( 20)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 20)= 0.5928032904741575D-10
       rk( 20)=-0.9216994718415690D-07+(azi- 0.40D+02) * rk( 20)
       rk( 20)=-0.6713828561063159D-05+(azi- 0.40D+02) * rk( 20)
       rk( 20)= 0.4308400000000000D-03+(azi- 0.40D+02) * rk( 20)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 20)= 0.2595877915944963D-09
       rk( 20)=-0.9039153731273486D-07+(azi- 0.50D+02) * rk( 20)
       rk( 20)=-0.8539443406032087D-05+(azi- 0.50D+02) * rk( 20)
       rk( 20)= 0.3545440000000000D-03+(azi- 0.50D+02) * rk( 20)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 20)= 0.4590368504578084D-08
       rk( 20)=-0.8260390356490844D-07+(azi- 0.60D+02) * rk( 20)
       rk( 20)=-0.1026939781480858D-04+(azi- 0.60D+02) * rk( 20)
       rk( 20)= 0.2603700000000000D-03+(azi- 0.60D+02) * rk( 20)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 20)= 0.7530009721131077D-08
       rk( 20)= 0.5510715157249846D-07+(azi- 0.70D+02) * rk( 20)
       rk( 20)=-0.1054436533473309D-04+(azi- 0.70D+02) * rk( 20)
       rk( 20)= 0.1540060000000000D-03+(azi- 0.70D+02) * rk( 20)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 20)=-0.7917656811272118D-08
       rk( 20)= 0.2358273848796985D-06+(azi- 0.78D+02) * rk( 20)
       rk( 20)=-0.8216889043116161D-05+(azi- 0.78D+02) * rk( 20)
       rk( 20)= 0.7703330000000000D-04+(azi- 0.78D+02) * rk( 20)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 20)= 0.1166127504485630D-06
       rk( 20)= 0.4580362140873401D-07+(azi- 0.86D+02) * rk( 20)
       rk( 20)=-0.5963840992804365D-05+(azi- 0.86D+02) * rk( 20)
       rk( 20)= 0.2233730000000000D-04+(azi- 0.86D+02) * rk( 20)
      elseif(azi.ge.90.D0)then
       rk( 20)= 0.6678010000000000D-05
      endif
      if(att.lt.0.99999) rk( 20) = rk( 20) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 21)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 21)=-0.6650705923705479D-11
       rk( 21)=-0.6611929407629450D-09+(azi- 0.00D+00) * rk( 21)
       rk( 21)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 21)
       rk( 21)= 0.3379090000000000D-05+(azi- 0.00D+00) * rk( 21)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 21)= 0.5602117771116236D-11
       rk( 21)=-0.8607141184741090D-09+(azi- 0.10D+02) * rk( 21)
       rk( 21)=-0.1521907059237054D-07+(azi- 0.10D+02) * rk( 21)
       rk( 21)= 0.3306320000000000D-05+(azi- 0.10D+02) * rk( 21)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 21)= 0.2622234839240618D-11
       rk( 21)=-0.6926505853406227D-09+(azi- 0.20D+02) * rk( 21)
       rk( 21)=-0.3075271763051784D-07+(azi- 0.20D+02) * rk( 21)
       rk( 21)= 0.3073660000000000D-05+(azi- 0.20D+02) * rk( 21)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 21)= 0.6018942871922055D-11
       rk( 21)=-0.6139835401634017D-09+(azi- 0.30D+02) * rk( 21)
       rk( 21)=-0.4381905888555809D-07+(azi- 0.30D+02) * rk( 21)
       rk( 21)= 0.2699490000000000D-05+(azi- 0.30D+02) * rk( 21)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 21)= 0.9631993673072422D-11
       rk( 21)=-0.4334152540057500D-09+(azi- 0.40D+02) * rk( 21)
       rk( 21)=-0.5429304682724973D-07+(azi- 0.40D+02) * rk( 21)
       rk( 21)= 0.2205920000000000D-05+(azi- 0.40D+02) * rk( 21)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 21)= 0.1346308243578111D-10
       rk( 21)=-0.1444554438135145D-09+(azi- 0.50D+02) * rk( 21)
       rk( 21)=-0.6007175380544298D-07+(azi- 0.50D+02) * rk( 21)
       rk( 21)= 0.1629280000000000D-05+(azi- 0.50D+02) * rk( 21)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 21)= 0.2754267658383055D-10
       rk( 21)= 0.2594370292596410D-09+(azi- 0.60D+02) * rk( 21)
       rk( 21)=-0.5892193795098066D-07+(azi- 0.60D+02) * rk( 21)
       rk( 21)= 0.1027580000000000D-05+(azi- 0.60D+02) * rk( 21)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 21)= 0.3078605881868256D-11
       rk( 21)= 0.1085717326774769D-08+(azi- 0.70D+02) * rk( 21)
       rk( 21)=-0.4547039439064206D-07+(azi- 0.70D+02) * rk( 21)
       rk( 21)= 0.4918470000000000D-06+(azi- 0.70D+02) * rk( 21)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 21)=-0.2153154079143221D-10
       rk( 21)= 0.1159603867942148D-08+(azi- 0.78D+02) * rk( 21)
       rk( 21)=-0.2750782483291689D-07+(azi- 0.78D+02) * rk( 21)
       rk( 21)= 0.1991460000000000D-06+(azi- 0.78D+02) * rk( 21)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 21)= 0.1655300763808969D-09
       rk( 21)= 0.6428468889409992D-09+(azi- 0.86D+02) * rk( 21)
       rk( 21)=-0.1308821877786526D-07+(azi- 0.86D+02) * rk( 21)
       rk( 21)= 0.4227390000000000D-07+(azi- 0.86D+02) * rk( 21)
      elseif(azi.ge.90.D0)then
       rk( 21)= 0.1080050000000000D-07
      endif
      if(att.lt.0.99999) rk( 21) = rk( 21) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 22)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 22)=-0.2724056225766411D-11
       rk( 22)=-0.2068594377423350D-09+(azi- 0.00D+00) * rk( 22)
       rk( 22)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 22)
       rk( 22)= 0.1769770000000000D-05+(azi- 0.00D+00) * rk( 22)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 22)= 0.1042168677298912D-11
       rk( 22)=-0.2885811245153273D-09+(azi- 0.10D+02) * rk( 22)
       rk( 22)=-0.4954405622576623D-08+(azi- 0.10D+02) * rk( 22)
       rk( 22)= 0.1746360000000000D-05+(azi- 0.10D+02) * rk( 22)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 22)=-0.7346184834290850D-12
       rk( 22)=-0.2573160641963604D-09+(azi- 0.20D+02) * rk( 22)
       rk( 22)=-0.1041337750969350D-07+(azi- 0.20D+02) * rk( 22)
       rk( 22)= 0.1669000000000000D-05+(azi- 0.20D+02) * rk( 22)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 22)=-0.4136947435822000D-12
       rk( 22)=-0.2793546186992334D-09+(azi- 0.30D+02) * rk( 22)
       rk( 22)=-0.1578008433864942D-07+(azi- 0.30D+02) * rk( 22)
       rk( 22)= 0.1538400000000000D-05+(azi- 0.30D+02) * rk( 22)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 22)= 0.3593974577559286D-12
       rk( 22)=-0.2917654610066926D-09+(azi- 0.40D+02) * rk( 22)
       rk( 22)=-0.2149128513570870D-07+(azi- 0.40D+02) * rk( 22)
       rk( 22)= 0.1352250000000000D-05+(azi- 0.40D+02) * rk( 22)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 22)= 0.1158104912559730D-11
       rk( 22)=-0.2809835372740098D-09+(azi- 0.50D+02) * rk( 22)
       rk( 22)=-0.2721877511851595D-07+(azi- 0.50D+02) * rk( 22)
       rk( 22)= 0.1108520000000000D-05+(azi- 0.50D+02) * rk( 22)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 22)= 0.1481218289200588D-10
       rk( 22)=-0.2462403898971914D-09+(azi- 0.60D+02) * rk( 22)
       rk( 22)=-0.3249101439022863D-07+(azi- 0.60D+02) * rk( 22)
       rk( 22)= 0.8093920000000000D-06+(azi- 0.60D+02) * rk( 22)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 22)= 0.2251236790098139D-10
       rk( 22)= 0.1981250968631836D-09+(azi- 0.70D+02) * rk( 22)
       rk( 22)=-0.3297216732056966D-07+(azi- 0.70D+02) * rk( 22)
       rk( 22)= 0.4746700000000000D-06+(azi- 0.70D+02) * rk( 22)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 22)=-0.2282006684570455D-10
       rk( 22)= 0.7384219264865253D-09+(azi- 0.78D+02) * rk( 22)
       rk( 22)=-0.2547979113377114D-07+(azi- 0.78D+02) * rk( 22)
       rk( 22)= 0.2350990000000000D-06+(azi- 0.78D+02) * rk( 22)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 22)= 0.3441785534773510D-09
       rk( 22)= 0.1907403221845338D-09+(azi- 0.86D+02) * rk( 22)
       rk( 22)=-0.1804649314436201D-07+(azi- 0.86D+02) * rk( 22)
       rk( 22)= 0.6683580000000001D-07+(azi- 0.86D+02) * rk( 22)
      elseif(azi.ge.90.D0)then
       rk( 22)= 0.1972910000000000D-07
      endif
      if(att.lt.0.99999) rk( 22) = rk( 22) * att
      endif
C
C
      if(option_photolysis.eq.2) then
       rk( 23)= 0.D0
      elseif(option_photolysis.eq.1) then
      if(azi.lt.0.D0)then
       STOP
      elseif(azi.ge. 0.00D+00 .and. azi.lt. 0.10D+02) then
       rk( 23)=-0.2139600241835154D-11
       rk( 23)=-0.2151039975816482D-09+(azi- 0.00D+00) * rk( 23)
       rk( 23)= 0.0000000000000000D+00+(azi- 0.00D+00) * rk( 23)
       rk( 23)= 0.1065630000000000D-05+(azi- 0.00D+00) * rk( 23)
      elseif(azi.ge. 0.10D+02 .and. azi.lt. 0.20D+02) then
       rk( 23)= 0.1813800725505395D-11
       rk( 23)=-0.2792920048367028D-09+(azi- 0.10D+02) * rk( 23)
       rk( 23)=-0.4943960024183510D-08+(azi- 0.10D+02) * rk( 23)
       rk( 23)= 0.1041980000000000D-05+(azi- 0.10D+02) * rk( 23)
      elseif(azi.ge. 0.20D+02 .and. azi.lt. 0.30D+02) then
       rk( 23)= 0.9033973398136872D-12
       rk( 23)=-0.2248779830715415D-09+(azi- 0.20D+02) * rk( 23)
       rk( 23)=-0.9985659903265952D-08+(azi- 0.20D+02) * rk( 23)
       rk( 23)= 0.9664250000000000D-06+(azi- 0.20D+02) * rk( 23)
      elseif(azi.ge. 0.30D+02 .and. azi.lt. 0.40D+02) then
       rk( 23)= 0.2075609915239675D-11
       rk( 23)=-0.1977760628771301D-09+(azi- 0.30D+02) * rk( 23)
       rk( 23)=-0.1421220036275265D-07+(azi- 0.30D+02) * rk( 23)
       rk( 23)= 0.8449840000000000D-06+(azi- 0.30D+02) * rk( 23)
      elseif(azi.ge. 0.40D+02 .and. azi.lt. 0.50D+02) then
       rk( 23)= 0.3345162999227387D-11
       rk( 23)=-0.1355077654199368D-09+(azi- 0.40D+02) * rk( 23)
       rk( 23)=-0.1754503864572331D-07+(azi- 0.40D+02) * rk( 23)
       rk( 23)= 0.6851600000000000D-06+(azi- 0.40D+02) * rk( 23)
      elseif(azi.ge. 0.50D+02 .and. azi.lt. 0.60D+02) then
       rk( 23)= 0.4733738087850787D-11
       rk( 23)=-0.3515287544311602D-10+(azi- 0.50D+02) * rk( 23)
       rk( 23)=-0.1925164505435384D-07+(azi- 0.50D+02) * rk( 23)
       rk( 23)= 0.4995040000000001D-06+(azi- 0.50D+02) * rk( 23)
      elseif(azi.ge. 0.60D+02 .and. azi.lt. 0.70D+02) then
       rk( 23)= 0.8639884649373739D-11
       rk( 23)= 0.1068592671923679D-09+(azi- 0.60D+02) * rk( 23)
       rk( 23)=-0.1853458113686135D-07+(azi- 0.60D+02) * rk( 23)
       rk( 23)= 0.3082060000000000D-06+(azi- 0.60D+02) * rk( 23)
      elseif(azi.ge. 0.70D+02 .and. azi.lt. 0.78D+02) then
       rk( 23)=-0.6489929990328960D-13
       rk( 23)= 0.3660558066739771D-09+(azi- 0.70D+02) * rk( 23)
       rk( 23)=-0.1380543039819970D-07+(azi- 0.70D+02) * rk( 23)
       rk( 23)= 0.1421860000000000D-06+(azi- 0.70D+02) * rk( 23)
      elseif(azi.ge. 0.78D+02 .and. azi.lt. 0.86D+02) then
       rk( 23)=-0.7060744231510420D-11
       rk( 23)= 0.3644982234767217D-09+(azi- 0.78D+02) * rk( 23)
       rk( 23)=-0.7960998156995803D-08+(azi- 0.78D+02) * rk( 23)
       rk( 23)= 0.5513690000000000D-07+(azi- 0.78D+02) * rk( 23)
      elseif(azi.ge. 0.86D+02 .and. azi.lt. 0.90D+02) then
       rk( 23)= 0.4009097038418610D-10
       rk( 23)= 0.1950403619196245D-09+(azi- 0.86D+02) * rk( 23)
       rk( 23)=-0.3484689473825034D-08+(azi- 0.86D+02) * rk( 23)
       rk( 23)= 0.1116170000000000D-07+(azi- 0.86D+02) * rk( 23)
      elseif(azi.ge.90.D0)then
       rk( 23)= 0.2909410000000000D-08
      endif
      if(att.lt.0.99999) rk( 23) = rk( 23) * att
      endif
C
      rk( 24) = SumM * 6.0d-34 * (temp/3.d2) ** (-2.3d0)
      rk( 24) = rk( 24) * SumM * 0.2d0
      rk( 25) =  DEXP(-0.2555157957424871D+02
     & - (  0.2060000000000000D+04 )/temp)
      rk( 26) =  DEXP(-0.2474064935803238D+02
     & - ( -0.1100000000000000D+03 )/temp)
      rk( 26) = rk( 26) * SumM * 0.8d0
      rk( 27) =  DEXP(-0.2416528521312882D+02
     & - ( -0.7000000000000000D+02 )/temp)
      rk( 27) = rk( 27) * SumM * 0.2d0
      rk( 28) =  0.2200000000000000D-09
      rk( 28) = rk( 28) * YlH2O
      rk( 29) =  DEXP(-0.2716101748668281D+02
     & - (  0.9400000000000000D+03 )/temp)
      rk( 30) =  DEXP(-0.3214088112211231D+02
     & - (  0.5000000000000000D+03 )/temp)
      rk( 31) =  DEXP(-0.2375982010502066D+02
     & - ( -0.2500000000000000D+03 )/temp)
      rk( 32) =  DEXP(-0.2656631037893612D+02
     & - (  0.1600000000000000D+03 )/temp)
      rk( 33) = 2.3d-13 * dexp(600.0d0 / temp)
     &            + 1.73d-33* SumM * dexp(1000.0d0 / temp)
      rk( 34) = 3.22d-34 * dexp(2800.0d0 / temp) + 
     &            2.38d-54 * SumM * dexp(3200.0d0 / temp)
      rk( 34) = rk( 34) * YlH2O
      Effko =  0.9000000000000000D-31* (temp / 3.d2)
     &           **(- ( 0.1500000000000000D+01))
      Rapk =  0.3000000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 35) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 36) =  DEXP(-0.2575921893902696D+02
     & - ( -0.1200000000000000D+03 )/temp)
      Effko =  0.9000000000000000D-31* (temp / 3.d2)
     &           **(- ( 0.2000000000000000D+01))
      Rapk =  0.2200000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 37) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.7000000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.2600000000000000D+01))
      Rapk =  0.1500000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.5000000000000000D+00))
      rk( 38) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      Effko =  0.2600000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.3200000000000000D+01))
      Rapk =  0.2400000000000000D-10* (temp / 3.d2)
     &            **(- ( 0.1300000000000000D+01))
      rk( 39) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 40) =  0.2200000000000000D-10
      rk( 41) =  DEXP(-0.2632268829627837D+02
     & - ( -0.2500000000000000D+03 )/temp)
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1400000000000000D+01))
      rk( 42) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 43) =  DEXP( 0.6142746008608852D+02
     & - (  0.1090000000000000D+05 )/temp)
      Effko =  0.1800000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3200000000000000D+01))
      Rapk =  0.4700000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1400000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 43) = facteur * rk( 43)
      rk( 44) =  0.3500000000000000D-11
      rk( 45) =  DEXP(-0.2474064935803238D+02
     & - (  0.3900000000000000D+03 )/temp)
      Effko = 7.2d-15 * dexp(785.0d0 / temp)
      Rapk = 4.1d-16 * dexp(1440.0d0 / temp)
      facteur =1.9d-33 * dexp(725.0d0 / temp) * SumM
      rk( 46) = Effko + facteur/(1.0d0 + facteur / Rapk)
      rk( 47) =  DEXP(-0.2736865685146106D+02
     & - ( -0.3800000000000000D+03 )/temp)
      rk( 48) =  DEXP(-0.2693787393536860D+02
     & - (  0.1400000000000000D+04 )/temp)
      rk( 49) =  DEXP(-0.2975128465212864D+02
     & - (  0.2450000000000000D+04 )/temp)
      rk( 50) =  DEXP(-0.8860689615829534D+02
     & - ( -0.5300000000000000D+03 )/temp)
      rk( 50) = rk( 50) * SumM * 0.2d0
      rk( 51) =  DEXP(-0.2492297091482634D+02
     & - ( -0.1700000000000000D+03 )/temp)
      rk( 52) =  DEXP(-0.3073211390514037D+02
     & - (  0.1260000000000000D+04 )/temp)
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.3900000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      rk( 53) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 54) =  DEXP( 0.6117554523749536D+02
     & - (  0.1100000000000000D+05 )/temp)
      Effko =  0.2200000000000000D-29* (temp / 3.d2)
     &           **(- ( 0.3900000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.7000000000000000D+00))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk( 54) = facteur * rk( 54)
      rk( 55) =  DEXP(-0.2779354004542632D+02
     & - (  0.2450000000000000D+04 )/temp)
      rk( 56) =  DEXP(-0.2592627302369012D+02
     & - (  0.2000000000000000D+04 )/temp)
      rk( 56) = rk( 56) * SumM * 5.8d-7
      Effko =  0.3000000000000000D-30* (temp / 3.d2)
     &           **(- ( 0.3300000000000000D+01))
      Rapk =  0.1500000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.0000000000000000D+00))
      rk( 57) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk( 58) = 1.5d-13 * (1.0d0 + 2.439d-20 * SumM)
      rk( 59) =  0.6000000000000000D-10
      rk( 60) =  DEXP(-0.2486470200670236D+02
     & - ( -0.1300000000000000D+02 )/temp)
      rk( 61) =  DEXP(-0.3943966082504782D+02
     & + ( 0.2000000000000000D+01 * DLOG(temp))
     & -  0.1361000000000000D+04/temp)
      rk( 62) =  DEXP(-0.3873183693007194D+02
     & + ( 0.2000000000000000D+01 * DLOG(temp))
     & -  0.4920000000000000D+03/temp)
      rk( 63) =  DEXP(-0.2597089008917893D+02
     & - (  0.2600000000000000D+03 )/temp)
      rk( 64) =  DEXP(-0.2554908269405012D+02
     & - (  0.1550000000000000D+03 )/temp)
      rk( 65) =  DEXP(-0.2483373978109839D+02
     & - (  0.1250000000000000D+03 )/temp)
      rk( 66) =  DEXP(-0.2695807664268612D+02
     & - ( -0.4380000000000000D+03 )/temp)
      rk( 67) =  DEXP(-0.2588705231053684D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 68) =  DEXP(-0.2504325708070084D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 69) =  DEXP(-0.2493639393515848D+02
     & - ( -0.4480000000000000D+03 )/temp)
      rk( 70) =  DEXP(-0.2439627194190406D+02
     & - ( -0.4100000000000000D+03 )/temp)
      rk( 71) =  DEXP(-0.2513781566332585D+02
     & - ( -0.4440000000000000D+03 )/temp)
      rk( 72) =  0.1710000000000000D-09
      rk( 73) =  DEXP(-0.2703769427065081D+02
     & - ( -0.3550000000000000D+03 )/temp)
      rk( 74) =  DEXP(-0.2564314676777420D+02
     & - ( -0.3550000000000000D+03 )/temp)
      rk( 75) =  0.6000000000000000D-10
      rk( 76) =  0.9999999999999999D-11
      rk( 77) =  DEXP(-0.2591722318817020D+02
     & - ( -0.3310000000000000D+03 )/temp)
      rk( 78) =  DEXP(-0.3970958044115977D+02
     & + ( 0.2000000000000000D+01 * DLOG(temp))
     & +  0.9200000000000000D+02/temp)
      rk( 79) =  0.3000000000000000D-11
      rk( 80) =  0.1140000000000000D-10
      rk( 81) =  0.1720000000000000D-10
      rk( 82) =  DEXP(-0.2470785953520939D+02
     & - ( -0.1750000000000000D+03 )/temp)
      rk( 83) =  DEXP(-0.2429881660575334D+02
     & - ( -0.1750000000000000D+03 )/temp)
      rk( 84) =  0.2700000000000000D-09
      rk( 85) =  DEXP(-0.2655601869289957D+02
     & - ( -0.1900000000000000D+03 )/temp)
      rk( 86) =  DEXP(-0.2640724568430643D+02
     & - ( -0.1900000000000000D+03 )/temp)
      rk( 87) =  DEXP(-0.2655601869289957D+02
     & - ( -0.1900000000000000D+03 )/temp)
      rk( 88) =  0.4000000000000000D-13
      rk( 89) =  DEXP(-0.2875495121258095D+02
     & - ( -0.5000000000000000D+03 )/temp)
      rk( 90) =  DEXP(-0.2596142928067470D+02
     & - (  0.2600000000000000D+03 )/temp)
      rk( 91) =  DEXP(-0.2870983077730048D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk( 92) =  DEXP(-0.2729454887930734D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk( 93) =  DEXP(-0.2656631037893612D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk( 94) =  DEXP(-0.2729454887930734D+02
     & - (  0.1900000000000000D+04 )/temp)
      rk( 95) =  DEXP(-0.3242614188587508D+02
     & - (  0.1500000000000000D+03 )/temp)
      rk( 96) =  DEXP(-0.2887929417915106D+02
     & - (  0.1000000000000000D+04 )/temp)
      rk( 97) =  0.2200000000000000D-10
      rk( 98) =  DEXP(-0.3986138645402777D+02
     & + ( 0.2000000000000000D+01 * DLOG(temp))
     & -  0.2282000000000000D+04/temp)
      rk( 99) =  DEXP(-0.2935139058906993D+02
     & - (  0.4500000000000000D+03 )/temp)
      rk(100) =  DEXP(-0.2777720362610663D+02
     & - ( -0.4500000000000000D+03 )/temp)
      rk(101) =  0.1000000000000000D-12
      rk(102) =  DEXP(-0.2624472675480866D+02
     & - (  0.4460000000000000D+03 )/temp)
      rk(103) =  DEXP(-0.2745706780880511D+02
     & - ( -0.4900000000000000D+03 )/temp)
      rk(104) =  0.1220000000000000D-10
      rk(105) =  DEXP(-0.3144773394155237D+02
     & - (  0.5000000000000000D+03 )/temp)
      rk(106) =  DEXP(-0.3232611600944463D+02
     & - (  0.2580000000000000D+04 )/temp)
      rk(107) =  DEXP(-0.3307320885289629D+02
     & - (  0.1800000000000000D+04 )/temp)
      rk(108) =  DEXP(-0.3305717185398647D+02
     & - (  0.8450000000000000D+03 )/temp)
      rk(109) =  DEXP(-0.3194352168795382D+02
     & - (  0.2283000000000000D+04 )/temp)
      rk(110) =  DEXP(-0.3247698978846957D+02
     & - (  0.1913000000000000D+04 )/temp)
      rk(111) =  DEXP(-0.3452882606405752D+02
     & - (  0.7320000000000000D+03 )/temp)
      rk(112) =  0.2000000000000000D-15
      rk(113) =  DEXP(-0.3423129169516272D+02
     & - (  0.2112000000000000D+04 )/temp)
      rk(114) =  0.2000000000000000D-17
      rk(115) =  DEXP(-0.3363861504496641D+02
     & - (  0.1700000000000000D+04 )/temp)
      rk(116) =  0.2000000000000000D-10
      rk(117) =  0.9999999999999999D-11
      rk(118) =  0.3600000000000000D-10
      rk(119) =  DEXP(-0.3863712897853033D+02
     & - ( -0.1044000000000000D+04 )/temp)
      rk(119) = rk(119) * SumM * 0.2d0
      rk(120) =  0.5000000000000000D-10
      rk(121) =  0.3600000000000000D-10
      rk(122) =  DEXP(-0.3863712897853033D+02
     & - ( -0.1044000000000000D+04 )/temp)
      rk(122) = rk(122) * SumM * 0.2d0
      rk(123) =  0.9999999999999999D-11
      rk(124) =  0.3600000000000000D-10
      rk(125) =  DEXP(-0.3863712897853033D+02
     & - ( -0.1044000000000000D+04 )/temp)
      rk(125) = rk(125) * SumM * 0.2d0
      rk(126) =  0.5000000000000000D-10
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1500000000000000D+01))
      rk(127) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk(128) =  DEXP( 0.6462080260895155D+02
     & - (  0.1395400000000000D+05 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1500000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk(128) = facteur * rk(128)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1500000000000000D+01))
      rk(129) = (Effko * SumM / 
     &            ( 1.0d0 + Effko * SumM / Rapk)) *
     &            0.6000D+00** (1.0d0 / (1.0d0 + 
     &             (dlog10(Effko * SumM / Rapk))**2))
      rk(130) =  DEXP( 0.6462080260895155D+02
     & - (  0.1395400000000000D+05 )/temp)
      Effko =  0.9700000000000000D-28* (temp / 3.d2)
     &           **(- ( 0.5600000000000000D+01))
      Rapk =  0.9300000000000000D-11* (temp / 3.d2)
     &            **(- ( 0.1500000000000000D+01))
      facteur = (Effko * SumM / ( 1.0d0 + Effko * SumM / 
     &         Rapk)) * 0.6d0 ** (1.0d0 / (1.0d0 + 
     &          (dlog10(Effko * SumM / Rapk))**2))
      rk(130) = facteur * rk(130)
      rk(131) =  DEXP(-0.2619593659063922D+02
     & - ( -0.1800000000000000D+03 )/temp)
      rk(132) =  0.8700000000000000D-11
      rk(133) =  0.4000000000000000D-11
      rk(134) =  0.4000000000000000D-11
      rk(135) =  0.4000000000000000D-11
      rk(136) =  0.9000000000000000D-11
      rk(137) =  0.4000000000000000D-11
      rk(138) =  0.4000000000000000D-11
      rk(139) =  0.4000000000000000D-11
      rk(140) =  0.4000000000000000D-11
      rk(141) =  0.4000000000000000D-11
      rk(142) =  0.4000000000000000D-11
      rk(143) =  0.4000000000000000D-11
      rk(144) =  0.4000000000000000D-11
      rk(145) =  0.2000000000000000D-10
      rk(146) =  0.2000000000000000D-10
      rk(147) =  0.4000000000000000D-11
      rk(148) =  0.4000000000000000D-11
      rk(149) =  0.4000000000000000D-11
      rk(150) =  DEXP(-0.2859860514219026D+02
     & - ( -0.8000000000000000D+03 )/temp)
      rk(151) =  DEXP(-0.2791870318838033D+02
     & - ( -0.7000000000000000D+03 )/temp)
      rk(152) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(153) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(154) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(155) =  DEXP(-0.2929175232275020D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(156) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(157) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(158) =  DEXP(-0.2968674613099107D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(159) =  0.1500000000000000D-10
      rk(160) =  0.1500000000000000D-10
      rk(161) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(162) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(163) =  DEXP(-0.2861185036894027D+02
     & - ( -0.9800000000000000D+03 )/temp)
      rk(164) =  DEXP(-0.2749125917355339D+02
     & - ( -0.5500000000000000D+03 )/temp)
      rk(165) =  DEXP(-0.3549069430442799D+02
     & - ( -0.2640000000000000D+04 )/temp)
      rk(166) =  DEXP(-0.2749125917355339D+02
     & - ( -0.5500000000000000D+03 )/temp)
      rk(167) =  DEXP(-0.3549069430442799D+02
     & - ( -0.2640000000000000D+04 )/temp)
      rk(168) =  DEXP(-0.2979384426654743D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(169) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(170) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(171) =  DEXP(-0.3002791688839384D+02
     & - ( -0.4160000000000000D+03 )/temp)
      rk(172) =  DEXP(-0.2976809177044502D+02
     & - ( -0.1580000000000000D+03 )/temp)
      rk(173) =  DEXP(-0.2998911891885285D+02
     & - ( -0.4310000000000000D+03 )/temp)
      rk(174) =  DEXP(-0.2993360620892259D+02
     & - ( -0.4670000000000000D+03 )/temp)
      rk(175) =  DEXP(-0.3076831695380433D+02
     & - ( -0.6330000000000000D+03 )/temp)
      rk(176) =  DEXP(-0.2939711283840802D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(177) =  DEXP(-0.2955516977320235D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(178) =  DEXP(-0.3001916409728424D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(179) =  DEXP(-0.2962612150917463D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(180) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(181) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(182) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(183) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(184) =  DEXP(-0.3096643075705270D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(185) =  DEXP(-0.2416216508579258D+02
     & - (  0.4400000000000000D+03 )/temp)
      rk(186) =  DEXP(-0.3585554469338197D+02
     & - ( -0.2510000000000000D+04 )/temp)
      rk(187) =  DEXP(-0.2416216508579258D+02
     & - (  0.4400000000000000D+03 )/temp)
      rk(188) =  DEXP(-0.3585554469338197D+02
     & - ( -0.2510000000000000D+04 )/temp)
      rk(189) =  DEXP(-0.2800063657114302D+02
     & - ( -0.5080000000000000D+03 )/temp)
      rk(190) =  DEXP(-0.2946360257967686D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(191) =  DEXP(-0.2996612940062816D+02
     & - ( -0.7080000000000000D+03 )/temp)
      rk(192) =  DEXP(-0.2760146231368700D+02
     & - ( -0.2110000000000000D+03 )/temp)
      rk(193) =  DEXP(-0.2800208479731938D+02
     & - ( -0.4600000000000000D+03 )/temp)
      rk(194) =  DEXP(-0.2821262692175559D+02
     & - ( -0.5220000000000000D+03 )/temp)
      rk(195) =  DEXP(-0.2902938805828271D+02
     & - ( -0.6830000000000000D+03 )/temp)
      rk(196) =  DEXP(-0.2768442189265566D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(197) =  DEXP(-0.2784050834079527D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(198) =  DEXP(-0.2830632837836016D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(199) =  DEXP(-0.2790545796163031D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(200) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(201) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(202) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(203) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(204) =  DEXP(-0.2793212620871247D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(205) =  DEXP(-0.2660140169874739D+02
     & - ( -0.5300000000000000D+03 )/temp)
      rk(206) =  DEXP(-0.2660140169874739D+02
     & - ( -0.5300000000000000D+03 )/temp)
      rk(207) =  DEXP(-0.2791737074314655D+02
     & - ( -0.5650000000000000D+03 )/temp)
      rk(208) =  DEXP(-0.2775318874990275D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(209) =  DEXP(-0.2825277830040182D+02
     & - ( -0.7650000000000000D+03 )/temp)
      rk(210) =  DEXP(-0.3029028115286133D+02
     & - ( -0.1000000000000000D+04 )/temp)
      rk(211) =  DEXP(-0.3078927231898031D+02
     & - ( -0.1000000000000000D+04 )/temp)
      rk(212) =  DEXP(-0.3115100203358067D+02
     & - ( -0.1000000000000000D+04 )/temp)
      rk(213) =  0.1200000000000000D-11
      rk(214) =  0.1200000000000000D-11
      rk(215) =  0.1200000000000000D-11
      rk(216) =  0.1200000000000000D-11
      rk(217) =  0.1200000000000000D-11
      rk(218) =  0.1200000000000000D-11
      rk(219) =  0.1200000000000000D-11
      rk(220) =  0.1200000000000000D-11
      rk(221) =  0.1200000000000000D-11
      rk(222) =  0.1200000000000000D-11
      rk(223) =  0.1200000000000000D-11
      rk(224) =  0.1200000000000000D-11
      rk(225) =  0.1200000000000000D-11
      rk(226) =  0.1200000000000000D-11
      rk(227) =  0.4000000000000000D-11
      rk(228) =  0.4000000000000000D-11
      rk(229) =  0.1200000000000000D-11
      rk(230) =  0.1200000000000000D-11
      rk(231) =  0.1200000000000000D-11
      rk(232) =  DEXP(-0.2942678860655414D+02
     & - ( -0.1300000000000000D+04 )/temp)
      rk(233) =  DEXP(-0.3274868498278332D+02
     & - ( -0.1510000000000000D+04 )/temp)
      rk(234) =  DEXP(-0.3101241587029453D+02
     & - ( -0.1560000000000000D+04 )/temp)
      rk(235) =  DEXP(-0.3717963534647257D+02
     & - ( -0.2950000000000000D+04 )/temp)
      rk(236) =  0.4000000000000000D-11
      rk(237) =  0.1200000000000000D-11
      rk(238) =  0.1200000000000000D-11
      rk(239) =  0.1200000000000000D-11
      rk(240) =  0.1200000000000000D-11
      rk(241) =  0.1200000000000000D-11
C    Reactions for traffic SVOC
      rk(242) =  0.2930000000000000D-09
      rk(243) =  0.3000000000000000D-10
      rk(244) =  0.3000000000000000D-10
      rk(245) =  0.3000000000000000D-10

C    Heteroheneous Reactions on aerosol surface:
C
C    Reaction 238: HO2  -->  0.5 H2O2
C    Reaction 239: NO2  -->  0.5 HONO + 0.5 HNO3
C    Reaction 240: NO3  -->  HNO3
C    Reaction 241: N2O5 -->  2 HNO3
 
      rk238=0.D0
      rk239=0.D0
      rk240=0.D0
      rk241=0.D0
 
      if (IHETER.eq.1) then
         call HETRXN(Ns,Nbin_aer,temp,press,ICLD,lwctmp,
     &        WetDiam,granulo,rk238,rk239,rk240,rk241,
     &        dsf_aero,ispeclost,Wmol,LWCmin)
      endif
 
      rk(238) = rk238
      rk(239) = rk239
      rk(240) = rk240
      rk(241) = rk241
 
      RETURN
      END
 
