C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine rates(ns,nr,rk,y,w)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the reaction rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM_AEC            
C     Species: _ciRACM_AEC         
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     W: reaction rates.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns
      double precision rk(nr),y(ns),w(nr)
 
 
 
      w(  1) =  rk(  1) * Y( 84)
      w(  2) =  rk(  2) * Y( 65)
      w(  3) =  rk(  3) * Y( 65)
      w(  4) =  rk(  4) * Y( 33)
      w(  5) =  rk(  5) * Y( 74)
      w(  6) =  rk(  6) * Y( 24)
      w(  7) =  rk(  7) * Y( 87)
      w(  8) =  rk(  8) * Y( 87)
      w(  9) =  rk(  9) * Y( 44)
      w( 10) =  rk( 10) * Y( 79)
      w( 11) =  rk( 11) * Y( 79)
      w( 12) =  rk( 12) * Y( 81)
      w( 13) =  rk( 13) * Y( 21)
      w( 14) =  rk( 14) * Y( 73)
      w( 15) =  rk( 15) * Y( 38)
      w( 16) =  rk( 16) * Y( 77)
      w( 17) =  rk( 17) * Y( 66)
      w( 18) =  rk( 18) * Y( 66)
      w( 19) =  rk( 19) * Y( 72)
      w( 20) =  rk( 20) * Y( 54)
      w( 21) =  rk( 21) * Y( 83)
      w( 22) =  rk( 22) * Y( 59)
      w( 23) =  rk( 23) * Y( 47)
      w( 24) =  rk( 24) * Y( 43)
      w( 25) =  rk( 25) * Y( 43) * Y( 65)
      w( 26) =  rk( 26) * Y(  9)
      w( 27) =  rk( 27) * Y(  9)
      w( 28) =  rk( 28) * Y(  9)
      w( 29) =  rk( 29) * Y( 65) * Y( 80)
      w( 30) =  rk( 30) * Y( 65) * Y( 88)
      w( 31) =  rk( 31) * Y( 80) * Y( 88)
      w( 32) =  rk( 32) * Y( 44) * Y( 80)
      w( 33) =  rk( 33) * Y( 88) * Y( 88)
      w( 34) =  rk( 34) * Y( 88) * Y( 88)
      w( 35) =  rk( 35) * Y( 43) * Y( 85)
      w( 36) =  rk( 36) * Y( 43) * Y( 84)
      w( 37) =  rk( 37) * Y( 43) * Y( 84)
      w( 38) =  rk( 38) * Y( 80) * Y( 85)
      w( 39) =  rk( 39) * Y( 80) * Y( 84)
      w( 40) =  rk( 40) * Y( 80) * Y( 87)
      w( 41) =  rk( 41) * Y( 88) * Y( 85)
      w( 42) =  rk( 42) * Y( 88) * Y( 84)
      w( 43) =  rk( 43) * Y( 24)
      w( 44) =  rk( 44) * Y( 88) * Y( 87)
      w( 45) =  rk( 45) * Y( 80) * Y( 33)
      w( 46) =  rk( 46) * Y( 80) * Y( 74)
      w( 47) =  rk( 47) * Y( 80) * Y( 24)
      w( 48) =  rk( 48) * Y( 65) * Y( 85)
      w( 49) =  rk( 49) * Y( 65) * Y( 84)
      w( 50) =  rk( 50) * Y( 85) * Y( 85)
      w( 51) =  rk( 51) * Y( 87) * Y( 85)
      w( 52) =  rk( 52) * Y( 87) * Y( 84)
      w( 53) =  rk( 53) * Y( 87) * Y( 84)
      w( 54) =  rk( 54) * Y( 17)
      w( 55) =  rk( 55) * Y( 87) * Y( 87)
      w( 56) =  rk( 56) * Y( 80)
      w( 57) =  rk( 57) * Y( 80) * Y(  3)
      w( 58) =  rk( 58) * Y( 67) * Y( 80)
      w( 59) =  rk( 59) * Y( 35) * Y( 43)
      w( 60) =  rk( 60) * Y( 59) * Y( 43)
      w( 61) =  rk( 61) * Y( 37) * Y( 80)
      w( 62) =  rk( 62) * Y( 34) * Y( 80)
      w( 63) =  rk( 63) * Y(  4) * Y( 80)
      w( 64) =  rk( 64) * Y(  5) * Y( 80)
      w( 65) =  rk( 65) * Y(  6) * Y( 80)
      w( 66) =  rk( 66) * Y( 25) * Y( 80)
      w( 67) =  rk( 67) * Y( 60) * Y( 80)
      w( 68) =  rk( 68) * Y( 62) * Y( 80)
      w( 69) =  rk( 69) * Y( 26) * Y( 80)
      w( 70) =  rk( 70) * Y( 35) * Y( 80)
      w( 71) =  rk( 71) * Y( 27) * Y( 80)
      w( 72) =  rk( 72) * Y( 30) * Y( 80)
      w( 73) =  rk( 73) * Y(  7) * Y( 80)
      w( 74) =  rk( 74) * Y(  8) * Y( 80)
      w( 75) =  rk( 75) * Y( 45) * Y( 80)
      w( 76) =  rk( 76) * Y( 79) * Y( 80)
      w( 77) =  rk( 77) * Y( 81) * Y( 80)
      w( 78) =  rk( 78) * Y( 77) * Y( 80)
      w( 79) =  rk( 79) * Y( 47) * Y( 80)
      w( 80) =  rk( 80) * Y( 66) * Y( 80)
      w( 81) =  rk( 81) * Y( 72) * Y( 80)
      w( 82) =  rk( 82) * Y( 59) * Y( 80)
      w( 83) =  rk( 83) * Y( 80) * Y( 54)
      w( 84) =  rk( 84) * Y( 80) * Y( 18)
      w( 85) =  rk( 85) * Y( 21) * Y( 80)
      w( 86) =  rk( 86) * Y( 73) * Y( 80)
      w( 87) =  rk( 87) * Y( 38) * Y( 80)
      w( 88) =  rk( 88) * Y( 50) * Y( 80)
      w( 89) =  rk( 89) * Y( 48) * Y( 80)
      w( 90) =  rk( 90) * Y( 83) * Y( 80)
      w( 91) =  rk( 91) * Y( 79) * Y( 87)
      w( 92) =  rk( 92) * Y( 81) * Y( 87)
      w( 93) =  rk( 93) * Y( 66) * Y( 87)
      w( 94) =  rk( 94) * Y( 72) * Y( 87)
      w( 95) =  rk( 95) * Y( 59) * Y( 87)
      w( 96) =  rk( 96) * Y( 54) * Y( 87)
      w( 97) =  rk( 97) * Y( 45) * Y( 87)
      w( 98) =  rk( 98) * Y( 25) * Y( 87)
      w( 99) =  rk( 99) * Y( 60) * Y( 87)
      w(100) =  rk(100) * Y( 62) * Y( 87)
      w(101) =  rk(101) * Y( 26) * Y( 87)
      w(102) =  rk(102) * Y( 35) * Y( 87)
      w(103) =  rk(103) * Y( 27) * Y( 87)
      w(104) =  rk(104) * Y( 30) * Y( 87)
      w(105) =  rk(105) * Y( 48) * Y( 87)
      w(106) =  rk(106) * Y( 25) * Y( 65)
      w(107) =  rk(107) * Y( 60) * Y( 65)
      w(108) =  rk(108) * Y( 62) * Y( 65)
      w(109) =  rk(109) * Y( 26) * Y( 65)
      w(110) =  rk(110) * Y( 35) * Y( 65)
      w(111) =  rk(111) * Y( 27) * Y( 65)
      w(112) =  rk(112) * Y( 30) * Y( 65)
      w(113) =  rk(113) * Y( 59) * Y( 65)
      w(114) =  rk(114) * Y( 54) * Y( 65)
      w(115) =  rk(115) * Y( 48) * Y( 65)
      w(116) =  rk(116) * Y( 39) * Y( 84)
      w(117) =  rk(117) * Y( 39) * Y( 88)
      w(118) =  rk(118) * Y( 22) * Y( 84)
      w(119) =  rk(119) * Y( 22)
      w(120) =  rk(120) * Y( 22) * Y( 65)
      w(121) =  rk(121) * Y( 23) * Y( 84)
      w(122) =  rk(122) * Y( 23)
      w(123) =  rk(123) * Y( 23) * Y( 65)
      w(124) =  rk(124) * Y( 36) * Y( 84)
      w(125) =  rk(125) * Y( 36)
      w(126) =  rk(126) * Y( 36) * Y( 65)
      w(127) =  rk(127) * Y( 89) * Y( 84)
      w(128) =  rk(128) * Y( 50)
      w(129) =  rk(129) * Y( 86) * Y( 84)
      w(130) =  rk(130) * Y( 48)
      w(131) =  rk(131) * Y( 82) * Y( 85)
      w(132) =  rk(132) * Y( 78) * Y( 85)
      w(133) =  rk(133) * Y( 76) * Y( 85)
      w(134) =  rk(134) * Y( 53) * Y( 85)
      w(135) =  rk(135) * Y( 57) * Y( 85)
      w(136) =  rk(136) * Y( 56) * Y( 85)
      w(137) =  rk(137) * Y( 61) * Y( 85)
      w(138) =  rk(138) * Y( 68) * Y( 85)
      w(139) =  rk(139) * Y( 58) * Y( 85)
      w(140) =  rk(140) * Y( 69) * Y( 85)
      w(141) =  rk(141) * Y( 52) * Y( 85)
      w(142) =  rk(142) * Y( 40) * Y( 85)
      w(143) =  rk(143) * Y( 51) * Y( 85)
      w(144) =  rk(144) * Y( 42) * Y( 85)
      w(145) =  rk(145) * Y( 89) * Y( 85)
      w(146) =  rk(146) * Y( 86) * Y( 85)
      w(147) =  rk(147) * Y( 70) * Y( 85)
      w(148) =  rk(148) * Y( 64) * Y( 85)
      w(149) =  rk(149) * Y( 63) * Y( 85)
      w(150) =  rk(150) * Y( 82) * Y( 88)
      w(151) =  rk(151) * Y( 78) * Y( 88)
      w(152) =  rk(152) * Y( 76) * Y( 88)
      w(153) =  rk(153) * Y( 53) * Y( 88)
      w(154) =  rk(154) * Y( 57) * Y( 88)
      w(155) =  rk(155) * Y( 56) * Y( 88)
      w(156) =  rk(156) * Y( 61) * Y( 88)
      w(157) =  rk(157) * Y( 68) * Y( 88)
      w(158) =  rk(158) * Y( 58) * Y( 88)
      w(159) =  rk(159) * Y( 69) * Y( 88)
      w(160) =  rk(160) * Y( 52) * Y( 88)
      w(161) =  rk(161) * Y( 40) * Y( 88)
      w(162) =  rk(162) * Y( 51) * Y( 88)
      w(163) =  rk(163) * Y( 42) * Y( 88)
      w(164) =  rk(164) * Y( 89) * Y( 88)
      w(165) =  rk(165) * Y( 89) * Y( 88)
      w(166) =  rk(166) * Y( 86) * Y( 88)
      w(167) =  rk(167) * Y( 86) * Y( 88)
      w(168) =  rk(168) * Y( 70) * Y( 88)
      w(169) =  rk(169) * Y( 64) * Y( 88)
      w(170) =  rk(170) * Y( 63) * Y( 88)
      w(171) =  rk(171) * Y( 82) * Y( 82)
      w(172) =  rk(172) * Y( 78) * Y( 82)
      w(173) =  rk(173) * Y( 76) * Y( 82)
      w(174) =  rk(174) * Y( 53) * Y( 82)
      w(175) =  rk(175) * Y( 57) * Y( 82)
      w(176) =  rk(176) * Y( 56) * Y( 82)
      w(177) =  rk(177) * Y( 61) * Y( 82)
      w(178) =  rk(178) * Y( 68) * Y( 82)
      w(179) =  rk(179) * Y( 58) * Y( 82)
      w(180) =  rk(180) * Y( 69) * Y( 82)
      w(181) =  rk(181) * Y( 52) * Y( 82)
      w(182) =  rk(182) * Y( 40) * Y( 82)
      w(183) =  rk(183) * Y( 51) * Y( 82)
      w(184) =  rk(184) * Y( 42) * Y( 82)
      w(185) =  rk(185) * Y( 89) * Y( 82)
      w(186) =  rk(186) * Y( 89) * Y( 82)
      w(187) =  rk(187) * Y( 86) * Y( 82)
      w(188) =  rk(188) * Y( 86) * Y( 82)
      w(189) =  rk(189) * Y( 70) * Y( 82)
      w(190) =  rk(190) * Y( 64) * Y( 82)
      w(191) =  rk(191) * Y( 63) * Y( 82)
      w(192) =  rk(192) * Y( 78) * Y( 89)
      w(193) =  rk(193) * Y( 76) * Y( 89)
      w(194) =  rk(194) * Y( 53) * Y( 89)
      w(195) =  rk(195) * Y( 57) * Y( 89)
      w(196) =  rk(196) * Y( 56) * Y( 89)
      w(197) =  rk(197) * Y( 61) * Y( 89)
      w(198) =  rk(198) * Y( 68) * Y( 89)
      w(199) =  rk(199) * Y( 58) * Y( 89)
      w(200) =  rk(200) * Y( 69) * Y( 89)
      w(201) =  rk(201) * Y( 52) * Y( 89)
      w(202) =  rk(202) * Y( 40) * Y( 89)
      w(203) =  rk(203) * Y( 51) * Y( 89)
      w(204) =  rk(204) * Y( 42) * Y( 89)
      w(205) =  rk(205) * Y( 89) * Y( 89)
      w(206) =  rk(206) * Y( 86) * Y( 89)
      w(207) =  rk(207) * Y( 70) * Y( 89)
      w(208) =  rk(208) * Y( 64) * Y( 89)
      w(209) =  rk(209) * Y( 63) * Y( 89)
      w(210) =  rk(210) * Y( 64) * Y( 64)
      w(211) =  rk(211) * Y( 64) * Y( 63)
      w(212) =  rk(212) * Y( 63) * Y( 63)
      w(213) =  rk(213) * Y( 82) * Y( 87)
      w(214) =  rk(214) * Y( 78) * Y( 87)
      w(215) =  rk(215) * Y( 76) * Y( 87)
      w(216) =  rk(216) * Y( 53) * Y( 87)
      w(217) =  rk(217) * Y( 57) * Y( 87)
      w(218) =  rk(218) * Y( 56) * Y( 87)
      w(219) =  rk(219) * Y( 61) * Y( 87)
      w(220) =  rk(220) * Y( 68) * Y( 87)
      w(221) =  rk(221) * Y( 58) * Y( 87)
      w(222) =  rk(222) * Y( 69) * Y( 87)
      w(223) =  rk(223) * Y( 52) * Y( 87)
      w(224) =  rk(224) * Y( 40) * Y( 87)
      w(225) =  rk(225) * Y( 51) * Y( 87)
      w(226) =  rk(226) * Y( 42) * Y( 87)
      w(227) =  rk(227) * Y( 89) * Y( 87)
      w(228) =  rk(228) * Y( 86) * Y( 87)
      w(229) =  rk(229) * Y( 70) * Y( 87)
      w(230) =  rk(230) * Y( 64) * Y( 87)
      w(231) =  rk(231) * Y( 63) * Y( 87)
      w(232) =  rk(232) * Y( 75) * Y( 88)
      w(233) =  rk(233) * Y( 75) * Y( 82)
      w(234) =  rk(234) * Y( 75) * Y( 89)
      w(235) =  rk(235) * Y( 75) * Y( 75)
      w(236) =  rk(236) * Y( 75) * Y( 85)
      w(237) =  rk(237) * Y( 75) * Y( 87)
      w(238) =  rk(238) * Y( 88)
      w(239) =  rk(239) * Y( 84)
      w(240) =  rk(240) * Y( 87)
      w(241) =  rk(241) * Y( 17)
      w(242) =  rk(242) * Y( 11) * Y( 80)
      w(243) =  rk(243) * Y( 13) * Y( 80)
      w(244) =  rk(244) * Y( 14) * Y( 80)
      w(245) =  rk(245) * Y( 15) * Y( 80)
 
      RETURN
      END
 
