C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C	  nesp: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      temp = M(5, 4) * x(4)
      x(5) = ( x(5) - temp ) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      x(8) = x(8) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      x(10) = x(10) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      temp = M(12, 11) * x(11)
      x(12) = ( x(12) - temp ) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      temp = M(14, 13) * x(13)
      x(14) = ( x(14) - temp ) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      temp = M(16, 15) * x(15)
      x(16) = ( x(16) - temp ) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      temp = M(19, 7) * x(7)
      x(19) = ( x(19) - temp ) / M(19, 19)

      x(20) = x(20) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      x(23) = x(23) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      temp = M(26, 12) * x(12)
      temp = temp + M(26, 14) * x(14)
      temp = temp + M(26, 16) * x(16)
      x(26) = ( x(26) - temp ) / M(26, 26)

      x(27) = x(27) / M(27, 27)

      x(28) = x(28) / M(28, 28)

      x(29) = x(29) / M(29, 29)

      x(30) = x(30) / M(30, 30)

      x(31) = x(31) / M(31, 31)

      temp = M(32, 22) * x(22)
      temp = temp + M(32, 31) * x(31)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 22) * x(22)
      temp = temp + M(33, 31) * x(31)
      x(33) = ( x(33) - temp ) / M(33, 33)

      x(34) = x(34) / M(34, 34)

      temp = M(35, 19) * x(19)
      x(35) = ( x(35) - temp ) / M(35, 35)

      x(36) = x(36) / M(36, 36)

      temp = M(37, 24) * x(24)
      temp = temp + M(37, 31) * x(31)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(38, 37) * x(37)
      x(38) = ( x(38) - temp ) / M(38, 38)

      x(39) = x(39) / M(39, 39)

      x(40) = x(40) / M(40, 40)

      x(41) = x(41) / M(41, 41)

      x(42) = x(42) / M(42, 42)

      temp = M(43, 22) * x(22)
      temp = temp + M(43, 31) * x(31)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 22) * x(22)
      temp = temp + M(44, 31) * x(31)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 37) * x(37)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 30) * x(30)
      x(46) = ( x(46) - temp ) / M(46, 46)

      x(47) = x(47) / M(47, 47)

      temp = M(48, 3) * x(3)
      temp = temp + M(48, 24) * x(24)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(49, 22) * x(22)
      temp = temp + M(49, 24) * x(24)
      temp = temp + M(49, 30) * x(30)
      temp = temp + M(49, 31) * x(31)
      temp = temp + M(49, 37) * x(37)
      x(49) = ( x(49) - temp ) / M(49, 49)

      x(50) = x(50) / M(50, 50)

      temp = M(51, 50) * x(50)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 12) * x(12)
      x(52) = ( x(52) - temp ) / M(52, 52)

      temp = M(53, 11) * x(11)
      x(53) = ( x(53) - temp ) / M(53, 53)

      temp = M(54, 12) * x(12)
      x(54) = ( x(54) - temp ) / M(54, 54)

      temp = M(55, 13) * x(13)
      temp = temp + M(55, 15) * x(15)
      x(55) = ( x(55) - temp ) / M(55, 55)

      temp = M(56, 14) * x(14)
      x(56) = ( x(56) - temp ) / M(56, 56)

      temp = M(57, 54) * x(54)
      temp = temp + M(57, 56) * x(56)
      x(57) = ( x(57) - temp ) / M(57, 57)

      temp = M(58, 11) * x(11)
      temp = temp + M(58, 12) * x(12)
      temp = temp + M(58, 13) * x(13)
      temp = temp + M(58, 14) * x(14)
      temp = temp + M(58, 15) * x(15)
      temp = temp + M(58, 16) * x(16)
      temp = temp + M(58, 54) * x(54)
      temp = temp + M(58, 56) * x(56)
      x(58) = ( x(58) - temp ) / M(58, 58)

      temp = M(59, 19) * x(19)
      temp = temp + M(59, 54) * x(54)
      temp = temp + M(59, 56) * x(56)
      temp = temp + M(59, 58) * x(58)
      x(59) = ( x(59) - temp ) / M(59, 59)

      temp = M(60, 19) * x(19)
      temp = temp + M(60, 58) * x(58)
      x(60) = ( x(60) - temp ) / M(60, 60)

      temp = M(61, 19) * x(19)
      temp = temp + M(61, 58) * x(58)
      temp = temp + M(61, 60) * x(60)
      x(61) = ( x(61) - temp ) / M(61, 61)

      temp = M(62, 14) * x(14)
      temp = temp + M(62, 16) * x(16)
      temp = temp + M(62, 56) * x(56)
      x(62) = ( x(62) - temp ) / M(62, 62)

      temp = M(63, 53) * x(53)
      temp = temp + M(63, 55) * x(55)
      x(63) = ( x(63) - temp ) / M(63, 63)

      temp = M(64, 16) * x(16)
      x(64) = ( x(64) - temp ) / M(64, 64)

      temp = M(65, 12) * x(12)
      temp = temp + M(65, 14) * x(14)
      temp = temp + M(65, 16) * x(16)
      temp = temp + M(65, 54) * x(54)
      temp = temp + M(65, 56) * x(56)
      temp = temp + M(65, 64) * x(64)
      x(65) = ( x(65) - temp ) / M(65, 65)

      temp = M(66, 10) * x(10)
      temp = temp + M(66, 19) * x(19)
      temp = temp + M(66, 37) * x(37)
      temp = temp + M(66, 54) * x(54)
      temp = temp + M(66, 56) * x(56)
      temp = temp + M(66, 58) * x(58)
      temp = temp + M(66, 60) * x(60)
      temp = temp + M(66, 63) * x(63)
      temp = temp + M(66, 64) * x(64)
      x(66) = ( x(66) - temp ) / M(66, 66)

      temp = M(67, 63) * x(63)
      x(67) = ( x(67) - temp ) / M(67, 67)

      temp = M(68, 36) * x(36)
      x(68) = ( x(68) - temp ) / M(68, 68)

      temp = M(69, 52) * x(52)
      temp = temp + M(69, 54) * x(54)
      temp = temp + M(69, 62) * x(62)
      temp = temp + M(69, 64) * x(64)
      temp = temp + M(69, 68) * x(68)
      x(69) = ( x(69) - temp ) / M(69, 69)

      temp = M(70, 37) * x(37)
      x(70) = ( x(70) - temp ) / M(70, 70)

      x(71) = x(71) / M(71, 71)

      temp = M(72, 9) * x(9)
      x(72) = ( x(72) - temp ) / M(72, 72)

      temp = M(73, 72) * x(72)
      x(73) = ( x(73) - temp ) / M(73, 73)

      temp = M(74, 22) * x(22)
      x(74) = ( x(74) - temp ) / M(74, 74)

      temp = M(75, 10) * x(10)
      x(75) = ( x(75) - temp ) / M(75, 75)

      temp = M(76, 46) * x(46)
      temp = temp + M(76, 47) * x(47)
      x(76) = ( x(76) - temp ) / M(76, 76)

      temp = M(77, 10) * x(10)
      x(77) = ( x(77) - temp ) / M(77, 77)

      temp = M(78, 19) * x(19)
      temp = temp + M(78, 58) * x(58)
      temp = temp + M(78, 60) * x(60)
      temp = temp + M(78, 63) * x(63)
      temp = temp + M(78, 64) * x(64)
      x(78) = ( x(78) - temp ) / M(78, 78)

      temp = M(79, 31) * x(31)
      x(79) = ( x(79) - temp ) / M(79, 79)

      temp = M(80, 30) * x(30)
      x(80) = ( x(80) - temp ) / M(80, 80)

      temp = M(81, 30) * x(30)
      temp = temp + M(81, 80) * x(80)
      x(81) = ( x(81) - temp ) / M(81, 81)

      temp = M(82, 6) * x(6)
      temp = temp + M(82, 24) * x(24)
      temp = temp + M(82, 27) * x(27)
      temp = temp + M(82, 30) * x(30)
      temp = temp + M(82, 31) * x(31)
      temp = temp + M(82, 37) * x(37)
      temp = temp + M(82, 74) * x(74)
      temp = temp + M(82, 81) * x(81)
      x(82) = ( x(82) - temp ) / M(82, 82)

      temp = M(83, 81) * x(81)
      x(83) = ( x(83) - temp ) / M(83, 83)

      temp = M(84, 24) * x(24)
      temp = temp + M(84, 29) * x(29)
      temp = temp + M(84, 30) * x(30)
      temp = temp + M(84, 31) * x(31)
      temp = temp + M(84, 79) * x(79)
      temp = temp + M(84, 80) * x(80)
      x(84) = ( x(84) - temp ) / M(84, 84)

      temp = M(85, 27) * x(27)
      x(85) = ( x(85) - temp ) / M(85, 85)

      temp = M(86, 7) * x(7)
      x(86) = ( x(86) - temp ) / M(86, 86)

      temp = M(87, 7) * x(7)
      temp = temp + M(87, 81) * x(81)
      temp = temp + M(87, 86) * x(86)
      x(87) = ( x(87) - temp ) / M(87, 87)

      temp = M(88, 87) * x(87)
      x(88) = ( x(88) - temp ) / M(88, 88)

      temp = M(89, 79) * x(79)
      temp = temp + M(89, 86) * x(86)
      x(89) = ( x(89) - temp ) / M(89, 89)

      temp = M(90, 22) * x(22)
      temp = temp + M(90, 24) * x(24)
      temp = temp + M(90, 26) * x(26)
      temp = temp + M(90, 27) * x(27)
      temp = temp + M(90, 30) * x(30)
      temp = temp + M(90, 31) * x(31)
      temp = temp + M(90, 37) * x(37)
      temp = temp + M(90, 48) * x(48)
      temp = temp + M(90, 81) * x(81)
      temp = temp + M(90, 84) * x(84)
      temp = temp + M(90, 87) * x(87)
      temp = temp + M(90, 89) * x(89)
      x(90) = ( x(90) - temp ) / M(90, 90)

      temp = M(91, 62) * x(62)
      temp = temp + M(91, 64) * x(64)
      temp = temp + M(91, 90) * x(90)
      x(91) = ( x(91) - temp ) / M(91, 91)

      temp = M(92, 24) * x(24)
      temp = temp + M(92, 89) * x(89)
      temp = temp + M(92, 90) * x(90)
      temp = temp + M(92, 91) * x(91)
      x(92) = ( x(92) - temp ) / M(92, 92)

      temp = M(93, 22) * x(22)
      temp = temp + M(93, 24) * x(24)
      temp = temp + M(93, 27) * x(27)
      temp = temp + M(93, 31) * x(31)
      temp = temp + M(93, 37) * x(37)
      temp = temp + M(93, 89) * x(89)
      temp = temp + M(93, 90) * x(90)
      temp = temp + M(93, 91) * x(91)
      x(93) = ( x(93) - temp ) / M(93, 93)

      temp = M(94, 22) * x(22)
      temp = temp + M(94, 24) * x(24)
      temp = temp + M(94, 27) * x(27)
      temp = temp + M(94, 31) * x(31)
      temp = temp + M(94, 37) * x(37)
      temp = temp + M(94, 89) * x(89)
      temp = temp + M(94, 90) * x(90)
      temp = temp + M(94, 91) * x(91)
      temp = temp + M(94, 93) * x(93)
      x(94) = ( x(94) - temp ) / M(94, 94)

      temp = M(95, 68) * x(68)
      temp = temp + M(95, 70) * x(70)
      temp = temp + M(95, 72) * x(72)
      temp = temp + M(95, 74) * x(74)
      temp = temp + M(95, 75) * x(75)
      temp = temp + M(95, 79) * x(79)
      temp = temp + M(95, 80) * x(80)
      temp = temp + M(95, 83) * x(83)
      temp = temp + M(95, 88) * x(88)
      temp = temp + M(95, 90) * x(90)
      temp = temp + M(95, 91) * x(91)
      temp = temp + M(95, 92) * x(92)
      temp = temp + M(95, 94) * x(94)
      x(95) = ( x(95) - temp ) / M(95, 95)

      temp = M(96, 90) * x(90)
      temp = temp + M(96, 91) * x(91)
      x(96) = ( x(96) - temp ) / M(96, 96)

      temp = M(97, 35) * x(35)
      temp = temp + M(97, 58) * x(58)
      temp = temp + M(97, 60) * x(60)
      temp = temp + M(97, 63) * x(63)
      temp = temp + M(97, 64) * x(64)
      temp = temp + M(97, 90) * x(90)
      temp = temp + M(97, 91) * x(91)
      temp = temp + M(97, 96) * x(96)
      x(97) = ( x(97) - temp ) / M(97, 97)

      temp = M(98, 73) * x(73)
      temp = temp + M(98, 74) * x(74)
      temp = temp + M(98, 79) * x(79)
      temp = temp + M(98, 90) * x(90)
      temp = temp + M(98, 91) * x(91)
      temp = temp + M(98, 97) * x(97)
      x(98) = ( x(98) - temp ) / M(98, 98)

      temp = M(99, 68) * x(68)
      temp = temp + M(99, 70) * x(70)
      temp = temp + M(99, 72) * x(72)
      temp = temp + M(99, 74) * x(74)
      temp = temp + M(99, 75) * x(75)
      temp = temp + M(99, 79) * x(79)
      temp = temp + M(99, 80) * x(80)
      temp = temp + M(99, 83) * x(83)
      temp = temp + M(99, 85) * x(85)
      temp = temp + M(99, 88) * x(88)
      temp = temp + M(99, 90) * x(90)
      temp = temp + M(99, 91) * x(91)
      temp = temp + M(99, 92) * x(92)
      temp = temp + M(99, 94) * x(94)
      temp = temp + M(99, 97) * x(97)
      temp = temp + M(99, 98) * x(98)
      x(99) = ( x(99) - temp ) / M(99, 99)

      temp = M(100, 25) * x(25)
      temp = temp + M(100, 95) * x(95)
      temp = temp + M(100, 97) * x(97)
      temp = temp + M(100, 98) * x(98)
      x(100) = ( x(100) - temp ) / M(100, 100)

      temp = M(101, 22) * x(22)
      temp = temp + M(101, 24) * x(24)
      temp = temp + M(101, 31) * x(31)
      temp = temp + M(101, 37) * x(37)
      temp = temp + M(101, 89) * x(89)
      temp = temp + M(101, 90) * x(90)
      temp = temp + M(101, 91) * x(91)
      temp = temp + M(101, 97) * x(97)
      x(101) = ( x(101) - temp ) / M(101, 101)

      temp = M(102, 52) * x(52)
      temp = temp + M(102, 54) * x(54)
      temp = temp + M(102, 62) * x(62)
      temp = temp + M(102, 64) * x(64)
      temp = temp + M(102, 65) * x(65)
      temp = temp + M(102, 69) * x(69)
      temp = temp + M(102, 72) * x(72)
      temp = temp + M(102, 76) * x(76)
      temp = temp + M(102, 77) * x(77)
      temp = temp + M(102, 78) * x(78)
      temp = temp + M(102, 80) * x(80)
      temp = temp + M(102, 81) * x(81)
      temp = temp + M(102, 83) * x(83)
      temp = temp + M(102, 84) * x(84)
      temp = temp + M(102, 87) * x(87)
      temp = temp + M(102, 88) * x(88)
      temp = temp + M(102, 90) * x(90)
      temp = temp + M(102, 91) * x(91)
      temp = temp + M(102, 97) * x(97)
      temp = temp + M(102, 101) * x(101)
      x(102) = ( x(102) - temp ) / M(102, 102)

      temp = M(103, 17) * x(17)
      temp = temp + M(103, 19) * x(19)
      temp = temp + M(103, 26) * x(26)
      temp = temp + M(103, 35) * x(35)
      temp = temp + M(103, 58) * x(58)
      temp = temp + M(103, 60) * x(60)
      temp = temp + M(103, 63) * x(63)
      temp = temp + M(103, 64) * x(64)
      temp = temp + M(103, 84) * x(84)
      temp = temp + M(103, 90) * x(90)
      temp = temp + M(103, 91) * x(91)
      temp = temp + M(103, 97) * x(97)
      temp = temp + M(103, 100) * x(100)
      temp = temp + M(103, 101) * x(101)
      temp = temp + M(103, 102) * x(102)
      x(103) = ( x(103) - temp ) / M(103, 103)

      temp = M(104, 6) * x(6)
      temp = temp + M(104, 26) * x(26)
      temp = temp + M(104, 54) * x(54)
      temp = temp + M(104, 61) * x(61)
      temp = temp + M(104, 63) * x(63)
      temp = temp + M(104, 64) * x(64)
      temp = temp + M(104, 65) * x(65)
      temp = temp + M(104, 69) * x(69)
      temp = temp + M(104, 72) * x(72)
      temp = temp + M(104, 78) * x(78)
      temp = temp + M(104, 86) * x(86)
      temp = temp + M(104, 87) * x(87)
      temp = temp + M(104, 88) * x(88)
      temp = temp + M(104, 90) * x(90)
      temp = temp + M(104, 91) * x(91)
      temp = temp + M(104, 97) * x(97)
      temp = temp + M(104, 101) * x(101)
      x(104) = ( x(104) - temp ) / M(104, 104)

      temp = M(105, 30) * x(30)
      temp = temp + M(105, 34) * x(34)
      temp = temp + M(105, 47) * x(47)
      temp = temp + M(105, 81) * x(81)
      temp = temp + M(105, 84) * x(84)
      temp = temp + M(105, 90) * x(90)
      temp = temp + M(105, 91) * x(91)
      temp = temp + M(105, 97) * x(97)
      x(105) = ( x(105) - temp ) / M(105, 105)

      temp = M(106, 31) * x(31)
      temp = temp + M(106, 37) * x(37)
      temp = temp + M(106, 68) * x(68)
      temp = temp + M(106, 70) * x(70)
      temp = temp + M(106, 72) * x(72)
      temp = temp + M(106, 74) * x(74)
      temp = temp + M(106, 75) * x(75)
      temp = temp + M(106, 79) * x(79)
      temp = temp + M(106, 80) * x(80)
      temp = temp + M(106, 83) * x(83)
      temp = temp + M(106, 85) * x(85)
      temp = temp + M(106, 88) * x(88)
      temp = temp + M(106, 89) * x(89)
      temp = temp + M(106, 90) * x(90)
      temp = temp + M(106, 91) * x(91)
      temp = temp + M(106, 92) * x(92)
      temp = temp + M(106, 94) * x(94)
      temp = temp + M(106, 97) * x(97)
      temp = temp + M(106, 98) * x(98)
      temp = temp + M(106, 101) * x(101)
      temp = temp + M(106, 105) * x(105)
      x(106) = ( x(106) - temp ) / M(106, 106)

      temp = M(107, 106) * x(106)
      x(107) = ( x(107) - temp ) / M(107, 107)

      temp = M(108, 6) * x(6)
      temp = temp + M(108, 18) * x(18)
      temp = temp + M(108, 22) * x(22)
      temp = temp + M(108, 24) * x(24)
      temp = temp + M(108, 26) * x(26)
      temp = temp + M(108, 27) * x(27)
      temp = temp + M(108, 30) * x(30)
      temp = temp + M(108, 31) * x(31)
      temp = temp + M(108, 37) * x(37)
      temp = temp + M(108, 46) * x(46)
      temp = temp + M(108, 63) * x(63)
      temp = temp + M(108, 65) * x(65)
      temp = temp + M(108, 69) * x(69)
      temp = temp + M(108, 72) * x(72)
      temp = temp + M(108, 80) * x(80)
      temp = temp + M(108, 81) * x(81)
      temp = temp + M(108, 84) * x(84)
      temp = temp + M(108, 87) * x(87)
      temp = temp + M(108, 88) * x(88)
      temp = temp + M(108, 89) * x(89)
      temp = temp + M(108, 90) * x(90)
      temp = temp + M(108, 91) * x(91)
      temp = temp + M(108, 97) * x(97)
      temp = temp + M(108, 100) * x(100)
      temp = temp + M(108, 101) * x(101)
      temp = temp + M(108, 102) * x(102)
      temp = temp + M(108, 104) * x(104)
      temp = temp + M(108, 105) * x(105)
      temp = temp + M(108, 107) * x(107)
      x(108) = ( x(108) - temp ) / M(108, 108)

      temp = M(109, 22) * x(22)
      temp = temp + M(109, 37) * x(37)
      temp = temp + M(109, 70) * x(70)
      temp = temp + M(109, 72) * x(72)
      temp = temp + M(109, 74) * x(74)
      temp = temp + M(109, 75) * x(75)
      temp = temp + M(109, 79) * x(79)
      temp = temp + M(109, 87) * x(87)
      temp = temp + M(109, 88) * x(88)
      temp = temp + M(109, 89) * x(89)
      temp = temp + M(109, 90) * x(90)
      temp = temp + M(109, 91) * x(91)
      temp = temp + M(109, 92) * x(92)
      temp = temp + M(109, 93) * x(93)
      temp = temp + M(109, 94) * x(94)
      temp = temp + M(109, 97) * x(97)
      x(109) = ( x(109) - temp ) / M(109, 109)

      temp = M(110, 8) * x(8)
      x(110) = ( x(110) - temp ) / M(110, 110)

      temp = M(111, 51) * x(51)
      temp = temp + M(111, 52) * x(52)
      temp = temp + M(111, 54) * x(54)
      temp = temp + M(111, 56) * x(56)
      temp = temp + M(111, 60) * x(60)
      temp = temp + M(111, 61) * x(61)
      temp = temp + M(111, 62) * x(62)
      temp = temp + M(111, 63) * x(63)
      temp = temp + M(111, 64) * x(64)
      temp = temp + M(111, 67) * x(67)
      temp = temp + M(111, 72) * x(72)
      temp = temp + M(111, 74) * x(74)
      temp = temp + M(111, 75) * x(75)
      temp = temp + M(111, 79) * x(79)
      temp = temp + M(111, 84) * x(84)
      temp = temp + M(111, 86) * x(86)
      temp = temp + M(111, 87) * x(87)
      temp = temp + M(111, 90) * x(90)
      temp = temp + M(111, 91) * x(91)
      temp = temp + M(111, 93) * x(93)
      temp = temp + M(111, 94) * x(94)
      temp = temp + M(111, 97) * x(97)
      temp = temp + M(111, 110) * x(110)
      x(111) = ( x(111) - temp ) / M(111, 111)

      temp = M(112, 10) * x(10)
      temp = temp + M(112, 22) * x(22)
      temp = temp + M(112, 26) * x(26)
      temp = temp + M(112, 28) * x(28)
      temp = temp + M(112, 37) * x(37)
      temp = temp + M(112, 65) * x(65)
      temp = temp + M(112, 69) * x(69)
      temp = temp + M(112, 70) * x(70)
      temp = temp + M(112, 72) * x(72)
      temp = temp + M(112, 74) * x(74)
      temp = temp + M(112, 75) * x(75)
      temp = temp + M(112, 83) * x(83)
      temp = temp + M(112, 85) * x(85)
      temp = temp + M(112, 87) * x(87)
      temp = temp + M(112, 88) * x(88)
      temp = temp + M(112, 89) * x(89)
      temp = temp + M(112, 90) * x(90)
      temp = temp + M(112, 91) * x(91)
      temp = temp + M(112, 92) * x(92)
      temp = temp + M(112, 93) * x(93)
      temp = temp + M(112, 94) * x(94)
      temp = temp + M(112, 95) * x(95)
      temp = temp + M(112, 97) * x(97)
      temp = temp + M(112, 98) * x(98)
      temp = temp + M(112, 101) * x(101)
      temp = temp + M(112, 105) * x(105)
      temp = temp + M(112, 109) * x(109)
      temp = temp + M(112, 110) * x(110)
      temp = temp + M(112, 111) * x(111)
      x(112) = ( x(112) - temp ) / M(112, 112)

      temp = M(113, 22) * x(22)
      temp = temp + M(113, 31) * x(31)
      temp = temp + M(113, 36) * x(36)
      temp = temp + M(113, 37) * x(37)
      temp = temp + M(113, 38) * x(38)
      temp = temp + M(113, 72) * x(72)
      temp = temp + M(113, 75) * x(75)
      temp = temp + M(113, 89) * x(89)
      temp = temp + M(113, 90) * x(90)
      temp = temp + M(113, 91) * x(91)
      temp = temp + M(113, 97) * x(97)
      temp = temp + M(113, 109) * x(109)
      temp = temp + M(113, 110) * x(110)
      temp = temp + M(113, 111) * x(111)
      temp = temp + M(113, 112) * x(112)
      x(113) = ( x(113) - temp ) / M(113, 113)

      temp = M(114, 24) * x(24)
      temp = temp + M(114, 30) * x(30)
      temp = temp + M(114, 36) * x(36)
      temp = temp + M(114, 37) * x(37)
      temp = temp + M(114, 39) * x(39)
      temp = temp + M(114, 40) * x(40)
      temp = temp + M(114, 45) * x(45)
      temp = temp + M(114, 50) * x(50)
      temp = temp + M(114, 52) * x(52)
      temp = temp + M(114, 53) * x(53)
      temp = temp + M(114, 54) * x(54)
      temp = temp + M(114, 55) * x(55)
      temp = temp + M(114, 56) * x(56)
      temp = temp + M(114, 61) * x(61)
      temp = temp + M(114, 62) * x(62)
      temp = temp + M(114, 63) * x(63)
      temp = temp + M(114, 64) * x(64)
      temp = temp + M(114, 67) * x(67)
      temp = temp + M(114, 68) * x(68)
      temp = temp + M(114, 70) * x(70)
      temp = temp + M(114, 71) * x(71)
      temp = temp + M(114, 72) * x(72)
      temp = temp + M(114, 73) * x(73)
      temp = temp + M(114, 74) * x(74)
      temp = temp + M(114, 75) * x(75)
      temp = temp + M(114, 78) * x(78)
      temp = temp + M(114, 79) * x(79)
      temp = temp + M(114, 80) * x(80)
      temp = temp + M(114, 81) * x(81)
      temp = temp + M(114, 83) * x(83)
      temp = temp + M(114, 85) * x(85)
      temp = temp + M(114, 86) * x(86)
      temp = temp + M(114, 87) * x(87)
      temp = temp + M(114, 88) * x(88)
      temp = temp + M(114, 89) * x(89)
      temp = temp + M(114, 90) * x(90)
      temp = temp + M(114, 91) * x(91)
      temp = temp + M(114, 92) * x(92)
      temp = temp + M(114, 93) * x(93)
      temp = temp + M(114, 94) * x(94)
      temp = temp + M(114, 96) * x(96)
      temp = temp + M(114, 97) * x(97)
      temp = temp + M(114, 98) * x(98)
      temp = temp + M(114, 100) * x(100)
      temp = temp + M(114, 101) * x(101)
      temp = temp + M(114, 105) * x(105)
      temp = temp + M(114, 106) * x(106)
      temp = temp + M(114, 107) * x(107)
      temp = temp + M(114, 109) * x(109)
      temp = temp + M(114, 110) * x(110)
      temp = temp + M(114, 111) * x(111)
      temp = temp + M(114, 113) * x(113)
      x(114) = ( x(114) - temp ) / M(114, 114)

      temp = M(115, 54) * x(54)
      temp = temp + M(115, 56) * x(56)
      temp = temp + M(115, 61) * x(61)
      temp = temp + M(115, 63) * x(63)
      temp = temp + M(115, 64) * x(64)
      temp = temp + M(115, 68) * x(68)
      temp = temp + M(115, 70) * x(70)
      temp = temp + M(115, 72) * x(72)
      temp = temp + M(115, 74) * x(74)
      temp = temp + M(115, 75) * x(75)
      temp = temp + M(115, 78) * x(78)
      temp = temp + M(115, 79) * x(79)
      temp = temp + M(115, 83) * x(83)
      temp = temp + M(115, 85) * x(85)
      temp = temp + M(115, 86) * x(86)
      temp = temp + M(115, 88) * x(88)
      temp = temp + M(115, 90) * x(90)
      temp = temp + M(115, 91) * x(91)
      temp = temp + M(115, 92) * x(92)
      temp = temp + M(115, 96) * x(96)
      temp = temp + M(115, 97) * x(97)
      temp = temp + M(115, 98) * x(98)
      temp = temp + M(115, 101) * x(101)
      temp = temp + M(115, 107) * x(107)
      temp = temp + M(115, 109) * x(109)
      temp = temp + M(115, 110) * x(110)
      temp = temp + M(115, 111) * x(111)
      temp = temp + M(115, 113) * x(113)
      temp = temp + M(115, 114) * x(114)
      x(115) = ( x(115) - temp ) / M(115, 115)

      temp = M(116, 24) * x(24)
      temp = temp + M(116, 26) * x(26)
      temp = temp + M(116, 40) * x(40)
      temp = temp + M(116, 41) * x(41)
      temp = temp + M(116, 65) * x(65)
      temp = temp + M(116, 69) * x(69)
      temp = temp + M(116, 71) * x(71)
      temp = temp + M(116, 72) * x(72)
      temp = temp + M(116, 75) * x(75)
      temp = temp + M(116, 81) * x(81)
      temp = temp + M(116, 83) * x(83)
      temp = temp + M(116, 84) * x(84)
      temp = temp + M(116, 87) * x(87)
      temp = temp + M(116, 90) * x(90)
      temp = temp + M(116, 91) * x(91)
      temp = temp + M(116, 97) * x(97)
      temp = temp + M(116, 101) * x(101)
      temp = temp + M(116, 109) * x(109)
      temp = temp + M(116, 110) * x(110)
      temp = temp + M(116, 111) * x(111)
      temp = temp + M(116, 114) * x(114)
      temp = temp + M(116, 115) * x(115)
      x(116) = ( x(116) - temp ) / M(116, 116)

      temp = M(117, 23) * x(23)
      temp = temp + M(117, 48) * x(48)
      temp = temp + M(117, 50) * x(50)
      temp = temp + M(117, 52) * x(52)
      temp = temp + M(117, 53) * x(53)
      temp = temp + M(117, 54) * x(54)
      temp = temp + M(117, 55) * x(55)
      temp = temp + M(117, 56) * x(56)
      temp = temp + M(117, 61) * x(61)
      temp = temp + M(117, 62) * x(62)
      temp = temp + M(117, 63) * x(63)
      temp = temp + M(117, 64) * x(64)
      temp = temp + M(117, 67) * x(67)
      temp = temp + M(117, 68) * x(68)
      temp = temp + M(117, 70) * x(70)
      temp = temp + M(117, 72) * x(72)
      temp = temp + M(117, 74) * x(74)
      temp = temp + M(117, 75) * x(75)
      temp = temp + M(117, 78) * x(78)
      temp = temp + M(117, 79) * x(79)
      temp = temp + M(117, 80) * x(80)
      temp = temp + M(117, 83) * x(83)
      temp = temp + M(117, 85) * x(85)
      temp = temp + M(117, 86) * x(86)
      temp = temp + M(117, 88) * x(88)
      temp = temp + M(117, 90) * x(90)
      temp = temp + M(117, 91) * x(91)
      temp = temp + M(117, 92) * x(92)
      temp = temp + M(117, 93) * x(93)
      temp = temp + M(117, 94) * x(94)
      temp = temp + M(117, 96) * x(96)
      temp = temp + M(117, 97) * x(97)
      temp = temp + M(117, 98) * x(98)
      temp = temp + M(117, 101) * x(101)
      temp = temp + M(117, 105) * x(105)
      temp = temp + M(117, 107) * x(107)
      temp = temp + M(117, 109) * x(109)
      temp = temp + M(117, 110) * x(110)
      temp = temp + M(117, 111) * x(111)
      temp = temp + M(117, 113) * x(113)
      temp = temp + M(117, 114) * x(114)
      temp = temp + M(117, 115) * x(115)
      temp = temp + M(117, 116) * x(116)
      x(117) = ( x(117) - temp ) / M(117, 117)

      temp = M(118, 24) * x(24)
      temp = temp + M(118, 30) * x(30)
      temp = temp + M(118, 36) * x(36)
      temp = temp + M(118, 40) * x(40)
      temp = temp + M(118, 50) * x(50)
      temp = temp + M(118, 52) * x(52)
      temp = temp + M(118, 53) * x(53)
      temp = temp + M(118, 54) * x(54)
      temp = temp + M(118, 55) * x(55)
      temp = temp + M(118, 56) * x(56)
      temp = temp + M(118, 61) * x(61)
      temp = temp + M(118, 62) * x(62)
      temp = temp + M(118, 63) * x(63)
      temp = temp + M(118, 64) * x(64)
      temp = temp + M(118, 65) * x(65)
      temp = temp + M(118, 67) * x(67)
      temp = temp + M(118, 68) * x(68)
      temp = temp + M(118, 69) * x(69)
      temp = temp + M(118, 70) * x(70)
      temp = temp + M(118, 71) * x(71)
      temp = temp + M(118, 72) * x(72)
      temp = temp + M(118, 73) * x(73)
      temp = temp + M(118, 74) * x(74)
      temp = temp + M(118, 75) * x(75)
      temp = temp + M(118, 77) * x(77)
      temp = temp + M(118, 78) * x(78)
      temp = temp + M(118, 79) * x(79)
      temp = temp + M(118, 80) * x(80)
      temp = temp + M(118, 81) * x(81)
      temp = temp + M(118, 83) * x(83)
      temp = temp + M(118, 84) * x(84)
      temp = temp + M(118, 85) * x(85)
      temp = temp + M(118, 86) * x(86)
      temp = temp + M(118, 87) * x(87)
      temp = temp + M(118, 88) * x(88)
      temp = temp + M(118, 90) * x(90)
      temp = temp + M(118, 91) * x(91)
      temp = temp + M(118, 92) * x(92)
      temp = temp + M(118, 93) * x(93)
      temp = temp + M(118, 94) * x(94)
      temp = temp + M(118, 96) * x(96)
      temp = temp + M(118, 97) * x(97)
      temp = temp + M(118, 98) * x(98)
      temp = temp + M(118, 100) * x(100)
      temp = temp + M(118, 101) * x(101)
      temp = temp + M(118, 102) * x(102)
      temp = temp + M(118, 105) * x(105)
      temp = temp + M(118, 107) * x(107)
      temp = temp + M(118, 109) * x(109)
      temp = temp + M(118, 110) * x(110)
      temp = temp + M(118, 111) * x(111)
      temp = temp + M(118, 113) * x(113)
      temp = temp + M(118, 114) * x(114)
      temp = temp + M(118, 115) * x(115)
      temp = temp + M(118, 116) * x(116)
      temp = temp + M(118, 117) * x(117)
      x(118) = ( x(118) - temp ) / M(118, 118)

      temp = M(119, 18) * x(18)
      temp = temp + M(119, 24) * x(24)
      temp = temp + M(119, 27) * x(27)
      temp = temp + M(119, 30) * x(30)
      temp = temp + M(119, 31) * x(31)
      temp = temp + M(119, 37) * x(37)
      temp = temp + M(119, 39) * x(39)
      temp = temp + M(119, 40) * x(40)
      temp = temp + M(119, 41) * x(41)
      temp = temp + M(119, 46) * x(46)
      temp = temp + M(119, 50) * x(50)
      temp = temp + M(119, 52) * x(52)
      temp = temp + M(119, 53) * x(53)
      temp = temp + M(119, 54) * x(54)
      temp = temp + M(119, 55) * x(55)
      temp = temp + M(119, 56) * x(56)
      temp = temp + M(119, 61) * x(61)
      temp = temp + M(119, 62) * x(62)
      temp = temp + M(119, 63) * x(63)
      temp = temp + M(119, 64) * x(64)
      temp = temp + M(119, 67) * x(67)
      temp = temp + M(119, 68) * x(68)
      temp = temp + M(119, 70) * x(70)
      temp = temp + M(119, 71) * x(71)
      temp = temp + M(119, 72) * x(72)
      temp = temp + M(119, 74) * x(74)
      temp = temp + M(119, 75) * x(75)
      temp = temp + M(119, 77) * x(77)
      temp = temp + M(119, 78) * x(78)
      temp = temp + M(119, 79) * x(79)
      temp = temp + M(119, 80) * x(80)
      temp = temp + M(119, 81) * x(81)
      temp = temp + M(119, 83) * x(83)
      temp = temp + M(119, 84) * x(84)
      temp = temp + M(119, 85) * x(85)
      temp = temp + M(119, 86) * x(86)
      temp = temp + M(119, 87) * x(87)
      temp = temp + M(119, 88) * x(88)
      temp = temp + M(119, 89) * x(89)
      temp = temp + M(119, 90) * x(90)
      temp = temp + M(119, 91) * x(91)
      temp = temp + M(119, 92) * x(92)
      temp = temp + M(119, 93) * x(93)
      temp = temp + M(119, 94) * x(94)
      temp = temp + M(119, 96) * x(96)
      temp = temp + M(119, 97) * x(97)
      temp = temp + M(119, 98) * x(98)
      temp = temp + M(119, 99) * x(99)
      temp = temp + M(119, 101) * x(101)
      temp = temp + M(119, 104) * x(104)
      temp = temp + M(119, 105) * x(105)
      temp = temp + M(119, 107) * x(107)
      temp = temp + M(119, 109) * x(109)
      temp = temp + M(119, 110) * x(110)
      temp = temp + M(119, 111) * x(111)
      temp = temp + M(119, 113) * x(113)
      temp = temp + M(119, 114) * x(114)
      temp = temp + M(119, 115) * x(115)
      temp = temp + M(119, 116) * x(116)
      temp = temp + M(119, 117) * x(117)
      temp = temp + M(119, 118) * x(118)
      x(119) = ( x(119) - temp ) / M(119, 119)

      temp = M(120, 3) * x(3)
      temp = temp + M(120, 4) * x(4)
      temp = temp + M(120, 6) * x(6)
      temp = temp + M(120, 7) * x(7)
      temp = temp + M(120, 8) * x(8)
      temp = temp + M(120, 9) * x(9)
      temp = temp + M(120, 10) * x(10)
      temp = temp + M(120, 11) * x(11)
      temp = temp + M(120, 12) * x(12)
      temp = temp + M(120, 13) * x(13)
      temp = temp + M(120, 14) * x(14)
      temp = temp + M(120, 15) * x(15)
      temp = temp + M(120, 16) * x(16)
      temp = temp + M(120, 18) * x(18)
      temp = temp + M(120, 19) * x(19)
      temp = temp + M(120, 22) * x(22)
      temp = temp + M(120, 23) * x(23)
      temp = temp + M(120, 24) * x(24)
      temp = temp + M(120, 25) * x(25)
      temp = temp + M(120, 26) * x(26)
      temp = temp + M(120, 27) * x(27)
      temp = temp + M(120, 28) * x(28)
      temp = temp + M(120, 30) * x(30)
      temp = temp + M(120, 31) * x(31)
      temp = temp + M(120, 34) * x(34)
      temp = temp + M(120, 35) * x(35)
      temp = temp + M(120, 36) * x(36)
      temp = temp + M(120, 37) * x(37)
      temp = temp + M(120, 38) * x(38)
      temp = temp + M(120, 39) * x(39)
      temp = temp + M(120, 40) * x(40)
      temp = temp + M(120, 41) * x(41)
      temp = temp + M(120, 42) * x(42)
      temp = temp + M(120, 45) * x(45)
      temp = temp + M(120, 46) * x(46)
      temp = temp + M(120, 47) * x(47)
      temp = temp + M(120, 49) * x(49)
      temp = temp + M(120, 54) * x(54)
      temp = temp + M(120, 56) * x(56)
      temp = temp + M(120, 58) * x(58)
      temp = temp + M(120, 60) * x(60)
      temp = temp + M(120, 63) * x(63)
      temp = temp + M(120, 64) * x(64)
      temp = temp + M(120, 65) * x(65)
      temp = temp + M(120, 69) * x(69)
      temp = temp + M(120, 71) * x(71)
      temp = temp + M(120, 72) * x(72)
      temp = temp + M(120, 73) * x(73)
      temp = temp + M(120, 74) * x(74)
      temp = temp + M(120, 76) * x(76)
      temp = temp + M(120, 77) * x(77)
      temp = temp + M(120, 78) * x(78)
      temp = temp + M(120, 79) * x(79)
      temp = temp + M(120, 80) * x(80)
      temp = temp + M(120, 81) * x(81)
      temp = temp + M(120, 82) * x(82)
      temp = temp + M(120, 84) * x(84)
      temp = temp + M(120, 85) * x(85)
      temp = temp + M(120, 87) * x(87)
      temp = temp + M(120, 89) * x(89)
      temp = temp + M(120, 90) * x(90)
      temp = temp + M(120, 91) * x(91)
      temp = temp + M(120, 95) * x(95)
      temp = temp + M(120, 97) * x(97)
      temp = temp + M(120, 98) * x(98)
      temp = temp + M(120, 99) * x(99)
      temp = temp + M(120, 100) * x(100)
      temp = temp + M(120, 101) * x(101)
      temp = temp + M(120, 102) * x(102)
      temp = temp + M(120, 103) * x(103)
      temp = temp + M(120, 104) * x(104)
      temp = temp + M(120, 105) * x(105)
      temp = temp + M(120, 106) * x(106)
      temp = temp + M(120, 107) * x(107)
      temp = temp + M(120, 108) * x(108)
      temp = temp + M(120, 109) * x(109)
      temp = temp + M(120, 110) * x(110)
      temp = temp + M(120, 111) * x(111)
      temp = temp + M(120, 112) * x(112)
      temp = temp + M(120, 113) * x(113)
      temp = temp + M(120, 114) * x(114)
      temp = temp + M(120, 115) * x(115)
      temp = temp + M(120, 116) * x(116)
      temp = temp + M(120, 117) * x(117)
      temp = temp + M(120, 118) * x(118)
      temp = temp + M(120, 119) * x(119)
      x(120) = ( x(120) - temp ) / M(120, 120)

      temp = M(121, 17) * x(17)
      temp = temp + M(121, 19) * x(19)
      temp = temp + M(121, 22) * x(22)
      temp = temp + M(121, 24) * x(24)
      temp = temp + M(121, 26) * x(26)
      temp = temp + M(121, 27) * x(27)
      temp = temp + M(121, 30) * x(30)
      temp = temp + M(121, 31) * x(31)
      temp = temp + M(121, 35) * x(35)
      temp = temp + M(121, 37) * x(37)
      temp = temp + M(121, 40) * x(40)
      temp = temp + M(121, 41) * x(41)
      temp = temp + M(121, 42) * x(42)
      temp = temp + M(121, 47) * x(47)
      temp = temp + M(121, 48) * x(48)
      temp = temp + M(121, 50) * x(50)
      temp = temp + M(121, 52) * x(52)
      temp = temp + M(121, 53) * x(53)
      temp = temp + M(121, 54) * x(54)
      temp = temp + M(121, 55) * x(55)
      temp = temp + M(121, 56) * x(56)
      temp = temp + M(121, 58) * x(58)
      temp = temp + M(121, 60) * x(60)
      temp = temp + M(121, 61) * x(61)
      temp = temp + M(121, 62) * x(62)
      temp = temp + M(121, 63) * x(63)
      temp = temp + M(121, 64) * x(64)
      temp = temp + M(121, 67) * x(67)
      temp = temp + M(121, 68) * x(68)
      temp = temp + M(121, 70) * x(70)
      temp = temp + M(121, 72) * x(72)
      temp = temp + M(121, 74) * x(74)
      temp = temp + M(121, 75) * x(75)
      temp = temp + M(121, 78) * x(78)
      temp = temp + M(121, 79) * x(79)
      temp = temp + M(121, 80) * x(80)
      temp = temp + M(121, 83) * x(83)
      temp = temp + M(121, 84) * x(84)
      temp = temp + M(121, 85) * x(85)
      temp = temp + M(121, 86) * x(86)
      temp = temp + M(121, 87) * x(87)
      temp = temp + M(121, 88) * x(88)
      temp = temp + M(121, 89) * x(89)
      temp = temp + M(121, 90) * x(90)
      temp = temp + M(121, 91) * x(91)
      temp = temp + M(121, 92) * x(92)
      temp = temp + M(121, 93) * x(93)
      temp = temp + M(121, 94) * x(94)
      temp = temp + M(121, 96) * x(96)
      temp = temp + M(121, 97) * x(97)
      temp = temp + M(121, 98) * x(98)
      temp = temp + M(121, 100) * x(100)
      temp = temp + M(121, 101) * x(101)
      temp = temp + M(121, 102) * x(102)
      temp = temp + M(121, 103) * x(103)
      temp = temp + M(121, 104) * x(104)
      temp = temp + M(121, 105) * x(105)
      temp = temp + M(121, 107) * x(107)
      temp = temp + M(121, 109) * x(109)
      temp = temp + M(121, 110) * x(110)
      temp = temp + M(121, 111) * x(111)
      temp = temp + M(121, 112) * x(112)
      temp = temp + M(121, 113) * x(113)
      temp = temp + M(121, 114) * x(114)
      temp = temp + M(121, 115) * x(115)
      temp = temp + M(121, 116) * x(116)
      temp = temp + M(121, 117) * x(117)
      temp = temp + M(121, 118) * x(118)
      temp = temp + M(121, 119) * x(119)
      temp = temp + M(121, 120) * x(120)
      x(121) = ( x(121) - temp ) / M(121, 121)

      temp = M(122, 41) * x(41)
      temp = temp + M(122, 112) * x(112)
      temp = temp + M(122, 114) * x(114)
      temp = temp + M(122, 115) * x(115)
      temp = temp + M(122, 116) * x(116)
      temp = temp + M(122, 117) * x(117)
      temp = temp + M(122, 118) * x(118)
      temp = temp + M(122, 120) * x(120)
      temp = temp + M(122, 121) * x(121)
      x(122) = ( x(122) - temp ) / M(122, 122)

      temp = M(123, 4) * x(4)
      temp = temp + M(123, 6) * x(6)
      temp = temp + M(123, 7) * x(7)
      temp = temp + M(123, 10) * x(10)
      temp = temp + M(123, 11) * x(11)
      temp = temp + M(123, 12) * x(12)
      temp = temp + M(123, 13) * x(13)
      temp = temp + M(123, 14) * x(14)
      temp = temp + M(123, 15) * x(15)
      temp = temp + M(123, 16) * x(16)
      temp = temp + M(123, 19) * x(19)
      temp = temp + M(123, 22) * x(22)
      temp = temp + M(123, 24) * x(24)
      temp = temp + M(123, 25) * x(25)
      temp = temp + M(123, 26) * x(26)
      temp = temp + M(123, 27) * x(27)
      temp = temp + M(123, 28) * x(28)
      temp = temp + M(123, 30) * x(30)
      temp = temp + M(123, 31) * x(31)
      temp = temp + M(123, 37) * x(37)
      temp = temp + M(123, 39) * x(39)
      temp = temp + M(123, 42) * x(42)
      temp = temp + M(123, 49) * x(49)
      temp = temp + M(123, 50) * x(50)
      temp = temp + M(123, 52) * x(52)
      temp = temp + M(123, 53) * x(53)
      temp = temp + M(123, 54) * x(54)
      temp = temp + M(123, 55) * x(55)
      temp = temp + M(123, 56) * x(56)
      temp = temp + M(123, 58) * x(58)
      temp = temp + M(123, 60) * x(60)
      temp = temp + M(123, 61) * x(61)
      temp = temp + M(123, 62) * x(62)
      temp = temp + M(123, 63) * x(63)
      temp = temp + M(123, 64) * x(64)
      temp = temp + M(123, 65) * x(65)
      temp = temp + M(123, 67) * x(67)
      temp = temp + M(123, 68) * x(68)
      temp = temp + M(123, 69) * x(69)
      temp = temp + M(123, 70) * x(70)
      temp = temp + M(123, 72) * x(72)
      temp = temp + M(123, 74) * x(74)
      temp = temp + M(123, 75) * x(75)
      temp = temp + M(123, 76) * x(76)
      temp = temp + M(123, 77) * x(77)
      temp = temp + M(123, 78) * x(78)
      temp = temp + M(123, 79) * x(79)
      temp = temp + M(123, 80) * x(80)
      temp = temp + M(123, 81) * x(81)
      temp = temp + M(123, 82) * x(82)
      temp = temp + M(123, 83) * x(83)
      temp = temp + M(123, 84) * x(84)
      temp = temp + M(123, 85) * x(85)
      temp = temp + M(123, 86) * x(86)
      temp = temp + M(123, 87) * x(87)
      temp = temp + M(123, 88) * x(88)
      temp = temp + M(123, 89) * x(89)
      temp = temp + M(123, 90) * x(90)
      temp = temp + M(123, 91) * x(91)
      temp = temp + M(123, 92) * x(92)
      temp = temp + M(123, 93) * x(93)
      temp = temp + M(123, 94) * x(94)
      temp = temp + M(123, 95) * x(95)
      temp = temp + M(123, 96) * x(96)
      temp = temp + M(123, 97) * x(97)
      temp = temp + M(123, 98) * x(98)
      temp = temp + M(123, 99) * x(99)
      temp = temp + M(123, 100) * x(100)
      temp = temp + M(123, 101) * x(101)
      temp = temp + M(123, 102) * x(102)
      temp = temp + M(123, 104) * x(104)
      temp = temp + M(123, 105) * x(105)
      temp = temp + M(123, 107) * x(107)
      temp = temp + M(123, 108) * x(108)
      temp = temp + M(123, 109) * x(109)
      temp = temp + M(123, 110) * x(110)
      temp = temp + M(123, 111) * x(111)
      temp = temp + M(123, 112) * x(112)
      temp = temp + M(123, 113) * x(113)
      temp = temp + M(123, 114) * x(114)
      temp = temp + M(123, 115) * x(115)
      temp = temp + M(123, 116) * x(116)
      temp = temp + M(123, 117) * x(117)
      temp = temp + M(123, 118) * x(118)
      temp = temp + M(123, 119) * x(119)
      temp = temp + M(123, 120) * x(120)
      temp = temp + M(123, 121) * x(121)
      temp = temp + M(123, 122) * x(122)
      x(123) = ( x(123) - temp ) / M(123, 123)

      temp = M(124, 17) * x(17)
      temp = temp + M(124, 18) * x(18)
      temp = temp + M(124, 23) * x(23)
      temp = temp + M(124, 26) * x(26)
      temp = temp + M(124, 40) * x(40)
      temp = temp + M(124, 41) * x(41)
      temp = temp + M(124, 42) * x(42)
      temp = temp + M(124, 46) * x(46)
      temp = temp + M(124, 47) * x(47)
      temp = temp + M(124, 48) * x(48)
      temp = temp + M(124, 50) * x(50)
      temp = temp + M(124, 51) * x(51)
      temp = temp + M(124, 52) * x(52)
      temp = temp + M(124, 53) * x(53)
      temp = temp + M(124, 54) * x(54)
      temp = temp + M(124, 55) * x(55)
      temp = temp + M(124, 56) * x(56)
      temp = temp + M(124, 60) * x(60)
      temp = temp + M(124, 61) * x(61)
      temp = temp + M(124, 62) * x(62)
      temp = temp + M(124, 63) * x(63)
      temp = temp + M(124, 64) * x(64)
      temp = temp + M(124, 67) * x(67)
      temp = temp + M(124, 68) * x(68)
      temp = temp + M(124, 70) * x(70)
      temp = temp + M(124, 72) * x(72)
      temp = temp + M(124, 74) * x(74)
      temp = temp + M(124, 75) * x(75)
      temp = temp + M(124, 78) * x(78)
      temp = temp + M(124, 79) * x(79)
      temp = temp + M(124, 80) * x(80)
      temp = temp + M(124, 83) * x(83)
      temp = temp + M(124, 85) * x(85)
      temp = temp + M(124, 86) * x(86)
      temp = temp + M(124, 88) * x(88)
      temp = temp + M(124, 90) * x(90)
      temp = temp + M(124, 91) * x(91)
      temp = temp + M(124, 92) * x(92)
      temp = temp + M(124, 93) * x(93)
      temp = temp + M(124, 94) * x(94)
      temp = temp + M(124, 96) * x(96)
      temp = temp + M(124, 97) * x(97)
      temp = temp + M(124, 98) * x(98)
      temp = temp + M(124, 101) * x(101)
      temp = temp + M(124, 103) * x(103)
      temp = temp + M(124, 104) * x(104)
      temp = temp + M(124, 105) * x(105)
      temp = temp + M(124, 107) * x(107)
      temp = temp + M(124, 109) * x(109)
      temp = temp + M(124, 110) * x(110)
      temp = temp + M(124, 111) * x(111)
      temp = temp + M(124, 112) * x(112)
      temp = temp + M(124, 113) * x(113)
      temp = temp + M(124, 114) * x(114)
      temp = temp + M(124, 115) * x(115)
      temp = temp + M(124, 116) * x(116)
      temp = temp + M(124, 117) * x(117)
      temp = temp + M(124, 118) * x(118)
      temp = temp + M(124, 119) * x(119)
      temp = temp + M(124, 120) * x(120)
      temp = temp + M(124, 121) * x(121)
      temp = temp + M(124, 122) * x(122)
      temp = temp + M(124, 123) * x(123)
      x(124) = ( x(124) - temp ) / M(124, 124)


C     Backward substitution.

      temp = M(123, 124) * x(124)
      x(123) = x(123) - temp

      temp = M(122, 123) * x(123)
      temp = temp + M(122, 124) * x(124)
      x(122) = x(122) - temp

      temp = M(121, 122) * x(122)
      temp = temp + M(121, 123) * x(123)
      temp = temp + M(121, 124) * x(124)
      x(121) = x(121) - temp

      temp = M(120, 121) * x(121)
      temp = temp + M(120, 122) * x(122)
      temp = temp + M(120, 123) * x(123)
      temp = temp + M(120, 124) * x(124)
      x(120) = x(120) - temp

      temp = M(119, 120) * x(120)
      temp = temp + M(119, 121) * x(121)
      temp = temp + M(119, 122) * x(122)
      temp = temp + M(119, 123) * x(123)
      temp = temp + M(119, 124) * x(124)
      x(119) = x(119) - temp

      temp = M(118, 120) * x(120)
      temp = temp + M(118, 121) * x(121)
      temp = temp + M(118, 122) * x(122)
      temp = temp + M(118, 123) * x(123)
      temp = temp + M(118, 124) * x(124)
      x(118) = x(118) - temp

      temp = M(117, 118) * x(118)
      temp = temp + M(117, 120) * x(120)
      temp = temp + M(117, 121) * x(121)
      temp = temp + M(117, 122) * x(122)
      temp = temp + M(117, 123) * x(123)
      temp = temp + M(117, 124) * x(124)
      x(117) = x(117) - temp

      temp = M(116, 117) * x(117)
      temp = temp + M(116, 118) * x(118)
      temp = temp + M(116, 120) * x(120)
      temp = temp + M(116, 121) * x(121)
      temp = temp + M(116, 122) * x(122)
      temp = temp + M(116, 123) * x(123)
      temp = temp + M(116, 124) * x(124)
      x(116) = x(116) - temp

      temp = M(115, 116) * x(116)
      temp = temp + M(115, 117) * x(117)
      temp = temp + M(115, 118) * x(118)
      temp = temp + M(115, 120) * x(120)
      temp = temp + M(115, 121) * x(121)
      temp = temp + M(115, 122) * x(122)
      temp = temp + M(115, 123) * x(123)
      temp = temp + M(115, 124) * x(124)
      x(115) = x(115) - temp

      temp = M(114, 115) * x(115)
      temp = temp + M(114, 116) * x(116)
      temp = temp + M(114, 117) * x(117)
      temp = temp + M(114, 118) * x(118)
      temp = temp + M(114, 120) * x(120)
      temp = temp + M(114, 121) * x(121)
      temp = temp + M(114, 122) * x(122)
      temp = temp + M(114, 123) * x(123)
      temp = temp + M(114, 124) * x(124)
      x(114) = x(114) - temp

      temp = M(113, 114) * x(114)
      temp = temp + M(113, 115) * x(115)
      temp = temp + M(113, 117) * x(117)
      temp = temp + M(113, 118) * x(118)
      temp = temp + M(113, 120) * x(120)
      temp = temp + M(113, 121) * x(121)
      temp = temp + M(113, 122) * x(122)
      temp = temp + M(113, 123) * x(123)
      temp = temp + M(113, 124) * x(124)
      x(113) = x(113) - temp

      temp = M(112, 114) * x(114)
      temp = temp + M(112, 115) * x(115)
      temp = temp + M(112, 117) * x(117)
      temp = temp + M(112, 118) * x(118)
      temp = temp + M(112, 120) * x(120)
      temp = temp + M(112, 121) * x(121)
      temp = temp + M(112, 123) * x(123)
      temp = temp + M(112, 124) * x(124)
      x(112) = x(112) - temp

      temp = M(111, 114) * x(114)
      temp = temp + M(111, 115) * x(115)
      temp = temp + M(111, 117) * x(117)
      temp = temp + M(111, 118) * x(118)
      temp = temp + M(111, 120) * x(120)
      temp = temp + M(111, 121) * x(121)
      temp = temp + M(111, 123) * x(123)
      temp = temp + M(111, 124) * x(124)
      x(111) = x(111) - temp

      temp = M(110, 111) * x(111)
      temp = temp + M(110, 114) * x(114)
      temp = temp + M(110, 115) * x(115)
      temp = temp + M(110, 117) * x(117)
      temp = temp + M(110, 118) * x(118)
      temp = temp + M(110, 120) * x(120)
      temp = temp + M(110, 121) * x(121)
      temp = temp + M(110, 123) * x(123)
      x(110) = x(110) - temp

      temp = M(109, 110) * x(110)
      temp = temp + M(109, 111) * x(111)
      temp = temp + M(109, 114) * x(114)
      temp = temp + M(109, 115) * x(115)
      temp = temp + M(109, 117) * x(117)
      temp = temp + M(109, 118) * x(118)
      temp = temp + M(109, 120) * x(120)
      temp = temp + M(109, 121) * x(121)
      temp = temp + M(109, 123) * x(123)
      temp = temp + M(109, 124) * x(124)
      x(109) = x(109) - temp

      temp = M(108, 109) * x(109)
      temp = temp + M(108, 110) * x(110)
      temp = temp + M(108, 112) * x(112)
      temp = temp + M(108, 113) * x(113)
      temp = temp + M(108, 114) * x(114)
      temp = temp + M(108, 117) * x(117)
      temp = temp + M(108, 118) * x(118)
      temp = temp + M(108, 119) * x(119)
      temp = temp + M(108, 120) * x(120)
      temp = temp + M(108, 121) * x(121)
      temp = temp + M(108, 122) * x(122)
      temp = temp + M(108, 123) * x(123)
      temp = temp + M(108, 124) * x(124)
      x(108) = x(108) - temp

      temp = M(107, 109) * x(109)
      temp = temp + M(107, 110) * x(110)
      temp = temp + M(107, 113) * x(113)
      temp = temp + M(107, 114) * x(114)
      temp = temp + M(107, 117) * x(117)
      temp = temp + M(107, 118) * x(118)
      temp = temp + M(107, 120) * x(120)
      temp = temp + M(107, 121) * x(121)
      temp = temp + M(107, 122) * x(122)
      temp = temp + M(107, 123) * x(123)
      temp = temp + M(107, 124) * x(124)
      x(107) = x(107) - temp

      temp = M(106, 109) * x(109)
      temp = temp + M(106, 110) * x(110)
      temp = temp + M(106, 113) * x(113)
      temp = temp + M(106, 114) * x(114)
      temp = temp + M(106, 117) * x(117)
      temp = temp + M(106, 118) * x(118)
      temp = temp + M(106, 120) * x(120)
      temp = temp + M(106, 121) * x(121)
      temp = temp + M(106, 122) * x(122)
      temp = temp + M(106, 123) * x(123)
      temp = temp + M(106, 124) * x(124)
      x(106) = x(106) - temp

      temp = M(105, 114) * x(114)
      temp = temp + M(105, 117) * x(117)
      temp = temp + M(105, 118) * x(118)
      temp = temp + M(105, 120) * x(120)
      temp = temp + M(105, 121) * x(121)
      temp = temp + M(105, 123) * x(123)
      temp = temp + M(105, 124) * x(124)
      x(105) = x(105) - temp

      temp = M(104, 107) * x(107)
      temp = temp + M(104, 109) * x(109)
      temp = temp + M(104, 110) * x(110)
      temp = temp + M(104, 114) * x(114)
      temp = temp + M(104, 117) * x(117)
      temp = temp + M(104, 118) * x(118)
      temp = temp + M(104, 120) * x(120)
      temp = temp + M(104, 121) * x(121)
      temp = temp + M(104, 123) * x(123)
      temp = temp + M(104, 124) * x(124)
      x(104) = x(104) - temp

      temp = M(103, 104) * x(104)
      temp = temp + M(103, 105) * x(105)
      temp = temp + M(103, 109) * x(109)
      temp = temp + M(103, 110) * x(110)
      temp = temp + M(103, 112) * x(112)
      temp = temp + M(103, 113) * x(113)
      temp = temp + M(103, 114) * x(114)
      temp = temp + M(103, 117) * x(117)
      temp = temp + M(103, 118) * x(118)
      temp = temp + M(103, 119) * x(119)
      temp = temp + M(103, 120) * x(120)
      temp = temp + M(103, 121) * x(121)
      temp = temp + M(103, 123) * x(123)
      temp = temp + M(103, 124) * x(124)
      x(103) = x(103) - temp

      temp = M(102, 105) * x(105)
      temp = temp + M(102, 109) * x(109)
      temp = temp + M(102, 114) * x(114)
      temp = temp + M(102, 117) * x(117)
      temp = temp + M(102, 118) * x(118)
      temp = temp + M(102, 120) * x(120)
      temp = temp + M(102, 121) * x(121)
      temp = temp + M(102, 123) * x(123)
      temp = temp + M(102, 124) * x(124)
      x(102) = x(102) - temp

      temp = M(101, 109) * x(109)
      temp = temp + M(101, 114) * x(114)
      temp = temp + M(101, 117) * x(117)
      temp = temp + M(101, 118) * x(118)
      temp = temp + M(101, 120) * x(120)
      temp = temp + M(101, 121) * x(121)
      temp = temp + M(101, 123) * x(123)
      temp = temp + M(101, 124) * x(124)
      x(101) = x(101) - temp

      temp = M(100, 101) * x(101)
      temp = temp + M(100, 105) * x(105)
      temp = temp + M(100, 110) * x(110)
      temp = temp + M(100, 113) * x(113)
      temp = temp + M(100, 114) * x(114)
      temp = temp + M(100, 117) * x(117)
      temp = temp + M(100, 118) * x(118)
      temp = temp + M(100, 120) * x(120)
      temp = temp + M(100, 121) * x(121)
      temp = temp + M(100, 123) * x(123)
      temp = temp + M(100, 124) * x(124)
      x(100) = x(100) - temp

      temp = M(99, 101) * x(101)
      temp = temp + M(99, 105) * x(105)
      temp = temp + M(99, 110) * x(110)
      temp = temp + M(99, 113) * x(113)
      temp = temp + M(99, 114) * x(114)
      temp = temp + M(99, 117) * x(117)
      temp = temp + M(99, 118) * x(118)
      temp = temp + M(99, 120) * x(120)
      temp = temp + M(99, 121) * x(121)
      temp = temp + M(99, 123) * x(123)
      temp = temp + M(99, 124) * x(124)
      x(99) = x(99) - temp

      temp = M(98, 110) * x(110)
      temp = temp + M(98, 114) * x(114)
      temp = temp + M(98, 117) * x(117)
      temp = temp + M(98, 118) * x(118)
      temp = temp + M(98, 120) * x(120)
      temp = temp + M(98, 121) * x(121)
      temp = temp + M(98, 123) * x(123)
      temp = temp + M(98, 124) * x(124)
      x(98) = x(98) - temp

      temp = M(97, 114) * x(114)
      temp = temp + M(97, 117) * x(117)
      temp = temp + M(97, 118) * x(118)
      temp = temp + M(97, 120) * x(120)
      temp = temp + M(97, 121) * x(121)
      temp = temp + M(97, 123) * x(123)
      temp = temp + M(97, 124) * x(124)
      x(97) = x(97) - temp

      temp = M(96, 97) * x(97)
      temp = temp + M(96, 114) * x(114)
      temp = temp + M(96, 117) * x(117)
      temp = temp + M(96, 118) * x(118)
      temp = temp + M(96, 120) * x(120)
      temp = temp + M(96, 121) * x(121)
      temp = temp + M(96, 123) * x(123)
      temp = temp + M(96, 124) * x(124)
      x(96) = x(96) - temp

      temp = M(95, 97) * x(97)
      temp = temp + M(95, 98) * x(98)
      temp = temp + M(95, 101) * x(101)
      temp = temp + M(95, 105) * x(105)
      temp = temp + M(95, 110) * x(110)
      temp = temp + M(95, 114) * x(114)
      temp = temp + M(95, 117) * x(117)
      temp = temp + M(95, 118) * x(118)
      temp = temp + M(95, 120) * x(120)
      temp = temp + M(95, 121) * x(121)
      temp = temp + M(95, 123) * x(123)
      temp = temp + M(95, 124) * x(124)
      x(95) = x(95) - temp

      temp = M(94, 97) * x(97)
      temp = temp + M(94, 114) * x(114)
      temp = temp + M(94, 117) * x(117)
      temp = temp + M(94, 118) * x(118)
      temp = temp + M(94, 120) * x(120)
      temp = temp + M(94, 121) * x(121)
      temp = temp + M(94, 123) * x(123)
      temp = temp + M(94, 124) * x(124)
      x(94) = x(94) - temp

      temp = M(93, 94) * x(94)
      temp = temp + M(93, 97) * x(97)
      temp = temp + M(93, 114) * x(114)
      temp = temp + M(93, 117) * x(117)
      temp = temp + M(93, 118) * x(118)
      temp = temp + M(93, 120) * x(120)
      temp = temp + M(93, 121) * x(121)
      temp = temp + M(93, 123) * x(123)
      temp = temp + M(93, 124) * x(124)
      x(93) = x(93) - temp

      temp = M(92, 97) * x(97)
      temp = temp + M(92, 114) * x(114)
      temp = temp + M(92, 117) * x(117)
      temp = temp + M(92, 118) * x(118)
      temp = temp + M(92, 120) * x(120)
      temp = temp + M(92, 121) * x(121)
      temp = temp + M(92, 123) * x(123)
      temp = temp + M(92, 124) * x(124)
      x(92) = x(92) - temp

      temp = M(91, 97) * x(97)
      temp = temp + M(91, 114) * x(114)
      temp = temp + M(91, 117) * x(117)
      temp = temp + M(91, 118) * x(118)
      temp = temp + M(91, 120) * x(120)
      temp = temp + M(91, 121) * x(121)
      temp = temp + M(91, 123) * x(123)
      temp = temp + M(91, 124) * x(124)
      x(91) = x(91) - temp

      temp = M(90, 91) * x(91)
      temp = temp + M(90, 97) * x(97)
      temp = temp + M(90, 114) * x(114)
      temp = temp + M(90, 117) * x(117)
      temp = temp + M(90, 118) * x(118)
      temp = temp + M(90, 120) * x(120)
      temp = temp + M(90, 121) * x(121)
      temp = temp + M(90, 123) * x(123)
      temp = temp + M(90, 124) * x(124)
      x(90) = x(90) - temp

      temp = M(89, 90) * x(90)
      temp = temp + M(89, 114) * x(114)
      temp = temp + M(89, 117) * x(117)
      temp = temp + M(89, 118) * x(118)
      temp = temp + M(89, 120) * x(120)
      temp = temp + M(89, 121) * x(121)
      temp = temp + M(89, 123) * x(123)
      x(89) = x(89) - temp

      temp = M(88, 90) * x(90)
      temp = temp + M(88, 114) * x(114)
      temp = temp + M(88, 117) * x(117)
      temp = temp + M(88, 118) * x(118)
      temp = temp + M(88, 120) * x(120)
      temp = temp + M(88, 121) * x(121)
      temp = temp + M(88, 123) * x(123)
      x(88) = x(88) - temp

      temp = M(87, 90) * x(90)
      temp = temp + M(87, 114) * x(114)
      temp = temp + M(87, 117) * x(117)
      temp = temp + M(87, 118) * x(118)
      temp = temp + M(87, 120) * x(120)
      temp = temp + M(87, 121) * x(121)
      temp = temp + M(87, 123) * x(123)
      x(87) = x(87) - temp

      temp = M(86, 114) * x(114)
      temp = temp + M(86, 117) * x(117)
      temp = temp + M(86, 118) * x(118)
      temp = temp + M(86, 120) * x(120)
      temp = temp + M(86, 121) * x(121)
      temp = temp + M(86, 123) * x(123)
      x(86) = x(86) - temp

      temp = M(85, 90) * x(90)
      temp = temp + M(85, 114) * x(114)
      temp = temp + M(85, 117) * x(117)
      temp = temp + M(85, 118) * x(118)
      temp = temp + M(85, 120) * x(120)
      temp = temp + M(85, 121) * x(121)
      temp = temp + M(85, 123) * x(123)
      x(85) = x(85) - temp

      temp = M(84, 90) * x(90)
      temp = temp + M(84, 114) * x(114)
      temp = temp + M(84, 117) * x(117)
      temp = temp + M(84, 118) * x(118)
      temp = temp + M(84, 120) * x(120)
      temp = temp + M(84, 121) * x(121)
      temp = temp + M(84, 123) * x(123)
      x(84) = x(84) - temp

      temp = M(83, 90) * x(90)
      temp = temp + M(83, 114) * x(114)
      temp = temp + M(83, 117) * x(117)
      temp = temp + M(83, 118) * x(118)
      temp = temp + M(83, 120) * x(120)
      temp = temp + M(83, 121) * x(121)
      temp = temp + M(83, 123) * x(123)
      x(83) = x(83) - temp

      temp = M(82, 84) * x(84)
      temp = temp + M(82, 87) * x(87)
      temp = temp + M(82, 90) * x(90)
      temp = temp + M(82, 91) * x(91)
      temp = temp + M(82, 114) * x(114)
      temp = temp + M(82, 117) * x(117)
      temp = temp + M(82, 118) * x(118)
      temp = temp + M(82, 120) * x(120)
      temp = temp + M(82, 121) * x(121)
      temp = temp + M(82, 123) * x(123)
      x(82) = x(82) - temp

      temp = M(81, 90) * x(90)
      temp = temp + M(81, 114) * x(114)
      temp = temp + M(81, 117) * x(117)
      temp = temp + M(81, 118) * x(118)
      temp = temp + M(81, 120) * x(120)
      temp = temp + M(81, 121) * x(121)
      temp = temp + M(81, 123) * x(123)
      x(81) = x(81) - temp

      temp = M(80, 90) * x(90)
      temp = temp + M(80, 114) * x(114)
      temp = temp + M(80, 117) * x(117)
      temp = temp + M(80, 118) * x(118)
      temp = temp + M(80, 120) * x(120)
      temp = temp + M(80, 121) * x(121)
      temp = temp + M(80, 123) * x(123)
      x(80) = x(80) - temp

      temp = M(79, 90) * x(90)
      temp = temp + M(79, 114) * x(114)
      temp = temp + M(79, 117) * x(117)
      temp = temp + M(79, 118) * x(118)
      temp = temp + M(79, 120) * x(120)
      temp = temp + M(79, 121) * x(121)
      temp = temp + M(79, 123) * x(123)
      x(79) = x(79) - temp

      temp = M(78, 114) * x(114)
      temp = temp + M(78, 117) * x(117)
      temp = temp + M(78, 118) * x(118)
      temp = temp + M(78, 120) * x(120)
      temp = temp + M(78, 121) * x(121)
      temp = temp + M(78, 123) * x(123)
      temp = temp + M(78, 124) * x(124)
      x(78) = x(78) - temp

      temp = M(77, 78) * x(78)
      temp = temp + M(77, 114) * x(114)
      temp = temp + M(77, 117) * x(117)
      temp = temp + M(77, 118) * x(118)
      temp = temp + M(77, 120) * x(120)
      temp = temp + M(77, 121) * x(121)
      x(77) = x(77) - temp

      temp = M(76, 80) * x(80)
      temp = temp + M(76, 90) * x(90)
      temp = temp + M(76, 105) * x(105)
      temp = temp + M(76, 114) * x(114)
      temp = temp + M(76, 117) * x(117)
      temp = temp + M(76, 118) * x(118)
      temp = temp + M(76, 120) * x(120)
      temp = temp + M(76, 121) * x(121)
      temp = temp + M(76, 124) * x(124)
      x(76) = x(76) - temp

      temp = M(75, 114) * x(114)
      temp = temp + M(75, 117) * x(117)
      temp = temp + M(75, 118) * x(118)
      temp = temp + M(75, 120) * x(120)
      temp = temp + M(75, 121) * x(121)
      temp = temp + M(75, 123) * x(123)
      x(75) = x(75) - temp

      temp = M(74, 90) * x(90)
      temp = temp + M(74, 114) * x(114)
      temp = temp + M(74, 117) * x(117)
      temp = temp + M(74, 118) * x(118)
      temp = temp + M(74, 120) * x(120)
      temp = temp + M(74, 121) * x(121)
      temp = temp + M(74, 123) * x(123)
      x(74) = x(74) - temp

      temp = M(73, 74) * x(74)
      temp = temp + M(73, 79) * x(79)
      temp = temp + M(73, 110) * x(110)
      temp = temp + M(73, 114) * x(114)
      temp = temp + M(73, 117) * x(117)
      temp = temp + M(73, 118) * x(118)
      temp = temp + M(73, 120) * x(120)
      temp = temp + M(73, 121) * x(121)
      temp = temp + M(73, 123) * x(123)
      x(73) = x(73) - temp

      temp = M(72, 114) * x(114)
      temp = temp + M(72, 117) * x(117)
      temp = temp + M(72, 118) * x(118)
      temp = temp + M(72, 120) * x(120)
      temp = temp + M(72, 121) * x(121)
      temp = temp + M(72, 123) * x(123)
      x(72) = x(72) - temp

      temp = M(71, 90) * x(90)
      temp = temp + M(71, 91) * x(91)
      temp = temp + M(71, 118) * x(118)
      temp = temp + M(71, 120) * x(120)
      temp = temp + M(71, 122) * x(122)
      temp = temp + M(71, 123) * x(123)
      x(71) = x(71) - temp

      temp = M(70, 90) * x(90)
      temp = temp + M(70, 114) * x(114)
      temp = temp + M(70, 117) * x(117)
      temp = temp + M(70, 118) * x(118)
      temp = temp + M(70, 120) * x(120)
      temp = temp + M(70, 121) * x(121)
      temp = temp + M(70, 123) * x(123)
      x(70) = x(70) - temp

      temp = M(69, 72) * x(72)
      temp = temp + M(69, 101) * x(101)
      temp = temp + M(69, 114) * x(114)
      temp = temp + M(69, 117) * x(117)
      temp = temp + M(69, 118) * x(118)
      temp = temp + M(69, 120) * x(120)
      temp = temp + M(69, 121) * x(121)
      temp = temp + M(69, 123) * x(123)
      x(69) = x(69) - temp

      temp = M(68, 72) * x(72)
      temp = temp + M(68, 114) * x(114)
      temp = temp + M(68, 117) * x(117)
      temp = temp + M(68, 118) * x(118)
      temp = temp + M(68, 120) * x(120)
      temp = temp + M(68, 121) * x(121)
      temp = temp + M(68, 123) * x(123)
      x(68) = x(68) - temp

      temp = M(67, 114) * x(114)
      temp = temp + M(67, 117) * x(117)
      temp = temp + M(67, 118) * x(118)
      temp = temp + M(67, 120) * x(120)
      temp = temp + M(67, 121) * x(121)
      x(67) = x(67) - temp

      temp = M(66, 89) * x(89)
      temp = temp + M(66, 90) * x(90)
      temp = temp + M(66, 114) * x(114)
      temp = temp + M(66, 117) * x(117)
      temp = temp + M(66, 118) * x(118)
      temp = temp + M(66, 120) * x(120)
      temp = temp + M(66, 121) * x(121)
      temp = temp + M(66, 123) * x(123)
      temp = temp + M(66, 124) * x(124)
      x(66) = x(66) - temp

      temp = M(65, 114) * x(114)
      temp = temp + M(65, 117) * x(117)
      temp = temp + M(65, 118) * x(118)
      temp = temp + M(65, 120) * x(120)
      temp = temp + M(65, 121) * x(121)
      temp = temp + M(65, 123) * x(123)
      x(65) = x(65) - temp

      temp = M(64, 114) * x(114)
      temp = temp + M(64, 117) * x(117)
      temp = temp + M(64, 118) * x(118)
      temp = temp + M(64, 120) * x(120)
      temp = temp + M(64, 121) * x(121)
      temp = temp + M(64, 123) * x(123)
      x(64) = x(64) - temp

      temp = M(63, 114) * x(114)
      temp = temp + M(63, 117) * x(117)
      temp = temp + M(63, 118) * x(118)
      temp = temp + M(63, 120) * x(120)
      temp = temp + M(63, 121) * x(121)
      x(63) = x(63) - temp

      temp = M(62, 64) * x(64)
      temp = temp + M(62, 114) * x(114)
      temp = temp + M(62, 117) * x(117)
      temp = temp + M(62, 118) * x(118)
      temp = temp + M(62, 120) * x(120)
      temp = temp + M(62, 121) * x(121)
      temp = temp + M(62, 123) * x(123)
      x(62) = x(62) - temp

      temp = M(61, 63) * x(63)
      temp = temp + M(61, 64) * x(64)
      temp = temp + M(61, 114) * x(114)
      temp = temp + M(61, 117) * x(117)
      temp = temp + M(61, 118) * x(118)
      temp = temp + M(61, 120) * x(120)
      temp = temp + M(61, 121) * x(121)
      temp = temp + M(61, 123) * x(123)
      temp = temp + M(61, 124) * x(124)
      x(61) = x(61) - temp

      temp = M(60, 63) * x(63)
      temp = temp + M(60, 64) * x(64)
      temp = temp + M(60, 114) * x(114)
      temp = temp + M(60, 117) * x(117)
      temp = temp + M(60, 118) * x(118)
      temp = temp + M(60, 120) * x(120)
      temp = temp + M(60, 121) * x(121)
      temp = temp + M(60, 123) * x(123)
      temp = temp + M(60, 124) * x(124)
      x(60) = x(60) - temp

      temp = M(59, 60) * x(60)
      temp = temp + M(59, 64) * x(64)
      temp = temp + M(59, 114) * x(114)
      temp = temp + M(59, 117) * x(117)
      temp = temp + M(59, 118) * x(118)
      temp = temp + M(59, 120) * x(120)
      temp = temp + M(59, 121) * x(121)
      temp = temp + M(59, 123) * x(123)
      x(59) = x(59) - temp

      temp = M(58, 60) * x(60)
      temp = temp + M(58, 64) * x(64)
      temp = temp + M(58, 114) * x(114)
      temp = temp + M(58, 117) * x(117)
      temp = temp + M(58, 118) * x(118)
      temp = temp + M(58, 120) * x(120)
      temp = temp + M(58, 121) * x(121)
      temp = temp + M(58, 123) * x(123)
      x(58) = x(58) - temp

      temp = M(57, 64) * x(64)
      temp = temp + M(57, 114) * x(114)
      temp = temp + M(57, 117) * x(117)
      temp = temp + M(57, 118) * x(118)
      temp = temp + M(57, 120) * x(120)
      temp = temp + M(57, 121) * x(121)
      temp = temp + M(57, 123) * x(123)
      x(57) = x(57) - temp

      temp = M(56, 114) * x(114)
      temp = temp + M(56, 117) * x(117)
      temp = temp + M(56, 118) * x(118)
      temp = temp + M(56, 120) * x(120)
      temp = temp + M(56, 121) * x(121)
      temp = temp + M(56, 123) * x(123)
      x(56) = x(56) - temp

      temp = M(55, 114) * x(114)
      temp = temp + M(55, 117) * x(117)
      temp = temp + M(55, 118) * x(118)
      temp = temp + M(55, 120) * x(120)
      temp = temp + M(55, 121) * x(121)
      x(55) = x(55) - temp

      temp = M(54, 114) * x(114)
      temp = temp + M(54, 117) * x(117)
      temp = temp + M(54, 118) * x(118)
      temp = temp + M(54, 120) * x(120)
      temp = temp + M(54, 121) * x(121)
      temp = temp + M(54, 123) * x(123)
      x(54) = x(54) - temp

      temp = M(53, 114) * x(114)
      temp = temp + M(53, 117) * x(117)
      temp = temp + M(53, 118) * x(118)
      temp = temp + M(53, 120) * x(120)
      temp = temp + M(53, 121) * x(121)
      x(53) = x(53) - temp

      temp = M(52, 54) * x(54)
      temp = temp + M(52, 114) * x(114)
      temp = temp + M(52, 117) * x(117)
      temp = temp + M(52, 118) * x(118)
      temp = temp + M(52, 120) * x(120)
      temp = temp + M(52, 121) * x(121)
      x(52) = x(52) - temp

      temp = M(51, 67) * x(67)
      temp = temp + M(51, 114) * x(114)
      temp = temp + M(51, 117) * x(117)
      temp = temp + M(51, 118) * x(118)
      temp = temp + M(51, 121) * x(121)
      temp = temp + M(51, 124) * x(124)
      x(51) = x(51) - temp

      temp = M(50, 67) * x(67)
      temp = temp + M(50, 114) * x(114)
      temp = temp + M(50, 117) * x(117)
      temp = temp + M(50, 118) * x(118)
      temp = temp + M(50, 121) * x(121)
      x(50) = x(50) - temp

      temp = M(49, 89) * x(89)
      temp = temp + M(49, 90) * x(90)
      temp = temp + M(49, 120) * x(120)
      temp = temp + M(49, 121) * x(121)
      temp = temp + M(49, 123) * x(123)
      x(49) = x(49) - temp

      temp = M(48, 90) * x(90)
      temp = temp + M(48, 117) * x(117)
      temp = temp + M(48, 120) * x(120)
      temp = temp + M(48, 121) * x(121)
      temp = temp + M(48, 124) * x(124)
      x(48) = x(48) - temp

      temp = M(47, 105) * x(105)
      temp = temp + M(47, 120) * x(120)
      temp = temp + M(47, 121) * x(121)
      temp = temp + M(47, 124) * x(124)
      x(47) = x(47) - temp

      temp = M(46, 80) * x(80)
      temp = temp + M(46, 90) * x(90)
      temp = temp + M(46, 117) * x(117)
      temp = temp + M(46, 120) * x(120)
      temp = temp + M(46, 121) * x(121)
      x(46) = x(46) - temp

      temp = M(45, 89) * x(89)
      temp = temp + M(45, 90) * x(90)
      temp = temp + M(45, 120) * x(120)
      temp = temp + M(45, 121) * x(121)
      x(45) = x(45) - temp

      temp = M(44, 90) * x(90)
      temp = temp + M(44, 120) * x(120)
      temp = temp + M(44, 121) * x(121)
      x(44) = x(44) - temp

      temp = M(43, 90) * x(90)
      temp = temp + M(43, 120) * x(120)
      temp = temp + M(43, 121) * x(121)
      x(43) = x(43) - temp

      temp = M(42, 120) * x(120)
      temp = temp + M(42, 123) * x(123)
      temp = temp + M(42, 124) * x(124)
      x(42) = x(42) - temp

      temp = M(41, 120) * x(120)
      temp = temp + M(41, 122) * x(122)
      temp = temp + M(41, 124) * x(124)
      x(41) = x(41) - temp

      temp = M(40, 118) * x(118)
      temp = temp + M(40, 120) * x(120)
      temp = temp + M(40, 124) * x(124)
      x(40) = x(40) - temp

      temp = M(39, 114) * x(114)
      temp = temp + M(39, 120) * x(120)
      temp = temp + M(39, 123) * x(123)
      x(39) = x(39) - temp

      temp = M(38, 89) * x(89)
      temp = temp + M(38, 90) * x(90)
      temp = temp + M(38, 120) * x(120)
      temp = temp + M(38, 121) * x(121)
      x(38) = x(38) - temp

      temp = M(37, 90) * x(90)
      temp = temp + M(37, 120) * x(120)
      temp = temp + M(37, 121) * x(121)
      x(37) = x(37) - temp

      temp = M(36, 72) * x(72)
      temp = temp + M(36, 117) * x(117)
      temp = temp + M(36, 120) * x(120)
      x(36) = x(36) - temp

      temp = M(35, 58) * x(58)
      temp = temp + M(35, 120) * x(120)
      temp = temp + M(35, 121) * x(121)
      x(35) = x(35) - temp

      temp = M(34, 105) * x(105)
      temp = temp + M(34, 120) * x(120)
      temp = temp + M(34, 123) * x(123)
      x(34) = x(34) - temp

      temp = M(33, 90) * x(90)
      temp = temp + M(33, 120) * x(120)
      temp = temp + M(33, 121) * x(121)
      x(33) = x(33) - temp

      temp = M(32, 90) * x(90)
      temp = temp + M(32, 120) * x(120)
      temp = temp + M(32, 121) * x(121)
      x(32) = x(32) - temp

      temp = M(31, 90) * x(90)
      temp = temp + M(31, 120) * x(120)
      temp = temp + M(31, 121) * x(121)
      x(31) = x(31) - temp

      temp = M(30, 90) * x(90)
      temp = temp + M(30, 120) * x(120)
      temp = temp + M(30, 121) * x(121)
      x(30) = x(30) - temp

      temp = M(29, 80) * x(80)
      temp = temp + M(29, 120) * x(120)
      temp = temp + M(29, 123) * x(123)
      x(29) = x(29) - temp

      temp = M(28, 85) * x(85)
      temp = temp + M(28, 114) * x(114)
      temp = temp + M(28, 120) * x(120)
      x(28) = x(28) - temp

      temp = M(27, 90) * x(90)
      temp = temp + M(27, 120) * x(120)
      temp = temp + M(27, 121) * x(121)
      x(27) = x(27) - temp

      temp = M(26, 90) * x(90)
      temp = temp + M(26, 120) * x(120)
      temp = temp + M(26, 121) * x(121)
      x(26) = x(26) - temp

      temp = M(25, 113) * x(113)
      temp = temp + M(25, 114) * x(114)
      temp = temp + M(25, 120) * x(120)
      x(25) = x(25) - temp

      temp = M(24, 90) * x(90)
      temp = temp + M(24, 120) * x(120)
      temp = temp + M(24, 121) * x(121)
      x(24) = x(24) - temp

      temp = M(23, 117) * x(117)
      temp = temp + M(23, 120) * x(120)
      temp = temp + M(23, 124) * x(124)
      x(23) = x(23) - temp

      temp = M(22, 90) * x(90)
      temp = temp + M(22, 120) * x(120)
      temp = temp + M(22, 121) * x(121)
      x(22) = x(22) - temp

      temp = M(21, 30) * x(30)
      temp = temp + M(21, 120) * x(120)
      x(21) = x(21) - temp

      temp = M(20, 30) * x(30)
      temp = temp + M(20, 120) * x(120)
      x(20) = x(20) - temp

      temp = M(19, 120) * x(120)
      temp = temp + M(19, 121) * x(121)
      x(19) = x(19) - temp

      temp = M(18, 46) * x(46)
      temp = temp + M(18, 120) * x(120)
      x(18) = x(18) - temp

      temp = M(17, 121) * x(121)
      temp = temp + M(17, 124) * x(124)
      x(17) = x(17) - temp

      temp = M(16, 120) * x(120)
      x(16) = x(16) - temp

      temp = M(15, 120) * x(120)
      x(15) = x(15) - temp

      temp = M(14, 120) * x(120)
      x(14) = x(14) - temp

      temp = M(13, 120) * x(120)
      x(13) = x(13) - temp

      temp = M(12, 120) * x(120)
      x(12) = x(12) - temp

      temp = M(11, 120) * x(120)
      x(11) = x(11) - temp

      temp = M(10, 120) * x(120)
      x(10) = x(10) - temp

      temp = M(9, 120) * x(120)
      x(9) = x(9) - temp

      temp = M(8, 120) * x(120)
      x(8) = x(8) - temp

      temp = M(7, 120) * x(120)
      x(7) = x(7) - temp

      temp = M(6, 120) * x(120)
      x(6) = x(6) - temp

      temp = M(5, 120) * x(120)
      x(5) = x(5) - temp

      temp = M(4, 120) * x(120)
      x(4) = x(4) - temp

      temp = M(3, 90) * x(90)
      x(3) = x(3) - temp


      END
