C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc(ns,nr,y,convers_factor,
     $                    convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05_SORGAM         
C     Species: _ciCB05_SORGAM      
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc(ns,nr,rk,conc,dw)
 
      JacC( 57, 65) = JacC( 57, 65) + dw(  1, 65)
      JacC( 64, 65) = JacC( 64, 65) + dw(  1, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw(  1, 65)
      JacC( 57, 57) = JacC( 57, 57) - dw(  2, 57)
      JacC( 59, 57) = JacC( 59, 57) + dw(  2, 57)
      JacC( 59, 59) = JacC( 59, 59) - dw(  3, 59)
      JacC( 59, 64) = JacC( 59, 64) - dw(  3, 64)
      JacC( 64, 59) = JacC( 64, 59) - dw(  3, 59)
      JacC( 64, 64) = JacC( 64, 64) - dw(  3, 64)
      JacC( 65, 59) = JacC( 65, 59) + dw(  3, 59)
      JacC( 65, 64) = JacC( 65, 64) + dw(  3, 64)
      JacC( 57, 57) = JacC( 57, 57) - dw(  4, 57)
      JacC( 57, 65) = JacC( 57, 65) - dw(  4, 65)
      JacC( 64, 57) = JacC( 64, 57) + dw(  4, 57)
      JacC( 64, 65) = JacC( 64, 65) + dw(  4, 65)
      JacC( 65, 57) = JacC( 65, 57) - dw(  4, 57)
      JacC( 65, 65) = JacC( 65, 65) - dw(  4, 65)
      JacC( 56, 57) = JacC( 56, 57) + dw(  5, 57)
      JacC( 56, 65) = JacC( 56, 65) + dw(  5, 65)
      JacC( 57, 57) = JacC( 57, 57) - dw(  5, 57)
      JacC( 57, 65) = JacC( 57, 65) - dw(  5, 65)
      JacC( 65, 57) = JacC( 65, 57) - dw(  5, 57)
      JacC( 65, 65) = JacC( 65, 65) - dw(  5, 65)
      JacC( 57, 57) = JacC( 57, 57) - dw(  6, 57)
      JacC( 57, 64) = JacC( 57, 64) - dw(  6, 64)
      JacC( 64, 57) = JacC( 64, 57) - dw(  6, 57)
      JacC( 64, 64) = JacC( 64, 64) - dw(  6, 64)
      JacC( 65, 57) = JacC( 65, 57) + dw(  6, 57)
      JacC( 65, 64) = JacC( 65, 64) + dw(  6, 64)
      JacC( 56, 65) = JacC( 56, 65) + dw(  7, 65)
      JacC( 56, 59) = JacC( 56, 59) + dw(  7, 59)
      JacC( 59, 65) = JacC( 59, 65) - dw(  7, 65)
      JacC( 59, 59) = JacC( 59, 59) - dw(  7, 59)
      JacC( 65, 65) = JacC( 65, 65) - dw(  7, 65)
      JacC( 65, 59) = JacC( 65, 59) - dw(  7, 59)
      JacC( 57, 59) = JacC( 57, 59) + dw(  8, 59)
      JacC( 59, 59) = JacC( 59, 59) - dw(  8, 59)
      JacC(  3, 59) = JacC(  3, 59) + dw(  9, 59)
      JacC( 59, 59) = JacC( 59, 59) - dw(  9, 59)
      JacC(  3,  3) = JacC(  3,  3) - dw( 10,  3)
      JacC( 57,  3) = JacC( 57,  3) + dw( 10,  3)
      JacC(  3,  3) = JacC(  3,  3) - dw( 11,  3)
      JacC( 55,  3) = JacC( 55,  3)+ 0.2000000000000000D+01*dw( 11,  3)
      JacC( 55, 59) = JacC( 55, 59) - dw( 12, 59)
      JacC( 55, 55) = JacC( 55, 55) - dw( 12, 55)
      JacC( 59, 59) = JacC( 59, 59) - dw( 12, 59)
      JacC( 59, 55) = JacC( 59, 55) - dw( 12, 55)
      JacC( 61, 59) = JacC( 61, 59) + dw( 12, 59)
      JacC( 61, 55) = JacC( 61, 55) + dw( 12, 55)
      JacC( 55, 59) = JacC( 55, 59) + dw( 13, 59)
      JacC( 55, 61) = JacC( 55, 61) + dw( 13, 61)
      JacC( 59, 59) = JacC( 59, 59) - dw( 13, 59)
      JacC( 59, 61) = JacC( 59, 61) - dw( 13, 61)
      JacC( 61, 59) = JacC( 61, 59) - dw( 13, 59)
      JacC( 61, 61) = JacC( 61, 61) - dw( 13, 61)
      JacC( 56, 56) = JacC( 56, 56) - dw( 14, 56)
      JacC( 57, 56) = JacC( 57, 56) + dw( 14, 56)
      JacC( 65, 56) = JacC( 65, 56) + dw( 14, 56)
      JacC( 56, 56) = JacC( 56, 56) - dw( 15, 56)
      JacC( 64, 56) = JacC( 64, 56) + dw( 15, 56)
      JacC( 56, 56) = JacC( 56, 56) - dw( 16, 56)
      JacC( 56, 64) = JacC( 56, 64) - dw( 16, 64)
      JacC( 64, 56) = JacC( 64, 56) - dw( 16, 56)
      JacC( 64, 64) = JacC( 64, 64) - dw( 16, 64)
      JacC( 65, 56) = JacC( 65, 56)+ 0.2000000000000000D+01*dw( 16, 56)
      JacC( 65, 64) = JacC( 65, 64)+ 0.2000000000000000D+01*dw( 16, 64)
      JacC( 56, 56) = JacC( 56, 56) - dw( 17, 56)
      JacC( 56, 65) = JacC( 56, 65) - dw( 17, 65)
      JacC( 64, 56) = JacC( 64, 56) + dw( 17, 56)
      JacC( 64, 65) = JacC( 64, 65) + dw( 17, 65)
      JacC( 16, 56) = JacC( 16, 56) + dw( 18, 56)
      JacC( 16, 65) = JacC( 16, 65) + dw( 18, 65)
      JacC( 56, 56) = JacC( 56, 56) - dw( 18, 56)
      JacC( 56, 65) = JacC( 56, 65) - dw( 18, 65)
      JacC( 65, 56) = JacC( 65, 56) - dw( 18, 56)
      JacC( 65, 65) = JacC( 65, 65) - dw( 18, 65)
      JacC( 16, 16) = JacC( 16, 16) - dw( 19, 16)
      JacC( 50, 16) = JacC( 50, 16)+ 0.2000000000000000D+01*dw( 19, 16)
      JacC( 16, 16) = JacC( 16, 16) - dw( 20, 16)
      JacC( 56, 16) = JacC( 56, 16) + dw( 20, 16)
      JacC( 65, 16) = JacC( 65, 16) + dw( 20, 16)
      JacC( 64, 64) = JacC( 64, 64)- 0.2000000000000000D+01*dw( 21, 64)
      JacC( 64, 64) = JacC( 64, 64)- 0.2000000000000000D+01*dw( 21, 64)
      JacC( 65, 64) = JacC( 65, 64)+ 0.2000000000000000D+01*dw( 21, 64)
      JacC( 65, 64) = JacC( 65, 64)+ 0.2000000000000000D+01*dw( 21, 64)
      JacC( 23, 64) = JacC( 23, 64)+ 0.2000000000000000D+01*dw( 22, 64)
      JacC( 23, 65) = JacC( 23, 65)+ 0.2000000000000000D+01*dw( 22, 65)
      JacC( 64, 64) = JacC( 64, 64) - dw( 22, 64)
      JacC( 64, 65) = JacC( 64, 65) - dw( 22, 65)
      JacC( 65, 64) = JacC( 65, 64) - dw( 22, 64)
      JacC( 65, 65) = JacC( 65, 65) - dw( 22, 65)
      JacC( 23, 55) = JacC( 23, 55) + dw( 23, 55)
      JacC( 23, 64) = JacC( 23, 64) + dw( 23, 64)
      JacC( 55, 55) = JacC( 55, 55) - dw( 23, 55)
      JacC( 55, 64) = JacC( 55, 64) - dw( 23, 64)
      JacC( 64, 55) = JacC( 64, 55) - dw( 23, 55)
      JacC( 64, 64) = JacC( 64, 64) - dw( 23, 64)
      JacC( 23, 23) = JacC( 23, 23) - dw( 24, 23)
      JacC( 55, 23) = JacC( 55, 23) + dw( 24, 23)
      JacC( 64, 23) = JacC( 64, 23) + dw( 24, 23)
      JacC( 23, 55) = JacC( 23, 55) - dw( 25, 55)
      JacC( 23, 23) = JacC( 23, 23) - dw( 25, 23)
      JacC( 55, 55) = JacC( 55, 55) - dw( 25, 55)
      JacC( 55, 23) = JacC( 55, 23) - dw( 25, 23)
      JacC( 65, 55) = JacC( 65, 55) + dw( 25, 55)
      JacC( 65, 23) = JacC( 65, 23) + dw( 25, 23)
      JacC( 23, 23) = JacC( 23, 23)- 0.2000000000000000D+01*dw( 26, 23)
      JacC( 23, 23) = JacC( 23, 23)- 0.2000000000000000D+01*dw( 26, 23)
      JacC( 64, 23) = JacC( 64, 23) + dw( 26, 23)
      JacC( 64, 23) = JacC( 64, 23) + dw( 26, 23)
      JacC( 65, 23) = JacC( 65, 23) + dw( 26, 23)
      JacC( 65, 23) = JacC( 65, 23) + dw( 26, 23)
      JacC( 50, 65) = JacC( 50, 65) + dw( 27, 65)
      JacC( 50, 55) = JacC( 50, 55) + dw( 27, 55)
      JacC( 55, 65) = JacC( 55, 65) - dw( 27, 65)
      JacC( 55, 55) = JacC( 55, 55) - dw( 27, 55)
      JacC( 65, 65) = JacC( 65, 65) - dw( 27, 65)
      JacC( 65, 55) = JacC( 65, 55) - dw( 27, 55)
      JacC( 50, 55) = JacC( 50, 55) - dw( 28, 55)
      JacC( 50, 50) = JacC( 50, 50) - dw( 28, 50)
      JacC( 55, 55) = JacC( 55, 55) - dw( 28, 55)
      JacC( 55, 50) = JacC( 55, 50) - dw( 28, 50)
      JacC( 56, 55) = JacC( 56, 55) + dw( 28, 55)
      JacC( 56, 50) = JacC( 56, 50) + dw( 28, 50)
      JacC( 55, 61) = JacC( 55, 61) + dw( 29, 61)
      JacC( 55, 64) = JacC( 55, 64) + dw( 29, 64)
      JacC( 61, 61) = JacC( 61, 61) - dw( 29, 61)
      JacC( 61, 64) = JacC( 61, 64) - dw( 29, 64)
      JacC( 64, 61) = JacC( 64, 61) - dw( 29, 61)
      JacC( 64, 64) = JacC( 64, 64) - dw( 29, 64)
      JacC( 65, 61) = JacC( 65, 61) + dw( 29, 61)
      JacC( 65, 64) = JacC( 65, 64) + dw( 29, 64)
      JacC( 17, 61) = JacC( 17, 61) + dw( 30, 61)
      JacC( 17, 65) = JacC( 17, 65) + dw( 30, 65)
      JacC( 61, 61) = JacC( 61, 61) - dw( 30, 61)
      JacC( 61, 65) = JacC( 61, 65) - dw( 30, 65)
      JacC( 65, 61) = JacC( 65, 61) - dw( 30, 61)
      JacC( 65, 65) = JacC( 65, 65) - dw( 30, 65)
      JacC( 17, 17) = JacC( 17, 17) - dw( 31, 17)
      JacC( 61, 17) = JacC( 61, 17) + dw( 31, 17)
      JacC( 65, 17) = JacC( 65, 17) + dw( 31, 17)
      JacC( 17, 55) = JacC( 17, 55) - dw( 32, 55)
      JacC( 17, 17) = JacC( 17, 17) - dw( 32, 17)
      JacC( 55, 55) = JacC( 55, 55) - dw( 32, 55)
      JacC( 55, 17) = JacC( 55, 17) - dw( 32, 17)
      JacC( 65, 55) = JacC( 65, 55) + dw( 32, 55)
      JacC( 65, 17) = JacC( 65, 17) + dw( 32, 17)
      JacC( 20, 61) = JacC( 20, 61) + dw( 33, 61)
      JacC( 20, 61) = JacC( 20, 61) + dw( 33, 61)
      JacC( 61, 61) = JacC( 61, 61)- 0.2000000000000000D+01*dw( 33, 61)
      JacC( 61, 61) = JacC( 61, 61)- 0.2000000000000000D+01*dw( 33, 61)
      JacC( 20, 61) = JacC( 20, 61) + dw( 34, 61)
      JacC( 20, 61) = JacC( 20, 61) + dw( 34, 61)
      JacC( 61, 61) = JacC( 61, 61)- 0.2000000000000000D+01*dw( 34, 61)
      JacC( 61, 61) = JacC( 61, 61)- 0.2000000000000000D+01*dw( 34, 61)
      JacC( 20, 20) = JacC( 20, 20) - dw( 35, 20)
      JacC( 55, 20) = JacC( 55, 20)+ 0.2000000000000000D+01*dw( 35, 20)
      JacC( 20, 55) = JacC( 20, 55) - dw( 36, 55)
      JacC( 20, 20) = JacC( 20, 20) - dw( 36, 20)
      JacC( 55, 55) = JacC( 55, 55) - dw( 36, 55)
      JacC( 55, 20) = JacC( 55, 20) - dw( 36, 20)
      JacC( 61, 55) = JacC( 61, 55) + dw( 36, 55)
      JacC( 61, 20) = JacC( 61, 20) + dw( 36, 20)
      JacC(  3,  3) = JacC(  3,  3) - dw( 37,  3)
      JacC( 55,  3) = JacC( 55,  3) + dw( 37,  3)
      JacC( 61,  3) = JacC( 61,  3) + dw( 37,  3)
      JacC( 55, 55) = JacC( 55, 55) - dw( 38, 55)
      JacC( 61, 55) = JacC( 61, 55) + dw( 38, 55)
      JacC( 55, 55) = JacC( 55, 55) - dw( 39, 55)
      JacC( 55, 57) = JacC( 55, 57) - dw( 39, 57)
      JacC( 57, 55) = JacC( 57, 55) - dw( 39, 55)
      JacC( 57, 57) = JacC( 57, 57) - dw( 39, 57)
      JacC( 61, 55) = JacC( 61, 55) + dw( 39, 55)
      JacC( 61, 57) = JacC( 61, 57) + dw( 39, 57)
      JacC( 55, 55) = JacC( 55, 55)- 0.2000000000000000D+01*dw( 40, 55)
      JacC( 55, 55) = JacC( 55, 55)- 0.2000000000000000D+01*dw( 40, 55)
      JacC( 57, 55) = JacC( 57, 55) + dw( 40, 55)
      JacC( 57, 55) = JacC( 57, 55) + dw( 40, 55)
      JacC( 20, 55) = JacC( 20, 55) + dw( 41, 55)
      JacC( 20, 55) = JacC( 20, 55) + dw( 41, 55)
      JacC( 55, 55) = JacC( 55, 55)- 0.2000000000000000D+01*dw( 41, 55)
      JacC( 55, 55) = JacC( 55, 55)- 0.2000000000000000D+01*dw( 41, 55)
      JacC( 55, 55) = JacC( 55, 55) - dw( 42, 55)
      JacC( 55, 61) = JacC( 55, 61) - dw( 42, 61)
      JacC( 61, 55) = JacC( 61, 55) - dw( 42, 55)
      JacC( 61, 61) = JacC( 61, 61) - dw( 42, 61)
      JacC( 55, 61) = JacC( 55, 61) + dw( 43, 61)
      JacC( 55, 57) = JacC( 55, 57) + dw( 43, 57)
      JacC( 57, 61) = JacC( 57, 61) - dw( 43, 61)
      JacC( 57, 57) = JacC( 57, 57) - dw( 43, 57)
      JacC( 61, 61) = JacC( 61, 61) - dw( 43, 61)
      JacC( 61, 57) = JacC( 61, 57) - dw( 43, 57)
      JacC( 20, 20) = JacC( 20, 20) - dw( 44, 20)
      JacC( 20, 57) = JacC( 20, 57) - dw( 44, 57)
      JacC( 55, 20) = JacC( 55, 20) + dw( 44, 20)
      JacC( 55, 57) = JacC( 55, 57) + dw( 44, 57)
      JacC( 57, 20) = JacC( 57, 20) - dw( 44, 20)
      JacC( 57, 57) = JacC( 57, 57) - dw( 44, 57)
      JacC( 61, 20) = JacC( 61, 20) + dw( 44, 20)
      JacC( 61, 57) = JacC( 61, 57) + dw( 44, 57)
      JacC( 56, 56) = JacC( 56, 56) - dw( 45, 56)
      JacC( 56, 57) = JacC( 56, 57) - dw( 45, 57)
      JacC( 57, 56) = JacC( 57, 56) - dw( 45, 56)
      JacC( 57, 57) = JacC( 57, 57) - dw( 45, 57)
      JacC( 65, 56) = JacC( 65, 56) + dw( 45, 56)
      JacC( 65, 57) = JacC( 65, 57) + dw( 45, 57)
      JacC( 55, 56) = JacC( 55, 56) - dw( 46, 56)
      JacC( 55, 55) = JacC( 55, 55) - dw( 46, 55)
      JacC( 56, 56) = JacC( 56, 56) - dw( 46, 56)
      JacC( 56, 55) = JacC( 56, 55) - dw( 46, 55)
      JacC( 61, 56) = JacC( 61, 56) + dw( 46, 56)
      JacC( 61, 55) = JacC( 61, 55) + dw( 46, 55)
      JacC( 65, 56) = JacC( 65, 56) + dw( 46, 56)
      JacC( 65, 55) = JacC( 65, 55) + dw( 46, 55)
      JacC( 50, 56) = JacC( 50, 56) + dw( 47, 56)
      JacC( 50, 61) = JacC( 50, 61) + dw( 47, 61)
      JacC( 56, 56) = JacC( 56, 56) - dw( 47, 56)
      JacC( 56, 61) = JacC( 56, 61) - dw( 47, 61)
      JacC( 61, 56) = JacC( 61, 56) - dw( 47, 56)
      JacC( 61, 61) = JacC( 61, 61) - dw( 47, 61)
      JacC( 56, 56) = JacC( 56, 56) - dw( 48, 56)
      JacC( 56, 59) = JacC( 56, 59) - dw( 48, 59)
      JacC( 59, 56) = JacC( 59, 56) - dw( 48, 56)
      JacC( 59, 59) = JacC( 59, 59) - dw( 48, 59)
      JacC( 65, 56) = JacC( 65, 56) + dw( 48, 56)
      JacC( 65, 59) = JacC( 65, 59) + dw( 48, 59)
      JacC( 56, 56) = JacC( 56, 56)- 0.2000000000000000D+01*dw( 49, 56)
      JacC( 56, 56) = JacC( 56, 56)- 0.2000000000000000D+01*dw( 49, 56)
      JacC( 65, 56) = JacC( 65, 56)+ 0.2000000000000000D+01*dw( 49, 56)
      JacC( 65, 56) = JacC( 65, 56)+ 0.2000000000000000D+01*dw( 49, 56)
      JacC( 17, 17) = JacC( 17, 17) - dw( 50, 17)
      JacC( 55, 17) = JacC( 55, 17)+ 0.3900000000000000D+00*dw( 50, 17)
      JacC( 56, 17) = JacC( 56, 17)+ 0.3900000000000000D+00*dw( 50, 17)
      JacC( 61, 17) = JacC( 61, 17)+ 0.6100000000000000D+00*dw( 50, 17)
      JacC( 65, 17) = JacC( 65, 17)+ 0.6100000000000000D+00*dw( 50, 17)
      JacC( 50, 50) = JacC( 50, 50) - dw( 51, 50)
      JacC( 55, 50) = JacC( 55, 50) + dw( 51, 50)
      JacC( 65, 50) = JacC( 65, 50) + dw( 51, 50)
      JacC( 16, 16) = JacC( 16, 16) - dw( 52, 16)
      JacC( 56, 16) = JacC( 56, 16) + dw( 52, 16)
      JacC( 65, 16) = JacC( 65, 16) + dw( 52, 16)
      JacC( 63, 63) = JacC( 63, 63) - dw( 53, 63)
      JacC( 63, 64) = JacC( 63, 64) - dw( 53, 64)
      JacC( 64, 63) = JacC( 64, 63) - dw( 53, 63)
      JacC( 64, 64) = JacC( 64, 64) - dw( 53, 64)
      JacC( 65, 63) = JacC( 65, 63) + dw( 53, 63)
      JacC( 65, 64) = JacC( 65, 64) + dw( 53, 64)
      JacC( 46, 52) = JacC( 46, 52) + dw( 54, 52)
      JacC( 46, 64) = JacC( 46, 64) + dw( 54, 64)
      JacC( 52, 52) = JacC( 52, 52) - dw( 54, 52)
      JacC( 52, 64) = JacC( 52, 64) - dw( 54, 64)
      JacC( 64, 52) = JacC( 64, 52) - dw( 54, 52)
      JacC( 64, 64) = JacC( 64, 64) - dw( 54, 64)
      JacC( 32, 63) = JacC( 32, 63) + dw( 55, 63)
      JacC( 32, 61) = JacC( 32, 61) + dw( 55, 61)
      JacC( 61, 63) = JacC( 61, 63) - dw( 55, 63)
      JacC( 61, 61) = JacC( 61, 61) - dw( 55, 61)
      JacC( 63, 63) = JacC( 63, 63) - dw( 55, 63)
      JacC( 63, 61) = JacC( 63, 61) - dw( 55, 61)
      JacC( 32, 52) = JacC( 32, 52) + dw( 56, 52)
      JacC( 32, 61) = JacC( 32, 61) + dw( 56, 61)
      JacC( 52, 52) = JacC( 52, 52) - dw( 56, 52)
      JacC( 52, 61) = JacC( 52, 61) - dw( 56, 61)
      JacC( 61, 52) = JacC( 61, 52) - dw( 56, 52)
      JacC( 61, 61) = JacC( 61, 61) - dw( 56, 61)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw( 57, 63)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw( 57, 63)
      JacC( 52, 52) = JacC( 52, 52)- 0.2000000000000000D+01*dw( 58, 52)
      JacC( 52, 52) = JacC( 52, 52)- 0.2000000000000000D+01*dw( 58, 52)
      JacC( 52, 63) = JacC( 52, 63) - dw( 59, 63)
      JacC( 52, 52) = JacC( 52, 52) - dw( 59, 52)
      JacC( 63, 63) = JacC( 63, 63) - dw( 59, 63)
      JacC( 63, 52) = JacC( 63, 52) - dw( 59, 52)
      JacC( 46, 46) = JacC( 46, 46) - dw( 60, 46)
      JacC( 46, 55) = JacC( 46, 55) - dw( 60, 55)
      JacC( 47, 46) = JacC( 47, 46)+ 0.6600000000000000D+00*dw( 60, 46)
      JacC( 47, 55) = JacC( 47, 55)+ 0.6600000000000000D+00*dw( 60, 55)
      JacC( 48, 46) = JacC( 48, 46)+ 0.3300000000000000D+00*dw( 60, 46)
      JacC( 48, 55) = JacC( 48, 55)+ 0.3300000000000000D+00*dw( 60, 55)
      JacC( 50, 46) = JacC( 50, 46) + dw( 60, 46)
      JacC( 50, 55) = JacC( 50, 55) + dw( 60, 55)
      JacC( 54, 46) = JacC( 54, 46)+ 0.3300000000000000D+00*dw( 60, 46)
      JacC( 54, 55) = JacC( 54, 55)+ 0.3300000000000000D+00*dw( 60, 55)
      JacC( 55, 46) = JacC( 55, 46) - dw( 60, 46)
      JacC( 55, 55) = JacC( 55, 55) - dw( 60, 55)
      JacC( 60, 46) = JacC( 60, 46)+ 0.3300000000000000D+00*dw( 60, 46)
      JacC( 60, 55) = JacC( 60, 55)+ 0.3300000000000000D+00*dw( 60, 55)
      JacC( 61, 46) = JacC( 61, 46) + dw( 60, 46)
      JacC( 61, 55) = JacC( 61, 55) + dw( 60, 55)
      JacC( 46, 46) = JacC( 46, 46) - dw( 61, 46)
      JacC( 47, 46) = JacC( 47, 46)+ 0.6600000000000000D+00*dw( 61, 46)
      JacC( 48, 46) = JacC( 48, 46)+ 0.3300000000000000D+00*dw( 61, 46)
      JacC( 54, 46) = JacC( 54, 46)+ 0.3300000000000000D+00*dw( 61, 46)
      JacC( 60, 46) = JacC( 60, 46)+ 0.3300000000000000D+00*dw( 61, 46)
      JacC( 61, 46) = JacC( 61, 46) + dw( 61, 46)
      JacC( 65, 46) = JacC( 65, 46) + dw( 61, 46)
      JacC( 32, 32) = JacC( 32, 32) - dw( 62, 32)
      JacC( 32, 55) = JacC( 32, 55) - dw( 62, 55)
      JacC( 48, 32) = JacC( 48, 32)+ 0.5000000000000000D+00*dw( 62, 32)
      JacC( 48, 55) = JacC( 48, 55)+ 0.5000000000000000D+00*dw( 62, 55)
      JacC( 55, 32) = JacC( 55, 32) - dw( 62, 32)
      JacC( 55, 55) = JacC( 55, 55) - dw( 62, 55)
      JacC( 60, 32) = JacC( 60, 32)+ 0.5000000000000000D+00*dw( 62, 32)
      JacC( 60, 55) = JacC( 60, 55)+ 0.5000000000000000D+00*dw( 62, 55)
      JacC( 63, 32) = JacC( 63, 32) + dw( 62, 32)
      JacC( 63, 55) = JacC( 63, 55) + dw( 62, 55)
      JacC( 32, 32) = JacC( 32, 32) - dw( 63, 32)
      JacC( 48, 32) = JacC( 48, 32)+ 0.5000000000000000D+00*dw( 63, 32)
      JacC( 55, 32) = JacC( 55, 32) + dw( 63, 32)
      JacC( 60, 32) = JacC( 60, 32)+ 0.5000000000000000D+00*dw( 63, 32)
      JacC( 61, 32) = JacC( 61, 32) + dw( 63, 32)
      JacC( 51, 55) = JacC( 51, 55) - dw( 64, 55)
      JacC( 51, 51) = JacC( 51, 51) - dw( 64, 51)
      JacC( 55, 55) = JacC( 55, 55) - dw( 64, 55)
      JacC( 55, 51) = JacC( 55, 51) - dw( 64, 51)
      JacC( 61, 55) = JacC( 61, 55) + dw( 64, 55)
      JacC( 61, 51) = JacC( 61, 51) + dw( 64, 51)
      JacC(  5, 55) = JacC(  5, 55) - dw( 65, 55)
      JacC(  5,  5) = JacC(  5,  5) - dw( 65,  5)
      JacC( 53, 55) = JacC( 53, 55) + dw( 65, 55)
      JacC( 53,  5) = JacC( 53,  5) + dw( 65,  5)
      JacC( 55, 55) = JacC( 55, 55) - dw( 65, 55)
      JacC( 55,  5) = JacC( 55,  5) - dw( 65,  5)
      JacC( 53, 53) = JacC( 53, 53) - dw( 66, 53)
      JacC( 53, 64) = JacC( 53, 64) - dw( 66, 64)
      JacC( 54, 53) = JacC( 54, 53) + dw( 66, 53)
      JacC( 54, 64) = JacC( 54, 64) + dw( 66, 64)
      JacC( 61, 53) = JacC( 61, 53) + dw( 66, 53)
      JacC( 61, 64) = JacC( 61, 64) + dw( 66, 64)
      JacC( 64, 53) = JacC( 64, 53) - dw( 66, 53)
      JacC( 64, 64) = JacC( 64, 64) - dw( 66, 64)
      JacC( 65, 53) = JacC( 65, 53) + dw( 66, 53)
      JacC( 65, 64) = JacC( 65, 64) + dw( 66, 64)
      JacC( 22, 53) = JacC( 22, 53) + dw( 67, 53)
      JacC( 22, 61) = JacC( 22, 61) + dw( 67, 61)
      JacC( 53, 53) = JacC( 53, 53) - dw( 67, 53)
      JacC( 53, 61) = JacC( 53, 61) - dw( 67, 61)
      JacC( 61, 53) = JacC( 61, 53) - dw( 67, 53)
      JacC( 61, 61) = JacC( 61, 61) - dw( 67, 61)
      JacC( 14, 53) = JacC( 14, 53)+ 0.6300000000000000D+00*dw( 68, 53)
      JacC( 14, 53) = JacC( 14, 53)+ 0.6300000000000000D+00*dw( 68, 53)
      JacC( 53, 53) = JacC( 53, 53)- 0.2000000000000000D+01*dw( 68, 53)
      JacC( 53, 53) = JacC( 53, 53)- 0.2000000000000000D+01*dw( 68, 53)
      JacC( 54, 53) = JacC( 54, 53)+ 0.1370000000000000D+01*dw( 68, 53)
      JacC( 54, 53) = JacC( 54, 53)+ 0.1370000000000000D+01*dw( 68, 53)
      JacC( 61, 53) = JacC( 61, 53)+ 0.7400000000000000D+00*dw( 68, 53)
      JacC( 61, 53) = JacC( 61, 53)+ 0.7400000000000000D+00*dw( 68, 53)
      JacC( 22, 22) = JacC( 22, 22) - dw( 69, 22)
      JacC( 22, 55) = JacC( 22, 55) - dw( 69, 55)
      JacC( 53, 22) = JacC( 53, 22)+ 0.7000000000000000D+00*dw( 69, 22)
      JacC( 53, 55) = JacC( 53, 55)+ 0.7000000000000000D+00*dw( 69, 55)
      JacC( 55, 22) = JacC( 55, 22) - dw( 69, 22)
      JacC( 55, 55) = JacC( 55, 55) - dw( 69, 55)
      JacC( 61, 22) = JacC( 61, 22)+ 0.3000000000000000D-01*dw( 69, 22)
      JacC( 61, 55) = JacC( 61, 55)+ 0.3000000000000000D-01*dw( 69, 55)
      JacC( 63, 22) = JacC( 63, 22)+ 0.3000000000000000D+00*dw( 69, 22)
      JacC( 63, 55) = JacC( 63, 55)+ 0.3000000000000000D+00*dw( 69, 55)
      JacC( 22, 22) = JacC( 22, 22) - dw( 70, 22)
      JacC( 54, 22) = JacC( 54, 22) + dw( 70, 22)
      JacC( 55, 22) = JacC( 55, 22) + dw( 70, 22)
      JacC( 61, 22) = JacC( 61, 22) + dw( 70, 22)
      JacC( 14, 14) = JacC( 14, 14) - dw( 71, 14)
      JacC( 14, 55) = JacC( 14, 55) - dw( 71, 55)
      JacC( 54, 14) = JacC( 54, 14) + dw( 71, 14)
      JacC( 54, 55) = JacC( 54, 55) + dw( 71, 55)
      JacC( 55, 14) = JacC( 55, 14) - dw( 71, 14)
      JacC( 55, 55) = JacC( 55, 55) - dw( 71, 55)
      JacC( 61, 14) = JacC( 61, 14) + dw( 71, 14)
      JacC( 61, 55) = JacC( 61, 55) + dw( 71, 55)
      JacC( 51, 54) = JacC( 51, 54) + dw( 72, 54)
      JacC( 51, 55) = JacC( 51, 55) + dw( 72, 55)
      JacC( 54, 54) = JacC( 54, 54) - dw( 72, 54)
      JacC( 54, 55) = JacC( 54, 55) - dw( 72, 55)
      JacC( 55, 54) = JacC( 55, 54) - dw( 72, 54)
      JacC( 55, 55) = JacC( 55, 55) - dw( 72, 55)
      JacC( 61, 54) = JacC( 61, 54) + dw( 72, 54)
      JacC( 61, 55) = JacC( 61, 55) + dw( 72, 55)
      JacC( 51, 54) = JacC( 51, 54) + dw( 73, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 73, 54)
      JacC( 61, 54) = JacC( 61, 54)+ 0.2000000000000000D+01*dw( 73, 54)
      JacC( 51, 54) = JacC( 51, 54) + dw( 74, 54)
      JacC( 54, 54) = JacC( 54, 54) - dw( 74, 54)
      JacC( 51, 54) = JacC( 51, 54) + dw( 75, 54)
      JacC( 51, 57) = JacC( 51, 57) + dw( 75, 57)
      JacC( 54, 54) = JacC( 54, 54) - dw( 75, 54)
      JacC( 54, 57) = JacC( 54, 57) - dw( 75, 57)
      JacC( 55, 54) = JacC( 55, 54) + dw( 75, 54)
      JacC( 55, 57) = JacC( 55, 57) + dw( 75, 57)
      JacC( 57, 54) = JacC( 57, 54) - dw( 75, 54)
      JacC( 57, 57) = JacC( 57, 57) - dw( 75, 57)
      JacC( 61, 54) = JacC( 61, 54) + dw( 75, 54)
      JacC( 61, 57) = JacC( 61, 57) + dw( 75, 57)
      JacC( 50, 54) = JacC( 50, 54) + dw( 76, 54)
      JacC( 50, 56) = JacC( 50, 56) + dw( 76, 56)
      JacC( 51, 54) = JacC( 51, 54) + dw( 76, 54)
      JacC( 51, 56) = JacC( 51, 56) + dw( 76, 56)
      JacC( 54, 54) = JacC( 54, 54) - dw( 76, 54)
      JacC( 54, 56) = JacC( 54, 56) - dw( 76, 56)
      JacC( 56, 54) = JacC( 56, 54) - dw( 76, 54)
      JacC( 56, 56) = JacC( 56, 56) - dw( 76, 56)
      JacC( 61, 54) = JacC( 61, 54) + dw( 76, 54)
      JacC( 61, 56) = JacC( 61, 56) + dw( 76, 56)
      JacC( 21, 54) = JacC( 21, 54) + dw( 77, 54)
      JacC( 21, 61) = JacC( 21, 61) + dw( 77, 61)
      JacC( 54, 54) = JacC( 54, 54) - dw( 77, 54)
      JacC( 54, 61) = JacC( 54, 61) - dw( 77, 61)
      JacC( 61, 54) = JacC( 61, 54) - dw( 77, 54)
      JacC( 61, 61) = JacC( 61, 61) - dw( 77, 61)
      JacC( 21, 21) = JacC( 21, 21) - dw( 78, 21)
      JacC( 54, 21) = JacC( 54, 21) + dw( 78, 21)
      JacC( 61, 21) = JacC( 61, 21) + dw( 78, 21)
      JacC( 21, 21) = JacC( 21, 21) - dw( 79, 21)
      JacC( 21, 64) = JacC( 21, 64) - dw( 79, 64)
      JacC( 35, 21) = JacC( 35, 21) + dw( 79, 21)
      JacC( 35, 64) = JacC( 35, 64) + dw( 79, 64)
      JacC( 61, 21) = JacC( 61, 21) + dw( 79, 21)
      JacC( 61, 64) = JacC( 61, 64) + dw( 79, 64)
      JacC( 64, 21) = JacC( 64, 21) - dw( 79, 21)
      JacC( 64, 64) = JacC( 64, 64) - dw( 79, 64)
      JacC( 65, 21) = JacC( 65, 21) + dw( 79, 21)
      JacC( 65, 64) = JacC( 65, 64) + dw( 79, 64)
      JacC( 21, 21) = JacC( 21, 21) - dw( 80, 21)
      JacC( 21, 61) = JacC( 21, 61) - dw( 80, 61)
      JacC( 22, 21) = JacC( 22, 21) + dw( 80, 21)
      JacC( 22, 61) = JacC( 22, 61) + dw( 80, 61)
      JacC( 61, 21) = JacC( 61, 21) - dw( 80, 21)
      JacC( 61, 61) = JacC( 61, 61) - dw( 80, 61)
      JacC( 35, 35) = JacC( 35, 35) - dw( 81, 35)
      JacC( 35, 55) = JacC( 35, 55) - dw( 81, 55)
      JacC( 55, 35) = JacC( 55, 35) - dw( 81, 35)
      JacC( 55, 55) = JacC( 55, 55) - dw( 81, 55)
      JacC( 61, 35) = JacC( 61, 35) + dw( 81, 35)
      JacC( 61, 55) = JacC( 61, 55) + dw( 81, 55)
      JacC( 55, 60) = JacC( 55, 60) + dw( 82, 60)
      JacC( 55, 57) = JacC( 55, 57) + dw( 82, 57)
      JacC( 57, 60) = JacC( 57, 60) - dw( 82, 60)
      JacC( 57, 57) = JacC( 57, 57) - dw( 82, 57)
      JacC( 60, 60) = JacC( 60, 60) - dw( 82, 60)
      JacC( 60, 57) = JacC( 60, 57) - dw( 82, 57)
      JacC( 62, 60) = JacC( 62, 60) + dw( 82, 60)
      JacC( 62, 57) = JacC( 62, 57) + dw( 82, 57)
      JacC( 55, 60) = JacC( 55, 60) - dw( 83, 60)
      JacC( 55, 55) = JacC( 55, 55) - dw( 83, 55)
      JacC( 60, 60) = JacC( 60, 60) - dw( 83, 60)
      JacC( 60, 55) = JacC( 60, 55) - dw( 83, 55)
      JacC( 62, 60) = JacC( 62, 60) + dw( 83, 60)
      JacC( 62, 55) = JacC( 62, 55) + dw( 83, 55)
      JacC( 50, 60) = JacC( 50, 60) + dw( 84, 60)
      JacC( 50, 56) = JacC( 50, 56) + dw( 84, 56)
      JacC( 56, 60) = JacC( 56, 60) - dw( 84, 60)
      JacC( 56, 56) = JacC( 56, 56) - dw( 84, 56)
      JacC( 60, 60) = JacC( 60, 60) - dw( 84, 60)
      JacC( 60, 56) = JacC( 60, 56) - dw( 84, 56)
      JacC( 62, 60) = JacC( 62, 60) + dw( 84, 60)
      JacC( 62, 56) = JacC( 62, 56) + dw( 84, 56)
      JacC( 51, 60) = JacC( 51, 60) + dw( 85, 60)
      JacC( 53, 60) = JacC( 53, 60) + dw( 85, 60)
      JacC( 60, 60) = JacC( 60, 60) - dw( 85, 60)
      JacC( 61, 60) = JacC( 61, 60) + dw( 85, 60)
      JacC( 53, 62) = JacC( 53, 62) + dw( 86, 62)
      JacC( 53, 64) = JacC( 53, 64) + dw( 86, 64)
      JacC( 62, 62) = JacC( 62, 62) - dw( 86, 62)
      JacC( 62, 64) = JacC( 62, 64) - dw( 86, 64)
      JacC( 64, 62) = JacC( 64, 62) - dw( 86, 62)
      JacC( 64, 64) = JacC( 64, 64) - dw( 86, 64)
      JacC( 65, 62) = JacC( 65, 62) + dw( 86, 62)
      JacC( 65, 64) = JacC( 65, 64) + dw( 86, 64)
      JacC( 13, 62) = JacC( 13, 62) + dw( 87, 62)
      JacC( 13, 65) = JacC( 13, 65) + dw( 87, 65)
      JacC( 62, 62) = JacC( 62, 62) - dw( 87, 62)
      JacC( 62, 65) = JacC( 62, 65) - dw( 87, 65)
      JacC( 65, 62) = JacC( 65, 62) - dw( 87, 62)
      JacC( 65, 65) = JacC( 65, 65) - dw( 87, 65)
      JacC( 13, 13) = JacC( 13, 13) - dw( 88, 13)
      JacC( 62, 13) = JacC( 62, 13) + dw( 88, 13)
      JacC( 65, 13) = JacC( 65, 13) + dw( 88, 13)
      JacC( 13, 13) = JacC( 13, 13) - dw( 89, 13)
      JacC( 62, 13) = JacC( 62, 13) + dw( 89, 13)
      JacC( 65, 13) = JacC( 65, 13) + dw( 89, 13)
      JacC( 33, 62) = JacC( 33, 62)+ 0.8000000000000000D+00*dw( 90, 62)
      JacC( 33, 61) = JacC( 33, 61)+ 0.8000000000000000D+00*dw( 90, 61)
      JacC( 49, 62) = JacC( 49, 62)+ 0.2000000000000000D+00*dw( 90, 62)
      JacC( 49, 61) = JacC( 49, 61)+ 0.2000000000000000D+00*dw( 90, 61)
      JacC( 59, 62) = JacC( 59, 62)+ 0.2000000000000000D+00*dw( 90, 62)
      JacC( 59, 61) = JacC( 59, 61)+ 0.2000000000000000D+00*dw( 90, 61)
      JacC( 61, 62) = JacC( 61, 62) - dw( 90, 62)
      JacC( 61, 61) = JacC( 61, 61) - dw( 90, 61)
      JacC( 62, 62) = JacC( 62, 62) - dw( 90, 62)
      JacC( 62, 61) = JacC( 62, 61) - dw( 90, 61)
      JacC( 49, 62) = JacC( 49, 62)+ 0.1000000000000000D+00*dw( 91, 62)
      JacC( 49, 53) = JacC( 49, 53)+ 0.1000000000000000D+00*dw( 91, 53)
      JacC( 53, 62) = JacC( 53, 62)- 0.9999999999999998D-01*dw( 91, 62)
      JacC( 53, 53) = JacC( 53, 53)- 0.9999999999999998D-01*dw( 91, 53)
      JacC( 54, 62) = JacC( 54, 62) + dw( 91, 62)
      JacC( 54, 53) = JacC( 54, 53) + dw( 91, 53)
      JacC( 61, 62) = JacC( 61, 62)+ 0.9000000000000000D+00*dw( 91, 62)
      JacC( 61, 53) = JacC( 61, 53)+ 0.9000000000000000D+00*dw( 91, 53)
      JacC( 62, 62) = JacC( 62, 62) - dw( 91, 62)
      JacC( 62, 53) = JacC( 62, 53) - dw( 91, 53)
      JacC( 49, 62) = JacC( 49, 62)+ 0.1000000000000000D+00*dw( 92, 62)
      JacC( 49, 63) = JacC( 49, 63)+ 0.1000000000000000D+00*dw( 92, 63)
      JacC( 53, 62) = JacC( 53, 62)+ 0.9000000000000000D+00*dw( 92, 62)
      JacC( 53, 63) = JacC( 53, 63)+ 0.9000000000000000D+00*dw( 92, 63)
      JacC( 62, 62) = JacC( 62, 62) - dw( 92, 62)
      JacC( 62, 63) = JacC( 62, 63) - dw( 92, 63)
      JacC( 63, 62) = JacC( 63, 62) - dw( 92, 62)
      JacC( 63, 63) = JacC( 63, 63) - dw( 92, 63)
      JacC( 53, 62) = JacC( 53, 62)+ 0.2000000000000000D+01*dw( 93, 62)
      JacC( 53, 62) = JacC( 53, 62)+ 0.2000000000000000D+01*dw( 93, 62)
      JacC( 62, 62) = JacC( 62, 62)- 0.2000000000000000D+01*dw( 93, 62)
      JacC( 62, 62) = JacC( 62, 62)- 0.2000000000000000D+01*dw( 93, 62)
      JacC( 33, 33) = JacC( 33, 33) - dw( 94, 33)
      JacC( 33, 55) = JacC( 33, 55) - dw( 94, 55)
      JacC( 55, 33) = JacC( 55, 33) - dw( 94, 33)
      JacC( 55, 55) = JacC( 55, 55) - dw( 94, 55)
      JacC( 62, 33) = JacC( 62, 33) + dw( 94, 33)
      JacC( 62, 55) = JacC( 62, 55) + dw( 94, 55)
      JacC( 33, 33) = JacC( 33, 33) - dw( 95, 33)
      JacC( 53, 33) = JacC( 53, 33) + dw( 95, 33)
      JacC( 55, 33) = JacC( 55, 33) + dw( 95, 33)
      JacC( 49, 49) = JacC( 49, 49) - dw( 96, 49)
      JacC( 49, 55) = JacC( 49, 55) - dw( 96, 55)
      JacC( 53, 49) = JacC( 53, 49) + dw( 96, 49)
      JacC( 53, 55) = JacC( 53, 55) + dw( 96, 55)
      JacC( 55, 49) = JacC( 55, 49) - dw( 96, 49)
      JacC( 55, 55) = JacC( 55, 55) - dw( 96, 55)
      JacC( 48, 48) = JacC( 48, 48) - dw( 97, 48)
      JacC( 48, 57) = JacC( 48, 57) - dw( 97, 57)
      JacC( 55, 48) = JacC( 55, 48) + dw( 97, 48)
      JacC( 55, 57) = JacC( 55, 57) + dw( 97, 57)
      JacC( 57, 48) = JacC( 57, 48) - dw( 97, 48)
      JacC( 57, 57) = JacC( 57, 57) - dw( 97, 57)
      JacC( 58, 48) = JacC( 58, 48) + dw( 97, 48)
      JacC( 58, 57) = JacC( 58, 57) + dw( 97, 57)
      JacC( 48, 48) = JacC( 48, 48) - dw( 98, 48)
      JacC( 48, 55) = JacC( 48, 55) - dw( 98, 55)
      JacC( 55, 48) = JacC( 55, 48) - dw( 98, 48)
      JacC( 55, 55) = JacC( 55, 55) - dw( 98, 55)
      JacC( 58, 48) = JacC( 58, 48) + dw( 98, 48)
      JacC( 58, 55) = JacC( 58, 55) + dw( 98, 55)
      JacC( 48, 48) = JacC( 48, 48) - dw( 99, 48)
      JacC( 48, 56) = JacC( 48, 56) - dw( 99, 56)
      JacC( 50, 48) = JacC( 50, 48) + dw( 99, 48)
      JacC( 50, 56) = JacC( 50, 56) + dw( 99, 56)
      JacC( 56, 48) = JacC( 56, 48) - dw( 99, 48)
      JacC( 56, 56) = JacC( 56, 56) - dw( 99, 56)
      JacC( 58, 48) = JacC( 58, 48) + dw( 99, 48)
      JacC( 58, 56) = JacC( 58, 56) + dw( 99, 56)
      JacC( 48, 48) = JacC( 48, 48) - dw(100, 48)
      JacC( 51, 48) = JacC( 51, 48) + dw(100, 48)
      JacC( 53, 48) = JacC( 53, 48) + dw(100, 48)
      JacC( 61, 48) = JacC( 61, 48) + dw(100, 48)
      JacC( 58, 58) = JacC( 58, 58) - dw(101, 58)
      JacC( 58, 64) = JacC( 58, 64) - dw(101, 64)
      JacC( 60, 58) = JacC( 60, 58) + dw(101, 58)
      JacC( 60, 64) = JacC( 60, 64) + dw(101, 64)
      JacC( 61, 58) = JacC( 61, 58) + dw(101, 58)
      JacC( 61, 64) = JacC( 61, 64) + dw(101, 64)
      JacC( 63, 58) = JacC( 63, 58) + dw(101, 58)
      JacC( 63, 64) = JacC( 63, 64) + dw(101, 64)
      JacC( 64, 58) = JacC( 64, 58) - dw(101, 58)
      JacC( 64, 64) = JacC( 64, 64) - dw(101, 64)
      JacC( 65, 58) = JacC( 65, 58) + dw(101, 58)
      JacC( 65, 64) = JacC( 65, 64) + dw(101, 64)
      JacC( 18, 58) = JacC( 18, 58) + dw(102, 58)
      JacC( 18, 65) = JacC( 18, 65) + dw(102, 65)
      JacC( 58, 58) = JacC( 58, 58) - dw(102, 58)
      JacC( 58, 65) = JacC( 58, 65) - dw(102, 65)
      JacC( 65, 58) = JacC( 65, 58) - dw(102, 58)
      JacC( 65, 65) = JacC( 65, 65) - dw(102, 65)
      JacC( 18, 18) = JacC( 18, 18) - dw(103, 18)
      JacC( 58, 18) = JacC( 58, 18) + dw(103, 18)
      JacC( 65, 18) = JacC( 65, 18) + dw(103, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw(104, 18)
      JacC( 58, 18) = JacC( 58, 18) + dw(104, 18)
      JacC( 65, 18) = JacC( 65, 18) + dw(104, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw(105, 18)
      JacC( 18, 55) = JacC( 18, 55) - dw(105, 55)
      JacC( 55, 18) = JacC( 55, 18) - dw(105, 18)
      JacC( 55, 55) = JacC( 55, 55) - dw(105, 55)
      JacC( 60, 18) = JacC( 60, 18) + dw(105, 18)
      JacC( 60, 55) = JacC( 60, 55) + dw(105, 55)
      JacC( 65, 18) = JacC( 65, 18) + dw(105, 18)
      JacC( 65, 55) = JacC( 65, 55) + dw(105, 55)
      JacC( 33, 58) = JacC( 33, 58)+ 0.8000000000000000D+00*dw(106, 58)
      JacC( 33, 61) = JacC( 33, 61)+ 0.8000000000000000D+00*dw(106, 61)
      JacC( 49, 58) = JacC( 49, 58)+ 0.2000000000000000D+00*dw(106, 58)
      JacC( 49, 61) = JacC( 49, 61)+ 0.2000000000000000D+00*dw(106, 61)
      JacC( 58, 58) = JacC( 58, 58) - dw(106, 58)
      JacC( 58, 61) = JacC( 58, 61) - dw(106, 61)
      JacC( 59, 58) = JacC( 59, 58)+ 0.2000000000000000D+00*dw(106, 58)
      JacC( 59, 61) = JacC( 59, 61)+ 0.2000000000000000D+00*dw(106, 61)
      JacC( 61, 58) = JacC( 61, 58) - dw(106, 58)
      JacC( 61, 61) = JacC( 61, 61) - dw(106, 61)
      JacC( 49, 62) = JacC( 49, 62)+ 0.1000000000000000D+00*dw(107, 62)
      JacC( 49, 53) = JacC( 49, 53)+ 0.1000000000000000D+00*dw(107, 53)
      JacC( 53, 62) = JacC( 53, 62) - dw(107, 62)
      JacC( 53, 53) = JacC( 53, 53) - dw(107, 53)
      JacC( 54, 62) = JacC( 54, 62)+ 0.1000000000000000D+00*dw(107, 62)
      JacC( 54, 53) = JacC( 54, 53)+ 0.1000000000000000D+00*dw(107, 53)
      JacC( 60, 62) = JacC( 60, 62)+ 0.9000000000000000D+00*dw(107, 62)
      JacC( 60, 53) = JacC( 60, 53)+ 0.9000000000000000D+00*dw(107, 53)
      JacC( 61, 62) = JacC( 61, 62) + dw(107, 62)
      JacC( 61, 53) = JacC( 61, 53) + dw(107, 53)
      JacC( 62, 62) = JacC( 62, 62) - dw(107, 62)
      JacC( 62, 53) = JacC( 62, 53) - dw(107, 53)
      JacC( 63, 62) = JacC( 63, 62)+ 0.9000000000000000D+00*dw(107, 62)
      JacC( 63, 53) = JacC( 63, 53)+ 0.9000000000000000D+00*dw(107, 53)
      JacC( 49, 62) = JacC( 49, 62)+ 0.1000000000000000D+00*dw(108, 62)
      JacC( 49, 63) = JacC( 49, 63)+ 0.1000000000000000D+00*dw(108, 63)
      JacC( 60, 62) = JacC( 60, 62)+ 0.9000000000000000D+00*dw(108, 62)
      JacC( 60, 63) = JacC( 60, 63)+ 0.9000000000000000D+00*dw(108, 63)
      JacC( 62, 62) = JacC( 62, 62) - dw(108, 62)
      JacC( 62, 63) = JacC( 62, 63) - dw(108, 63)
      JacC( 63, 62) = JacC( 63, 62) - dw(108, 62)
      JacC( 63, 63) = JacC( 63, 63) - dw(108, 63)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw(109, 58)
      JacC( 58, 58) = JacC( 58, 58)- 0.2000000000000000D+01*dw(109, 58)
      JacC( 61, 58) = JacC( 61, 58)+ 0.2000000000000000D+01*dw(109, 58)
      JacC( 61, 58) = JacC( 61, 58)+ 0.2000000000000000D+01*dw(109, 58)
      JacC( 63, 58) = JacC( 63, 58)+ 0.2000000000000000D+01*dw(109, 58)
      JacC( 63, 58) = JacC( 63, 58)+ 0.2000000000000000D+01*dw(109, 58)
      JacC( 53, 58) = JacC( 53, 58) + dw(110, 58)
      JacC( 53, 62) = JacC( 53, 62) + dw(110, 62)
      JacC( 58, 58) = JacC( 58, 58) - dw(110, 58)
      JacC( 58, 62) = JacC( 58, 62) - dw(110, 62)
      JacC( 60, 58) = JacC( 60, 58) + dw(110, 58)
      JacC( 60, 62) = JacC( 60, 62) + dw(110, 62)
      JacC( 61, 58) = JacC( 61, 58) + dw(110, 58)
      JacC( 61, 62) = JacC( 61, 62) + dw(110, 62)
      JacC( 62, 58) = JacC( 62, 58) - dw(110, 58)
      JacC( 62, 62) = JacC( 62, 62) - dw(110, 62)
      JacC( 63, 58) = JacC( 63, 58) + dw(110, 58)
      JacC( 63, 62) = JacC( 63, 62) + dw(110, 62)
      JacC( 19, 47) = JacC( 19, 47)+ 0.7600000000000000D+00*dw(111, 47)
      JacC( 19, 55) = JacC( 19, 55)+ 0.7600000000000000D+00*dw(111, 55)
      JacC( 47, 47) = JacC( 47, 47)- 0.8900000000000000D+00*dw(111, 47)
      JacC( 47, 55) = JacC( 47, 55)- 0.8900000000000000D+00*dw(111, 55)
      JacC( 48, 47) = JacC( 48, 47)+ 0.5000000000000000D-01*dw(111, 47)
      JacC( 48, 55) = JacC( 48, 55)+ 0.5000000000000000D-01*dw(111, 55)
      JacC( 52, 47) = JacC( 52, 47)+ 0.1300000000000000D+00*dw(111, 47)
      JacC( 52, 55) = JacC( 52, 55)+ 0.1300000000000000D+00*dw(111, 55)
      JacC( 55, 47) = JacC( 55, 47) - dw(111, 47)
      JacC( 55, 55) = JacC( 55, 55) - dw(111, 55)
      JacC( 60, 47) = JacC( 60, 47)+ 0.6000000000000000D-01*dw(111, 47)
      JacC( 60, 55) = JacC( 60, 55)+ 0.6000000000000000D-01*dw(111, 55)
      JacC( 61, 47) = JacC( 61, 47)+ 0.1100000000000000D+00*dw(111, 47)
      JacC( 61, 55) = JacC( 61, 55)+ 0.1100000000000000D+00*dw(111, 55)
      JacC( 63, 47) = JacC( 63, 47)+ 0.8700000000000000D+00*dw(111, 47)
      JacC( 63, 55) = JacC( 63, 55)+ 0.8700000000000000D+00*dw(111, 55)
      JacC( 19, 19) = JacC( 19, 19)- 0.9800000000000000D+00*dw(112, 19)
      JacC( 47, 19) = JacC( 47, 19)+ 0.2100000000000000D+01*dw(112, 19)
      JacC( 48, 19) = JacC( 48, 19)+ 0.5000000000000000D+00*dw(112, 19)
      JacC( 52, 19) = JacC( 52, 19)+ 0.4000000000000000D-01*dw(112, 19)
      JacC( 60, 19) = JacC( 60, 19)+ 0.6000000000000000D+00*dw(112, 19)
      JacC( 61, 19) = JacC( 61, 19)+ 0.9399999999999999D+00*dw(112, 19)
      JacC( 63, 19) = JacC( 63, 19)+ 0.9600000000000000D+00*dw(112, 19)
      JacC( 19, 19) = JacC( 19, 19) - dw(113, 19)
      JacC( 61, 19) = JacC( 61, 19) + dw(113, 19)
      JacC( 19, 19) = JacC( 19, 19) - dw(114, 19)
      JacC( 19, 65) = JacC( 19, 65) - dw(114, 65)
      JacC( 46, 19) = JacC( 46, 19) + dw(114, 19)
      JacC( 46, 65) = JacC( 46, 65) + dw(114, 65)
      JacC( 65, 19) = JacC( 65, 19) - dw(114, 19)
      JacC( 65, 65) = JacC( 65, 65) - dw(114, 65)
      JacC( 36, 57) = JacC( 36, 57) - dw(115, 57)
      JacC( 36, 36) = JacC( 36, 36) - dw(115, 36)
      JacC( 47, 57) = JacC( 47, 57)+ 0.2000000000000000D+00*dw(115, 57)
      JacC( 47, 36) = JacC( 47, 36)+ 0.2000000000000000D+00*dw(115, 36)
      JacC( 48, 57) = JacC( 48, 57)+ 0.3000000000000000D+00*dw(115, 57)
      JacC( 48, 36) = JacC( 48, 36)+ 0.3000000000000000D+00*dw(115, 36)
      JacC( 51, 57) = JacC( 51, 57)+ 0.2000000000000000D+00*dw(115, 57)
      JacC( 51, 36) = JacC( 51, 36)+ 0.2000000000000000D+00*dw(115, 36)
      JacC( 52, 57) = JacC( 52, 57)+ 0.1000000000000000D-01*dw(115, 57)
      JacC( 52, 36) = JacC( 52, 36)+ 0.1000000000000000D-01*dw(115, 36)
      JacC( 54, 57) = JacC( 54, 57)+ 0.2000000000000000D+00*dw(115, 57)
      JacC( 54, 36) = JacC( 54, 36)+ 0.2000000000000000D+00*dw(115, 36)
      JacC( 55, 57) = JacC( 55, 57)+ 0.1000000000000000D+00*dw(115, 57)
      JacC( 55, 36) = JacC( 55, 36)+ 0.1000000000000000D+00*dw(115, 36)
      JacC( 57, 57) = JacC( 57, 57) - dw(115, 57)
      JacC( 57, 36) = JacC( 57, 36) - dw(115, 36)
      JacC( 60, 57) = JacC( 60, 57)+ 0.2000000000000000D+00*dw(115, 57)
      JacC( 60, 36) = JacC( 60, 36)+ 0.2000000000000000D+00*dw(115, 36)
      JacC( 61, 57) = JacC( 61, 57)+ 0.3000000000000000D+00*dw(115, 57)
      JacC( 61, 36) = JacC( 61, 36)+ 0.3000000000000000D+00*dw(115, 36)
      JacC( 63, 57) = JacC( 63, 57)+ 0.2000000000000000D+00*dw(115, 57)
      JacC( 63, 36) = JacC( 63, 36)+ 0.2000000000000000D+00*dw(115, 36)
      JacC( 36, 55) = JacC( 36, 55) - dw(116, 55)
      JacC( 36, 36) = JacC( 36, 36) - dw(116, 36)
      JacC( 38, 55) = JacC( 38, 55)+ 0.8000000000000000D-02*dw(116, 55)
      JacC( 38, 36) = JacC( 38, 36)+ 0.8000000000000000D-02*dw(116, 36)
      JacC( 47, 55) = JacC( 47, 55)+ 0.7000000000000000D+00*dw(116, 55)
      JacC( 47, 36) = JacC( 47, 36)+ 0.7000000000000000D+00*dw(116, 36)
      JacC( 48, 55) = JacC( 48, 55)+ 0.6200000000000000D+00*dw(116, 55)
      JacC( 48, 36) = JacC( 48, 36)+ 0.6200000000000000D+00*dw(116, 36)
      JacC( 54, 55) = JacC( 54, 55)+ 0.8000000000000000D+00*dw(116, 55)
      JacC( 54, 36) = JacC( 54, 36)+ 0.8000000000000000D+00*dw(116, 36)
      JacC( 55, 55) = JacC( 55, 55) - dw(116, 55)
      JacC( 55, 36) = JacC( 55, 36) - dw(116, 36)
      JacC( 60, 55) = JacC( 60, 55)+ 0.3300000000000000D+00*dw(116, 55)
      JacC( 60, 36) = JacC( 60, 36)+ 0.3300000000000000D+00*dw(116, 36)
      JacC( 61, 55) = JacC( 61, 55)+ 0.9500000000000000D+00*dw(116, 55)
      JacC( 61, 36) = JacC( 61, 36)+ 0.9500000000000000D+00*dw(116, 36)
      JacC( 63, 55) = JacC( 63, 55)+ 0.8000000000000000D+00*dw(116, 55)
      JacC( 63, 36) = JacC( 63, 36)+ 0.8000000000000000D+00*dw(116, 36)
      JacC( 36, 59) = JacC( 36, 59) - dw(117, 59)
      JacC( 36, 36) = JacC( 36, 36) - dw(117, 36)
      JacC( 38, 59) = JacC( 38, 59)+ 0.8000000000000000D-02*dw(117, 59)
      JacC( 38, 36) = JacC( 38, 36)+ 0.8000000000000000D-02*dw(117, 36)
      JacC( 47, 59) = JacC( 47, 59) + dw(117, 59)
      JacC( 47, 36) = JacC( 47, 36) + dw(117, 36)
      JacC( 48, 59) = JacC( 48, 59)+ 0.3200000000000000D+00*dw(117, 59)
      JacC( 48, 36) = JacC( 48, 36)+ 0.3200000000000000D+00*dw(117, 36)
      JacC( 51, 59) = JacC( 51, 59)+ 0.3300000000000000D+00*dw(117, 59)
      JacC( 51, 36) = JacC( 51, 36)+ 0.3300000000000000D+00*dw(117, 36)
      JacC( 54, 59) = JacC( 54, 59)+ 0.7400000000000000D+00*dw(117, 59)
      JacC( 54, 36) = JacC( 54, 36)+ 0.7400000000000000D+00*dw(117, 36)
      JacC( 55, 59) = JacC( 55, 59)+ 0.1000000000000000D+00*dw(117, 59)
      JacC( 55, 36) = JacC( 55, 36)+ 0.1000000000000000D+00*dw(117, 36)
      JacC( 59, 59) = JacC( 59, 59) - dw(117, 59)
      JacC( 59, 36) = JacC( 59, 36) - dw(117, 36)
      JacC( 60, 59) = JacC( 60, 59)+ 0.1800000000000000D+00*dw(117, 59)
      JacC( 60, 36) = JacC( 60, 36)+ 0.1800000000000000D+00*dw(117, 36)
      JacC( 61, 59) = JacC( 61, 59)+ 0.4400000000000000D+00*dw(117, 59)
      JacC( 61, 36) = JacC( 61, 36)+ 0.4400000000000000D+00*dw(117, 36)
      JacC( 63, 59) = JacC( 63, 59)+ 0.2200000000000000D+00*dw(117, 59)
      JacC( 63, 36) = JacC( 63, 36)+ 0.2200000000000000D+00*dw(117, 36)
      JacC( 36, 56) = JacC( 36, 56) - dw(118, 56)
      JacC( 36, 36) = JacC( 36, 36) - dw(118, 36)
      JacC( 38, 56) = JacC( 38, 56)+ 0.8000000000000000D-02*dw(118, 56)
      JacC( 38, 36) = JacC( 38, 36)+ 0.8000000000000000D-02*dw(118, 36)
      JacC( 47, 56) = JacC( 47, 56) + dw(118, 56)
      JacC( 47, 36) = JacC( 47, 36) + dw(118, 36)
      JacC( 48, 56) = JacC( 48, 56)+ 0.5600000000000001D+00*dw(118, 56)
      JacC( 48, 36) = JacC( 48, 36)+ 0.5600000000000001D+00*dw(118, 36)
      JacC( 52, 56) = JacC( 52, 56)+ 0.9000000000000000D-01*dw(118, 56)
      JacC( 52, 36) = JacC( 52, 36)+ 0.9000000000000000D-01*dw(118, 36)
      JacC( 54, 56) = JacC( 54, 56) + dw(118, 56)
      JacC( 54, 36) = JacC( 54, 36) + dw(118, 36)
      JacC( 56, 56) = JacC( 56, 56) - dw(118, 56)
      JacC( 56, 36) = JacC( 56, 36) - dw(118, 36)
      JacC( 60, 56) = JacC( 60, 56)+ 0.3500000000000000D+00*dw(118, 56)
      JacC( 60, 36) = JacC( 60, 36)+ 0.3500000000000000D+00*dw(118, 36)
      JacC( 63, 56) = JacC( 63, 56)+ 0.9100000000000000D+00*dw(118, 56)
      JacC( 63, 36) = JacC( 63, 36)+ 0.9100000000000000D+00*dw(118, 36)
      JacC( 65, 56) = JacC( 65, 56) + dw(118, 56)
      JacC( 65, 36) = JacC( 65, 36) + dw(118, 36)
      JacC( 34, 57) = JacC( 34, 57) - dw(119, 57)
      JacC( 34, 34) = JacC( 34, 34) - dw(119, 34)
      JacC( 51, 57) = JacC( 51, 57) + dw(119, 57)
      JacC( 51, 34) = JacC( 51, 34) + dw(119, 34)
      JacC( 54, 57) = JacC( 54, 57) + dw(119, 57)
      JacC( 54, 34) = JacC( 54, 34) + dw(119, 34)
      JacC( 55, 57) = JacC( 55, 57)+ 0.3000000000000000D+00*dw(119, 57)
      JacC( 55, 34) = JacC( 55, 34)+ 0.3000000000000000D+00*dw(119, 34)
      JacC( 57, 57) = JacC( 57, 57) - dw(119, 57)
      JacC( 57, 34) = JacC( 57, 34) - dw(119, 34)
      JacC( 61, 57) = JacC( 61, 57)+ 0.1700000000000000D+01*dw(119, 57)
      JacC( 61, 34) = JacC( 61, 34)+ 0.1700000000000000D+01*dw(119, 34)
      JacC( 63, 57) = JacC( 63, 57)+ 0.7000000000000000D+00*dw(119, 57)
      JacC( 63, 34) = JacC( 63, 34)+ 0.7000000000000000D+00*dw(119, 34)
      JacC( 34, 55) = JacC( 34, 55) - dw(120, 55)
      JacC( 34, 34) = JacC( 34, 34) - dw(120, 34)
      JacC( 48, 55) = JacC( 48, 55)+ 0.2200000000000000D+00*dw(120, 55)
      JacC( 48, 34) = JacC( 48, 34)+ 0.2200000000000000D+00*dw(120, 34)
      JacC( 54, 55) = JacC( 54, 55)+ 0.1560000000000000D+01*dw(120, 55)
      JacC( 54, 34) = JacC( 54, 34)+ 0.1560000000000000D+01*dw(120, 34)
      JacC( 55, 55) = JacC( 55, 55) - dw(120, 55)
      JacC( 55, 34) = JacC( 55, 34) - dw(120, 34)
      JacC( 61, 55) = JacC( 61, 55) + dw(120, 55)
      JacC( 61, 34) = JacC( 61, 34) + dw(120, 34)
      JacC( 63, 55) = JacC( 63, 55) + dw(120, 55)
      JacC( 63, 34) = JacC( 63, 34) + dw(120, 34)
      JacC( 34, 59) = JacC( 34, 59) - dw(121, 59)
      JacC( 34, 34) = JacC( 34, 34) - dw(121, 34)
      JacC( 35, 59) = JacC( 35, 59)+ 0.3700000000000000D+00*dw(121, 59)
      JacC( 35, 34) = JacC( 35, 34)+ 0.3700000000000000D+00*dw(121, 34)
      JacC( 51, 59) = JacC( 51, 59)+ 0.6300000000000000D+00*dw(121, 59)
      JacC( 51, 34) = JacC( 51, 34)+ 0.6300000000000000D+00*dw(121, 34)
      JacC( 54, 59) = JacC( 54, 59) + dw(121, 59)
      JacC( 54, 34) = JacC( 54, 34) + dw(121, 34)
      JacC( 55, 59) = JacC( 55, 59)+ 0.1300000000000000D+00*dw(121, 59)
      JacC( 55, 34) = JacC( 55, 34)+ 0.1300000000000000D+00*dw(121, 34)
      JacC( 59, 59) = JacC( 59, 59) - dw(121, 59)
      JacC( 59, 34) = JacC( 59, 34) - dw(121, 34)
      JacC( 61, 59) = JacC( 61, 59)+ 0.1300000000000000D+00*dw(121, 59)
      JacC( 61, 34) = JacC( 61, 34)+ 0.1300000000000000D+00*dw(121, 34)
      JacC( 34, 56) = JacC( 34, 56) - dw(122, 56)
      JacC( 34, 34) = JacC( 34, 34) - dw(122, 34)
      JacC( 54, 56) = JacC( 54, 56)+ 0.2000000000000000D+01*dw(122, 56)
      JacC( 54, 34) = JacC( 54, 34)+ 0.2000000000000000D+01*dw(122, 34)
      JacC( 56, 56) = JacC( 56, 56) - dw(122, 56)
      JacC( 56, 34) = JacC( 56, 34) - dw(122, 34)
      JacC( 63, 56) = JacC( 63, 56) + dw(122, 56)
      JacC( 63, 34) = JacC( 63, 34) + dw(122, 34)
      JacC( 65, 56) = JacC( 65, 56) + dw(122, 56)
      JacC( 65, 34) = JacC( 65, 34) + dw(122, 34)
      JacC( 37, 37) = JacC( 37, 37) - dw(123, 37)
      JacC( 37, 57) = JacC( 37, 57) - dw(123, 57)
      JacC( 47, 37) = JacC( 47, 37)+ 0.1000000000000000D+00*dw(123, 37)
      JacC( 47, 57) = JacC( 47, 57)+ 0.1000000000000000D+00*dw(123, 57)
      JacC( 48, 37) = JacC( 48, 37)+ 0.6600000000000000D+00*dw(123, 37)
      JacC( 48, 57) = JacC( 48, 57)+ 0.6600000000000000D+00*dw(123, 57)
      JacC( 51, 37) = JacC( 51, 37)+ 0.1000000000000000D+00*dw(123, 37)
      JacC( 51, 57) = JacC( 51, 57)+ 0.1000000000000000D+00*dw(123, 57)
      JacC( 57, 37) = JacC( 57, 37) - dw(123, 37)
      JacC( 57, 57) = JacC( 57, 57) - dw(123, 57)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1240000000000000D+01*dw(123, 37)
      JacC( 60, 57) = JacC( 60, 57)+ 0.1240000000000000D+01*dw(123, 57)
      JacC( 61, 37) = JacC( 61, 37)+ 0.1000000000000000D+00*dw(123, 37)
      JacC( 61, 57) = JacC( 61, 57)+ 0.1000000000000000D+00*dw(123, 57)
      JacC( 63, 37) = JacC( 63, 37)+ 0.1000000000000000D+00*dw(123, 37)
      JacC( 63, 57) = JacC( 63, 57)+ 0.1000000000000000D+00*dw(123, 57)
      JacC( 37, 37) = JacC( 37, 37) - dw(124, 37)
      JacC( 37, 55) = JacC( 37, 55) - dw(124, 55)
      JacC( 38, 37) = JacC( 38, 37)+ 0.8000000000000000D-02*dw(124, 37)
      JacC( 38, 55) = JacC( 38, 55)+ 0.8000000000000000D-02*dw(124, 55)
      JacC( 48, 37) = JacC( 48, 37)+ 0.7000000000000000D+00*dw(124, 37)
      JacC( 48, 55) = JacC( 48, 55)+ 0.7000000000000000D+00*dw(124, 55)
      JacC( 55, 37) = JacC( 55, 37) - dw(124, 37)
      JacC( 55, 55) = JacC( 55, 55) - dw(124, 55)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1300000000000000D+01*dw(124, 37)
      JacC( 60, 55) = JacC( 60, 55)+ 0.1300000000000000D+01*dw(124, 55)
      JacC( 61, 37) = JacC( 61, 37) + dw(124, 37)
      JacC( 61, 55) = JacC( 61, 55) + dw(124, 55)
      JacC( 63, 37) = JacC( 63, 37) + dw(124, 37)
      JacC( 63, 55) = JacC( 63, 55) + dw(124, 55)
      JacC( 37, 37) = JacC( 37, 37) - dw(125, 37)
      JacC( 37, 59) = JacC( 37, 59) - dw(125, 59)
      JacC( 38, 37) = JacC( 38, 37)+ 0.8000000000000000D-02*dw(125, 37)
      JacC( 38, 59) = JacC( 38, 59)+ 0.8000000000000000D-02*dw(125, 59)
      JacC( 48, 37) = JacC( 48, 37)+ 0.3500000000000000D+00*dw(125, 37)
      JacC( 48, 59) = JacC( 48, 59)+ 0.3500000000000000D+00*dw(125, 59)
      JacC( 51, 37) = JacC( 51, 37)+ 0.2500000000000000D+00*dw(125, 37)
      JacC( 51, 59) = JacC( 51, 59)+ 0.2500000000000000D+00*dw(125, 59)
      JacC( 54, 37) = JacC( 54, 37)+ 0.2500000000000000D+00*dw(125, 37)
      JacC( 54, 59) = JacC( 54, 59)+ 0.2500000000000000D+00*dw(125, 59)
      JacC( 55, 37) = JacC( 55, 37)+ 0.5000000000000000D+00*dw(125, 37)
      JacC( 55, 59) = JacC( 55, 59)+ 0.5000000000000000D+00*dw(125, 59)
      JacC( 57, 37) = JacC( 57, 37)+ 0.5000000000000000D+00*dw(125, 37)
      JacC( 57, 59) = JacC( 57, 59)+ 0.5000000000000000D+00*dw(125, 59)
      JacC( 59, 37) = JacC( 59, 37) - dw(125, 37)
      JacC( 59, 59) = JacC( 59, 59) - dw(125, 59)
      JacC( 60, 37) = JacC( 60, 37)+ 0.6500000000000000D+00*dw(125, 37)
      JacC( 60, 59) = JacC( 60, 59)+ 0.6500000000000000D+00*dw(125, 59)
      JacC( 61, 37) = JacC( 61, 37)+ 0.5000000000000000D+00*dw(125, 37)
      JacC( 61, 59) = JacC( 61, 59)+ 0.5000000000000000D+00*dw(125, 59)
      JacC( 37, 37) = JacC( 37, 37) - dw(126, 37)
      JacC( 37, 56) = JacC( 37, 56) - dw(126, 56)
      JacC( 38, 37) = JacC( 38, 37)+ 0.8000000000000000D-02*dw(126, 37)
      JacC( 38, 56) = JacC( 38, 56)+ 0.8000000000000000D-02*dw(126, 56)
      JacC( 48, 37) = JacC( 48, 37)+ 0.6400000000000000D+00*dw(126, 37)
      JacC( 48, 56) = JacC( 48, 56)+ 0.6400000000000000D+00*dw(126, 56)
      JacC( 56, 37) = JacC( 56, 37) - dw(126, 37)
      JacC( 56, 56) = JacC( 56, 56) - dw(126, 56)
      JacC( 60, 37) = JacC( 60, 37)+ 0.1180000000000000D+01*dw(126, 37)
      JacC( 60, 56) = JacC( 60, 56)+ 0.1180000000000000D+01*dw(126, 56)
      JacC( 61, 37) = JacC( 61, 37) + dw(126, 37)
      JacC( 61, 56) = JacC( 61, 56) + dw(126, 56)
      JacC( 65, 37) = JacC( 65, 37) + dw(126, 37)
      JacC( 65, 56) = JacC( 65, 56) + dw(126, 56)
      JacC(  7,  7) = JacC(  7,  7) - dw(127,  7)
      JacC(  7, 55) = JacC(  7, 55) - dw(127, 55)
      JacC( 15,  7) = JacC( 15,  7)+ 0.5600000000000001D+00*dw(127,  7)
      JacC( 15, 55) = JacC( 15, 55)+ 0.5600000000000001D+00*dw(127, 55)
      JacC( 30,  7) = JacC( 30,  7)+ 0.3900000000000000D-01*dw(127,  7)
      JacC( 30, 55) = JacC( 30, 55)+ 0.3900000000000000D-01*dw(127, 55)
      JacC( 31,  7) = JacC( 31,  7)+ 0.1080000000000000D+00*dw(127,  7)
      JacC( 31, 55) = JacC( 31, 55)+ 0.1080000000000000D+00*dw(127, 55)
      JacC( 40,  7) = JacC( 40,  7)+ 0.3600000000000000D+00*dw(127,  7)
      JacC( 40, 55) = JacC( 40, 55)+ 0.3600000000000000D+00*dw(127, 55)
      JacC( 55,  7) = JacC( 55,  7) - dw(127,  7)
      JacC( 55, 55) = JacC( 55, 55) - dw(127, 55)
      JacC( 61,  7) = JacC( 61,  7)+ 0.4400000000000000D+00*dw(127,  7)
      JacC( 61, 55) = JacC( 61, 55)+ 0.4400000000000000D+00*dw(127, 55)
      JacC( 63,  7) = JacC( 63,  7)+ 0.8000000000000000D-01*dw(127,  7)
      JacC( 63, 55) = JacC( 63, 55)+ 0.8000000000000000D-01*dw(127, 55)
      JacC( 15, 15) = JacC( 15, 15) - dw(128, 15)
      JacC( 15, 64) = JacC( 15, 64) - dw(128, 64)
      JacC( 41, 15) = JacC( 41, 15)+ 0.9000000000000000D+00*dw(128, 15)
      JacC( 41, 64) = JacC( 41, 64)+ 0.9000000000000000D+00*dw(128, 64)
      JacC( 46, 15) = JacC( 46, 15)+ 0.1000000000000000D+00*dw(128, 15)
      JacC( 46, 64) = JacC( 46, 64)+ 0.1000000000000000D+00*dw(128, 64)
      JacC( 61, 15) = JacC( 61, 15)+ 0.9000000000000000D+00*dw(128, 15)
      JacC( 61, 64) = JacC( 61, 64)+ 0.9000000000000000D+00*dw(128, 64)
      JacC( 64, 15) = JacC( 64, 15) - dw(128, 15)
      JacC( 64, 64) = JacC( 64, 64) - dw(128, 64)
      JacC( 65, 15) = JacC( 65, 15)+ 0.9000000000000000D+00*dw(128, 15)
      JacC( 65, 64) = JacC( 65, 64)+ 0.9000000000000000D+00*dw(128, 64)
      JacC( 15, 15) = JacC( 15, 15) - dw(129, 15)
      JacC( 40, 15) = JacC( 40, 15) + dw(129, 15)
      JacC( 61, 15) = JacC( 61, 15) + dw(129, 15)
      JacC( 30, 55) = JacC( 30, 55)+ 0.3900000000000000D-01*dw(130, 55)
      JacC( 30, 40) = JacC( 30, 40)+ 0.3900000000000000D-01*dw(130, 40)
      JacC( 31, 55) = JacC( 31, 55)+ 0.1080000000000000D+00*dw(130, 55)
      JacC( 31, 40) = JacC( 31, 40)+ 0.1080000000000000D+00*dw(130, 40)
      JacC( 40, 55) = JacC( 40, 55) - dw(130, 55)
      JacC( 40, 40) = JacC( 40, 40) - dw(130, 40)
      JacC( 41, 55) = JacC( 41, 55)+ 0.3000000000000000D+00*dw(130, 55)
      JacC( 41, 40) = JacC( 41, 40)+ 0.3000000000000000D+00*dw(130, 40)
      JacC( 43, 55) = JacC( 43, 55)+ 0.4000000000000000D+00*dw(130, 55)
      JacC( 43, 40) = JacC( 43, 40)+ 0.4000000000000000D+00*dw(130, 40)
      JacC( 55, 55) = JacC( 55, 55) - dw(130, 55)
      JacC( 55, 40) = JacC( 55, 40) - dw(130, 40)
      JacC( 61, 55) = JacC( 61, 55)+ 0.6000000000000000D+00*dw(130, 55)
      JacC( 61, 40) = JacC( 61, 40)+ 0.6000000000000000D+00*dw(130, 40)
      JacC( 63, 55) = JacC( 63, 55)+ 0.6000000000000000D+00*dw(130, 55)
      JacC( 63, 40) = JacC( 63, 40)+ 0.6000000000000000D+00*dw(130, 40)
      JacC( 30, 40) = JacC( 30, 40)+ 0.3900000000000000D-01*dw(131, 40)
      JacC( 30, 56) = JacC( 30, 56)+ 0.3900000000000000D-01*dw(131, 56)
      JacC( 31, 40) = JacC( 31, 40)+ 0.1080000000000000D+00*dw(131, 40)
      JacC( 31, 56) = JacC( 31, 56)+ 0.1080000000000000D+00*dw(131, 56)
      JacC( 40, 40) = JacC( 40, 40) - dw(131, 40)
      JacC( 40, 56) = JacC( 40, 56) - dw(131, 56)
      JacC( 43, 40) = JacC( 43, 40) + dw(131, 40)
      JacC( 43, 56) = JacC( 43, 56) + dw(131, 56)
      JacC( 50, 40) = JacC( 50, 40) + dw(131, 40)
      JacC( 50, 56) = JacC( 50, 56) + dw(131, 56)
      JacC( 56, 40) = JacC( 56, 40) - dw(131, 40)
      JacC( 56, 56) = JacC( 56, 56) - dw(131, 56)
      JacC( 43, 43) = JacC( 43, 43) - dw(132, 43)
      JacC( 43, 65) = JacC( 43, 65) - dw(132, 65)
      JacC( 46, 43) = JacC( 46, 43) + dw(132, 43)
      JacC( 46, 65) = JacC( 46, 65) + dw(132, 65)
      JacC( 65, 43) = JacC( 65, 43) - dw(132, 43)
      JacC( 65, 65) = JacC( 65, 65) - dw(132, 65)
      JacC( 40, 43) = JacC( 40, 43) + dw(133, 43)
      JacC( 40, 61) = JacC( 40, 61) + dw(133, 61)
      JacC( 43, 43) = JacC( 43, 43) - dw(133, 43)
      JacC( 43, 61) = JacC( 43, 61) - dw(133, 61)
      JacC( 61, 43) = JacC( 61, 43) - dw(133, 43)
      JacC( 61, 61) = JacC( 61, 61) - dw(133, 61)
      JacC( 41, 41) = JacC( 41, 41) - dw(134, 41)
      JacC( 51, 41) = JacC( 51, 41) + dw(134, 41)
      JacC( 61, 41) = JacC( 61, 41) + dw(134, 41)
      JacC( 62, 41) = JacC( 62, 41) + dw(134, 41)
      JacC( 41, 41) = JacC( 41, 41) - dw(135, 41)
      JacC( 41, 55) = JacC( 41, 55) - dw(135, 55)
      JacC( 51, 41) = JacC( 51, 41)+ 0.2000000000000000D+01*dw(135, 41)
      JacC( 51, 55) = JacC( 51, 55)+ 0.2000000000000000D+01*dw(135, 55)
      JacC( 54, 41) = JacC( 54, 41) + dw(135, 41)
      JacC( 54, 55) = JacC( 54, 55) + dw(135, 55)
      JacC( 55, 41) = JacC( 55, 41) - dw(135, 41)
      JacC( 55, 55) = JacC( 55, 55) - dw(135, 55)
      JacC( 61, 41) = JacC( 61, 41)+ 0.2000000000000000D+01*dw(135, 41)
      JacC( 61, 55) = JacC( 61, 55)+ 0.2000000000000000D+01*dw(135, 55)
      JacC( 62, 41) = JacC( 62, 41) + dw(135, 41)
      JacC( 62, 55) = JacC( 62, 55) + dw(135, 55)
      JacC( 63, 41) = JacC( 63, 41) + dw(135, 41)
      JacC( 63, 55) = JacC( 63, 55) + dw(135, 55)
      JacC( 41, 41) = JacC( 41, 41) - dw(136, 41)
      JacC( 41, 59) = JacC( 41, 59) - dw(136, 59)
      JacC( 42, 41) = JacC( 42, 41)+ 0.2000000000000000D+00*dw(136, 41)
      JacC( 42, 59) = JacC( 42, 59)+ 0.2000000000000000D+00*dw(136, 59)
      JacC( 48, 41) = JacC( 48, 41)+ 0.3000000000000000D-01*dw(136, 41)
      JacC( 48, 59) = JacC( 48, 59)+ 0.3000000000000000D-01*dw(136, 59)
      JacC( 51, 41) = JacC( 51, 41)+ 0.6899999999999999D+00*dw(136, 41)
      JacC( 51, 59) = JacC( 51, 59)+ 0.6899999999999999D+00*dw(136, 59)
      JacC( 54, 41) = JacC( 54, 41)+ 0.7000000000000000D+00*dw(136, 41)
      JacC( 54, 59) = JacC( 54, 59)+ 0.7000000000000000D+00*dw(136, 59)
      JacC( 55, 41) = JacC( 55, 41)+ 0.8000000000000000D-01*dw(136, 41)
      JacC( 55, 59) = JacC( 55, 59)+ 0.8000000000000000D-01*dw(136, 59)
      JacC( 59, 41) = JacC( 59, 41) - dw(136, 41)
      JacC( 59, 59) = JacC( 59, 59) - dw(136, 59)
      JacC( 61, 41) = JacC( 61, 41)+ 0.7600000000000000D+00*dw(136, 41)
      JacC( 61, 59) = JacC( 61, 59)+ 0.7600000000000000D+00*dw(136, 59)
      JacC( 62, 41) = JacC( 62, 41)+ 0.6200000000000000D+00*dw(136, 41)
      JacC( 62, 59) = JacC( 62, 59)+ 0.6200000000000000D+00*dw(136, 59)
      JacC( 63, 41) = JacC( 63, 41)+ 0.3000000000000000D-01*dw(136, 41)
      JacC( 63, 59) = JacC( 63, 59)+ 0.3000000000000000D-01*dw(136, 59)
      JacC(  8, 55) = JacC(  8, 55) - dw(137, 55)
      JacC(  8,  8) = JacC(  8,  8) - dw(137,  8)
      JacC( 15, 55) = JacC( 15, 55)+ 0.3000000000000000D+00*dw(137, 55)
      JacC( 15,  8) = JacC( 15,  8)+ 0.3000000000000000D+00*dw(137,  8)
      JacC( 30, 55) = JacC( 30, 55)+ 0.3900000000000000D-01*dw(137, 55)
      JacC( 30,  8) = JacC( 30,  8)+ 0.3900000000000000D-01*dw(137,  8)
      JacC( 31, 55) = JacC( 31, 55)+ 0.1080000000000000D+00*dw(137, 55)
      JacC( 31,  8) = JacC( 31,  8)+ 0.1080000000000000D+00*dw(137,  8)
      JacC( 40, 55) = JacC( 40, 55)+ 0.2000000000000000D-01*dw(137, 55)
      JacC( 40,  8) = JacC( 40,  8)+ 0.2000000000000000D-01*dw(137,  8)
      JacC( 42, 55) = JacC( 42, 55)+ 0.8000000000000000D+00*dw(137, 55)
      JacC( 42,  8) = JacC( 42,  8)+ 0.8000000000000000D+00*dw(137,  8)
      JacC( 47, 55) = JacC( 47, 55)+ 0.1100000000000000D+01*dw(137, 55)
      JacC( 47,  8) = JacC( 47,  8)+ 0.1100000000000000D+01*dw(137,  8)
      JacC( 55, 55) = JacC( 55, 55) - dw(137, 55)
      JacC( 55,  8) = JacC( 55,  8) - dw(137,  8)
      JacC( 61, 55) = JacC( 61, 55)+ 0.7000000000000000D+00*dw(137, 55)
      JacC( 61,  8) = JacC( 61,  8)+ 0.7000000000000000D+00*dw(137,  8)
      JacC( 63, 55) = JacC( 63, 55)+ 0.5000000000000000D+00*dw(137, 55)
      JacC( 63,  8) = JacC( 63,  8)+ 0.5000000000000000D+00*dw(137,  8)
      JacC( 42, 55) = JacC( 42, 55) - dw(138, 55)
      JacC( 42, 42) = JacC( 42, 42) - dw(138, 42)
      JacC( 55, 55) = JacC( 55, 55) - dw(138, 55)
      JacC( 55, 42) = JacC( 55, 42) - dw(138, 42)
      JacC( 62, 55) = JacC( 62, 55) + dw(138, 55)
      JacC( 62, 42) = JacC( 62, 42) + dw(138, 42)
      JacC( 63, 55) = JacC( 63, 55) + dw(138, 55)
      JacC( 63, 42) = JacC( 63, 42) + dw(138, 42)
      JacC( 42, 42) = JacC( 42, 42) - dw(139, 42)
      JacC( 51, 42) = JacC( 51, 42) + dw(139, 42)
      JacC( 61, 42) = JacC( 61, 42) + dw(139, 42)
      JacC( 62, 42) = JacC( 62, 42) + dw(139, 42)
      JacC( 44, 57) = JacC( 44, 57) - dw(140, 57)
      JacC( 44, 44) = JacC( 44, 44) - dw(140, 44)
      JacC( 45, 57) = JacC( 45, 57)+ 0.7500000000000000D+00*dw(140, 57)
      JacC( 45, 44) = JacC( 45, 44)+ 0.7500000000000000D+00*dw(140, 44)
      JacC( 47, 57) = JacC( 47, 57)+ 0.2500000000000000D+00*dw(140, 57)
      JacC( 47, 44) = JacC( 47, 44)+ 0.2500000000000000D+00*dw(140, 44)
      JacC( 54, 57) = JacC( 54, 57)+ 0.5000000000000000D+00*dw(140, 57)
      JacC( 54, 44) = JacC( 54, 44)+ 0.5000000000000000D+00*dw(140, 44)
      JacC( 57, 57) = JacC( 57, 57) - dw(140, 57)
      JacC( 57, 44) = JacC( 57, 44) - dw(140, 44)
      JacC( 58, 57) = JacC( 58, 57)+ 0.2500000000000000D+00*dw(140, 57)
      JacC( 58, 44) = JacC( 58, 44)+ 0.2500000000000000D+00*dw(140, 44)
      JacC( 61, 57) = JacC( 61, 57)+ 0.2500000000000000D+00*dw(140, 57)
      JacC( 61, 44) = JacC( 61, 44)+ 0.2500000000000000D+00*dw(140, 44)
      JacC( 63, 57) = JacC( 63, 57)+ 0.2500000000000000D+00*dw(140, 57)
      JacC( 63, 44) = JacC( 63, 44)+ 0.2500000000000000D+00*dw(140, 44)
      JacC( 44, 55) = JacC( 44, 55) - dw(141, 55)
      JacC( 44, 44) = JacC( 44, 44) - dw(141, 44)
      JacC( 45, 55) = JacC( 45, 55)+ 0.9120000000000000D+00*dw(141, 55)
      JacC( 45, 44) = JacC( 45, 44)+ 0.9120000000000000D+00*dw(141, 44)
      JacC( 52, 55) = JacC( 52, 55)+ 0.8799999999999999D-01*dw(141, 55)
      JacC( 52, 44) = JacC( 52, 44)+ 0.8799999999999999D-01*dw(141, 44)
      JacC( 54, 55) = JacC( 54, 55)+ 0.6290000000000000D+00*dw(141, 55)
      JacC( 54, 44) = JacC( 54, 44)+ 0.6290000000000000D+00*dw(141, 44)
      JacC( 55, 55) = JacC( 55, 55) - dw(141, 55)
      JacC( 55, 44) = JacC( 55, 44) - dw(141, 44)
      JacC( 61, 55) = JacC( 61, 55)+ 0.9120000000000000D+00*dw(141, 55)
      JacC( 61, 44) = JacC( 61, 44)+ 0.9120000000000000D+00*dw(141, 44)
      JacC( 63, 55) = JacC( 63, 55)+ 0.9910000000000000D+00*dw(141, 55)
      JacC( 63, 44) = JacC( 63, 44)+ 0.9910000000000000D+00*dw(141, 44)
      JacC( 44, 59) = JacC( 44, 59) - dw(142, 59)
      JacC( 44, 44) = JacC( 44, 44) - dw(142, 44)
      JacC( 45, 59) = JacC( 45, 59)+ 0.6500000000000000D+00*dw(142, 59)
      JacC( 45, 44) = JacC( 45, 44)+ 0.6500000000000000D+00*dw(142, 44)
      JacC( 47, 59) = JacC( 47, 59)+ 0.3500000000000000D+00*dw(142, 59)
      JacC( 47, 44) = JacC( 47, 44)+ 0.3500000000000000D+00*dw(142, 44)
      JacC( 48, 59) = JacC( 48, 59)+ 0.1500000000000000D+00*dw(142, 59)
      JacC( 48, 44) = JacC( 48, 44)+ 0.1500000000000000D+00*dw(142, 44)
      JacC( 51, 59) = JacC( 51, 59)+ 0.6600000000000000D-01*dw(142, 59)
      JacC( 51, 44) = JacC( 51, 44)+ 0.6600000000000000D-01*dw(142, 44)
      JacC( 54, 59) = JacC( 54, 59)+ 0.6000000000000000D+00*dw(142, 59)
      JacC( 54, 44) = JacC( 54, 44)+ 0.6000000000000000D+00*dw(142, 44)
      JacC( 55, 59) = JacC( 55, 59)+ 0.2660000000000000D+00*dw(142, 59)
      JacC( 55, 44) = JacC( 55, 44)+ 0.2660000000000000D+00*dw(142, 44)
      JacC( 58, 59) = JacC( 58, 59)+ 0.2000000000000000D+00*dw(142, 59)
      JacC( 58, 44) = JacC( 58, 44)+ 0.2000000000000000D+00*dw(142, 44)
      JacC( 59, 59) = JacC( 59, 59) - dw(142, 59)
      JacC( 59, 44) = JacC( 59, 44) - dw(142, 44)
      JacC( 61, 59) = JacC( 61, 59)+ 0.6600000000000000D-01*dw(142, 59)
      JacC( 61, 44) = JacC( 61, 44)+ 0.6600000000000000D-01*dw(142, 44)
      JacC( 63, 59) = JacC( 63, 59)+ 0.2000000000000000D+00*dw(142, 59)
      JacC( 63, 44) = JacC( 63, 44)+ 0.2000000000000000D+00*dw(142, 44)
      JacC( 44, 56) = JacC( 44, 56) - dw(143, 56)
      JacC( 44, 44) = JacC( 44, 44) - dw(143, 44)
      JacC( 45, 56) = JacC( 45, 56)+ 0.2000000000000000D+00*dw(143, 56)
      JacC( 45, 44) = JacC( 45, 44)+ 0.2000000000000000D+00*dw(143, 44)
      JacC( 46, 56) = JacC( 46, 56)+ 0.8000000000000000D+00*dw(143, 56)
      JacC( 46, 44) = JacC( 46, 44)+ 0.8000000000000000D+00*dw(143, 44)
      JacC( 47, 56) = JacC( 47, 56)+ 0.2400000000000000D+01*dw(143, 56)
      JacC( 47, 44) = JacC( 47, 44)+ 0.2400000000000000D+01*dw(143, 44)
      JacC( 48, 56) = JacC( 48, 56)+ 0.8000000000000000D+00*dw(143, 56)
      JacC( 48, 44) = JacC( 48, 44)+ 0.8000000000000000D+00*dw(143, 44)
      JacC( 56, 56) = JacC( 56, 56) - dw(143, 56)
      JacC( 56, 44) = JacC( 56, 44) - dw(143, 44)
      JacC( 61, 56) = JacC( 61, 56)+ 0.8000000000000000D+00*dw(143, 56)
      JacC( 61, 44) = JacC( 61, 44)+ 0.8000000000000000D+00*dw(143, 44)
      JacC( 63, 56) = JacC( 63, 56) + dw(143, 56)
      JacC( 63, 44) = JacC( 63, 44) + dw(143, 44)
      JacC( 65, 56) = JacC( 65, 56)+ 0.2000000000000000D+00*dw(143, 56)
      JacC( 65, 44) = JacC( 65, 44)+ 0.2000000000000000D+00*dw(143, 44)
      JacC( 42, 55) = JacC( 42, 55)+ 0.1680000000000000D+00*dw(144, 55)
      JacC( 42, 45) = JacC( 42, 45)+ 0.1680000000000000D+00*dw(144, 45)
      JacC( 45, 55) = JacC( 45, 55) - dw(144, 55)
      JacC( 45, 45) = JacC( 45, 45) - dw(144, 45)
      JacC( 47, 55) = JacC( 47, 55)+ 0.1565000000000000D+01*dw(144, 55)
      JacC( 47, 45) = JacC( 47, 45)+ 0.1565000000000000D+01*dw(144, 45)
      JacC( 48, 55) = JacC( 48, 55)+ 0.1200000000000000D+00*dw(144, 55)
      JacC( 48, 45) = JacC( 48, 45)+ 0.1200000000000000D+00*dw(144, 45)
      JacC( 51, 55) = JacC( 51, 55)+ 0.3340000000000000D+00*dw(144, 55)
      JacC( 51, 45) = JacC( 51, 45)+ 0.3340000000000000D+00*dw(144, 45)
      JacC( 54, 55) = JacC( 54, 55)+ 0.1670000000000000D+00*dw(144, 55)
      JacC( 54, 45) = JacC( 54, 45)+ 0.1670000000000000D+00*dw(144, 45)
      JacC( 55, 55) = JacC( 55, 55) - dw(144, 55)
      JacC( 55, 45) = JacC( 55, 45) - dw(144, 45)
      JacC( 58, 55) = JacC( 58, 55)+ 0.2500000000000000D+00*dw(144, 55)
      JacC( 58, 45) = JacC( 58, 45)+ 0.2500000000000000D+00*dw(144, 45)
      JacC( 60, 55) = JacC( 60, 55)+ 0.2520000000000000D+00*dw(144, 55)
      JacC( 60, 45) = JacC( 60, 45)+ 0.2520000000000000D+00*dw(144, 45)
      JacC( 61, 55) = JacC( 61, 55)+ 0.5030000000000000D+00*dw(144, 55)
      JacC( 61, 45) = JacC( 61, 45)+ 0.5030000000000000D+00*dw(144, 45)
      JacC( 62, 55) = JacC( 62, 55)+ 0.2100000000000000D+00*dw(144, 55)
      JacC( 62, 45) = JacC( 62, 45)+ 0.2100000000000000D+00*dw(144, 45)
      JacC( 63, 55) = JacC( 63, 55)+ 0.7130000000000000D+00*dw(144, 55)
      JacC( 63, 45) = JacC( 63, 45)+ 0.7130000000000000D+00*dw(144, 45)
      JacC( 42, 59) = JacC( 42, 59)+ 0.8500000000000000D+00*dw(145, 59)
      JacC( 42, 45) = JacC( 42, 45)+ 0.8500000000000000D+00*dw(145, 45)
      JacC( 45, 59) = JacC( 45, 59) - dw(145, 59)
      JacC( 45, 45) = JacC( 45, 45) - dw(145, 45)
      JacC( 47, 59) = JacC( 47, 59)+ 0.3600000000000000D+00*dw(145, 59)
      JacC( 47, 45) = JacC( 47, 45)+ 0.3600000000000000D+00*dw(145, 45)
      JacC( 51, 59) = JacC( 51, 59)+ 0.2250000000000000D+00*dw(145, 59)
      JacC( 51, 45) = JacC( 51, 45)+ 0.2250000000000000D+00*dw(145, 45)
      JacC( 54, 59) = JacC( 54, 59)+ 0.1500000000000000D+00*dw(145, 59)
      JacC( 54, 45) = JacC( 54, 45)+ 0.1500000000000000D+00*dw(145, 45)
      JacC( 55, 59) = JacC( 55, 59)+ 0.2680000000000000D+00*dw(145, 59)
      JacC( 55, 45) = JacC( 55, 45)+ 0.2680000000000000D+00*dw(145, 45)
      JacC( 59, 59) = JacC( 59, 59) - dw(145, 59)
      JacC( 59, 45) = JacC( 59, 45) - dw(145, 45)
      JacC( 60, 59) = JacC( 60, 59)+ 0.2000000000000000D-01*dw(145, 59)
      JacC( 60, 45) = JacC( 60, 45)+ 0.2000000000000000D-01*dw(145, 45)
      JacC( 61, 59) = JacC( 61, 59)+ 0.1540000000000000D+00*dw(145, 59)
      JacC( 61, 45) = JacC( 61, 45)+ 0.1540000000000000D+00*dw(145, 45)
      JacC( 62, 59) = JacC( 62, 59)+ 0.1140000000000000D+00*dw(145, 59)
      JacC( 62, 45) = JacC( 62, 45)+ 0.1140000000000000D+00*dw(145, 45)
      JacC( 63, 59) = JacC( 63, 59)+ 0.6400000000000000D-01*dw(145, 59)
      JacC( 63, 45) = JacC( 63, 45)+ 0.6400000000000000D-01*dw(145, 45)
      JacC( 45, 56) = JacC( 45, 56) - dw(146, 56)
      JacC( 45, 45) = JacC( 45, 45) - dw(146, 45)
      JacC( 46, 56) = JacC( 46, 56)+ 0.8500000000000000D+00*dw(146, 56)
      JacC( 46, 45) = JacC( 46, 45)+ 0.8500000000000000D+00*dw(146, 45)
      JacC( 47, 56) = JacC( 47, 56)+ 0.1282000000000000D+01*dw(146, 56)
      JacC( 47, 45) = JacC( 47, 45)+ 0.1282000000000000D+01*dw(146, 45)
      JacC( 48, 56) = JacC( 48, 56)+ 0.3570000000000000D+00*dw(146, 56)
      JacC( 48, 45) = JacC( 48, 45)+ 0.3570000000000000D+00*dw(146, 45)
      JacC( 50, 56) = JacC( 50, 56)+ 0.1500000000000000D+00*dw(146, 56)
      JacC( 50, 45) = JacC( 50, 45)+ 0.1500000000000000D+00*dw(146, 45)
      JacC( 51, 56) = JacC( 51, 56)+ 0.6430000000000000D+00*dw(146, 56)
      JacC( 51, 45) = JacC( 51, 45)+ 0.6430000000000000D+00*dw(146, 45)
      JacC( 54, 56) = JacC( 54, 56)+ 0.2820000000000000D+00*dw(146, 56)
      JacC( 54, 45) = JacC( 54, 45)+ 0.2820000000000000D+00*dw(146, 45)
      JacC( 56, 56) = JacC( 56, 56) - dw(146, 56)
      JacC( 56, 45) = JacC( 56, 45) - dw(146, 45)
      JacC( 58, 56) = JacC( 58, 56)+ 0.7500000000000000D-01*dw(146, 56)
      JacC( 58, 45) = JacC( 58, 45)+ 0.7500000000000000D-01*dw(146, 45)
      JacC( 61, 56) = JacC( 61, 56)+ 0.9250000000000000D+00*dw(146, 56)
      JacC( 61, 45) = JacC( 61, 45)+ 0.9250000000000000D+00*dw(146, 45)
      JacC( 63, 56) = JacC( 63, 56)+ 0.7500000000000000D-01*dw(146, 56)
      JacC( 63, 45) = JacC( 63, 45)+ 0.7500000000000000D-01*dw(146, 45)
      JacC( 45, 45) = JacC( 45, 45) - dw(147, 45)
      JacC( 47, 45) = JacC( 47, 45)+ 0.8320000000000000D+00*dw(147, 45)
      JacC( 51, 45) = JacC( 51, 45)+ 0.3330000000000000D+00*dw(147, 45)
      JacC( 54, 45) = JacC( 54, 45)+ 0.9000000000000000D+00*dw(147, 45)
      JacC( 60, 45) = JacC( 60, 45)+ 0.6700000000000000D-01*dw(147, 45)
      JacC( 61, 45) = JacC( 61, 45)+ 0.1033000000000000D+01*dw(147, 45)
      JacC( 62, 45) = JacC( 62, 45)+ 0.9670000000000000D+00*dw(147, 45)
      JacC( 63, 45) = JacC( 63, 45)+ 0.7000000000000000D+00*dw(147, 45)
      JacC( 39, 39) = JacC( 39, 39) - dw(148, 39)
      JacC( 39, 57) = JacC( 39, 57) - dw(148, 57)
      JacC( 47, 39) = JacC( 47, 39)+ 0.5120000000000000D+01*dw(148, 39)
      JacC( 47, 57) = JacC( 47, 57)+ 0.5120000000000000D+01*dw(148, 57)
      JacC( 48, 39) = JacC( 48, 39)+ 0.1500000000000000D+00*dw(148, 39)
      JacC( 48, 57) = JacC( 48, 57)+ 0.1500000000000000D+00*dw(148, 57)
      JacC( 57, 39) = JacC( 57, 39) - dw(148, 39)
      JacC( 57, 57) = JacC( 57, 57) - dw(148, 57)
      JacC( 39, 39) = JacC( 39, 39) - dw(149, 39)
      JacC( 39, 55) = JacC( 39, 55) - dw(149, 55)
      JacC( 47, 39) = JacC( 47, 39)+ 0.1660000000000000D+01*dw(149, 39)
      JacC( 47, 55) = JacC( 47, 55)+ 0.1660000000000000D+01*dw(149, 55)
      JacC( 48, 39) = JacC( 48, 39)+ 0.4700000000000000D+00*dw(149, 39)
      JacC( 48, 55) = JacC( 48, 55)+ 0.4700000000000000D+00*dw(149, 55)
      JacC( 52, 39) = JacC( 52, 39)+ 0.2500000000000000D+00*dw(149, 39)
      JacC( 52, 55) = JacC( 52, 55)+ 0.2500000000000000D+00*dw(149, 55)
      JacC( 54, 39) = JacC( 54, 39)+ 0.2800000000000000D+00*dw(149, 39)
      JacC( 54, 55) = JacC( 54, 55)+ 0.2800000000000000D+00*dw(149, 55)
      JacC( 55, 39) = JacC( 55, 39) - dw(149, 39)
      JacC( 55, 55) = JacC( 55, 55) - dw(149, 55)
      JacC( 61, 39) = JacC( 61, 39)+ 0.7500000000000000D+00*dw(149, 39)
      JacC( 61, 55) = JacC( 61, 55)+ 0.7500000000000000D+00*dw(149, 55)
      JacC( 63, 39) = JacC( 63, 39)+ 0.1250000000000000D+01*dw(149, 39)
      JacC( 63, 55) = JacC( 63, 55)+ 0.1250000000000000D+01*dw(149, 55)
      JacC( 39, 39) = JacC( 39, 39) - dw(150, 39)
      JacC( 39, 59) = JacC( 39, 59) - dw(150, 59)
      JacC( 47, 39) = JacC( 47, 39)+ 0.7000000000000000D+01*dw(150, 39)
      JacC( 47, 59) = JacC( 47, 59)+ 0.7000000000000000D+01*dw(150, 59)
      JacC( 48, 39) = JacC( 48, 39)+ 0.2100000000000000D+00*dw(150, 39)
      JacC( 48, 59) = JacC( 48, 59)+ 0.2100000000000000D+00*dw(150, 59)
      JacC( 51, 39) = JacC( 51, 39)+ 0.1000000000000000D-02*dw(150, 39)
      JacC( 51, 59) = JacC( 51, 59)+ 0.1000000000000000D-02*dw(150, 59)
      JacC( 52, 39) = JacC( 52, 39)+ 0.1800000000000000D+00*dw(150, 39)
      JacC( 52, 59) = JacC( 52, 59)+ 0.1800000000000000D+00*dw(150, 59)
      JacC( 54, 39) = JacC( 54, 39)+ 0.2400000000000000D+00*dw(150, 39)
      JacC( 54, 59) = JacC( 54, 59)+ 0.2400000000000000D+00*dw(150, 59)
      JacC( 55, 39) = JacC( 55, 39)+ 0.5700000000000000D+00*dw(150, 39)
      JacC( 55, 59) = JacC( 55, 59)+ 0.5700000000000000D+00*dw(150, 59)
      JacC( 58, 39) = JacC( 58, 39)+ 0.3900000000000000D+00*dw(150, 39)
      JacC( 58, 59) = JacC( 58, 59)+ 0.3900000000000000D+00*dw(150, 59)
      JacC( 59, 39) = JacC( 59, 39) - dw(150, 39)
      JacC( 59, 59) = JacC( 59, 59) - dw(150, 59)
      JacC( 61, 39) = JacC( 61, 39)+ 0.7000000000000001D-01*dw(150, 39)
      JacC( 61, 59) = JacC( 61, 59)+ 0.7000000000000001D-01*dw(150, 59)
      JacC( 63, 39) = JacC( 63, 39)+ 0.7600000000000000D+00*dw(150, 39)
      JacC( 63, 59) = JacC( 63, 59)+ 0.7600000000000000D+00*dw(150, 59)
      JacC( 39, 39) = JacC( 39, 39) - dw(151, 39)
      JacC( 39, 56) = JacC( 39, 56) - dw(151, 56)
      JacC( 46, 39) = JacC( 46, 39)+ 0.5300000000000000D+00*dw(151, 39)
      JacC( 46, 56) = JacC( 46, 56)+ 0.5300000000000000D+00*dw(151, 56)
      JacC( 48, 39) = JacC( 48, 39)+ 0.4700000000000000D+00*dw(151, 39)
      JacC( 48, 56) = JacC( 48, 56)+ 0.4700000000000000D+00*dw(151, 56)
      JacC( 52, 39) = JacC( 52, 39)+ 0.2500000000000000D+00*dw(151, 39)
      JacC( 52, 56) = JacC( 52, 56)+ 0.2500000000000000D+00*dw(151, 56)
      JacC( 56, 39) = JacC( 56, 39) - dw(151, 39)
      JacC( 56, 56) = JacC( 56, 56) - dw(151, 56)
      JacC( 61, 39) = JacC( 61, 39)+ 0.2800000000000000D+00*dw(151, 39)
      JacC( 61, 56) = JacC( 61, 56)+ 0.2800000000000000D+00*dw(151, 56)
      JacC( 63, 39) = JacC( 63, 39)+ 0.1030000000000000D+01*dw(151, 39)
      JacC( 63, 56) = JacC( 63, 56)+ 0.1030000000000000D+01*dw(151, 56)
      JacC( 65, 39) = JacC( 65, 39)+ 0.4700000000000000D+00*dw(151, 39)
      JacC( 65, 56) = JacC( 65, 56)+ 0.4700000000000000D+00*dw(151, 56)
      JacC(  9,  9) = JacC(  9,  9) - dw(152,  9)
      JacC(  9, 55) = JacC(  9, 55) - dw(152, 55)
      JacC( 10,  9) = JacC( 10,  9) + dw(152,  9)
      JacC( 10, 55) = JacC( 10, 55) + dw(152, 55)
      JacC( 55,  9) = JacC( 55,  9) - dw(152,  9)
      JacC( 55, 55) = JacC( 55, 55) - dw(152, 55)
      JacC( 61,  9) = JacC( 61,  9) + dw(152,  9)
      JacC( 61, 55) = JacC( 61, 55) + dw(152, 55)
      JacC(  4, 55) = JacC(  4, 55) - dw(153, 55)
      JacC(  4,  4) = JacC(  4,  4) - dw(153,  4)
      JacC( 48, 55) = JacC( 48, 55)+ 0.5000000000000000D-01*dw(153, 55)
      JacC( 48,  4) = JacC( 48,  4)+ 0.5000000000000000D-01*dw(153,  4)
      JacC( 54, 55) = JacC( 54, 55)+ 0.1000000000000000D+00*dw(153, 55)
      JacC( 54,  4) = JacC( 54,  4)+ 0.1000000000000000D+00*dw(153,  4)
      JacC( 55, 55) = JacC( 55, 55) - dw(153, 55)
      JacC( 55,  4) = JacC( 55,  4) - dw(153,  4)
      JacC( 60, 55) = JacC( 60, 55)+ 0.9000000000000000D+00*dw(153, 55)
      JacC( 60,  4) = JacC( 60,  4)+ 0.9000000000000000D+00*dw(153,  4)
      JacC( 61, 55) = JacC( 61, 55) + dw(153, 55)
      JacC( 61,  4) = JacC( 61,  4) + dw(153,  4)
      JacC( 63, 55) = JacC( 63, 55)+ 0.1000000000000000D+00*dw(153, 55)
      JacC( 63,  4) = JacC( 63,  4)+ 0.1000000000000000D+00*dw(153,  4)
      JacC(  6, 55) = JacC(  6, 55) - dw(154, 55)
      JacC(  6,  6) = JacC(  6,  6) - dw(154,  6)
      JacC( 52, 55) = JacC( 52, 55)+ 0.8999999999999999D-02*dw(154, 55)
      JacC( 52,  6) = JacC( 52,  6)+ 0.8999999999999999D-02*dw(154,  6)
      JacC( 55, 55) = JacC( 55, 55) - dw(154, 55)
      JacC( 55,  6) = JacC( 55,  6) - dw(154,  6)
      JacC( 60, 55) = JacC( 60, 55)+ 0.9910000000000000D+00*dw(154, 55)
      JacC( 60,  6) = JacC( 60,  6)+ 0.9910000000000000D+00*dw(154,  6)
      JacC( 61, 55) = JacC( 61, 55) + dw(154, 55)
      JacC( 61,  6) = JacC( 61,  6) + dw(154,  6)
      JacC( 63, 55) = JacC( 63, 55)+ 0.9910000000000000D+00*dw(154, 55)
      JacC( 63,  6) = JacC( 63,  6)+ 0.9910000000000000D+00*dw(154,  6)
      JacC( 44, 65) = JacC( 44, 65) - dw(155, 65)
      JacC( 44, 44) = JacC( 44, 44) - dw(155, 44)
      JacC( 45, 65) = JacC( 45, 65)+ 0.2000000000000000D+00*dw(155, 65)
      JacC( 45, 44) = JacC( 45, 44)+ 0.2000000000000000D+00*dw(155, 44)
      JacC( 46, 65) = JacC( 46, 65)+ 0.8000000000000000D+00*dw(155, 65)
      JacC( 46, 44) = JacC( 46, 44)+ 0.8000000000000000D+00*dw(155, 44)
      JacC( 47, 65) = JacC( 47, 65)+ 0.2400000000000000D+01*dw(155, 65)
      JacC( 47, 44) = JacC( 47, 44)+ 0.2400000000000000D+01*dw(155, 44)
      JacC( 48, 65) = JacC( 48, 65)+ 0.8000000000000000D+00*dw(155, 65)
      JacC( 48, 44) = JacC( 48, 44)+ 0.8000000000000000D+00*dw(155, 44)
      JacC( 61, 65) = JacC( 61, 65)+ 0.8000000000000000D+00*dw(155, 65)
      JacC( 61, 44) = JacC( 61, 44)+ 0.8000000000000000D+00*dw(155, 44)
      JacC( 63, 65) = JacC( 63, 65) + dw(155, 65)
      JacC( 63, 44) = JacC( 63, 44) + dw(155, 44)
      JacC( 64, 65) = JacC( 64, 65)+ 0.2000000000000000D+00*dw(155, 65)
      JacC( 64, 44) = JacC( 64, 44)+ 0.2000000000000000D+00*dw(155, 44)
      JacC( 65, 65) = JacC( 65, 65) - dw(155, 65)
      JacC( 65, 44) = JacC( 65, 44) - dw(155, 44)
      JacC( 20, 61) = JacC( 20, 61)+ 0.5000000000000000D+00*dw(156, 61)
      JacC( 61, 61) = JacC( 61, 61) - dw(156, 61)
      JacC( 23, 65) = JacC( 23, 65)+ 0.5000000000000000D+00*dw(157, 65)
      JacC( 50, 65) = JacC( 50, 65)+ 0.5000000000000000D+00*dw(157, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw(157, 65)
      JacC( 50, 56) = JacC( 50, 56) + dw(158, 56)
      JacC( 56, 56) = JacC( 56, 56) - dw(158, 56)
      JacC( 16, 16) = JacC( 16, 16) - dw(159, 16)
      JacC( 50, 16) = JacC( 50, 16)+ 0.2000000000000000D+01*dw(159, 16)
      JacC( 11, 11) = JacC( 11, 11) - dw(160, 11)
      JacC( 11, 55) = JacC( 11, 55) - dw(160, 55)
      JacC( 12, 11) = JacC( 12, 11)+ 0.4800000000000000D-01*dw(160, 11)
      JacC( 12, 55) = JacC( 12, 55)+ 0.4800000000000000D-01*dw(160, 55)
      JacC( 24, 24) = JacC( 24, 24) - dw(161, 24)
      JacC( 24, 55) = JacC( 24, 55) - dw(161, 55)
      JacC( 25, 24) = JacC( 25, 24)+ 0.6384000000000000D-02*dw(161, 24)
      JacC( 25, 55) = JacC( 25, 55)+ 0.6384000000000000D-02*dw(161, 55)
      JacC( 26, 24) = JacC( 26, 24)+ 0.5494800000000000D-01*dw(161, 24)
      JacC( 26, 55) = JacC( 26, 55)+ 0.5494800000000000D-01*dw(161, 55)
      JacC( 24, 24) = JacC( 24, 24) - dw(162, 24)
      JacC( 24, 59) = JacC( 24, 59) - dw(162, 59)
      JacC( 25, 24) = JacC( 25, 24)+ 0.2158800000000000D-01*dw(162, 24)
      JacC( 25, 59) = JacC( 25, 59)+ 0.2158800000000000D-01*dw(162, 59)
      JacC( 26, 24) = JacC( 26, 24)+ 0.1858110000000000D+00*dw(162, 24)
      JacC( 26, 59) = JacC( 26, 59)+ 0.1858110000000000D+00*dw(162, 59)
      JacC( 27, 27) = JacC( 27, 27) - dw(163, 27)
      JacC( 27, 55) = JacC( 27, 55) - dw(163, 55)
      JacC( 28, 27) = JacC( 28, 27)+ 0.3716400000000000D-01*dw(163, 27)
      JacC( 28, 55) = JacC( 28, 55)+ 0.3716400000000000D-01*dw(163, 55)
      JacC( 29, 27) = JacC( 29, 27)+ 0.5631600000000000D-01*dw(163, 27)
      JacC( 29, 55) = JacC( 29, 55)+ 0.5631600000000000D-01*dw(163, 55)
      JacC( 27, 27) = JacC( 27, 27) - dw(164, 27)
      JacC( 27, 59) = JacC( 27, 59) - dw(164, 59)
      JacC( 28, 27) = JacC( 28, 27)+ 0.1256730000000000D+00*dw(164, 27)
      JacC( 28, 59) = JacC( 28, 59)+ 0.1256730000000000D+00*dw(164, 59)
      JacC( 29, 27) = JacC( 29, 27)+ 0.1904370000000000D+00*dw(164, 27)
      JacC( 29, 59) = JacC( 29, 59)+ 0.1904370000000000D+00*dw(164, 59)
      JacC( 24, 24) = JacC( 24, 24) - dw(165, 24)
      JacC( 24, 56) = JacC( 24, 56) - dw(165, 56)
      JacC( 27, 27) = JacC( 27, 27) - dw(166, 27)
      JacC( 27, 56) = JacC( 27, 56) - dw(166, 56)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
