C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine dratedc_racm2(ns,nr,rk,y,dw)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the derivative of reaction  rates.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2               
C     Species: _ciRACM2            
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     RK: kinetic rates.
C     Y: chemical concentrations.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     DW: derivative of reaction rates wrt Y.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns
      double precision rk(nr),y(ns),dw(nr,ns)
 
 
 
      dw(  1,110) =  rk(  1)
      dw(  2, 81) =  rk(  2)
      dw(  3, 81) =  rk(  3)
      dw(  4, 15) =  rk(  4)
      dw(  5, 94) =  rk(  5)
      dw(  6, 36) =  rk(  6)
      dw(  7,109) =  rk(  7)
      dw(  8,109) =  rk(  8)
      dw(  9, 38) =  rk(  9)
      dw( 10,108) =  rk( 10)
      dw( 11,108) =  rk( 11)
      dw( 12, 87) =  rk( 12)
      dw( 13,107) =  rk( 13)
      dw( 14, 58) =  rk( 14)
      dw( 15, 30) =  rk( 15)
      dw( 16,103) =  rk( 16)
      dw( 17, 76) =  rk( 17)
      dw( 18, 61) =  rk( 18)
      dw( 19, 66) =  rk( 19)
      dw( 20, 80) =  rk( 20)
      dw( 21, 91) =  rk( 21)
      dw( 22, 91) =  rk( 22)
      dw( 23, 91) =  rk( 23)
      dw( 24, 93) =  rk( 24)
      dw( 25, 77) =  rk( 25)
      dw( 26, 56) =  rk( 26)
      dw( 27, 78) =  rk( 27)
      dw( 28, 53) =  rk( 28)
      dw( 29, 34) =  rk( 29)
      dw( 30,106) =  rk( 30)
      dw( 31, 74) =  rk( 31)
      dw( 32,113) =  rk( 32)
      dw( 33, 35) =  rk( 33)
      dw( 34, 35) =  rk( 34)
      dw( 35, 44) =  rk( 35)
      dw( 36, 44) =  rk( 36) * Y( 81)
      dw( 36, 81) =  rk( 36) * Y( 44)
      dw( 37,  1) =  rk( 37)
      dw( 38,  1) =  rk( 38)
      dw( 39,  1) =  rk( 39)
      dw( 40, 81) =  rk( 40) * Y(112)
      dw( 40,112) =  rk( 40) * Y( 81)
      dw( 41, 81) =  rk( 41) * Y(111)
      dw( 41,111) =  rk( 41) * Y( 81)
      dw( 42,112) =  rk( 42) * Y(111)
      dw( 42,111) =  rk( 42) * Y(112)
      dw( 43, 38) =  rk( 43) * Y(112)
      dw( 43,112) =  rk( 43) * Y( 38)
      dw( 44,111) =  rk( 44) * Y(111)
      dw( 44,111) =  rk( 44) * Y(111)
      dw( 45,111) =  rk( 45) * Y(111)
      dw( 45,111) =  rk( 45) * Y(111)
      dw( 46, 44) =  rk( 46) * Y(102)
      dw( 46,102) =  rk( 46) * Y( 44)
      dw( 47, 44) =  rk( 47) * Y(110)
      dw( 47,110) =  rk( 47) * Y( 44)
      dw( 48, 44) =  rk( 48) * Y(110)
      dw( 48,110) =  rk( 48) * Y( 44)
      dw( 49,112) =  rk( 49) * Y(102)
      dw( 49,102) =  rk( 49) * Y(112)
      dw( 50,112) =  rk( 50) * Y(110)
      dw( 50,110) =  rk( 50) * Y(112)
      dw( 51,112) =  rk( 51) * Y(109)
      dw( 51,109) =  rk( 51) * Y(112)
      dw( 52,111) =  rk( 52) * Y(102)
      dw( 52,102) =  rk( 52) * Y(111)
      dw( 53,111) =  rk( 53) * Y(110)
      dw( 53,110) =  rk( 53) * Y(111)
      dw( 54, 36) =  rk( 54)
      dw( 55,111) =  rk( 55) * Y(109)
      dw( 55,109) =  rk( 55) * Y(111)
      dw( 56,112) =  rk( 56) * Y( 15)
      dw( 56, 15) =  rk( 56) * Y(112)
      dw( 57,112) =  rk( 57) * Y( 94)
      dw( 57, 94) =  rk( 57) * Y(112)
      dw( 58,112) =  rk( 58) * Y( 36)
      dw( 58, 36) =  rk( 58) * Y(112)
      dw( 59, 81) =  rk( 59) * Y(102)
      dw( 59,102) =  rk( 59) * Y( 81)
      dw( 60, 81) =  rk( 60) * Y(110)
      dw( 60,110) =  rk( 60) * Y( 81)
      dw( 61,102) =  rk( 61) * Y(102)
      dw( 61,102) =  rk( 61) * Y(102)
      dw( 62,109) =  rk( 62) * Y(102)
      dw( 62,102) =  rk( 62) * Y(109)
      dw( 63,109) =  rk( 63) * Y(110)
      dw( 63,110) =  rk( 63) * Y(109)
      dw( 64,109) =  rk( 64) * Y(110)
      dw( 64,110) =  rk( 64) * Y(109)
      dw( 65, 16) =  rk( 65)
      dw( 66, 16) =  rk( 66)
      dw( 67,109) =  rk( 67) * Y(109)
      dw( 67,109) =  rk( 67) * Y(109)
      dw( 68,112) =  rk( 68)
      dw( 69,112) =  rk( 69) * Y(  2)
      dw( 69,  2) =  rk( 69) * Y(112)
      dw( 70, 96) =  rk( 70) * Y(112)
      dw( 70,112) =  rk( 70) * Y( 96)
      dw( 71, 32) =  rk( 71) * Y(112)
      dw( 71,112) =  rk( 71) * Y( 32)
      dw( 72, 33) =  rk( 72) * Y(112)
      dw( 72,112) =  rk( 72) * Y( 33)
      dw( 73, 89) =  rk( 73) * Y(112)
      dw( 73,112) =  rk( 73) * Y( 89)
      dw( 74, 21) =  rk( 74) * Y(112)
      dw( 74,112) =  rk( 74) * Y( 21)
      dw( 75, 85) =  rk( 75) * Y(112)
      dw( 75,112) =  rk( 75) * Y( 85)
      dw( 76,  4) =  rk( 76) * Y(112)
      dw( 76,112) =  rk( 76) * Y(  4)
      dw( 77,  6) =  rk( 77) * Y(112)
      dw( 77,112) =  rk( 77) * Y(  6)
      dw( 78,  7) =  rk( 78) * Y(112)
      dw( 78,112) =  rk( 78) * Y(  7)
      dw( 79,  8) =  rk( 79) * Y(112)
      dw( 79,112) =  rk( 79) * Y(  8)
      dw( 80, 23) =  rk( 80) * Y(112)
      dw( 80,112) =  rk( 80) * Y( 23)
      dw( 81, 31) =  rk( 81) * Y(112)
      dw( 81,112) =  rk( 81) * Y( 31)
      dw( 82, 69) =  rk( 82) * Y(112)
      dw( 82,112) =  rk( 82) * Y( 69)
      dw( 83, 20) =  rk( 83) * Y(112)
      dw( 83,112) =  rk( 83) * Y( 20)
      dw( 84, 26) =  rk( 84) * Y(112)
      dw( 84,112) =  rk( 84) * Y( 26)
      dw( 85, 19) =  rk( 85) * Y(112)
      dw( 85,112) =  rk( 85) * Y( 19)
      dw( 86, 27) =  rk( 86) * Y(112)
      dw( 86,112) =  rk( 86) * Y( 27)
      dw( 87, 25) =  rk( 87) * Y(112)
      dw( 87,112) =  rk( 87) * Y( 25)
      dw( 88, 39) =  rk( 88) * Y(112)
      dw( 88,112) =  rk( 88) * Y( 39)
      dw( 89, 28) =  rk( 89) * Y(112)
      dw( 89,112) =  rk( 89) * Y( 28)
      dw( 90, 73) =  rk( 90) * Y(112)
      dw( 90,112) =  rk( 90) * Y( 73)
      dw( 91, 17) =  rk( 91) * Y(112)
      dw( 91,112) =  rk( 91) * Y( 17)
      dw( 92, 24) =  rk( 92) * Y(112)
      dw( 92,112) =  rk( 92) * Y( 24)
      dw( 93,  5) =  rk( 93) * Y(112)
      dw( 93,112) =  rk( 93) * Y(  5)
      dw( 94,  9) =  rk( 94) * Y(112)
      dw( 94,112) =  rk( 94) * Y(  9)
      dw( 95, 50) =  rk( 95) * Y(102)
      dw( 95,102) =  rk( 95) * Y( 50)
      dw( 96, 10) =  rk( 96)
      dw( 97, 41) =  rk( 97)
      dw( 98, 41) =  rk( 98) * Y(102)
      dw( 98,102) =  rk( 98) * Y( 41)
      dw( 99, 42) =  rk( 99) * Y(102)
      dw( 99,102) =  rk( 99) * Y( 42)
      dw(100, 13) =  rk(100) * Y(112)
      dw(100,112) =  rk(100) * Y( 13)
      dw(101, 11) =  rk(101) * Y(112)
      dw(101,112) =  rk(101) * Y( 11)
      dw(102, 52) =  rk(102) * Y(102)
      dw(102,102) =  rk(102) * Y( 52)
      dw(103, 12) =  rk(103)
      dw(104, 14) =  rk(104)
      dw(105, 43) =  rk(105)
      dw(106, 55) =  rk(106)
      dw(107, 43) =  rk(107) * Y(102)
      dw(107,102) =  rk(107) * Y( 43)
      dw(108, 49) =  rk(108) * Y(102)
      dw(108,102) =  rk(108) * Y( 49)
      dw(109, 53) =  rk(109) * Y(112)
      dw(109,112) =  rk(109) * Y( 53)
      dw(110, 54) =  rk(110) * Y(102)
      dw(110,102) =  rk(110) * Y( 54)
      dw(111, 45) =  rk(111) * Y(102)
      dw(111,102) =  rk(111) * Y( 45)
      dw(112, 46) =  rk(112) * Y(110)
      dw(112,110) =  rk(112) * Y( 46)
      dw(113, 18) =  rk(113) * Y(112)
      dw(113,112) =  rk(113) * Y( 18)
      dw(114, 47) =  rk(114) * Y(112)
      dw(114,112) =  rk(114) * Y( 47)
      dw(115, 29) =  rk(115) * Y(112)
      dw(115,112) =  rk(115) * Y( 29)
      dw(116, 29) =  rk(116) * Y(109)
      dw(116,109) =  rk(116) * Y( 29)
      dw(117, 83) =  rk(117) * Y( 81)
      dw(117, 81) =  rk(117) * Y( 83)
      dw(118, 83) =  rk(118) * Y(110)
      dw(118,110) =  rk(118) * Y( 83)
      dw(119, 82) =  rk(119) * Y(102)
      dw(119,102) =  rk(119) * Y( 82)
      dw(120, 82) =  rk(120) * Y(100)
      dw(120,100) =  rk(120) * Y( 82)
      dw(121, 82) =  rk(121) * Y(105)
      dw(121,105) =  rk(121) * Y( 82)
      dw(122, 82) =  rk(122) * Y(111)
      dw(122,111) =  rk(122) * Y( 82)
      dw(123, 82) =  rk(123) * Y(109)
      dw(123,109) =  rk(123) * Y( 82)
      dw(124,108) =  rk(124) * Y(112)
      dw(124,112) =  rk(124) * Y(108)
      dw(125, 87) =  rk(125) * Y(112)
      dw(125,112) =  rk(125) * Y( 87)
      dw(126,107) =  rk(126) * Y(112)
      dw(126,112) =  rk(126) * Y(107)
      dw(127, 58) =  rk(127) * Y(112)
      dw(127,112) =  rk(127) * Y( 58)
      dw(128, 30) =  rk(128) * Y(112)
      dw(128,112) =  rk(128) * Y( 30)
      dw(129,103) =  rk(129) * Y(112)
      dw(129,112) =  rk(129) * Y(103)
      dw(130, 76) =  rk(130) * Y(112)
      dw(130,112) =  rk(130) * Y( 76)
      dw(131, 91) =  rk(131) * Y(112)
      dw(131,112) =  rk(131) * Y( 91)
      dw(132, 93) =  rk(132) * Y(112)
      dw(132,112) =  rk(132) * Y( 93)
      dw(133, 61) =  rk(133) * Y(112)
      dw(133,112) =  rk(133) * Y( 61)
      dw(134, 66) =  rk(134) * Y(112)
      dw(134,112) =  rk(134) * Y( 66)
      dw(135, 80) =  rk(135) * Y(112)
      dw(135,112) =  rk(135) * Y( 80)
      dw(136, 22) =  rk(136) * Y(112)
      dw(136,112) =  rk(136) * Y( 22)
      dw(137, 56) =  rk(137) * Y(112)
      dw(137,112) =  rk(137) * Y( 56)
      dw(138, 77) =  rk(138) * Y(112)
      dw(138,112) =  rk(138) * Y( 77)
      dw(139, 78) =  rk(139) * Y(112)
      dw(139,112) =  rk(139) * Y( 78)
      dw(140, 34) =  rk(140) * Y(112)
      dw(140,112) =  rk(140) * Y( 34)
      dw(141,106) =  rk(141) * Y(112)
      dw(141,112) =  rk(141) * Y(106)
      dw(142, 74) =  rk(142) * Y(112)
      dw(142,112) =  rk(142) * Y( 74)
      dw(143, 35) =  rk(143) * Y(112)
      dw(143,112) =  rk(143) * Y( 35)
      dw(144, 37) =  rk(144) * Y(112)
      dw(144,112) =  rk(144) * Y( 37)
      dw(145, 40) =  rk(145) * Y(112)
      dw(145,112) =  rk(145) * Y( 40)
      dw(146,113) =  rk(146) * Y(112)
      dw(146,112) =  rk(146) * Y(113)
      dw(147, 67) =  rk(147) * Y(112)
      dw(147,112) =  rk(147) * Y( 67)
      dw(148, 97) =  rk(148) * Y(112)
      dw(148,112) =  rk(148) * Y( 97)
      dw(149,108) =  rk(149) * Y(109)
      dw(149,109) =  rk(149) * Y(108)
      dw(150, 87) =  rk(150) * Y(109)
      dw(150,109) =  rk(150) * Y( 87)
      dw(151,107) =  rk(151) * Y(109)
      dw(151,109) =  rk(151) * Y(107)
      dw(152, 91) =  rk(152) * Y(109)
      dw(152,109) =  rk(152) * Y( 91)
      dw(153, 93) =  rk(153) * Y(109)
      dw(153,109) =  rk(153) * Y( 93)
      dw(154, 22) =  rk(154) * Y(109)
      dw(154,109) =  rk(154) * Y( 22)
      dw(155, 18) =  rk(155) * Y(109)
      dw(155,109) =  rk(155) * Y( 18)
      dw(156, 47) =  rk(156) * Y(109)
      dw(156,109) =  rk(156) * Y( 47)
      dw(157, 51) =  rk(157) * Y(102)
      dw(157,102) =  rk(157) * Y( 51)
      dw(158, 51) =  rk(158) * Y(109)
      dw(158,109) =  rk(158) * Y( 51)
      dw(159, 51) =  rk(159) * Y(100)
      dw(159,100) =  rk(159) * Y( 51)
      dw(160, 51) =  rk(160) * Y(105)
      dw(160,105) =  rk(160) * Y( 51)
      dw(161, 51) =  rk(161) * Y(111)
      dw(161,111) =  rk(161) * Y( 51)
      dw(162, 23) =  rk(162) * Y(109)
      dw(162,109) =  rk(162) * Y( 23)
      dw(163, 31) =  rk(163) * Y(109)
      dw(163,109) =  rk(163) * Y( 31)
      dw(164, 69) =  rk(164) * Y(109)
      dw(164,109) =  rk(164) * Y( 69)
      dw(165, 20) =  rk(165) * Y(109)
      dw(165,109) =  rk(165) * Y( 20)
      dw(166, 26) =  rk(166) * Y(109)
      dw(166,109) =  rk(166) * Y( 26)
      dw(167, 61) =  rk(167) * Y(109)
      dw(167,109) =  rk(167) * Y( 61)
      dw(168, 80) =  rk(168) * Y(109)
      dw(168,109) =  rk(168) * Y( 80)
      dw(169, 19) =  rk(169) * Y(109)
      dw(169,109) =  rk(169) * Y( 19)
      dw(170, 27) =  rk(170) * Y(109)
      dw(170,109) =  rk(170) * Y( 27)
      dw(171, 40) =  rk(171) * Y(109)
      dw(171,109) =  rk(171) * Y( 40)
      dw(172, 23) =  rk(172) * Y( 81)
      dw(172, 81) =  rk(172) * Y( 23)
      dw(173, 31) =  rk(173) * Y( 81)
      dw(173, 81) =  rk(173) * Y( 31)
      dw(174, 69) =  rk(174) * Y( 81)
      dw(174, 81) =  rk(174) * Y( 69)
      dw(175, 20) =  rk(175) * Y( 81)
      dw(175, 81) =  rk(175) * Y( 20)
      dw(176, 26) =  rk(176) * Y( 81)
      dw(176, 81) =  rk(176) * Y( 26)
      dw(177, 61) =  rk(177) * Y( 81)
      dw(177, 81) =  rk(177) * Y( 61)
      dw(178, 66) =  rk(178) * Y( 81)
      dw(178, 81) =  rk(178) * Y( 66)
      dw(179, 80) =  rk(179) * Y( 81)
      dw(179, 81) =  rk(179) * Y( 80)
      dw(180, 19) =  rk(180) * Y( 81)
      dw(180, 81) =  rk(180) * Y( 19)
      dw(181, 27) =  rk(181) * Y( 81)
      dw(181, 81) =  rk(181) * Y( 27)
      dw(182, 22) =  rk(182) * Y( 81)
      dw(182, 81) =  rk(182) * Y( 22)
      dw(183, 78) =  rk(183) * Y( 81)
      dw(183, 81) =  rk(183) * Y( 78)
      dw(184, 48) =  rk(184) * Y(110)
      dw(184,110) =  rk(184) * Y( 48)
      dw(185,105) =  rk(185) * Y(110)
      dw(185,110) =  rk(185) * Y(105)
      dw(186, 98) =  rk(186) * Y(110)
      dw(186,110) =  rk(186) * Y( 98)
      dw(187, 35) =  rk(187)
      dw(188, 37) =  rk(188)
      dw(189, 95) =  rk(189) * Y(110)
      dw(189,110) =  rk(189) * Y( 95)
      dw(190, 40) =  rk(190)
      dw(191,100) =  rk(191) * Y(102)
      dw(191,102) =  rk(191) * Y(100)
      dw(192,104) =  rk(192) * Y(102)
      dw(192,102) =  rk(192) * Y(104)
      dw(193, 99) =  rk(193) * Y(102)
      dw(193,102) =  rk(193) * Y( 99)
      dw(194, 86) =  rk(194) * Y(102)
      dw(194,102) =  rk(194) * Y( 86)
      dw(195, 62) =  rk(195) * Y(102)
      dw(195,102) =  rk(195) * Y( 62)
      dw(196, 88) =  rk(196) * Y(102)
      dw(196,102) =  rk(196) * Y( 88)
      dw(197, 72) =  rk(197) * Y(102)
      dw(197,102) =  rk(197) * Y( 72)
      dw(198, 79) =  rk(198) * Y(102)
      dw(198,102) =  rk(198) * Y( 79)
      dw(199, 59) =  rk(199) * Y(102)
      dw(199,102) =  rk(199) * Y( 59)
      dw(200, 95) =  rk(200) * Y(102)
      dw(200,102) =  rk(200) * Y( 95)
      dw(201, 68) =  rk(201) * Y(102)
      dw(201,102) =  rk(201) * Y( 68)
      dw(202, 64) =  rk(202) * Y(102)
      dw(202,102) =  rk(202) * Y( 64)
      dw(203, 84) =  rk(203) * Y(102)
      dw(203,102) =  rk(203) * Y( 84)
      dw(204, 57) =  rk(204) * Y(102)
      dw(204,102) =  rk(204) * Y( 57)
      dw(205, 60) =  rk(205) * Y(102)
      dw(205,102) =  rk(205) * Y( 60)
      dw(206, 63) =  rk(206) * Y(102)
      dw(206,102) =  rk(206) * Y( 63)
      dw(207, 55) =  rk(207) * Y(102)
      dw(207,102) =  rk(207) * Y( 55)
      dw(208, 75) =  rk(208) * Y(102)
      dw(208,102) =  rk(208) * Y( 75)
      dw(209,105) =  rk(209) * Y(102)
      dw(209,102) =  rk(209) * Y(105)
      dw(210, 98) =  rk(210) * Y(102)
      dw(210,102) =  rk(210) * Y( 98)
      dw(211, 92) =  rk(211) * Y(102)
      dw(211,102) =  rk(211) * Y( 92)
      dw(212, 65) =  rk(212) * Y(102)
      dw(212,102) =  rk(212) * Y( 65)
      dw(213, 71) =  rk(213) * Y(102)
      dw(213,102) =  rk(213) * Y( 71)
      dw(214, 70) =  rk(214) * Y(102)
      dw(214,102) =  rk(214) * Y( 70)
      dw(215,100) =  rk(215) * Y(111)
      dw(215,111) =  rk(215) * Y(100)
      dw(216,104) =  rk(216) * Y(111)
      dw(216,111) =  rk(216) * Y(104)
      dw(217, 99) =  rk(217) * Y(111)
      dw(217,111) =  rk(217) * Y( 99)
      dw(218, 86) =  rk(218) * Y(111)
      dw(218,111) =  rk(218) * Y( 86)
      dw(219, 62) =  rk(219) * Y(111)
      dw(219,111) =  rk(219) * Y( 62)
      dw(220, 88) =  rk(220) * Y(111)
      dw(220,111) =  rk(220) * Y( 88)
      dw(221, 72) =  rk(221) * Y(111)
      dw(221,111) =  rk(221) * Y( 72)
      dw(222, 79) =  rk(222) * Y(111)
      dw(222,111) =  rk(222) * Y( 79)
      dw(223, 59) =  rk(223) * Y(111)
      dw(223,111) =  rk(223) * Y( 59)
      dw(224, 95) =  rk(224) * Y(111)
      dw(224,111) =  rk(224) * Y( 95)
      dw(225, 68) =  rk(225) * Y(111)
      dw(225,111) =  rk(225) * Y( 68)
      dw(226, 84) =  rk(226) * Y(111)
      dw(226,111) =  rk(226) * Y( 84)
      dw(227, 57) =  rk(227) * Y(111)
      dw(227,111) =  rk(227) * Y( 57)
      dw(228, 60) =  rk(228) * Y(111)
      dw(228,111) =  rk(228) * Y( 60)
      dw(229, 63) =  rk(229) * Y(111)
      dw(229,111) =  rk(229) * Y( 63)
      dw(230, 55) =  rk(230) * Y(111)
      dw(230,111) =  rk(230) * Y( 55)
      dw(231, 75) =  rk(231) * Y(111)
      dw(231,111) =  rk(231) * Y( 75)
      dw(232, 48) =  rk(232) * Y(111)
      dw(232,111) =  rk(232) * Y( 48)
      dw(233,105) =  rk(233) * Y(111)
      dw(233,111) =  rk(233) * Y(105)
      dw(234, 98) =  rk(234) * Y(111)
      dw(234,111) =  rk(234) * Y( 98)
      dw(235, 65) =  rk(235) * Y(111)
      dw(235,111) =  rk(235) * Y( 65)
      dw(236, 64) =  rk(236) * Y(111)
      dw(236,111) =  rk(236) * Y( 64)
      dw(237, 92) =  rk(237) * Y(111)
      dw(237,111) =  rk(237) * Y( 92)
      dw(238, 71) =  rk(238) * Y(111)
      dw(238,111) =  rk(238) * Y( 71)
      dw(239, 70) =  rk(239) * Y(111)
      dw(239,111) =  rk(239) * Y( 70)
      dw(240,100) =  rk(240) * Y(100)
      dw(240,100) =  rk(240) * Y(100)
      dw(241,104) =  rk(241) * Y(100)
      dw(241,100) =  rk(241) * Y(104)
      dw(242, 99) =  rk(242) * Y(100)
      dw(242,100) =  rk(242) * Y( 99)
      dw(243, 86) =  rk(243) * Y(100)
      dw(243,100) =  rk(243) * Y( 86)
      dw(244, 62) =  rk(244) * Y(100)
      dw(244,100) =  rk(244) * Y( 62)
      dw(245, 88) =  rk(245) * Y(100)
      dw(245,100) =  rk(245) * Y( 88)
      dw(246, 72) =  rk(246) * Y(100)
      dw(246,100) =  rk(246) * Y( 72)
      dw(247, 79) =  rk(247) * Y(100)
      dw(247,100) =  rk(247) * Y( 79)
      dw(248, 59) =  rk(248) * Y(100)
      dw(248,100) =  rk(248) * Y( 59)
      dw(249, 95) =  rk(249) * Y(100)
      dw(249,100) =  rk(249) * Y( 95)
      dw(250, 68) =  rk(250) * Y(100)
      dw(250,100) =  rk(250) * Y( 68)
      dw(251, 84) =  rk(251) * Y(100)
      dw(251,100) =  rk(251) * Y( 84)
      dw(252, 57) =  rk(252) * Y(100)
      dw(252,100) =  rk(252) * Y( 57)
      dw(253, 60) =  rk(253) * Y(100)
      dw(253,100) =  rk(253) * Y( 60)
      dw(254, 63) =  rk(254) * Y(100)
      dw(254,100) =  rk(254) * Y( 63)
      dw(255, 41) =  rk(255) * Y(100)
      dw(255,100) =  rk(255) * Y( 41)
      dw(256, 50) =  rk(256) * Y(100)
      dw(256,100) =  rk(256) * Y( 50)
      dw(257, 42) =  rk(257) * Y(100)
      dw(257,100) =  rk(257) * Y( 42)
      dw(258, 55) =  rk(258) * Y(100)
      dw(258,100) =  rk(258) * Y( 55)
      dw(259, 52) =  rk(259) * Y(100)
      dw(259,100) =  rk(259) * Y( 52)
      dw(260, 43) =  rk(260) * Y(100)
      dw(260,100) =  rk(260) * Y( 43)
      dw(261, 49) =  rk(261) * Y(100)
      dw(261,100) =  rk(261) * Y( 49)
      dw(262, 54) =  rk(262) * Y(100)
      dw(262,100) =  rk(262) * Y( 54)
      dw(263, 45) =  rk(263) * Y(100)
      dw(263,100) =  rk(263) * Y( 45)
      dw(264, 75) =  rk(264) * Y(100)
      dw(264,100) =  rk(264) * Y( 75)
      dw(265,105) =  rk(265) * Y(100)
      dw(265,100) =  rk(265) * Y(105)
      dw(266, 98) =  rk(266) * Y(100)
      dw(266,100) =  rk(266) * Y( 98)
      dw(267, 65) =  rk(267) * Y(100)
      dw(267,100) =  rk(267) * Y( 65)
      dw(268, 64) =  rk(268) * Y(100)
      dw(268,100) =  rk(268) * Y( 64)
      dw(269, 92) =  rk(269) * Y(100)
      dw(269,100) =  rk(269) * Y( 92)
      dw(270, 71) =  rk(270) * Y(100)
      dw(270,100) =  rk(270) * Y( 71)
      dw(271, 70) =  rk(271) * Y(100)
      dw(271,100) =  rk(271) * Y( 70)
      dw(272,104) =  rk(272) * Y(105)
      dw(272,105) =  rk(272) * Y(104)
      dw(273, 99) =  rk(273) * Y(105)
      dw(273,105) =  rk(273) * Y( 99)
      dw(274, 86) =  rk(274) * Y(105)
      dw(274,105) =  rk(274) * Y( 86)
      dw(275, 62) =  rk(275) * Y(105)
      dw(275,105) =  rk(275) * Y( 62)
      dw(276, 88) =  rk(276) * Y(105)
      dw(276,105) =  rk(276) * Y( 88)
      dw(277, 72) =  rk(277) * Y(105)
      dw(277,105) =  rk(277) * Y( 72)
      dw(278, 79) =  rk(278) * Y(105)
      dw(278,105) =  rk(278) * Y( 79)
      dw(279, 59) =  rk(279) * Y(105)
      dw(279,105) =  rk(279) * Y( 59)
      dw(280, 95) =  rk(280) * Y(105)
      dw(280,105) =  rk(280) * Y( 95)
      dw(281, 68) =  rk(281) * Y(105)
      dw(281,105) =  rk(281) * Y( 68)
      dw(282, 84) =  rk(282) * Y(105)
      dw(282,105) =  rk(282) * Y( 84)
      dw(283, 57) =  rk(283) * Y(105)
      dw(283,105) =  rk(283) * Y( 57)
      dw(284, 60) =  rk(284) * Y(105)
      dw(284,105) =  rk(284) * Y( 60)
      dw(285, 63) =  rk(285) * Y(105)
      dw(285,105) =  rk(285) * Y( 63)
      dw(286, 41) =  rk(286) * Y(105)
      dw(286,105) =  rk(286) * Y( 41)
      dw(287, 50) =  rk(287) * Y(105)
      dw(287,105) =  rk(287) * Y( 50)
      dw(288, 42) =  rk(288) * Y(105)
      dw(288,105) =  rk(288) * Y( 42)
      dw(289, 49) =  rk(289) * Y(105)
      dw(289,105) =  rk(289) * Y( 49)
      dw(290, 54) =  rk(290) * Y(105)
      dw(290,105) =  rk(290) * Y( 54)
      dw(291, 45) =  rk(291) * Y(105)
      dw(291,105) =  rk(291) * Y( 45)
      dw(292, 55) =  rk(292) * Y(105)
      dw(292,105) =  rk(292) * Y( 55)
      dw(293, 52) =  rk(293) * Y(105)
      dw(293,105) =  rk(293) * Y( 52)
      dw(294, 43) =  rk(294) * Y(105)
      dw(294,105) =  rk(294) * Y( 43)
      dw(295, 75) =  rk(295) * Y(105)
      dw(295,105) =  rk(295) * Y( 75)
      dw(296,105) =  rk(296) * Y(105)
      dw(296,105) =  rk(296) * Y(105)
      dw(297, 98) =  rk(297) * Y( 98)
      dw(297, 98) =  rk(297) * Y( 98)
      dw(298, 92) =  rk(298) * Y(105)
      dw(298,105) =  rk(298) * Y( 92)
      dw(299, 65) =  rk(299) * Y(105)
      dw(299,105) =  rk(299) * Y( 65)
      dw(300, 64) =  rk(300) * Y(105)
      dw(300,105) =  rk(300) * Y( 64)
      dw(301, 71) =  rk(301) * Y(105)
      dw(301,105) =  rk(301) * Y( 71)
      dw(302, 70) =  rk(302) * Y(105)
      dw(302,105) =  rk(302) * Y( 70)
      dw(303, 71) =  rk(303) * Y( 71)
      dw(303, 71) =  rk(303) * Y( 71)
      dw(304, 71) =  rk(304) * Y( 70)
      dw(304, 70) =  rk(304) * Y( 71)
      dw(305, 70) =  rk(305) * Y( 70)
      dw(305, 70) =  rk(305) * Y( 70)
      dw(306,100) =  rk(306) * Y(109)
      dw(306,109) =  rk(306) * Y(100)
      dw(307,104) =  rk(307) * Y(109)
      dw(307,109) =  rk(307) * Y(104)
      dw(308, 99) =  rk(308) * Y(109)
      dw(308,109) =  rk(308) * Y( 99)
      dw(309, 86) =  rk(309) * Y(109)
      dw(309,109) =  rk(309) * Y( 86)
      dw(310, 62) =  rk(310) * Y(109)
      dw(310,109) =  rk(310) * Y( 62)
      dw(311, 88) =  rk(311) * Y(109)
      dw(311,109) =  rk(311) * Y( 88)
      dw(312, 72) =  rk(312) * Y(109)
      dw(312,109) =  rk(312) * Y( 72)
      dw(313, 79) =  rk(313) * Y(109)
      dw(313,109) =  rk(313) * Y( 79)
      dw(314, 59) =  rk(314) * Y(109)
      dw(314,109) =  rk(314) * Y( 59)
      dw(315, 57) =  rk(315) * Y(109)
      dw(315,109) =  rk(315) * Y( 57)
      dw(316, 60) =  rk(316) * Y(109)
      dw(316,109) =  rk(316) * Y( 60)
      dw(317, 63) =  rk(317) * Y(109)
      dw(317,109) =  rk(317) * Y( 63)
      dw(318, 55) =  rk(318) * Y(109)
      dw(318,109) =  rk(318) * Y( 55)
      dw(319, 75) =  rk(319) * Y(109)
      dw(319,109) =  rk(319) * Y( 75)
      dw(320,105) =  rk(320) * Y(109)
      dw(320,109) =  rk(320) * Y(105)
      dw(321, 98) =  rk(321) * Y(109)
      dw(321,109) =  rk(321) * Y( 98)
      dw(322, 64) =  rk(322) * Y(109)
      dw(322,109) =  rk(322) * Y( 64)
      dw(323, 92) =  rk(323) * Y(109)
      dw(323,109) =  rk(323) * Y( 92)
      dw(324, 65) =  rk(324) * Y(109)
      dw(324,109) =  rk(324) * Y( 65)
      dw(325, 71) =  rk(325) * Y(109)
      dw(325,109) =  rk(325) * Y( 71)
      dw(326, 70) =  rk(326) * Y(109)
      dw(326,109) =  rk(326) * Y( 70)
      dw(327, 68) =  rk(327) * Y(109)
      dw(327,109) =  rk(327) * Y( 68)
      dw(328, 95) =  rk(328) * Y(109)
      dw(328,109) =  rk(328) * Y( 95)
      dw(329, 50) =  rk(329) * Y(109)
      dw(329,109) =  rk(329) * Y( 50)
      dw(330, 41) =  rk(330) * Y(109)
      dw(330,109) =  rk(330) * Y( 41)
      dw(331, 42) =  rk(331) * Y(109)
      dw(331,109) =  rk(331) * Y( 42)
      dw(332, 52) =  rk(332) * Y(109)
      dw(332,109) =  rk(332) * Y( 52)
      dw(333, 43) =  rk(333) * Y(109)
      dw(333,109) =  rk(333) * Y( 43)
      dw(334, 49) =  rk(334) * Y(109)
      dw(334,109) =  rk(334) * Y( 49)
      dw(335, 54) =  rk(335) * Y(109)
      dw(335,109) =  rk(335) * Y( 54)
      dw(336, 45) =  rk(336) * Y(109)
      dw(336,109) =  rk(336) * Y( 45)
      dw(337, 84) =  rk(337) * Y(109)
      dw(337,109) =  rk(337) * Y( 84)
      dw(338,101) =  rk(338) * Y(111)
      dw(338,111) =  rk(338) * Y(101)
      dw(339,101) =  rk(339) * Y(100)
      dw(339,100) =  rk(339) * Y(101)
      dw(340,101) =  rk(340) * Y(105)
      dw(340,105) =  rk(340) * Y(101)
      dw(341,101) =  rk(341) * Y(101)
      dw(341,101) =  rk(341) * Y(101)
      dw(342,101) =  rk(342) * Y(102)
      dw(342,102) =  rk(342) * Y(101)
      dw(343,101) =  rk(343) * Y(109)
      dw(343,109) =  rk(343) * Y(101)
      dw(344, 90) =  rk(344) * Y(102)
      dw(344,102) =  rk(344) * Y( 90)
      dw(345, 90) =  rk(345) * Y(111)
      dw(345,111) =  rk(345) * Y( 90)
      dw(346, 90) =  rk(346) * Y(100)
      dw(346,100) =  rk(346) * Y( 90)
      dw(347, 90) =  rk(347) * Y(105)
      dw(347,105) =  rk(347) * Y( 90)
      dw(348, 90) =  rk(348) * Y(109)
      dw(348,109) =  rk(348) * Y( 90)
      dw(349, 98) =  rk(349) * Y(105)
      dw(349,105) =  rk(349) * Y( 98)
 
      RETURN
      END
 
