C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine fexchem_radm(ns,nr,y,rk,ZCsourc,convers_factor,chem)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: RADM                
C     Species: _ciRADM             
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     CHEM: array of chemical production terms.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns,i
      double precision w(nr),rk(nr),y(ns),chem(ns),ZCsourc(ns)
      double precision conc(ns), convers_factor(ns)
 
      do i=1,ns
       chem(i)=0.d0
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
C     Compute reaction rates.
 
      call rates_radm(ns,nr,rk,conc,w)
 
C     Chemical production terms.
 
      chem( 23) = chem( 23) + w(  1)
      chem( 55) = chem( 55) - w(  1)
      chem( 56) = chem( 56) + w(  1)
      chem(  8) = chem(  8) + w(  2)
      chem( 26) = chem( 26) - w(  2)
      chem( 23) = chem( 23) + w(  3)
      chem( 26) = chem( 26) - w(  3)
      chem( 12) = chem( 12) - w(  4)
      chem( 50) = chem( 50) + w(  4)
      chem( 56) = chem( 56) + w(  4)
      chem( 49) = chem( 49) - w(  5)
      chem( 50) = chem( 50) + w(  5)
      chem( 55) = chem( 55) + w(  5)
      chem( 24) = chem( 24) - w(  6)
      chem( 50) = chem( 50) +  0.3500000000000000D+00 * w(  6)
      chem( 51) = chem( 51) +  0.3500000000000000D+00 * w(  6)
      chem( 55) = chem( 55) +  0.6500000000000000D+00 * w(  6)
      chem( 57) = chem( 57) +  0.6500000000000000D+00 * w(  6)
      chem( 51) = chem( 51) - w(  7)
      chem( 56) = chem( 56) + w(  7)
      chem( 23) = chem( 23) + w(  8)
      chem( 51) = chem( 51) - w(  8)
      chem( 55) = chem( 55) + w(  8)
      chem( 10) = chem( 10) - w(  9)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w(  9)
      chem( 48) = chem( 48) - w( 10)
      chem( 53) = chem( 53) + w( 10)
      chem( 48) = chem( 48) - w( 11)
      chem( 53) = chem( 53) + w( 11)
      chem( 57) = chem( 57) +  0.2000000000000000D+01 * w( 11)
      chem( 44) = chem( 44) - w( 12)
      chem( 46) = chem( 46) + w( 12)
      chem( 53) = chem( 53) + w( 12)
      chem( 57) = chem( 57) + w( 12)
      chem( 21) = chem( 21) - w( 13)
      chem( 48) = chem( 48) + w( 13)
      chem( 50) = chem( 50) + w( 13)
      chem( 57) = chem( 57) + w( 13)
      chem( 42) = chem( 42) - w( 14)
      chem( 44) = chem( 44) + w( 14)
      chem( 50) = chem( 50) + w( 14)
      chem( 57) = chem( 57) + w( 14)
      chem( 22) = chem( 22) - w( 15)
      chem( 46) = chem( 46) + w( 15)
      chem( 50) = chem( 50) + w( 15)
      chem( 38) = chem( 38) - w( 16)
      chem( 39) = chem( 39) + w( 16)
      chem( 58) = chem( 58) + w( 16)
      chem( 47) = chem( 47) - w( 17)
      chem( 48) = chem( 48) +  0.1300000000000000D+00 * w( 17)
      chem( 53) = chem( 53) +  0.1870000000000000D+01 * w( 17)
      chem( 47) = chem( 47) - w( 18)
      chem( 48) = chem( 48) +  0.4500000000000000D+00 * w( 18)
      chem( 53) = chem( 53) +  0.1550000000000000D+01 * w( 18)
      chem( 57) = chem( 57) +  0.8000000000000000D+00 * w( 18)
      chem( 52) = chem( 52) - w( 19)
      chem( 53) = chem( 53) + w( 19)
      chem( 57) = chem( 57) + w( 19)
      chem( 58) = chem( 58) + w( 19)
      chem( 33) = chem( 33) - w( 20)
      chem( 54) = chem( 54) + w( 20)
      chem( 57) = chem( 57) + w( 20)
      chem( 37) = chem( 37) - w( 21)
      chem( 38) = chem( 38) +  0.8000000000000000D+00 * w( 21)
      chem( 44) = chem( 44) +  0.2000000000000000D+00 * w( 21)
      chem( 55) = chem( 55) + w( 21)
      chem( 57) = chem( 57) + w( 21)
      chem( 23) = chem( 23) - w( 22)
      chem( 55) = chem( 55) - w( 22)
      chem( 56) = chem( 56) + w( 22)
      chem(  8) = chem(  8) - w( 23)
      chem( 23) = chem( 23) + w( 23)
      chem(  8) = chem(  8) - w( 24)
      chem( 23) = chem( 23) + w( 24)
      chem(  8) = chem(  8) - w( 25)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w( 25)
      chem( 26) = chem( 26) - w( 26)
      chem( 55) = chem( 55) + w( 26)
      chem( 56) = chem( 56) - w( 26)
      chem( 26) = chem( 26) - w( 27)
      chem( 50) = chem( 50) - w( 27)
      chem( 57) = chem( 57) + w( 27)
      chem( 26) = chem( 26) - w( 28)
      chem( 50) = chem( 50) + w( 28)
      chem( 57) = chem( 57) - w( 28)
      chem( 50) = chem( 50) + w( 29)
      chem( 55) = chem( 55) + w( 29)
      chem( 56) = chem( 56) - w( 29)
      chem( 57) = chem( 57) - w( 29)
      chem( 10) = chem( 10) - w( 30)
      chem( 50) = chem( 50) - w( 30)
      chem( 57) = chem( 57) + w( 30)
      chem( 55) = chem( 55) +  0.2000000000000000D+01 * w( 31)
      chem( 56) = chem( 56) -  0.2000000000000000D+01 * w( 31)
      chem( 26) = chem( 26) - w( 32)
      chem( 51) = chem( 51) + w( 32)
      chem( 55) = chem( 55) - w( 32)
      chem( 51) = chem( 51) - w( 33)
      chem( 55) = chem( 55) +  0.2000000000000000D+01 * w( 33)
      chem( 56) = chem( 56) - w( 33)
      chem( 51) = chem( 51) - w( 34)
      chem( 56) = chem( 56) + w( 34)
      chem( 49) = chem( 49) + w( 35)
      chem( 51) = chem( 51) - w( 35)
      chem( 57) = chem( 57) - w( 35)
      chem( 11) = chem( 11) - w( 36)
      chem( 49) = chem( 49) +  0.2000000000000000D+01 * w( 36)
      chem( 24) = chem( 24) - w( 37)
      chem( 50) = chem( 50) - w( 37)
      chem( 55) = chem( 55) + w( 37)
      chem( 50) = chem( 50) - w( 38)
      chem( 57) = chem( 57) - w( 38)
      chem( 17) = chem( 17) - w( 39)
      chem( 46) = chem( 46) + w( 39)
      chem( 50) = chem( 50) - w( 39)
      chem(  2) = chem(  2) - w( 40)
      chem( 39) = chem( 39) + w( 40)
      chem( 50) = chem( 50) - w( 40)
      chem(  3) = chem(  3) - w( 41)
      chem( 38) = chem( 38) +  0.2500000000000000D-01 * w( 41)
      chem( 43) = chem( 43) +  0.8300000000000000D+00 * w( 41)
      chem( 44) = chem( 44) +  0.7500000000000000D-01 * w( 41)
      chem( 48) = chem( 48) +  0.8999999999999999D-02 * w( 41)
      chem( 50) = chem( 50) - w( 41)
      chem( 57) = chem( 57) +  0.1700000000000000D+00 * w( 41)
      chem(  4) = chem(  4) - w( 42)
      chem( 27) = chem( 27) + w( 42)
      chem( 45) = chem( 45) +  0.2500000000000000D+00 * w( 42)
      chem( 50) = chem( 50) - w( 42)
      chem(  5) = chem(  5) - w( 43)
      chem( 28) = chem( 28) + w( 43)
      chem( 45) = chem( 45) +  0.7500000000000000D+00 * w( 43)
      chem( 50) = chem( 50) - w( 43)
      chem( 25) = chem( 25) - w( 44)
      chem( 34) = chem( 34) + w( 44)
      chem( 50) = chem( 50) - w( 44)
      chem( 15) = chem( 15) - w( 45)
      chem( 29) = chem( 29) + w( 45)
      chem( 50) = chem( 50) - w( 45)
      chem( 16) = chem( 16) - w( 46)
      chem( 30) = chem( 30) + w( 46)
      chem( 50) = chem( 50) - w( 46)
      chem(  6) = chem(  6) - w( 47)
      chem( 13) = chem( 13) +  0.2500000000000000D+00 * w( 47)
      chem( 31) = chem( 31) +  0.7500000000000000D+00 * w( 47)
      chem( 50) = chem( 50) - w( 47)
      chem( 57) = chem( 57) +  0.2500000000000000D+00 * w( 47)
      chem(  7) = chem(  7) - w( 48)
      chem( 13) = chem( 13) +  0.1700000000000000D+00 * w( 48)
      chem( 32) = chem( 32) +  0.8300000000000000D+00 * w( 48)
      chem( 50) = chem( 50) - w( 48)
      chem( 57) = chem( 57) +  0.1700000000000000D+00 * w( 48)
      chem( 13) = chem( 13) - w( 49)
      chem( 45) = chem( 45) +  0.9000000000000000D+00 * w( 49)
      chem( 50) = chem( 50) - w( 49)
      chem( 54) = chem( 54) +  0.9000000000000000D+00 * w( 49)
      chem( 57) = chem( 57) +  0.1000000000000000D+00 * w( 49)
      chem( 48) = chem( 48) - w( 50)
      chem( 50) = chem( 50) - w( 50)
      chem( 53) = chem( 53) + w( 50)
      chem( 57) = chem( 57) + w( 50)
      chem( 44) = chem( 44) - w( 51)
      chem( 50) = chem( 50) - w( 51)
      chem( 58) = chem( 58) + w( 51)
      chem( 38) = chem( 38) - w( 52)
      chem( 40) = chem( 40) + w( 52)
      chem( 50) = chem( 50) - w( 52)
      chem( 47) = chem( 47) - w( 53)
      chem( 50) = chem( 50) - w( 53)
      chem( 53) = chem( 53) +  0.2000000000000000D+01 * w( 53)
      chem( 57) = chem( 57) + w( 53)
      chem( 50) = chem( 50) - w( 54)
      chem( 52) = chem( 52) - w( 54)
      chem( 53) = chem( 53) + w( 54)
      chem( 58) = chem( 58) + w( 54)
      chem( 33) = chem( 33) - w( 55)
      chem( 50) = chem( 50) - w( 55)
      chem( 54) = chem( 54) + w( 55)
      chem( 21) = chem( 21) - w( 56)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w( 56)
      chem( 48) = chem( 48) +  0.5000000000000000D+00 * w( 56)
      chem( 50) = chem( 50) -  0.5000000000000000D+00 * w( 56)
      chem( 42) = chem( 42) - w( 57)
      chem( 43) = chem( 43) +  0.5000000000000000D+00 * w( 57)
      chem( 44) = chem( 44) +  0.5000000000000000D+00 * w( 57)
      chem( 50) = chem( 50) -  0.5000000000000000D+00 * w( 57)
      chem( 22) = chem( 22) - w( 58)
      chem( 50) = chem( 50) - w( 58)
      chem( 58) = chem( 58) + w( 58)
      chem( 20) = chem( 20) - w( 59)
      chem( 45) = chem( 45) + w( 59)
      chem( 48) = chem( 48) + w( 59)
      chem( 50) = chem( 50) - w( 59)
      chem( 51) = chem( 51) + w( 59)
      chem( 37) = chem( 37) - w( 60)
      chem( 43) = chem( 43) + w( 60)
      chem( 50) = chem( 50) - w( 60)
      chem( 55) = chem( 55) + w( 60)
      chem( 18) = chem( 18) - w( 61)
      chem( 29) = chem( 29) + w( 61)
      chem( 50) = chem( 50) - w( 61)
      chem( 20) = chem( 20) + w( 62)
      chem( 55) = chem( 55) - w( 62)
      chem( 58) = chem( 58) - w( 62)
      chem( 20) = chem( 20) - w( 63)
      chem( 55) = chem( 55) + w( 63)
      chem( 58) = chem( 58) + w( 63)
      chem( 14) = chem( 14) + w( 64)
      chem( 54) = chem( 54) - w( 64)
      chem( 55) = chem( 55) - w( 64)
      chem( 14) = chem( 14) - w( 65)
      chem( 54) = chem( 54) + w( 65)
      chem( 55) = chem( 55) + w( 65)
      chem( 46) = chem( 46) - w( 66)
      chem( 48) = chem( 48) + w( 66)
      chem( 55) = chem( 55) + w( 66)
      chem( 56) = chem( 56) - w( 66)
      chem( 57) = chem( 57) + w( 66)
      chem( 37) = chem( 37) +  0.3600000000000000D-01 * w( 67)
      chem( 38) = chem( 38) +  0.2500000000000000D+00 * w( 67)
      chem( 43) = chem( 43) - w( 67)
      chem( 44) = chem( 44) +  0.7500000000000000D+00 * w( 67)
      chem( 48) = chem( 48) +  0.9000000000000000D-01 * w( 67)
      chem( 55) = chem( 55) +  0.9640000000000000D+00 * w( 67)
      chem( 56) = chem( 56) - w( 67)
      chem( 57) = chem( 57) +  0.9640000000000000D+00 * w( 67)
      chem( 27) = chem( 27) - w( 68)
      chem( 37) = chem( 37) +  0.8000000000000000D-01 * w( 68)
      chem( 38) = chem( 38) +  0.6899999999999999D+00 * w( 68)
      chem( 44) = chem( 44) +  0.3800000000000000D+00 * w( 68)
      chem( 55) = chem( 55) +  0.9200000000000000D+00 * w( 68)
      chem( 56) = chem( 56) - w( 68)
      chem( 57) = chem( 57) +  0.9200000000000000D+00 * w( 68)
      chem( 28) = chem( 28) - w( 69)
      chem( 37) = chem( 37) +  0.2400000000000000D+00 * w( 69)
      chem( 38) = chem( 38) +  0.1060000000000000D+01 * w( 69)
      chem( 44) = chem( 44) +  0.3500000000000000D+00 * w( 69)
      chem( 48) = chem( 48) +  0.4000000000000000D-01 * w( 69)
      chem( 55) = chem( 55) +  0.7600000000000000D+00 * w( 69)
      chem( 56) = chem( 56) - w( 69)
      chem( 57) = chem( 57) +  0.7600000000000000D+00 * w( 69)
      chem( 34) = chem( 34) - w( 70)
      chem( 44) = chem( 44) +  0.2000000000000000D+00 * w( 70)
      chem( 48) = chem( 48) +  0.1600000000000000D+01 * w( 70)
      chem( 55) = chem( 55) + w( 70)
      chem( 56) = chem( 56) - w( 70)
      chem( 57) = chem( 57) + w( 70)
      chem( 29) = chem( 29) - w( 71)
      chem( 44) = chem( 44) + w( 71)
      chem( 48) = chem( 48) + w( 71)
      chem( 55) = chem( 55) + w( 71)
      chem( 56) = chem( 56) - w( 71)
      chem( 57) = chem( 57) + w( 71)
      chem( 30) = chem( 30) - w( 72)
      chem( 38) = chem( 38) +  0.1000000000000000D+00 * w( 72)
      chem( 44) = chem( 44) +  0.1450000000000000D+01 * w( 72)
      chem( 48) = chem( 48) +  0.2800000000000000D+00 * w( 72)
      chem( 55) = chem( 55) + w( 72)
      chem( 56) = chem( 56) - w( 72)
      chem( 57) = chem( 57) + w( 72)
      chem( 46) = chem( 46) + w( 73)
      chem( 55) = chem( 55) + w( 73)
      chem( 56) = chem( 56) - w( 73)
      chem( 58) = chem( 58) - w( 73)
      chem( 45) = chem( 45) +  0.2000000000000000D+01 * w( 74)
      chem( 47) = chem( 47) +  0.8900000000000000D+00 * w( 74)
      chem( 52) = chem( 52) +  0.1100000000000000D+00 * w( 74)
      chem( 53) = chem( 53) +  0.9500000000000000D+00 * w( 74)
      chem( 54) = chem( 54) - w( 74)
      chem( 55) = chem( 55) + w( 74)
      chem( 56) = chem( 56) - w( 74)
      chem( 57) = chem( 57) +  0.9200000000000000D+00 * w( 74)
      chem( 58) = chem( 58) +  0.5000000000000000D-01 * w( 74)
      chem( 31) = chem( 31) - w( 75)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w( 75)
      chem( 47) = chem( 47) +  0.1600000000000000D+00 * w( 75)
      chem( 52) = chem( 52) +  0.1700000000000000D+00 * w( 75)
      chem( 55) = chem( 55) + w( 75)
      chem( 56) = chem( 56) - w( 75)
      chem( 57) = chem( 57) + w( 75)
      chem( 32) = chem( 32) - w( 76)
      chem( 33) = chem( 33) +  0.8060000000000000D+00 * w( 76)
      chem( 52) = chem( 52) +  0.4500000000000000D+00 * w( 76)
      chem( 55) = chem( 55) + w( 76)
      chem( 56) = chem( 56) - w( 76)
      chem( 57) = chem( 57) + w( 76)
      chem( 39) = chem( 39) - w( 77)
      chem( 44) = chem( 44) + w( 77)
      chem( 55) = chem( 55) + w( 77)
      chem( 56) = chem( 56) - w( 77)
      chem( 57) = chem( 57) + w( 77)
      chem( 40) = chem( 40) - w( 78)
      chem( 52) = chem( 52) + w( 78)
      chem( 55) = chem( 55) + w( 78)
      chem( 56) = chem( 56) - w( 78)
      chem( 57) = chem( 57) + w( 78)
      chem( 35) = chem( 35) - w( 79)
      chem( 44) = chem( 44) + w( 79)
      chem( 48) = chem( 48) + w( 79)
      chem( 55) = chem( 55) +  0.2000000000000000D+01 * w( 79)
      chem( 56) = chem( 56) - w( 79)
      chem( 48) = chem( 48) - w( 80)
      chem( 49) = chem( 49) + w( 80)
      chem( 51) = chem( 51) - w( 80)
      chem( 53) = chem( 53) + w( 80)
      chem( 57) = chem( 57) + w( 80)
      chem( 44) = chem( 44) - w( 81)
      chem( 49) = chem( 49) + w( 81)
      chem( 51) = chem( 51) - w( 81)
      chem( 58) = chem( 58) + w( 81)
      chem( 47) = chem( 47) - w( 82)
      chem( 49) = chem( 49) + w( 82)
      chem( 51) = chem( 51) - w( 82)
      chem( 53) = chem( 53) +  0.2000000000000000D+01 * w( 82)
      chem( 57) = chem( 57) + w( 82)
      chem( 49) = chem( 49) + w( 83)
      chem( 51) = chem( 51) - w( 83)
      chem( 52) = chem( 52) - w( 83)
      chem( 53) = chem( 53) + w( 83)
      chem( 58) = chem( 58) + w( 83)
      chem( 33) = chem( 33) - w( 84)
      chem( 49) = chem( 49) + w( 84)
      chem( 51) = chem( 51) - w( 84)
      chem( 54) = chem( 54) + w( 84)
      chem( 13) = chem( 13) -  0.5000000000000000D+00 * w( 85)
      chem( 36) = chem( 36) + w( 85)
      chem( 49) = chem( 49) + w( 85)
      chem( 51) = chem( 51) - w( 85)
      chem( 25) = chem( 25) - w( 86)
      chem( 35) = chem( 35) + w( 86)
      chem( 51) = chem( 51) - w( 86)
      chem( 15) = chem( 15) - w( 87)
      chem( 35) = chem( 35) + w( 87)
      chem( 51) = chem( 51) - w( 87)
      chem( 16) = chem( 16) - w( 88)
      chem( 35) = chem( 35) + w( 88)
      chem( 51) = chem( 51) - w( 88)
      chem( 18) = chem( 18) - w( 89)
      chem( 35) = chem( 35) + w( 89)
      chem( 51) = chem( 51) - w( 89)
      chem( 19) = chem( 19) +  0.4000000000000000D+00 * w( 90)
      chem( 25) = chem( 25) - w( 90)
      chem( 26) = chem( 26) - w( 90)
      chem( 48) = chem( 48) + w( 90)
      chem( 53) = chem( 53) +  0.4200000000000000D+00 * w( 90)
      chem( 57) = chem( 57) +  0.1200000000000000D+00 * w( 90)
      chem( 15) = chem( 15) - w( 91)
      chem( 17) = chem( 17) +  0.6000000000000000D-01 * w( 91)
      chem( 19) = chem( 19) +  0.2000000000000000D+00 * w( 91)
      chem( 26) = chem( 26) - w( 91)
      chem( 41) = chem( 41) +  0.2000000000000000D+00 * w( 91)
      chem( 44) = chem( 44) +  0.5000000000000000D+00 * w( 91)
      chem( 46) = chem( 46) +  0.2200000000000000D+00 * w( 91)
      chem( 48) = chem( 48) +  0.5300000000000000D+00 * w( 91)
      chem( 50) = chem( 50) +  0.1000000000000000D+00 * w( 91)
      chem( 53) = chem( 53) +  0.3300000000000000D+00 * w( 91)
      chem( 57) = chem( 57) +  0.2300000000000000D+00 * w( 91)
      chem( 16) = chem( 16) - w( 92)
      chem( 17) = chem( 17) +  0.9000000000000000D-01 * w( 92)
      chem( 19) = chem( 19) +  0.6000000000000000D-01 * w( 92)
      chem( 26) = chem( 26) - w( 92)
      chem( 38) = chem( 38) +  0.1000000000000000D+00 * w( 92)
      chem( 41) = chem( 41) +  0.2900000000000000D+00 * w( 92)
      chem( 44) = chem( 44) +  0.7200000000000000D+00 * w( 92)
      chem( 46) = chem( 46) +  0.3100000000000000D+00 * w( 92)
      chem( 48) = chem( 48) +  0.1800000000000000D+00 * w( 92)
      chem( 50) = chem( 50) +  0.1400000000000000D+00 * w( 92)
      chem( 53) = chem( 53) +  0.2300000000000000D+00 * w( 92)
      chem( 57) = chem( 57) +  0.2600000000000000D+00 * w( 92)
      chem( 18) = chem( 18) - w( 93)
      chem( 19) = chem( 19) +  0.2000000000000000D+00 * w( 93)
      chem( 26) = chem( 26) - w( 93)
      chem( 41) = chem( 41) +  0.2000000000000000D+00 * w( 93)
      chem( 44) = chem( 44) +  0.5000000000000000D+00 * w( 93)
      chem( 46) = chem( 46) +  0.2200000000000000D+00 * w( 93)
      chem( 48) = chem( 48) +  0.5300000000000000D+00 * w( 93)
      chem( 50) = chem( 50) +  0.1000000000000000D+00 * w( 93)
      chem( 53) = chem( 53) +  0.3300000000000000D+00 * w( 93)
      chem( 57) = chem( 57) +  0.2300000000000000D+00 * w( 93)
      chem( 21) = chem( 21) + w( 94)
      chem( 46) = chem( 46) - w( 94)
      chem( 57) = chem( 57) - w( 94)
      chem( 39) = chem( 39) - w( 95)
      chem( 42) = chem( 42) + w( 95)
      chem( 57) = chem( 57) - w( 95)
      chem( 42) = chem( 42) + w( 96)
      chem( 43) = chem( 43) - w( 96)
      chem( 57) = chem( 57) - w( 96)
      chem( 27) = chem( 27) - w( 97)
      chem( 42) = chem( 42) + w( 97)
      chem( 57) = chem( 57) - w( 97)
      chem( 28) = chem( 28) - w( 98)
      chem( 42) = chem( 42) + w( 98)
      chem( 57) = chem( 57) - w( 98)
      chem( 34) = chem( 34) - w( 99)
      chem( 42) = chem( 42) + w( 99)
      chem( 57) = chem( 57) - w( 99)
      chem( 29) = chem( 29) - w(100)
      chem( 42) = chem( 42) + w(100)
      chem( 57) = chem( 57) - w(100)
      chem( 30) = chem( 30) - w(101)
      chem( 42) = chem( 42) + w(101)
      chem( 57) = chem( 57) - w(101)
      chem( 40) = chem( 40) - w(102)
      chem( 42) = chem( 42) + w(102)
      chem( 57) = chem( 57) - w(102)
      chem( 22) = chem( 22) + w(103)
      chem( 57) = chem( 57) - w(103)
      chem( 58) = chem( 58) - w(103)
      chem( 31) = chem( 31) - w(104)
      chem( 42) = chem( 42) + w(104)
      chem( 57) = chem( 57) - w(104)
      chem( 32) = chem( 32) - w(105)
      chem( 42) = chem( 42) + w(105)
      chem( 57) = chem( 57) - w(105)
      chem( 42) = chem( 42) + w(106)
      chem( 54) = chem( 54) - w(106)
      chem( 57) = chem( 57) - w(106)
      chem( 35) = chem( 35) - w(107)
      chem( 37) = chem( 37) + w(107)
      chem( 57) = chem( 57) - w(107)
      chem( 46) = chem( 46) -  0.2000000000000000D+01 * w(108)
      chem( 48) = chem( 48) +  0.1500000000000000D+01 * w(108)
      chem( 57) = chem( 57) + w(108)
      chem( 39) = chem( 39) - w(109)
      chem( 44) = chem( 44) +  0.7500000000000000D+00 * w(109)
      chem( 46) = chem( 46) - w(109)
      chem( 48) = chem( 48) +  0.7500000000000000D+00 * w(109)
      chem( 57) = chem( 57) + w(109)
      chem( 38) = chem( 38) +  0.2600000000000000D+00 * w(110)
      chem( 43) = chem( 43) - w(110)
      chem( 44) = chem( 44) +  0.7700000000000000D+00 * w(110)
      chem( 46) = chem( 46) - w(110)
      chem( 48) = chem( 48) +  0.8400000000000000D+00 * w(110)
      chem( 57) = chem( 57) + w(110)
      chem( 27) = chem( 27) - w(111)
      chem( 38) = chem( 38) +  0.7500000000000000D+00 * w(111)
      chem( 44) = chem( 44) +  0.4100000000000000D+00 * w(111)
      chem( 46) = chem( 46) - w(111)
      chem( 48) = chem( 48) +  0.7700000000000000D+00 * w(111)
      chem( 57) = chem( 57) + w(111)
      chem( 28) = chem( 28) - w(112)
      chem( 38) = chem( 38) +  0.1390000000000000D+01 * w(112)
      chem( 44) = chem( 44) +  0.4600000000000000D+00 * w(112)
      chem( 46) = chem( 46) - w(112)
      chem( 48) = chem( 48) +  0.8000000000000000D+00 * w(112)
      chem( 57) = chem( 57) + w(112)
      chem( 34) = chem( 34) - w(113)
      chem( 44) = chem( 44) +  0.3500000000000000D+00 * w(113)
      chem( 46) = chem( 46) - w(113)
      chem( 48) = chem( 48) +  0.1550000000000000D+01 * w(113)
      chem( 57) = chem( 57) + w(113)
      chem( 29) = chem( 29) - w(114)
      chem( 44) = chem( 44) +  0.7500000000000000D+00 * w(114)
      chem( 46) = chem( 46) - w(114)
      chem( 48) = chem( 48) +  0.1250000000000000D+01 * w(114)
      chem( 57) = chem( 57) + w(114)
      chem( 30) = chem( 30) - w(115)
      chem( 38) = chem( 38) +  0.5500000000000000D+00 * w(115)
      chem( 44) = chem( 44) +  0.7250000000000000D+00 * w(115)
      chem( 46) = chem( 46) - w(115)
      chem( 48) = chem( 48) +  0.8900000000000000D+00 * w(115)
      chem( 57) = chem( 57) + w(115)
      chem( 40) = chem( 40) - w(116)
      chem( 46) = chem( 46) - w(116)
      chem( 48) = chem( 48) +  0.7500000000000000D+00 * w(116)
      chem( 52) = chem( 52) +  0.7500000000000000D+00 * w(116)
      chem( 57) = chem( 57) + w(116)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(117)
      chem( 46) = chem( 46) -  0.5000000000000000D+00 * w(117)
      chem( 48) = chem( 48) + w(117)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(117)
      chem( 58) = chem( 58) - w(117)
      chem( 31) = chem( 31) - w(118)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w(118)
      chem( 46) = chem( 46) - w(118)
      chem( 47) = chem( 47) +  0.1600000000000000D+00 * w(118)
      chem( 48) = chem( 48) + w(118)
      chem( 52) = chem( 52) +  0.1700000000000000D+00 * w(118)
      chem( 57) = chem( 57) +  0.2000000000000000D+01 * w(118)
      chem( 32) = chem( 32) - w(119)
      chem( 33) = chem( 33) +  0.8060000000000000D+00 * w(119)
      chem( 46) = chem( 46) - w(119)
      chem( 48) = chem( 48) + w(119)
      chem( 52) = chem( 52) +  0.4500000000000000D+00 * w(119)
      chem( 57) = chem( 57) +  0.2000000000000000D+01 * w(119)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(120)
      chem( 45) = chem( 45) + w(120)
      chem( 46) = chem( 46) - w(120)
      chem( 47) = chem( 47) +  0.4450000000000000D+00 * w(120)
      chem( 48) = chem( 48) +  0.5000000000000000D+00 * w(120)
      chem( 52) = chem( 52) +  0.5500000000000000D-01 * w(120)
      chem( 53) = chem( 53) +  0.4750000000000000D+00 * w(120)
      chem( 54) = chem( 54) - w(120)
      chem( 57) = chem( 57) +  0.4600000000000000D+00 * w(120)
      chem( 58) = chem( 58) +  0.2500000000000000D-01 * w(120)
      chem( 35) = chem( 35) - w(121)
      chem( 44) = chem( 44) + w(121)
      chem( 46) = chem( 46) - w(121)
      chem( 48) = chem( 48) +  0.1750000000000000D+01 * w(121)
      chem( 55) = chem( 55) + w(121)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(121)
      chem( 39) = chem( 39) - w(122)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(122)
      chem( 44) = chem( 44) + w(122)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(122)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(122)
      chem( 58) = chem( 58) - w(122)
      chem( 38) = chem( 38) +  0.2600000000000000D+00 * w(123)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(123)
      chem( 43) = chem( 43) - w(123)
      chem( 44) = chem( 44) +  0.7700000000000000D+00 * w(123)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(123)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(123)
      chem( 58) = chem( 58) - w(123)
      chem( 27) = chem( 27) - w(124)
      chem( 38) = chem( 38) +  0.7500000000000000D+00 * w(124)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(124)
      chem( 44) = chem( 44) +  0.4100000000000000D+00 * w(124)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(124)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(124)
      chem( 58) = chem( 58) - w(124)
      chem( 28) = chem( 28) - w(125)
      chem( 38) = chem( 38) +  0.1390000000000000D+01 * w(125)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(125)
      chem( 44) = chem( 44) +  0.4600000000000000D+00 * w(125)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(125)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(125)
      chem( 58) = chem( 58) - w(125)
      chem( 34) = chem( 34) - w(126)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(126)
      chem( 44) = chem( 44) +  0.6000000000000000D+00 * w(126)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(126)
      chem( 48) = chem( 48) +  0.8000000000000000D+00 * w(126)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(126)
      chem( 58) = chem( 58) - w(126)
      chem( 29) = chem( 29) - w(127)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(127)
      chem( 44) = chem( 44) + w(127)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(127)
      chem( 48) = chem( 48) +  0.5000000000000000D+00 * w(127)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(127)
      chem( 58) = chem( 58) - w(127)
      chem( 30) = chem( 30) - w(128)
      chem( 38) = chem( 38) +  0.5500000000000000D+00 * w(128)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(128)
      chem( 44) = chem( 44) +  0.7250000000000000D+00 * w(128)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(128)
      chem( 48) = chem( 48) +  0.1400000000000000D+00 * w(128)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(128)
      chem( 58) = chem( 58) - w(128)
      chem( 40) = chem( 40) - w(129)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(129)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(129)
      chem( 52) = chem( 52) + w(129)
      chem( 57) = chem( 57) +  0.5000000000000000D+00 * w(129)
      chem( 58) = chem( 58) - w(129)
      chem( 46) = chem( 46) +  0.2000000000000000D+01 * w(130)
      chem( 58) = chem( 58) -  0.2000000000000000D+01 * w(130)
      chem( 31) = chem( 31) - w(131)
      chem( 33) = chem( 33) +  0.7000000000000000D+00 * w(131)
      chem( 46) = chem( 46) + w(131)
      chem( 47) = chem( 47) +  0.1600000000000000D+00 * w(131)
      chem( 52) = chem( 52) +  0.1700000000000000D+00 * w(131)
      chem( 57) = chem( 57) + w(131)
      chem( 58) = chem( 58) - w(131)
      chem( 32) = chem( 32) - w(132)
      chem( 33) = chem( 33) +  0.8060000000000000D+00 * w(132)
      chem( 46) = chem( 46) + w(132)
      chem( 52) = chem( 52) +  0.4500000000000000D+00 * w(132)
      chem( 57) = chem( 57) + w(132)
      chem( 58) = chem( 58) - w(132)
      chem( 45) = chem( 45) +  0.2000000000000000D+01 * w(133)
      chem( 46) = chem( 46) + w(133)
      chem( 47) = chem( 47) +  0.8900000000000000D+00 * w(133)
      chem( 52) = chem( 52) +  0.1100000000000000D+00 * w(133)
      chem( 53) = chem( 53) +  0.9500000000000000D+00 * w(133)
      chem( 54) = chem( 54) - w(133)
      chem( 57) = chem( 57) +  0.9200000000000000D+00 * w(133)
      chem( 58) = chem( 58) -  0.9500000000000000D+00 * w(133)
      chem( 35) = chem( 35) - w(134)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(134)
      chem( 44) = chem( 44) + w(134)
      chem( 46) = chem( 46) +  0.5000000000000000D+00 * w(134)
      chem( 48) = chem( 48) + w(134)
      chem( 55) = chem( 55) + w(134)
      chem( 58) = chem( 58) - w(134)
      chem( 35) = chem( 35) -  0.2000000000000000D+01 * w(135)
      chem( 44) = chem( 44) +  0.2000000000000000D+01 * w(135)
      chem( 48) = chem( 48) +  0.2000000000000000D+01 * w(135)
      chem( 55) = chem( 55) +  0.2000000000000000D+01 * w(135)
      chem( 42) = chem( 42) + w(136)
      chem( 45) = chem( 45) - w(136)
      chem( 57) = chem( 57) - w(136)
      chem( 45) = chem( 45) - w(137)
      chem( 46) = chem( 46) - w(137)
      chem( 48) = chem( 48) + w(137)
      chem( 57) = chem( 57) + w(137)
      chem( 45) = chem( 45) - w(138)
      chem( 46) = chem( 46) + w(138)
      chem( 58) = chem( 58) - w(138)
      chem( 45) = chem( 45) -  0.2000000000000000D+01 * w(139)
      chem( 45) = chem( 45) - w(140)
      chem( 55) = chem( 55) + w(140)
      chem( 56) = chem( 56) - w(140)
      chem( 36) = chem( 36) - w(141)
      chem( 37) = chem( 37) + w(141)
      chem( 55) = chem( 55) - w(141)
      chem( 36) = chem( 36) - w(142)
      chem( 42) = chem( 42) + w(142)
      chem( 57) = chem( 57) - w(142)
      chem( 36) = chem( 36) - w(143)
      chem( 46) = chem( 46) - w(143)
      chem( 48) = chem( 48) + w(143)
      chem( 57) = chem( 57) + w(143)
      chem( 36) = chem( 36) - w(144)
      chem( 46) = chem( 46) + w(144)
      chem( 58) = chem( 58) - w(144)
      chem( 36) = chem( 36) -  0.2000000000000000D+01 * w(145)
      chem( 24) = chem( 24) + w(146)
      chem( 55) = chem( 55) - w(146)
      chem( 57) = chem( 57) - w(146)
      chem( 12) = chem( 12) + w(147)
      chem( 50) = chem( 50) - w(147)
      chem( 56) = chem( 56) - w(147)
      chem( 11) = chem( 11) + w(148)
      chem( 51) = chem( 51) - w(148)
      chem( 55) = chem( 55) - w(148)
      chem( 49) = chem( 49) + w(149)
      chem( 50) = chem( 50) - w(149)
      chem( 55) = chem( 55) - w(149)
      chem(  1) = chem(  1) - w(150)
      chem(  9) = chem(  9) + w(150)
      chem( 50) = chem( 50) - w(150)
      chem( 57) = chem( 57) + w(150)
      chem( 24) = chem( 24) - w(151)
      chem( 55) = chem( 55) + w(151)
      chem( 57) = chem( 57) + w(151)
      chem( 11) = chem( 11) - w(152)
      chem( 51) = chem( 51) + w(152)
      chem( 55) = chem( 55) + w(152)
      chem( 23) = chem( 23) - w(153)
      chem( 26) = chem( 26) + w(153)
      chem( 10) = chem( 10) + w(154)
      chem( 57) = chem( 57) -  0.2000000000000000D+01 * w(154)
      chem( 10) = chem( 10) + w(155)
      chem( 57) = chem( 57) -  0.2000000000000000D+01 * w(155)
      chem( 49) = chem( 49) - w(156)
      chem( 50) = chem( 50) - w(156)
      chem( 51) = chem( 51) + w(156)
      chem( 50) = chem( 50) - w(157)
      chem( 53) = chem( 53) - w(157)
      chem( 57) = chem( 57) + w(157)
 
C    Conversion molecules/cm3 to mug/m3.
 
      do i = 1, ns
         chem(i) = chem(i) / convers_factor(i)
      enddo
 
C     Volumic source terms.
 
      do i=1,ns
      chem(i)=chem(i)+ZCsourc(i)
      enddo
 
      RETURN
      END
 
