C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 80) = M(3, 80) / M(3, 3)

C     Upper part.
      M(4, 80) = M(4, 80) / M(4, 4)

C     Upper part.
      M(5, 80) = M(5, 80) / M(5, 5)

C     Upper part.
      M(6, 80) = M(6, 80) / M(6, 6)

C     Upper part.
      M(7, 80) = M(7, 80) / M(7, 7)

C     Upper part.
      M(8, 80) = M(8, 80) / M(8, 8)

C     Upper part.
      M(9, 65) = M(9, 65) / M(9, 9)

C     Upper part.
      temp = M(10, 3) * M(3, 80)
      M(10, 80) = ( M(10, 80) - temp ) / M(10, 10)

C     Upper part.
      M(11, 80) = M(11, 80) / M(11, 11)

C     Upper part.
      temp = M(12, 11) * M(11, 80)
      M(12, 80) = ( M(12, 80) - temp ) / M(12, 12)

C     Upper part.
      M(13, 80) = M(13, 80) / M(13, 13)

C     Upper part.
      M(14, 80) = M(14, 80) / M(14, 14)

C     Upper part.
      M(15, 80) = M(15, 80) / M(15, 15)

C     Upper part.
      temp = M(16, 13) * M(13, 80)
      temp = temp + M(16, 14) * M(14, 80)
      temp = temp + M(16, 15) * M(15, 80)
      M(16, 80) = ( M(16, 80) - temp ) / M(16, 16)

C     Upper part.
      M(17, 84) = M(17, 84) / M(17, 17)
C     Upper part.
      M(17, 87) = M(17, 87) / M(17, 17)

C     Upper part.
      M(18, 54) = M(18, 54) / M(18, 18)
C     Upper part.
      M(18, 80) = M(18, 80) / M(18, 18)

C     Upper part.
      M(19, 35) = M(19, 35) / M(19, 19)
C     Upper part.
      M(19, 80) = M(19, 80) / M(19, 19)

C     Upper part.
      M(20, 35) = M(20, 35) / M(20, 20)
C     Upper part.
      M(20, 80) = M(20, 80) / M(20, 20)

C     Upper part.
      M(21, 80) = M(21, 80) / M(21, 21)
C     Upper part.
      M(21, 82) = M(21, 82) / M(21, 21)
C     Upper part.
      M(21, 88) = M(21, 88) / M(21, 21)

C     Upper part.
      M(22, 65) = M(22, 65) / M(22, 22)
C     Upper part.
      temp = M(22, 7) * M(7, 80)
      M(22, 80) = ( M(22, 80) - temp ) / M(22, 22)
C     Upper part.
      M(22, 84) = M(22, 84) / M(22, 22)

C     Upper part.
      M(23, 65) = M(23, 65) / M(23, 23)
C     Upper part.
      temp = M(23, 8) * M(8, 80)
      M(23, 80) = ( M(23, 80) - temp ) / M(23, 23)
C     Upper part.
      M(23, 84) = M(23, 84) / M(23, 23)

C     Upper part.
      M(24, 80) = M(24, 80) / M(24, 24)
C     Upper part.
      M(24, 84) = M(24, 84) / M(24, 24)
C     Upper part.
      M(24, 88) = M(24, 88) / M(24, 24)

C     Upper part.
      M(25, 65) = M(25, 65) / M(25, 25)
C     Upper part.
      M(25, 80) = M(25, 80) / M(25, 25)
C     Upper part.
      M(25, 87) = M(25, 87) / M(25, 25)

C     Upper part.
      M(26, 65) = M(26, 65) / M(26, 26)
C     Upper part.
      M(26, 80) = M(26, 80) / M(26, 26)
C     Upper part.
      M(26, 87) = M(26, 87) / M(26, 26)

C     Upper part.
      M(27, 65) = M(27, 65) / M(27, 27)
C     Upper part.
      M(27, 80) = M(27, 80) / M(27, 27)
C     Upper part.
      M(27, 87) = M(27, 87) / M(27, 27)

C     Upper part.
      M(28, 30) = M(28, 30) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 65)
      M(28, 65) = ( M(28, 65) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 80)
      M(28, 80) = ( M(28, 80) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 87)
      M(28, 87) = ( M(28, 87) - temp ) / M(28, 28)

C     Upper part.
      M(29, 30) = M(29, 30) / M(29, 29)
C     Upper part.
      temp = M(29, 27) * M(27, 65)
      M(29, 65) = ( M(29, 65) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 11) * M(11, 80)
      temp = temp + M(29, 27) * M(27, 80)
      M(29, 80) = ( M(29, 80) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 27) * M(27, 87)
      M(29, 87) = ( M(29, 87) - temp ) / M(29, 29)

C     Upper part.
      M(30, 65) = M(30, 65) / M(30, 30)
C     Upper part.
      M(30, 80) = M(30, 80) / M(30, 30)
C     Upper part.
      M(30, 87) = M(30, 87) / M(30, 30)

C     Upper part.
      temp = M(31, 27) * M(27, 65)
      temp = temp + M(31, 30) * M(30, 65)
      M(31, 65) = ( M(31, 65) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 27) * M(27, 80)
      temp = temp + M(31, 30) * M(30, 80)
      M(31, 80) = ( M(31, 80) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 27) * M(27, 87)
      temp = temp + M(31, 30) * M(30, 87)
      M(31, 87) = ( M(31, 87) - temp ) / M(31, 31)

C     Upper part.
      temp = M(32, 27) * M(27, 65)
      temp = temp + M(32, 30) * M(30, 65)
      M(32, 65) = ( M(32, 65) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 27) * M(27, 80)
      temp = temp + M(32, 30) * M(30, 80)
      M(32, 80) = ( M(32, 80) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 27) * M(27, 87)
      temp = temp + M(32, 30) * M(30, 87)
      M(32, 87) = ( M(32, 87) - temp ) / M(32, 32)

C     Upper part.
      M(33, 36) = M(33, 36) / M(33, 33)
C     Upper part.
      temp = M(33, 22) * M(22, 65)
      temp = temp + M(33, 23) * M(23, 65)
      M(33, 65) = ( M(33, 65) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 22) * M(22, 80)
      temp = temp + M(33, 23) * M(23, 80)
      M(33, 80) = ( M(33, 80) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 22) * M(22, 84)
      temp = temp + M(33, 23) * M(23, 84)
      M(33, 84) = ( M(33, 84) - temp ) / M(33, 33)
C     Upper part.
      M(33, 85) = M(33, 85) / M(33, 33)

C     Upper part.
      M(34, 60) = M(34, 60) / M(34, 34)
C     Upper part.
      M(34, 62) = M(34, 62) / M(34, 34)
C     Upper part.
      M(34, 65) = M(34, 65) / M(34, 34)
C     Upper part.
      M(34, 80) = M(34, 80) / M(34, 34)

C     Upper part.
      M(35, 43) = M(35, 43) / M(35, 35)
C     Upper part.
      M(35, 65) = M(35, 65) / M(35, 35)
C     Upper part.
      M(35, 80) = M(35, 80) / M(35, 35)
C     Upper part.
      M(35, 87) = M(35, 87) / M(35, 35)

C     Lower part.
      temp = M(80, 33) * M(33, 36)
      M(80, 36) = M(80, 36) - temp
C     Lower part.
      temp = M(84, 33) * M(33, 36)
      M(84, 36) = M(84, 36) - temp
C     Lower part.
      temp = M(85, 33) * M(33, 36)
      M(85, 36) = M(85, 36) - temp
C     Upper part.
      M(36, 45) = M(36, 45) / M(36, 36)
C     Upper part.
      M(36, 65) = M(36, 65) / M(36, 36)
C     Upper part.
      M(36, 80) = M(36, 80) / M(36, 36)
C     Upper part.
      M(36, 84) = M(36, 84) / M(36, 36)

C     Upper part.
      M(37, 60) = M(37, 60) / M(37, 37)
C     Upper part.
      M(37, 62) = M(37, 62) / M(37, 37)
C     Upper part.
      M(37, 65) = M(37, 65) / M(37, 37)
C     Upper part.
      M(37, 80) = M(37, 80) / M(37, 37)

C     Upper part.
      M(38, 54) = M(38, 54) / M(38, 38)
C     Upper part.
      M(38, 65) = M(38, 65) / M(38, 38)
C     Upper part.
      M(38, 80) = M(38, 80) / M(38, 38)
C     Upper part.
      M(38, 88) = M(38, 88) / M(38, 38)
C     Upper part.
      M(38, 89) = M(38, 89) / M(38, 38)

C     Upper part.
      M(39, 45) = M(39, 45) / M(39, 39)
C     Upper part.
      M(39, 80) = M(39, 80) / M(39, 39)
C     Upper part.
      M(39, 84) = M(39, 84) / M(39, 39)
C     Upper part.
      M(39, 87) = M(39, 87) / M(39, 39)
C     Upper part.
      M(39, 88) = M(39, 88) / M(39, 39)

C     Upper part.
      temp = M(40, 22) * M(22, 65)
      M(40, 65) = ( M(40, 65) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 22) * M(22, 80)
      M(40, 80) = ( M(40, 80) - temp ) / M(40, 40)
C     Upper part.
      M(40, 82) = M(40, 82) / M(40, 40)
C     Upper part.
      temp = M(40, 22) * M(22, 84)
      M(40, 84) = ( M(40, 84) - temp ) / M(40, 40)
C     Upper part.
      M(40, 85) = M(40, 85) / M(40, 40)
C     Upper part.
      M(40, 87) = M(40, 87) / M(40, 40)
C     Upper part.
      M(40, 88) = M(40, 88) / M(40, 40)
C     Upper part.
      M(40, 89) = M(40, 89) / M(40, 40)

C     Upper part.
      M(41, 51) = M(41, 51) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 65)
      M(41, 65) = ( M(41, 65) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 80)
      M(41, 80) = ( M(41, 80) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 82)
      M(41, 82) = ( M(41, 82) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 84)
      M(41, 84) = ( M(41, 84) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 85)
      M(41, 85) = ( M(41, 85) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 87)
      M(41, 87) = ( M(41, 87) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 88)
      M(41, 88) = ( M(41, 88) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 89)
      M(41, 89) = ( M(41, 89) - temp ) / M(41, 41)

C     Upper part.
      temp = M(42, 36) * M(36, 45)
      M(42, 45) = ( M(42, 45) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 36) * M(36, 65)
      M(42, 65) = ( M(42, 65) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 36) * M(36, 80)
      M(42, 80) = ( M(42, 80) - temp ) / M(42, 42)
C     Upper part.
      M(42, 82) = M(42, 82) / M(42, 42)
C     Upper part.
      temp = M(42, 36) * M(36, 84)
      M(42, 84) = ( M(42, 84) - temp ) / M(42, 42)
C     Upper part.
      M(42, 85) = M(42, 85) / M(42, 42)
C     Upper part.
      M(42, 87) = M(42, 87) / M(42, 42)
C     Upper part.
      M(42, 88) = M(42, 88) / M(42, 42)
C     Upper part.
      M(42, 89) = M(42, 89) / M(42, 42)

C     Lower part.
      temp = M(43, 35) * M(35, 43)
      M(43, 43) = M(43, 43) - temp
C     Lower part.
      temp = M(44, 35) * M(35, 43)
      M(44, 43) = M(44, 43) - temp
C     Lower part.
      temp = M(49, 35) * M(35, 43)
      M(49, 43) = M(49, 43) - temp
C     Lower part.
      temp = M(54, 35) * M(35, 43)
      M(54, 43) = M(54, 43) - temp
C     Lower part.
      temp = M(58, 35) * M(35, 43)
      M(58, 43) = M(58, 43) - temp
C     Lower part.
      temp = M(59, 35) * M(35, 43)
      M(59, 43) = M(59, 43) - temp
C     Lower part.
      temp = M(60, 35) * M(35, 43)
      M(60, 43) = M(60, 43) - temp
C     Lower part.
      temp = M(63, 35) * M(35, 43)
      M(63, 43) = M(63, 43) - temp
C     Lower part.
      temp = M(64, 35) * M(35, 43)
      M(64, 43) = M(64, 43) - temp
C     Lower part.
      temp = M(65, 35) * M(35, 43)
      M(65, 43) = M(65, 43) - temp
C     Lower part.
      temp = M(67, 35) * M(35, 43)
      M(67, 43) = M(67, 43) - temp
C     Lower part.
      temp = M(70, 35) * M(35, 43)
      M(70, 43) = M(70, 43) - temp
C     Lower part.
      temp = M(75, 35) * M(35, 43)
      M(75, 43) = M(75, 43) - temp
C     Lower part.
      temp = M(79, 35) * M(35, 43)
      M(79, 43) = M(79, 43) - temp
C     Lower part.
      temp = M(80, 35) * M(35, 43)
      M(80, 43) = M(80, 43) - temp
C     Lower part.
      temp = M(82, 35) * M(35, 43)
      M(82, 43) = M(82, 43) - temp
C     Lower part.
      temp = M(87, 35) * M(35, 43)
      M(87, 43) = M(87, 43) - temp
C     Lower part.
      temp = M(88, 35) * M(35, 43)
      M(88, 43) = M(88, 43) - temp
C     Lower part.
      temp = M(89, 35) * M(35, 43)
      M(89, 43) = M(89, 43) - temp
C     Upper part.
      M(43, 59) = M(43, 59) / M(43, 43)
C     Upper part.
      temp = M(43, 9) * M(9, 65)
      temp = temp + M(43, 26) * M(26, 65)
      temp = temp + M(43, 35) * M(35, 65)
      M(43, 65) = ( M(43, 65) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 26) * M(26, 80)
      temp = temp + M(43, 35) * M(35, 80)
      M(43, 80) = ( M(43, 80) - temp ) / M(43, 43)
C     Upper part.
      M(43, 84) = M(43, 84) / M(43, 43)
C     Upper part.
      M(43, 85) = M(43, 85) / M(43, 43)
C     Upper part.
      temp = M(43, 26) * M(26, 87)
      temp = temp + M(43, 35) * M(35, 87)
      M(43, 87) = ( M(43, 87) - temp ) / M(43, 43)

C     Upper part.
      temp = M(44, 43) * M(43, 59)
      M(44, 59) = ( M(44, 59) - temp ) / M(44, 44)
C     Upper part.
      M(44, 60) = M(44, 60) / M(44, 44)
C     Upper part.
      M(44, 62) = M(44, 62) / M(44, 44)
C     Upper part.
      temp = M(44, 26) * M(26, 65)
      temp = temp + M(44, 27) * M(27, 65)
      temp = temp + M(44, 30) * M(30, 65)
      temp = temp + M(44, 35) * M(35, 65)
      temp = temp + M(44, 43) * M(43, 65)
      M(44, 65) = ( M(44, 65) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 26) * M(26, 80)
      temp = temp + M(44, 27) * M(27, 80)
      temp = temp + M(44, 30) * M(30, 80)
      temp = temp + M(44, 35) * M(35, 80)
      temp = temp + M(44, 43) * M(43, 80)
      M(44, 80) = ( M(44, 80) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 43) * M(43, 84)
      M(44, 84) = ( M(44, 84) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 43) * M(43, 85)
      M(44, 85) = ( M(44, 85) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 26) * M(26, 87)
      temp = temp + M(44, 27) * M(27, 87)
      temp = temp + M(44, 30) * M(30, 87)
      temp = temp + M(44, 35) * M(35, 87)
      temp = temp + M(44, 43) * M(43, 87)
      M(44, 87) = ( M(44, 87) - temp ) / M(44, 44)
C     Upper part.
      M(44, 88) = M(44, 88) / M(44, 44)

C     Lower part.
      temp = M(45, 36) * M(36, 45)
      temp = temp + M(45, 39) * M(39, 45)
      M(45, 45) = M(45, 45) - temp
C     Lower part.
      temp = M(65, 36) * M(36, 45)
      M(65, 45) = M(65, 45) - temp
C     Lower part.
      temp = M(66, 42) * M(42, 45)
      M(66, 45) = M(66, 45) - temp
C     Lower part.
      temp = M(72, 42) * M(42, 45)
      M(72, 45) = M(72, 45) - temp
C     Lower part.
      temp = M(73, 42) * M(42, 45)
      M(73, 45) = M(73, 45) - temp
C     Lower part.
      temp = M(79, 42) * M(42, 45)
      M(79, 45) = M(79, 45) - temp
C     Lower part.
      temp = M(80, 36) * M(36, 45)
      M(80, 45) = M(80, 45) - temp
C     Lower part.
      temp = M(82, 42) * M(42, 45)
      M(82, 45) = M(82, 45) - temp
C     Lower part.
      temp = M(83, 39) * M(39, 45)
      M(83, 45) = M(83, 45) - temp
C     Lower part.
      temp = M(84, 36) * M(36, 45)
      temp = temp + M(84, 39) * M(39, 45)
      temp = temp + M(84, 42) * M(42, 45)
      M(84, 45) = M(84, 45) - temp
C     Lower part.
      temp = M(85, 36) * M(36, 45)
      temp = temp + M(85, 42) * M(42, 45)
      M(85, 45) = M(85, 45) - temp
C     Lower part.
      temp = M(87, 42) * M(42, 45)
      M(87, 45) = M(87, 45) - temp
C     Lower part.
      temp = M(88, 36) * M(36, 45)
      temp = temp + M(88, 39) * M(39, 45)
      temp = temp + M(88, 42) * M(42, 45)
      M(88, 45) = M(88, 45) - temp
C     Lower part.
      temp = M(89, 42) * M(42, 45)
      M(89, 45) = M(89, 45) - temp
C     Upper part.
      temp = M(45, 22) * M(22, 65)
      temp = temp + M(45, 23) * M(23, 65)
      temp = temp + M(45, 36) * M(36, 65)
      M(45, 65) = ( M(45, 65) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 22) * M(22, 80)
      temp = temp + M(45, 23) * M(23, 80)
      temp = temp + M(45, 36) * M(36, 80)
      temp = temp + M(45, 39) * M(39, 80)
      M(45, 80) = ( M(45, 80) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 22) * M(22, 84)
      temp = temp + M(45, 23) * M(23, 84)
      temp = temp + M(45, 36) * M(36, 84)
      temp = temp + M(45, 39) * M(39, 84)
      M(45, 84) = ( M(45, 84) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 39) * M(39, 87)
      M(45, 87) = ( M(45, 87) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 39) * M(39, 88)
      M(45, 88) = ( M(45, 88) - temp ) / M(45, 45)

C     Upper part.
      M(46, 51) = M(46, 51) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 65)
      temp = temp + M(46, 45) * M(45, 65)
      M(46, 65) = ( M(46, 65) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 80)
      temp = temp + M(46, 45) * M(45, 80)
      M(46, 80) = ( M(46, 80) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 82)
      M(46, 82) = ( M(46, 82) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 84)
      temp = temp + M(46, 45) * M(45, 84)
      M(46, 84) = ( M(46, 84) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 85)
      M(46, 85) = ( M(46, 85) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 87)
      temp = temp + M(46, 45) * M(45, 87)
      M(46, 87) = ( M(46, 87) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 88)
      temp = temp + M(46, 45) * M(45, 88)
      M(46, 88) = ( M(46, 88) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 40) * M(40, 89)
      M(46, 89) = ( M(46, 89) - temp ) / M(46, 46)

C     Upper part.
      M(47, 48) = M(47, 48) / M(47, 47)
C     Upper part.
      M(47, 59) = M(47, 59) / M(47, 47)
C     Upper part.
      M(47, 70) = M(47, 70) / M(47, 47)
C     Upper part.
      temp = M(47, 6) * M(6, 80)
      M(47, 80) = ( M(47, 80) - temp ) / M(47, 47)
C     Upper part.
      M(47, 82) = M(47, 82) / M(47, 47)

C     Lower part.
      temp = M(72, 47) * M(47, 48)
      M(72, 48) = M(72, 48) - temp
C     Lower part.
      temp = M(79, 47) * M(47, 48)
      M(79, 48) = M(79, 48) - temp
C     Lower part.
      temp = M(80, 47) * M(47, 48)
      M(80, 48) = M(80, 48) - temp
C     Lower part.
      temp = M(88, 47) * M(47, 48)
      M(88, 48) = M(88, 48) - temp
C     Lower part.
      temp = M(89, 47) * M(47, 48)
      M(89, 48) = M(89, 48) - temp
C     Upper part.
      M(48, 65) = M(48, 65) / M(48, 48)
C     Upper part.
      M(48, 80) = M(48, 80) / M(48, 48)
C     Upper part.
      M(48, 84) = M(48, 84) / M(48, 48)
C     Upper part.
      M(48, 86) = M(48, 86) / M(48, 48)
C     Upper part.
      M(48, 87) = M(48, 87) / M(48, 48)

C     Upper part.
      M(49, 54) = M(49, 54) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 59)
      M(49, 59) = ( M(49, 59) - temp ) / M(49, 49)
C     Upper part.
      M(49, 60) = M(49, 60) / M(49, 49)
C     Upper part.
      temp = M(49, 25) * M(25, 65)
      temp = temp + M(49, 26) * M(26, 65)
      temp = temp + M(49, 30) * M(30, 65)
      temp = temp + M(49, 35) * M(35, 65)
      temp = temp + M(49, 43) * M(43, 65)
      temp = temp + M(49, 48) * M(48, 65)
      M(49, 65) = ( M(49, 65) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 4) * M(4, 80)
      temp = temp + M(49, 25) * M(25, 80)
      temp = temp + M(49, 26) * M(26, 80)
      temp = temp + M(49, 30) * M(30, 80)
      temp = temp + M(49, 35) * M(35, 80)
      temp = temp + M(49, 43) * M(43, 80)
      temp = temp + M(49, 48) * M(48, 80)
      M(49, 80) = ( M(49, 80) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 84)
      temp = temp + M(49, 48) * M(48, 84)
      M(49, 84) = ( M(49, 84) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 85)
      M(49, 85) = ( M(49, 85) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 48) * M(48, 86)
      M(49, 86) = ( M(49, 86) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 25) * M(25, 87)
      temp = temp + M(49, 26) * M(26, 87)
      temp = temp + M(49, 30) * M(30, 87)
      temp = temp + M(49, 35) * M(35, 87)
      temp = temp + M(49, 43) * M(43, 87)
      temp = temp + M(49, 48) * M(48, 87)
      M(49, 87) = ( M(49, 87) - temp ) / M(49, 49)

C     Upper part.
      temp = M(50, 48) * M(48, 65)
      M(50, 65) = ( M(50, 65) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 48) * M(48, 80)
      M(50, 80) = ( M(50, 80) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 48) * M(48, 84)
      M(50, 84) = ( M(50, 84) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 48) * M(48, 86)
      M(50, 86) = ( M(50, 86) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 48) * M(48, 87)
      M(50, 87) = ( M(50, 87) - temp ) / M(50, 50)
C     Upper part.
      M(50, 89) = M(50, 89) / M(50, 50)

C     Upper part.
      temp = M(51, 23) * M(23, 65)
      M(51, 65) = ( M(51, 65) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 23) * M(23, 80)
      M(51, 80) = ( M(51, 80) - temp ) / M(51, 51)
C     Upper part.
      M(51, 82) = M(51, 82) / M(51, 51)
C     Upper part.
      temp = M(51, 23) * M(23, 84)
      M(51, 84) = ( M(51, 84) - temp ) / M(51, 51)
C     Upper part.
      M(51, 85) = M(51, 85) / M(51, 51)
C     Upper part.
      M(51, 87) = M(51, 87) / M(51, 51)
C     Upper part.
      M(51, 88) = M(51, 88) / M(51, 51)
C     Upper part.
      M(51, 89) = M(51, 89) / M(51, 51)

C     Upper part.
      temp = M(52, 30) * M(30, 65)
      M(52, 65) = ( M(52, 65) - temp ) / M(52, 52)
C     Upper part.
      temp = M(52, 30) * M(30, 80)
      M(52, 80) = ( M(52, 80) - temp ) / M(52, 52)
C     Upper part.
      M(52, 82) = M(52, 82) / M(52, 52)
C     Upper part.
      M(52, 85) = M(52, 85) / M(52, 52)
C     Upper part.
      temp = M(52, 30) * M(30, 87)
      M(52, 87) = ( M(52, 87) - temp ) / M(52, 52)
C     Upper part.
      M(52, 88) = M(52, 88) / M(52, 52)
C     Upper part.
      M(52, 89) = M(52, 89) / M(52, 52)

C     Upper part.
      temp = M(53, 5) * M(5, 80)
      M(53, 80) = ( M(53, 80) - temp ) / M(53, 53)
C     Upper part.
      M(53, 82) = M(53, 82) / M(53, 53)
C     Upper part.
      M(53, 85) = M(53, 85) / M(53, 53)
C     Upper part.
      M(53, 87) = M(53, 87) / M(53, 53)
C     Upper part.
      M(53, 88) = M(53, 88) / M(53, 53)
C     Upper part.
      M(53, 89) = M(53, 89) / M(53, 53)

C     Lower part.
      temp = M(75, 38) * M(38, 54)
      M(75, 54) = M(75, 54) - temp
C     Lower part.
      temp = M(77, 18) * M(18, 54)
      M(77, 54) = M(77, 54) - temp
C     Lower part.
      temp = M(79, 38) * M(38, 54)
      M(79, 54) = M(79, 54) - temp
C     Lower part.
      temp = M(80, 18) * M(18, 54)
      temp = temp + M(80, 38) * M(38, 54)
      M(80, 54) = M(80, 54) - temp
C     Lower part.
      temp = M(81, 18) * M(18, 54)
      M(81, 54) = M(81, 54) - temp
C     Lower part.
      temp = M(82, 38) * M(38, 54)
      M(82, 54) = M(82, 54) - temp
C     Lower part.
      temp = M(88, 18) * M(18, 54)
      temp = temp + M(88, 38) * M(38, 54)
      M(88, 54) = M(88, 54) - temp
C     Lower part.
      temp = M(89, 38) * M(38, 54)
      M(89, 54) = M(89, 54) - temp
C     Upper part.
      temp = M(54, 43) * M(43, 59)
      M(54, 59) = ( M(54, 59) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 35) * M(35, 65)
      temp = temp + M(54, 40) * M(40, 65)
      temp = temp + M(54, 43) * M(43, 65)
      temp = temp + M(54, 51) * M(51, 65)
      M(54, 65) = ( M(54, 65) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 35) * M(35, 80)
      temp = temp + M(54, 40) * M(40, 80)
      temp = temp + M(54, 43) * M(43, 80)
      temp = temp + M(54, 51) * M(51, 80)
      M(54, 80) = ( M(54, 80) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 40) * M(40, 82)
      temp = temp + M(54, 51) * M(51, 82)
      M(54, 82) = ( M(54, 82) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 40) * M(40, 84)
      temp = temp + M(54, 43) * M(43, 84)
      temp = temp + M(54, 51) * M(51, 84)
      M(54, 84) = ( M(54, 84) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 40) * M(40, 85)
      temp = temp + M(54, 43) * M(43, 85)
      temp = temp + M(54, 51) * M(51, 85)
      M(54, 85) = ( M(54, 85) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 35) * M(35, 87)
      temp = temp + M(54, 40) * M(40, 87)
      temp = temp + M(54, 43) * M(43, 87)
      temp = temp + M(54, 51) * M(51, 87)
      M(54, 87) = ( M(54, 87) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 40) * M(40, 88)
      temp = temp + M(54, 51) * M(51, 88)
      M(54, 88) = ( M(54, 88) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 40) * M(40, 89)
      temp = temp + M(54, 51) * M(51, 89)
      M(54, 89) = ( M(54, 89) - temp ) / M(54, 54)

C     Upper part.
      M(55, 60) = M(55, 60) / M(55, 55)
C     Upper part.
      M(55, 62) = M(55, 62) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 65)
      temp = temp + M(55, 45) * M(45, 65)
      temp = temp + M(55, 51) * M(51, 65)
      M(55, 65) = ( M(55, 65) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 6) * M(6, 80)
      temp = temp + M(55, 40) * M(40, 80)
      temp = temp + M(55, 45) * M(45, 80)
      temp = temp + M(55, 51) * M(51, 80)
      M(55, 80) = ( M(55, 80) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 82)
      temp = temp + M(55, 51) * M(51, 82)
      M(55, 82) = ( M(55, 82) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 84)
      temp = temp + M(55, 45) * M(45, 84)
      temp = temp + M(55, 51) * M(51, 84)
      M(55, 84) = ( M(55, 84) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 85)
      temp = temp + M(55, 51) * M(51, 85)
      M(55, 85) = ( M(55, 85) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 87)
      temp = temp + M(55, 45) * M(45, 87)
      temp = temp + M(55, 51) * M(51, 87)
      M(55, 87) = ( M(55, 87) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 88)
      temp = temp + M(55, 45) * M(45, 88)
      temp = temp + M(55, 51) * M(51, 88)
      M(55, 88) = ( M(55, 88) - temp ) / M(55, 55)
C     Upper part.
      temp = M(55, 40) * M(40, 89)
      temp = temp + M(55, 51) * M(51, 89)
      M(55, 89) = ( M(55, 89) - temp ) / M(55, 55)

C     Upper part.
      temp = M(56, 25) * M(25, 65)
      M(56, 65) = ( M(56, 65) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 25) * M(25, 80)
      M(56, 80) = ( M(56, 80) - temp ) / M(56, 56)
C     Upper part.
      M(56, 82) = M(56, 82) / M(56, 56)
C     Upper part.
      M(56, 85) = M(56, 85) / M(56, 56)
C     Upper part.
      temp = M(56, 25) * M(25, 87)
      M(56, 87) = ( M(56, 87) - temp ) / M(56, 56)
C     Upper part.
      M(56, 88) = M(56, 88) / M(56, 56)
C     Upper part.
      M(56, 89) = M(56, 89) / M(56, 56)

C     Upper part.
      temp = M(57, 6) * M(6, 80)
      M(57, 80) = ( M(57, 80) - temp ) / M(57, 57)
C     Upper part.
      M(57, 82) = M(57, 82) / M(57, 57)
C     Upper part.
      M(57, 85) = M(57, 85) / M(57, 57)
C     Upper part.
      M(57, 87) = M(57, 87) / M(57, 57)
C     Upper part.
      M(57, 88) = M(57, 88) / M(57, 57)
C     Upper part.
      M(57, 89) = M(57, 89) / M(57, 57)

C     Upper part.
      temp = M(58, 43) * M(43, 59)
      M(58, 59) = ( M(58, 59) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 26) * M(26, 65)
      temp = temp + M(58, 35) * M(35, 65)
      temp = temp + M(58, 43) * M(43, 65)
      M(58, 65) = ( M(58, 65) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 26) * M(26, 80)
      temp = temp + M(58, 35) * M(35, 80)
      temp = temp + M(58, 43) * M(43, 80)
      M(58, 80) = ( M(58, 80) - temp ) / M(58, 58)
C     Upper part.
      M(58, 82) = M(58, 82) / M(58, 58)
C     Upper part.
      temp = M(58, 43) * M(43, 84)
      M(58, 84) = ( M(58, 84) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 43) * M(43, 85)
      M(58, 85) = ( M(58, 85) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 26) * M(26, 87)
      temp = temp + M(58, 35) * M(35, 87)
      temp = temp + M(58, 43) * M(43, 87)
      M(58, 87) = ( M(58, 87) - temp ) / M(58, 58)
C     Upper part.
      M(58, 88) = M(58, 88) / M(58, 58)
C     Upper part.
      M(58, 89) = M(58, 89) / M(58, 58)

C     Lower part.
      temp = M(59, 43) * M(43, 59)
      temp = temp + M(59, 58) * M(58, 59)
      M(59, 59) = M(59, 59) - temp
C     Lower part.
      temp = M(60, 43) * M(43, 59)
      temp = temp + M(60, 58) * M(58, 59)
      M(60, 59) = M(60, 59) - temp
C     Lower part.
      temp = M(62, 58) * M(58, 59)
      M(62, 59) = M(62, 59) - temp
C     Lower part.
      temp = M(63, 43) * M(43, 59)
      M(63, 59) = M(63, 59) - temp
C     Lower part.
      temp = M(64, 43) * M(43, 59)
      M(64, 59) = M(64, 59) - temp
C     Lower part.
      temp = M(65, 43) * M(43, 59)
      temp = temp + M(65, 54) * M(54, 59)
      M(65, 59) = M(65, 59) - temp
C     Lower part.
      temp = M(66, 54) * M(54, 59)
      M(66, 59) = M(66, 59) - temp
C     Lower part.
      temp = M(67, 43) * M(43, 59)
      temp = temp + M(67, 54) * M(54, 59)
      M(67, 59) = M(67, 59) - temp
C     Lower part.
      temp = M(70, 43) * M(43, 59)
      M(70, 59) = M(70, 59) - temp
C     Lower part.
      temp = M(71, 54) * M(54, 59)
      temp = temp + M(71, 58) * M(58, 59)
      M(71, 59) = M(71, 59) - temp
C     Lower part.
      temp = M(72, 47) * M(47, 59)
      temp = temp + M(72, 54) * M(54, 59)
      M(72, 59) = M(72, 59) - temp
C     Lower part.
      temp = M(73, 58) * M(58, 59)
      M(73, 59) = M(73, 59) - temp
C     Lower part.
      temp = M(74, 54) * M(54, 59)
      M(74, 59) = M(74, 59) - temp
C     Lower part.
      temp = M(75, 43) * M(43, 59)
      temp = temp + M(75, 54) * M(54, 59)
      M(75, 59) = M(75, 59) - temp
C     Lower part.
      temp = M(77, 54) * M(54, 59)
      M(77, 59) = M(77, 59) - temp
C     Lower part.
      temp = M(79, 43) * M(43, 59)
      temp = temp + M(79, 47) * M(47, 59)
      temp = temp + M(79, 54) * M(54, 59)
      temp = temp + M(79, 58) * M(58, 59)
      M(79, 59) = M(79, 59) - temp
C     Lower part.
      temp = M(80, 43) * M(43, 59)
      temp = temp + M(80, 44) * M(44, 59)
      temp = temp + M(80, 47) * M(47, 59)
      temp = temp + M(80, 54) * M(54, 59)
      M(80, 59) = M(80, 59) - temp
C     Lower part.
      temp = M(81, 43) * M(43, 59)
      temp = temp + M(81, 54) * M(54, 59)
      M(81, 59) = M(81, 59) - temp
C     Lower part.
      temp = M(82, 43) * M(43, 59)
      temp = temp + M(82, 54) * M(54, 59)
      temp = temp + M(82, 58) * M(58, 59)
      M(82, 59) = M(82, 59) - temp
C     Lower part.
      temp = M(83, 58) * M(58, 59)
      M(83, 59) = M(83, 59) - temp
C     Lower part.
      temp = M(84, 43) * M(43, 59)
      temp = temp + M(84, 54) * M(54, 59)
      temp = temp + M(84, 58) * M(58, 59)
      M(84, 59) = M(84, 59) - temp
C     Lower part.
      temp = M(85, 43) * M(43, 59)
      temp = temp + M(85, 58) * M(58, 59)
      M(85, 59) = M(85, 59) - temp
C     Lower part.
      temp = M(86, 54) * M(54, 59)
      M(86, 59) = M(86, 59) - temp
C     Lower part.
      temp = M(87, 43) * M(43, 59)
      temp = temp + M(87, 54) * M(54, 59)
      temp = temp + M(87, 58) * M(58, 59)
      M(87, 59) = M(87, 59) - temp
C     Lower part.
      temp = M(88, 43) * M(43, 59)
      temp = temp + M(88, 44) * M(44, 59)
      temp = temp + M(88, 47) * M(47, 59)
      temp = temp + M(88, 54) * M(54, 59)
      temp = temp + M(88, 58) * M(58, 59)
      M(88, 59) = M(88, 59) - temp
C     Lower part.
      temp = M(89, 43) * M(43, 59)
      temp = temp + M(89, 47) * M(47, 59)
      temp = temp + M(89, 54) * M(54, 59)
      temp = temp + M(89, 58) * M(58, 59)
      M(89, 59) = M(89, 59) - temp
C     Upper part.
      temp = M(59, 26) * M(26, 65)
      temp = temp + M(59, 30) * M(30, 65)
      temp = temp + M(59, 35) * M(35, 65)
      temp = temp + M(59, 43) * M(43, 65)
      temp = temp + M(59, 52) * M(52, 65)
      temp = temp + M(59, 58) * M(58, 65)
      M(59, 65) = ( M(59, 65) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 26) * M(26, 80)
      temp = temp + M(59, 30) * M(30, 80)
      temp = temp + M(59, 35) * M(35, 80)
      temp = temp + M(59, 43) * M(43, 80)
      temp = temp + M(59, 52) * M(52, 80)
      temp = temp + M(59, 58) * M(58, 80)
      M(59, 80) = ( M(59, 80) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 52) * M(52, 82)
      temp = temp + M(59, 58) * M(58, 82)
      M(59, 82) = ( M(59, 82) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 43) * M(43, 84)
      temp = temp + M(59, 58) * M(58, 84)
      M(59, 84) = ( M(59, 84) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 43) * M(43, 85)
      temp = temp + M(59, 52) * M(52, 85)
      temp = temp + M(59, 58) * M(58, 85)
      M(59, 85) = ( M(59, 85) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 26) * M(26, 87)
      temp = temp + M(59, 30) * M(30, 87)
      temp = temp + M(59, 35) * M(35, 87)
      temp = temp + M(59, 43) * M(43, 87)
      temp = temp + M(59, 52) * M(52, 87)
      temp = temp + M(59, 58) * M(58, 87)
      M(59, 87) = ( M(59, 87) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 52) * M(52, 88)
      temp = temp + M(59, 58) * M(58, 88)
      M(59, 88) = ( M(59, 88) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 52) * M(52, 89)
      temp = temp + M(59, 58) * M(58, 89)
      M(59, 89) = ( M(59, 89) - temp ) / M(59, 59)

C     Lower part.
      temp = M(78, 34) * M(34, 60)
      M(78, 60) = M(78, 60) - temp
C     Lower part.
      temp = M(80, 34) * M(34, 60)
      temp = temp + M(80, 37) * M(37, 60)
      temp = temp + M(80, 44) * M(44, 60)
      M(80, 60) = M(80, 60) - temp
C     Lower part.
      temp = M(82, 37) * M(37, 60)
      M(82, 60) = M(82, 60) - temp
C     Lower part.
      temp = M(88, 44) * M(44, 60)
      M(88, 60) = M(88, 60) - temp
C     Upper part.
      temp = M(60, 26) * M(26, 65)
      temp = temp + M(60, 30) * M(30, 65)
      temp = temp + M(60, 35) * M(35, 65)
      temp = temp + M(60, 43) * M(43, 65)
      temp = temp + M(60, 58) * M(58, 65)
      temp = temp + M(60, 59) * M(59, 65)
      M(60, 65) = ( M(60, 65) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 26) * M(26, 80)
      temp = temp + M(60, 30) * M(30, 80)
      temp = temp + M(60, 35) * M(35, 80)
      temp = temp + M(60, 43) * M(43, 80)
      temp = temp + M(60, 58) * M(58, 80)
      temp = temp + M(60, 59) * M(59, 80)
      M(60, 80) = ( M(60, 80) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 58) * M(58, 82)
      temp = temp + M(60, 59) * M(59, 82)
      M(60, 82) = ( M(60, 82) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 43) * M(43, 84)
      temp = temp + M(60, 58) * M(58, 84)
      temp = temp + M(60, 59) * M(59, 84)
      M(60, 84) = ( M(60, 84) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 43) * M(43, 85)
      temp = temp + M(60, 58) * M(58, 85)
      temp = temp + M(60, 59) * M(59, 85)
      M(60, 85) = ( M(60, 85) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 26) * M(26, 87)
      temp = temp + M(60, 30) * M(30, 87)
      temp = temp + M(60, 35) * M(35, 87)
      temp = temp + M(60, 43) * M(43, 87)
      temp = temp + M(60, 58) * M(58, 87)
      temp = temp + M(60, 59) * M(59, 87)
      M(60, 87) = ( M(60, 87) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 58) * M(58, 88)
      temp = temp + M(60, 59) * M(59, 88)
      M(60, 88) = ( M(60, 88) - temp ) / M(60, 60)
C     Upper part.
      temp = M(60, 58) * M(58, 89)
      temp = temp + M(60, 59) * M(59, 89)
      M(60, 89) = ( M(60, 89) - temp ) / M(60, 60)

C     Upper part.
      temp = M(61, 60) * M(60, 65)
      M(61, 65) = ( M(61, 65) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 80)
      M(61, 80) = ( M(61, 80) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 82)
      M(61, 82) = ( M(61, 82) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 84)
      M(61, 84) = ( M(61, 84) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 85)
      M(61, 85) = ( M(61, 85) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 87)
      M(61, 87) = ( M(61, 87) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 88)
      M(61, 88) = ( M(61, 88) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 60) * M(60, 89)
      M(61, 89) = ( M(61, 89) - temp ) / M(61, 61)

C     Lower part.
      temp = M(78, 34) * M(34, 62)
      M(78, 62) = M(78, 62) - temp
C     Lower part.
      temp = M(80, 34) * M(34, 62)
      temp = temp + M(80, 37) * M(37, 62)
      temp = temp + M(80, 44) * M(44, 62)
      M(80, 62) = M(80, 62) - temp
C     Lower part.
      temp = M(82, 37) * M(37, 62)
      M(82, 62) = M(82, 62) - temp
C     Lower part.
      temp = M(88, 44) * M(44, 62)
      M(88, 62) = M(88, 62) - temp
C     Upper part.
      temp = M(62, 52) * M(52, 65)
      temp = temp + M(62, 58) * M(58, 65)
      temp = temp + M(62, 59) * M(59, 65)
      M(62, 65) = ( M(62, 65) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 80)
      temp = temp + M(62, 58) * M(58, 80)
      temp = temp + M(62, 59) * M(59, 80)
      M(62, 80) = ( M(62, 80) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 82)
      temp = temp + M(62, 58) * M(58, 82)
      temp = temp + M(62, 59) * M(59, 82)
      M(62, 82) = ( M(62, 82) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 58) * M(58, 84)
      temp = temp + M(62, 59) * M(59, 84)
      M(62, 84) = ( M(62, 84) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 85)
      temp = temp + M(62, 58) * M(58, 85)
      temp = temp + M(62, 59) * M(59, 85)
      M(62, 85) = ( M(62, 85) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 87)
      temp = temp + M(62, 58) * M(58, 87)
      temp = temp + M(62, 59) * M(59, 87)
      M(62, 87) = ( M(62, 87) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 88)
      temp = temp + M(62, 58) * M(58, 88)
      temp = temp + M(62, 59) * M(59, 88)
      M(62, 88) = ( M(62, 88) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 52) * M(52, 89)
      temp = temp + M(62, 58) * M(58, 89)
      temp = temp + M(62, 59) * M(59, 89)
      M(62, 89) = ( M(62, 89) - temp ) / M(62, 62)

C     Upper part.
      M(63, 64) = M(63, 64) / M(63, 63)
C     Upper part.
      temp = M(63, 25) * M(25, 65)
      temp = temp + M(63, 26) * M(26, 65)
      temp = temp + M(63, 27) * M(27, 65)
      temp = temp + M(63, 30) * M(30, 65)
      temp = temp + M(63, 35) * M(35, 65)
      temp = temp + M(63, 43) * M(43, 65)
      temp = temp + M(63, 59) * M(59, 65)
      temp = temp + M(63, 60) * M(60, 65)
      temp = temp + M(63, 62) * M(62, 65)
      M(63, 65) = ( M(63, 65) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 25) * M(25, 80)
      temp = temp + M(63, 26) * M(26, 80)
      temp = temp + M(63, 27) * M(27, 80)
      temp = temp + M(63, 30) * M(30, 80)
      temp = temp + M(63, 35) * M(35, 80)
      temp = temp + M(63, 43) * M(43, 80)
      temp = temp + M(63, 59) * M(59, 80)
      temp = temp + M(63, 60) * M(60, 80)
      temp = temp + M(63, 62) * M(62, 80)
      M(63, 80) = ( M(63, 80) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 59) * M(59, 82)
      temp = temp + M(63, 60) * M(60, 82)
      temp = temp + M(63, 62) * M(62, 82)
      M(63, 82) = ( M(63, 82) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 43) * M(43, 84)
      temp = temp + M(63, 59) * M(59, 84)
      temp = temp + M(63, 60) * M(60, 84)
      temp = temp + M(63, 62) * M(62, 84)
      M(63, 84) = ( M(63, 84) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 43) * M(43, 85)
      temp = temp + M(63, 59) * M(59, 85)
      temp = temp + M(63, 60) * M(60, 85)
      temp = temp + M(63, 62) * M(62, 85)
      M(63, 85) = ( M(63, 85) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 25) * M(25, 87)
      temp = temp + M(63, 26) * M(26, 87)
      temp = temp + M(63, 27) * M(27, 87)
      temp = temp + M(63, 30) * M(30, 87)
      temp = temp + M(63, 35) * M(35, 87)
      temp = temp + M(63, 43) * M(43, 87)
      temp = temp + M(63, 59) * M(59, 87)
      temp = temp + M(63, 60) * M(60, 87)
      temp = temp + M(63, 62) * M(62, 87)
      M(63, 87) = ( M(63, 87) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 59) * M(59, 88)
      temp = temp + M(63, 60) * M(60, 88)
      temp = temp + M(63, 62) * M(62, 88)
      M(63, 88) = ( M(63, 88) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 59) * M(59, 89)
      temp = temp + M(63, 60) * M(60, 89)
      temp = temp + M(63, 62) * M(62, 89)
      M(63, 89) = ( M(63, 89) - temp ) / M(63, 63)

C     Lower part.
      temp = M(64, 63) * M(63, 64)
      M(64, 64) = M(64, 64) - temp
C     Lower part.
      temp = M(71, 63) * M(63, 64)
      M(71, 64) = M(71, 64) - temp
C     Lower part.
      temp = M(77, 63) * M(63, 64)
      M(77, 64) = M(77, 64) - temp
C     Lower part.
      temp = M(79, 63) * M(63, 64)
      M(79, 64) = M(79, 64) - temp
C     Lower part.
      temp = M(81, 63) * M(63, 64)
      M(81, 64) = M(81, 64) - temp
C     Lower part.
      temp = M(82, 63) * M(63, 64)
      M(82, 64) = M(82, 64) - temp
C     Lower part.
      temp = M(83, 63) * M(63, 64)
      M(83, 64) = M(83, 64) - temp
C     Lower part.
      temp = M(84, 63) * M(63, 64)
      M(84, 64) = M(84, 64) - temp
C     Lower part.
      temp = M(85, 63) * M(63, 64)
      M(85, 64) = M(85, 64) - temp
C     Lower part.
      temp = M(87, 63) * M(63, 64)
      M(87, 64) = M(87, 64) - temp
C     Lower part.
      temp = M(88, 63) * M(63, 64)
      M(88, 64) = M(88, 64) - temp
C     Lower part.
      temp = M(89, 63) * M(63, 64)
      M(89, 64) = M(89, 64) - temp
C     Upper part.
      temp = M(64, 25) * M(25, 65)
      temp = temp + M(64, 26) * M(26, 65)
      temp = temp + M(64, 27) * M(27, 65)
      temp = temp + M(64, 30) * M(30, 65)
      temp = temp + M(64, 35) * M(35, 65)
      temp = temp + M(64, 43) * M(43, 65)
      temp = temp + M(64, 59) * M(59, 65)
      temp = temp + M(64, 60) * M(60, 65)
      temp = temp + M(64, 62) * M(62, 65)
      temp = temp + M(64, 63) * M(63, 65)
      M(64, 65) = ( M(64, 65) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 25) * M(25, 80)
      temp = temp + M(64, 26) * M(26, 80)
      temp = temp + M(64, 27) * M(27, 80)
      temp = temp + M(64, 30) * M(30, 80)
      temp = temp + M(64, 35) * M(35, 80)
      temp = temp + M(64, 43) * M(43, 80)
      temp = temp + M(64, 59) * M(59, 80)
      temp = temp + M(64, 60) * M(60, 80)
      temp = temp + M(64, 62) * M(62, 80)
      temp = temp + M(64, 63) * M(63, 80)
      M(64, 80) = ( M(64, 80) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 59) * M(59, 82)
      temp = temp + M(64, 60) * M(60, 82)
      temp = temp + M(64, 62) * M(62, 82)
      temp = temp + M(64, 63) * M(63, 82)
      M(64, 82) = ( M(64, 82) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 43) * M(43, 84)
      temp = temp + M(64, 59) * M(59, 84)
      temp = temp + M(64, 60) * M(60, 84)
      temp = temp + M(64, 62) * M(62, 84)
      temp = temp + M(64, 63) * M(63, 84)
      M(64, 84) = ( M(64, 84) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 43) * M(43, 85)
      temp = temp + M(64, 59) * M(59, 85)
      temp = temp + M(64, 60) * M(60, 85)
      temp = temp + M(64, 62) * M(62, 85)
      temp = temp + M(64, 63) * M(63, 85)
      M(64, 85) = ( M(64, 85) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 25) * M(25, 87)
      temp = temp + M(64, 26) * M(26, 87)
      temp = temp + M(64, 27) * M(27, 87)
      temp = temp + M(64, 30) * M(30, 87)
      temp = temp + M(64, 35) * M(35, 87)
      temp = temp + M(64, 43) * M(43, 87)
      temp = temp + M(64, 59) * M(59, 87)
      temp = temp + M(64, 60) * M(60, 87)
      temp = temp + M(64, 62) * M(62, 87)
      temp = temp + M(64, 63) * M(63, 87)
      M(64, 87) = ( M(64, 87) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 59) * M(59, 88)
      temp = temp + M(64, 60) * M(60, 88)
      temp = temp + M(64, 62) * M(62, 88)
      temp = temp + M(64, 63) * M(63, 88)
      M(64, 88) = ( M(64, 88) - temp ) / M(64, 64)
C     Upper part.
      temp = M(64, 59) * M(59, 89)
      temp = temp + M(64, 60) * M(60, 89)
      temp = temp + M(64, 62) * M(62, 89)
      temp = temp + M(64, 63) * M(63, 89)
      M(64, 89) = ( M(64, 89) - temp ) / M(64, 64)

C     Lower part.
      temp = M(65, 22) * M(22, 65)
      temp = temp + M(65, 23) * M(23, 65)
      temp = temp + M(65, 25) * M(25, 65)
      temp = temp + M(65, 26) * M(26, 65)
      temp = temp + M(65, 27) * M(27, 65)
      temp = temp + M(65, 30) * M(30, 65)
      temp = temp + M(65, 35) * M(35, 65)
      temp = temp + M(65, 36) * M(36, 65)
      temp = temp + M(65, 43) * M(43, 65)
      temp = temp + M(65, 45) * M(45, 65)
      temp = temp + M(65, 48) * M(48, 65)
      temp = temp + M(65, 54) * M(54, 65)
      temp = temp + M(65, 59) * M(59, 65)
      temp = temp + M(65, 60) * M(60, 65)
      temp = temp + M(65, 62) * M(62, 65)
      M(65, 65) = M(65, 65) - temp
C     Lower part.
      temp = M(66, 40) * M(40, 65)
      temp = temp + M(66, 42) * M(42, 65)
      temp = temp + M(66, 45) * M(45, 65)
      temp = temp + M(66, 51) * M(51, 65)
      temp = temp + M(66, 54) * M(54, 65)
      temp = temp + M(66, 59) * M(59, 65)
      M(66, 65) = M(66, 65) - temp
C     Lower part.
      temp = M(67, 25) * M(25, 65)
      temp = temp + M(67, 26) * M(26, 65)
      temp = temp + M(67, 27) * M(27, 65)
      temp = temp + M(67, 30) * M(30, 65)
      temp = temp + M(67, 35) * M(35, 65)
      temp = temp + M(67, 43) * M(43, 65)
      temp = temp + M(67, 48) * M(48, 65)
      temp = temp + M(67, 54) * M(54, 65)
      temp = temp + M(67, 59) * M(59, 65)
      temp = temp + M(67, 60) * M(60, 65)
      temp = temp + M(67, 62) * M(62, 65)
      M(67, 65) = M(67, 65) - temp
C     Lower part.
      temp = M(68, 62) * M(62, 65)
      M(68, 65) = M(68, 65) - temp
C     Lower part.
      temp = M(69, 27) * M(27, 65)
      M(69, 65) = M(69, 65) - temp
C     Lower part.
      temp = M(70, 26) * M(26, 65)
      temp = temp + M(70, 27) * M(27, 65)
      temp = temp + M(70, 30) * M(30, 65)
      temp = temp + M(70, 35) * M(35, 65)
      temp = temp + M(70, 43) * M(43, 65)
      temp = temp + M(70, 59) * M(59, 65)
      temp = temp + M(70, 60) * M(60, 65)
      temp = temp + M(70, 62) * M(62, 65)
      M(70, 65) = M(70, 65) - temp
C     Lower part.
      temp = M(71, 30) * M(30, 65)
      temp = temp + M(71, 54) * M(54, 65)
      temp = temp + M(71, 56) * M(56, 65)
      temp = temp + M(71, 58) * M(58, 65)
      temp = temp + M(71, 59) * M(59, 65)
      temp = temp + M(71, 60) * M(60, 65)
      temp = temp + M(71, 61) * M(61, 65)
      temp = temp + M(71, 62) * M(62, 65)
      temp = temp + M(71, 63) * M(63, 65)
      temp = temp + M(71, 64) * M(64, 65)
      M(71, 65) = M(71, 65) - temp
C     Lower part.
      temp = M(72, 40) * M(40, 65)
      temp = temp + M(72, 42) * M(42, 65)
      temp = temp + M(72, 45) * M(45, 65)
      temp = temp + M(72, 48) * M(48, 65)
      temp = temp + M(72, 51) * M(51, 65)
      temp = temp + M(72, 54) * M(54, 65)
      temp = temp + M(72, 59) * M(59, 65)
      M(72, 65) = M(72, 65) - temp
C     Lower part.
      temp = M(73, 40) * M(40, 65)
      temp = temp + M(73, 42) * M(42, 65)
      temp = temp + M(73, 45) * M(45, 65)
      temp = temp + M(73, 51) * M(51, 65)
      temp = temp + M(73, 52) * M(52, 65)
      temp = temp + M(73, 56) * M(56, 65)
      temp = temp + M(73, 58) * M(58, 65)
      temp = temp + M(73, 59) * M(59, 65)
      temp = temp + M(73, 61) * M(61, 65)
      M(73, 65) = M(73, 65) - temp
C     Lower part.
      temp = M(74, 45) * M(45, 65)
      temp = temp + M(74, 54) * M(54, 65)
      temp = temp + M(74, 59) * M(59, 65)
      M(74, 65) = M(74, 65) - temp
C     Lower part.
      temp = M(75, 26) * M(26, 65)
      temp = temp + M(75, 35) * M(35, 65)
      temp = temp + M(75, 38) * M(38, 65)
      temp = temp + M(75, 43) * M(43, 65)
      temp = temp + M(75, 45) * M(45, 65)
      temp = temp + M(75, 48) * M(48, 65)
      temp = temp + M(75, 50) * M(50, 65)
      temp = temp + M(75, 54) * M(54, 65)
      temp = temp + M(75, 59) * M(59, 65)
      M(75, 65) = M(75, 65) - temp
C     Lower part.
      temp = M(77, 27) * M(27, 65)
      temp = temp + M(77, 54) * M(54, 65)
      temp = temp + M(77, 59) * M(59, 65)
      temp = temp + M(77, 60) * M(60, 65)
      temp = temp + M(77, 61) * M(61, 65)
      temp = temp + M(77, 62) * M(62, 65)
      temp = temp + M(77, 63) * M(63, 65)
      temp = temp + M(77, 64) * M(64, 65)
      M(77, 65) = M(77, 65) - temp
C     Lower part.
      temp = M(78, 27) * M(27, 65)
      temp = temp + M(78, 30) * M(30, 65)
      temp = temp + M(78, 34) * M(34, 65)
      temp = temp + M(78, 60) * M(60, 65)
      temp = temp + M(78, 62) * M(62, 65)
      M(78, 65) = M(78, 65) - temp
C     Lower part.
      temp = M(79, 25) * M(25, 65)
      temp = temp + M(79, 26) * M(26, 65)
      temp = temp + M(79, 30) * M(30, 65)
      temp = temp + M(79, 35) * M(35, 65)
      temp = temp + M(79, 38) * M(38, 65)
      temp = temp + M(79, 40) * M(40, 65)
      temp = temp + M(79, 42) * M(42, 65)
      temp = temp + M(79, 43) * M(43, 65)
      temp = temp + M(79, 45) * M(45, 65)
      temp = temp + M(79, 48) * M(48, 65)
      temp = temp + M(79, 50) * M(50, 65)
      temp = temp + M(79, 51) * M(51, 65)
      temp = temp + M(79, 52) * M(52, 65)
      temp = temp + M(79, 54) * M(54, 65)
      temp = temp + M(79, 56) * M(56, 65)
      temp = temp + M(79, 58) * M(58, 65)
      temp = temp + M(79, 59) * M(59, 65)
      temp = temp + M(79, 60) * M(60, 65)
      temp = temp + M(79, 61) * M(61, 65)
      temp = temp + M(79, 62) * M(62, 65)
      temp = temp + M(79, 63) * M(63, 65)
      temp = temp + M(79, 64) * M(64, 65)
      M(79, 65) = M(79, 65) - temp
C     Lower part.
      temp = M(80, 9) * M(9, 65)
      temp = temp + M(80, 22) * M(22, 65)
      temp = temp + M(80, 23) * M(23, 65)
      temp = temp + M(80, 25) * M(25, 65)
      temp = temp + M(80, 26) * M(26, 65)
      temp = temp + M(80, 27) * M(27, 65)
      temp = temp + M(80, 30) * M(30, 65)
      temp = temp + M(80, 33) * M(33, 65)
      temp = temp + M(80, 34) * M(34, 65)
      temp = temp + M(80, 35) * M(35, 65)
      temp = temp + M(80, 36) * M(36, 65)
      temp = temp + M(80, 37) * M(37, 65)
      temp = temp + M(80, 38) * M(38, 65)
      temp = temp + M(80, 43) * M(43, 65)
      temp = temp + M(80, 44) * M(44, 65)
      temp = temp + M(80, 45) * M(45, 65)
      temp = temp + M(80, 48) * M(48, 65)
      temp = temp + M(80, 50) * M(50, 65)
      temp = temp + M(80, 54) * M(54, 65)
      temp = temp + M(80, 59) * M(59, 65)
      temp = temp + M(80, 60) * M(60, 65)
      temp = temp + M(80, 62) * M(62, 65)
      M(80, 65) = M(80, 65) - temp
C     Lower part.
      temp = M(81, 27) * M(27, 65)
      temp = temp + M(81, 43) * M(43, 65)
      temp = temp + M(81, 54) * M(54, 65)
      temp = temp + M(81, 56) * M(56, 65)
      temp = temp + M(81, 59) * M(59, 65)
      temp = temp + M(81, 60) * M(60, 65)
      temp = temp + M(81, 61) * M(61, 65)
      temp = temp + M(81, 62) * M(62, 65)
      temp = temp + M(81, 63) * M(63, 65)
      temp = temp + M(81, 64) * M(64, 65)
      M(81, 65) = M(81, 65) - temp
C     Lower part.
      temp = M(82, 26) * M(26, 65)
      temp = temp + M(82, 35) * M(35, 65)
      temp = temp + M(82, 37) * M(37, 65)
      temp = temp + M(82, 38) * M(38, 65)
      temp = temp + M(82, 40) * M(40, 65)
      temp = temp + M(82, 42) * M(42, 65)
      temp = temp + M(82, 43) * M(43, 65)
      temp = temp + M(82, 45) * M(45, 65)
      temp = temp + M(82, 51) * M(51, 65)
      temp = temp + M(82, 52) * M(52, 65)
      temp = temp + M(82, 54) * M(54, 65)
      temp = temp + M(82, 56) * M(56, 65)
      temp = temp + M(82, 58) * M(58, 65)
      temp = temp + M(82, 59) * M(59, 65)
      temp = temp + M(82, 60) * M(60, 65)
      temp = temp + M(82, 61) * M(61, 65)
      temp = temp + M(82, 62) * M(62, 65)
      temp = temp + M(82, 63) * M(63, 65)
      temp = temp + M(82, 64) * M(64, 65)
      M(82, 65) = M(82, 65) - temp
C     Lower part.
      temp = M(83, 40) * M(40, 65)
      temp = temp + M(83, 45) * M(45, 65)
      temp = temp + M(83, 48) * M(48, 65)
      temp = temp + M(83, 51) * M(51, 65)
      temp = temp + M(83, 52) * M(52, 65)
      temp = temp + M(83, 58) * M(58, 65)
      temp = temp + M(83, 59) * M(59, 65)
      temp = temp + M(83, 63) * M(63, 65)
      temp = temp + M(83, 64) * M(64, 65)
      M(83, 65) = M(83, 65) - temp
C     Lower part.
      temp = M(84, 22) * M(22, 65)
      temp = temp + M(84, 23) * M(23, 65)
      temp = temp + M(84, 33) * M(33, 65)
      temp = temp + M(84, 36) * M(36, 65)
      temp = temp + M(84, 40) * M(40, 65)
      temp = temp + M(84, 42) * M(42, 65)
      temp = temp + M(84, 43) * M(43, 65)
      temp = temp + M(84, 45) * M(45, 65)
      temp = temp + M(84, 48) * M(48, 65)
      temp = temp + M(84, 50) * M(50, 65)
      temp = temp + M(84, 51) * M(51, 65)
      temp = temp + M(84, 52) * M(52, 65)
      temp = temp + M(84, 54) * M(54, 65)
      temp = temp + M(84, 56) * M(56, 65)
      temp = temp + M(84, 58) * M(58, 65)
      temp = temp + M(84, 59) * M(59, 65)
      temp = temp + M(84, 61) * M(61, 65)
      temp = temp + M(84, 63) * M(63, 65)
      temp = temp + M(84, 64) * M(64, 65)
      M(84, 65) = M(84, 65) - temp
C     Lower part.
      temp = M(85, 33) * M(33, 65)
      temp = temp + M(85, 36) * M(36, 65)
      temp = temp + M(85, 40) * M(40, 65)
      temp = temp + M(85, 42) * M(42, 65)
      temp = temp + M(85, 43) * M(43, 65)
      temp = temp + M(85, 45) * M(45, 65)
      temp = temp + M(85, 51) * M(51, 65)
      temp = temp + M(85, 52) * M(52, 65)
      temp = temp + M(85, 56) * M(56, 65)
      temp = temp + M(85, 58) * M(58, 65)
      temp = temp + M(85, 59) * M(59, 65)
      temp = temp + M(85, 61) * M(61, 65)
      temp = temp + M(85, 63) * M(63, 65)
      temp = temp + M(85, 64) * M(64, 65)
      M(85, 65) = M(85, 65) - temp
C     Lower part.
      temp = M(86, 48) * M(48, 65)
      temp = temp + M(86, 54) * M(54, 65)
      temp = temp + M(86, 59) * M(59, 65)
      M(86, 65) = M(86, 65) - temp
C     Lower part.
      temp = M(87, 25) * M(25, 65)
      temp = temp + M(87, 26) * M(26, 65)
      temp = temp + M(87, 27) * M(27, 65)
      temp = temp + M(87, 30) * M(30, 65)
      temp = temp + M(87, 35) * M(35, 65)
      temp = temp + M(87, 40) * M(40, 65)
      temp = temp + M(87, 42) * M(42, 65)
      temp = temp + M(87, 43) * M(43, 65)
      temp = temp + M(87, 45) * M(45, 65)
      temp = temp + M(87, 48) * M(48, 65)
      temp = temp + M(87, 50) * M(50, 65)
      temp = temp + M(87, 51) * M(51, 65)
      temp = temp + M(87, 52) * M(52, 65)
      temp = temp + M(87, 54) * M(54, 65)
      temp = temp + M(87, 56) * M(56, 65)
      temp = temp + M(87, 58) * M(58, 65)
      temp = temp + M(87, 59) * M(59, 65)
      temp = temp + M(87, 60) * M(60, 65)
      temp = temp + M(87, 61) * M(61, 65)
      temp = temp + M(87, 62) * M(62, 65)
      temp = temp + M(87, 63) * M(63, 65)
      temp = temp + M(87, 64) * M(64, 65)
      M(87, 65) = M(87, 65) - temp
C     Lower part.
      temp = M(88, 22) * M(22, 65)
      temp = temp + M(88, 23) * M(23, 65)
      temp = temp + M(88, 25) * M(25, 65)
      temp = temp + M(88, 26) * M(26, 65)
      temp = temp + M(88, 27) * M(27, 65)
      temp = temp + M(88, 30) * M(30, 65)
      temp = temp + M(88, 35) * M(35, 65)
      temp = temp + M(88, 36) * M(36, 65)
      temp = temp + M(88, 38) * M(38, 65)
      temp = temp + M(88, 40) * M(40, 65)
      temp = temp + M(88, 42) * M(42, 65)
      temp = temp + M(88, 43) * M(43, 65)
      temp = temp + M(88, 44) * M(44, 65)
      temp = temp + M(88, 45) * M(45, 65)
      temp = temp + M(88, 48) * M(48, 65)
      temp = temp + M(88, 51) * M(51, 65)
      temp = temp + M(88, 52) * M(52, 65)
      temp = temp + M(88, 54) * M(54, 65)
      temp = temp + M(88, 56) * M(56, 65)
      temp = temp + M(88, 58) * M(58, 65)
      temp = temp + M(88, 59) * M(59, 65)
      temp = temp + M(88, 60) * M(60, 65)
      temp = temp + M(88, 61) * M(61, 65)
      temp = temp + M(88, 62) * M(62, 65)
      temp = temp + M(88, 63) * M(63, 65)
      temp = temp + M(88, 64) * M(64, 65)
      M(88, 65) = M(88, 65) - temp
C     Lower part.
      temp = M(89, 26) * M(26, 65)
      temp = temp + M(89, 35) * M(35, 65)
      temp = temp + M(89, 38) * M(38, 65)
      temp = temp + M(89, 40) * M(40, 65)
      temp = temp + M(89, 42) * M(42, 65)
      temp = temp + M(89, 43) * M(43, 65)
      temp = temp + M(89, 45) * M(45, 65)
      temp = temp + M(89, 48) * M(48, 65)
      temp = temp + M(89, 50) * M(50, 65)
      temp = temp + M(89, 51) * M(51, 65)
      temp = temp + M(89, 52) * M(52, 65)
      temp = temp + M(89, 54) * M(54, 65)
      temp = temp + M(89, 56) * M(56, 65)
      temp = temp + M(89, 58) * M(58, 65)
      temp = temp + M(89, 59) * M(59, 65)
      temp = temp + M(89, 61) * M(61, 65)
      temp = temp + M(89, 63) * M(63, 65)
      temp = temp + M(89, 64) * M(64, 65)
      M(89, 65) = M(89, 65) - temp
C     Upper part.
      temp = M(65, 22) * M(22, 80)
      temp = temp + M(65, 23) * M(23, 80)
      temp = temp + M(65, 25) * M(25, 80)
      temp = temp + M(65, 26) * M(26, 80)
      temp = temp + M(65, 27) * M(27, 80)
      temp = temp + M(65, 30) * M(30, 80)
      temp = temp + M(65, 35) * M(35, 80)
      temp = temp + M(65, 36) * M(36, 80)
      temp = temp + M(65, 43) * M(43, 80)
      temp = temp + M(65, 45) * M(45, 80)
      temp = temp + M(65, 48) * M(48, 80)
      temp = temp + M(65, 54) * M(54, 80)
      temp = temp + M(65, 59) * M(59, 80)
      temp = temp + M(65, 60) * M(60, 80)
      temp = temp + M(65, 62) * M(62, 80)
      M(65, 80) = ( M(65, 80) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 54) * M(54, 82)
      temp = temp + M(65, 59) * M(59, 82)
      temp = temp + M(65, 60) * M(60, 82)
      temp = temp + M(65, 62) * M(62, 82)
      M(65, 82) = ( M(65, 82) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 22) * M(22, 84)
      temp = temp + M(65, 23) * M(23, 84)
      temp = temp + M(65, 36) * M(36, 84)
      temp = temp + M(65, 43) * M(43, 84)
      temp = temp + M(65, 45) * M(45, 84)
      temp = temp + M(65, 48) * M(48, 84)
      temp = temp + M(65, 54) * M(54, 84)
      temp = temp + M(65, 59) * M(59, 84)
      temp = temp + M(65, 60) * M(60, 84)
      temp = temp + M(65, 62) * M(62, 84)
      M(65, 84) = ( M(65, 84) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 43) * M(43, 85)
      temp = temp + M(65, 54) * M(54, 85)
      temp = temp + M(65, 59) * M(59, 85)
      temp = temp + M(65, 60) * M(60, 85)
      temp = temp + M(65, 62) * M(62, 85)
      M(65, 85) = ( M(65, 85) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 48) * M(48, 86)
      M(65, 86) = ( M(65, 86) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 25) * M(25, 87)
      temp = temp + M(65, 26) * M(26, 87)
      temp = temp + M(65, 27) * M(27, 87)
      temp = temp + M(65, 30) * M(30, 87)
      temp = temp + M(65, 35) * M(35, 87)
      temp = temp + M(65, 43) * M(43, 87)
      temp = temp + M(65, 45) * M(45, 87)
      temp = temp + M(65, 48) * M(48, 87)
      temp = temp + M(65, 54) * M(54, 87)
      temp = temp + M(65, 59) * M(59, 87)
      temp = temp + M(65, 60) * M(60, 87)
      temp = temp + M(65, 62) * M(62, 87)
      M(65, 87) = ( M(65, 87) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 45) * M(45, 88)
      temp = temp + M(65, 54) * M(54, 88)
      temp = temp + M(65, 59) * M(59, 88)
      temp = temp + M(65, 60) * M(60, 88)
      temp = temp + M(65, 62) * M(62, 88)
      M(65, 88) = ( M(65, 88) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 54) * M(54, 89)
      temp = temp + M(65, 59) * M(59, 89)
      temp = temp + M(65, 60) * M(60, 89)
      temp = temp + M(65, 62) * M(62, 89)
      M(65, 89) = ( M(65, 89) - temp ) / M(65, 65)

C     Upper part.
      M(66, 76) = M(66, 76) / M(66, 66)
C     Upper part.
      temp = M(66, 4) * M(4, 80)
      temp = temp + M(66, 40) * M(40, 80)
      temp = temp + M(66, 42) * M(42, 80)
      temp = temp + M(66, 45) * M(45, 80)
      temp = temp + M(66, 51) * M(51, 80)
      temp = temp + M(66, 54) * M(54, 80)
      temp = temp + M(66, 59) * M(59, 80)
      temp = temp + M(66, 65) * M(65, 80)
      M(66, 80) = ( M(66, 80) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 40) * M(40, 82)
      temp = temp + M(66, 42) * M(42, 82)
      temp = temp + M(66, 51) * M(51, 82)
      temp = temp + M(66, 54) * M(54, 82)
      temp = temp + M(66, 59) * M(59, 82)
      temp = temp + M(66, 65) * M(65, 82)
      M(66, 82) = ( M(66, 82) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 40) * M(40, 84)
      temp = temp + M(66, 42) * M(42, 84)
      temp = temp + M(66, 45) * M(45, 84)
      temp = temp + M(66, 51) * M(51, 84)
      temp = temp + M(66, 54) * M(54, 84)
      temp = temp + M(66, 59) * M(59, 84)
      temp = temp + M(66, 65) * M(65, 84)
      M(66, 84) = ( M(66, 84) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 40) * M(40, 85)
      temp = temp + M(66, 42) * M(42, 85)
      temp = temp + M(66, 51) * M(51, 85)
      temp = temp + M(66, 54) * M(54, 85)
      temp = temp + M(66, 59) * M(59, 85)
      temp = temp + M(66, 65) * M(65, 85)
      M(66, 85) = ( M(66, 85) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 65) * M(65, 86)
      M(66, 86) = ( M(66, 86) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 40) * M(40, 87)
      temp = temp + M(66, 42) * M(42, 87)
      temp = temp + M(66, 45) * M(45, 87)
      temp = temp + M(66, 51) * M(51, 87)
      temp = temp + M(66, 54) * M(54, 87)
      temp = temp + M(66, 59) * M(59, 87)
      temp = temp + M(66, 65) * M(65, 87)
      M(66, 87) = ( M(66, 87) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 40) * M(40, 88)
      temp = temp + M(66, 42) * M(42, 88)
      temp = temp + M(66, 45) * M(45, 88)
      temp = temp + M(66, 51) * M(51, 88)
      temp = temp + M(66, 54) * M(54, 88)
      temp = temp + M(66, 59) * M(59, 88)
      temp = temp + M(66, 65) * M(65, 88)
      M(66, 88) = ( M(66, 88) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 40) * M(40, 89)
      temp = temp + M(66, 42) * M(42, 89)
      temp = temp + M(66, 51) * M(51, 89)
      temp = temp + M(66, 54) * M(54, 89)
      temp = temp + M(66, 59) * M(59, 89)
      temp = temp + M(66, 65) * M(65, 89)
      M(66, 89) = ( M(66, 89) - temp ) / M(66, 66)

C     Upper part.
      M(67, 72) = M(67, 72) / M(67, 67)
C     Upper part.
      temp = M(67, 66) * M(66, 76)
      M(67, 76) = ( M(67, 76) - temp ) / M(67, 67)
C     Upper part.
      M(67, 79) = M(67, 79) / M(67, 67)
C     Upper part.
      temp = M(67, 4) * M(4, 80)
      temp = temp + M(67, 25) * M(25, 80)
      temp = temp + M(67, 26) * M(26, 80)
      temp = temp + M(67, 27) * M(27, 80)
      temp = temp + M(67, 30) * M(30, 80)
      temp = temp + M(67, 35) * M(35, 80)
      temp = temp + M(67, 43) * M(43, 80)
      temp = temp + M(67, 48) * M(48, 80)
      temp = temp + M(67, 54) * M(54, 80)
      temp = temp + M(67, 59) * M(59, 80)
      temp = temp + M(67, 60) * M(60, 80)
      temp = temp + M(67, 62) * M(62, 80)
      temp = temp + M(67, 65) * M(65, 80)
      temp = temp + M(67, 66) * M(66, 80)
      M(67, 80) = ( M(67, 80) - temp ) / M(67, 67)
C     Upper part.
      M(67, 81) = M(67, 81) / M(67, 67)
C     Upper part.
      temp = M(67, 54) * M(54, 82)
      temp = temp + M(67, 59) * M(59, 82)
      temp = temp + M(67, 60) * M(60, 82)
      temp = temp + M(67, 62) * M(62, 82)
      temp = temp + M(67, 65) * M(65, 82)
      temp = temp + M(67, 66) * M(66, 82)
      M(67, 82) = ( M(67, 82) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 43) * M(43, 84)
      temp = temp + M(67, 48) * M(48, 84)
      temp = temp + M(67, 54) * M(54, 84)
      temp = temp + M(67, 59) * M(59, 84)
      temp = temp + M(67, 60) * M(60, 84)
      temp = temp + M(67, 62) * M(62, 84)
      temp = temp + M(67, 65) * M(65, 84)
      temp = temp + M(67, 66) * M(66, 84)
      M(67, 84) = ( M(67, 84) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 43) * M(43, 85)
      temp = temp + M(67, 54) * M(54, 85)
      temp = temp + M(67, 59) * M(59, 85)
      temp = temp + M(67, 60) * M(60, 85)
      temp = temp + M(67, 62) * M(62, 85)
      temp = temp + M(67, 65) * M(65, 85)
      temp = temp + M(67, 66) * M(66, 85)
      M(67, 85) = ( M(67, 85) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 48) * M(48, 86)
      temp = temp + M(67, 65) * M(65, 86)
      temp = temp + M(67, 66) * M(66, 86)
      M(67, 86) = ( M(67, 86) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 25) * M(25, 87)
      temp = temp + M(67, 26) * M(26, 87)
      temp = temp + M(67, 27) * M(27, 87)
      temp = temp + M(67, 30) * M(30, 87)
      temp = temp + M(67, 35) * M(35, 87)
      temp = temp + M(67, 43) * M(43, 87)
      temp = temp + M(67, 48) * M(48, 87)
      temp = temp + M(67, 54) * M(54, 87)
      temp = temp + M(67, 59) * M(59, 87)
      temp = temp + M(67, 60) * M(60, 87)
      temp = temp + M(67, 62) * M(62, 87)
      temp = temp + M(67, 65) * M(65, 87)
      temp = temp + M(67, 66) * M(66, 87)
      M(67, 87) = ( M(67, 87) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 54) * M(54, 88)
      temp = temp + M(67, 59) * M(59, 88)
      temp = temp + M(67, 60) * M(60, 88)
      temp = temp + M(67, 62) * M(62, 88)
      temp = temp + M(67, 65) * M(65, 88)
      temp = temp + M(67, 66) * M(66, 88)
      M(67, 88) = ( M(67, 88) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 54) * M(54, 89)
      temp = temp + M(67, 59) * M(59, 89)
      temp = temp + M(67, 60) * M(60, 89)
      temp = temp + M(67, 62) * M(62, 89)
      temp = temp + M(67, 65) * M(65, 89)
      temp = temp + M(67, 66) * M(66, 89)
      M(67, 89) = ( M(67, 89) - temp ) / M(67, 67)

C     Upper part.
      temp = M(68, 62) * M(62, 80)
      temp = temp + M(68, 65) * M(65, 80)
      M(68, 80) = ( M(68, 80) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 62) * M(62, 82)
      temp = temp + M(68, 65) * M(65, 82)
      M(68, 82) = ( M(68, 82) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 62) * M(62, 84)
      temp = temp + M(68, 65) * M(65, 84)
      M(68, 84) = ( M(68, 84) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 62) * M(62, 85)
      temp = temp + M(68, 65) * M(65, 85)
      M(68, 85) = ( M(68, 85) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 65) * M(65, 86)
      M(68, 86) = ( M(68, 86) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 62) * M(62, 87)
      temp = temp + M(68, 65) * M(65, 87)
      M(68, 87) = ( M(68, 87) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 62) * M(62, 88)
      temp = temp + M(68, 65) * M(65, 88)
      M(68, 88) = ( M(68, 88) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 62) * M(62, 89)
      temp = temp + M(68, 65) * M(65, 89)
      M(68, 89) = ( M(68, 89) - temp ) / M(68, 68)

C     Upper part.
      temp = M(69, 27) * M(27, 80)
      temp = temp + M(69, 65) * M(65, 80)
      M(69, 80) = ( M(69, 80) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 82)
      M(69, 82) = ( M(69, 82) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 84)
      M(69, 84) = ( M(69, 84) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 85)
      M(69, 85) = ( M(69, 85) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 86)
      M(69, 86) = ( M(69, 86) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 27) * M(27, 87)
      temp = temp + M(69, 65) * M(65, 87)
      M(69, 87) = ( M(69, 87) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 88)
      M(69, 88) = ( M(69, 88) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 65) * M(65, 89)
      M(69, 89) = ( M(69, 89) - temp ) / M(69, 69)

C     Lower part.
      temp = M(72, 47) * M(47, 70)
      M(72, 70) = M(72, 70) - temp
C     Lower part.
      temp = M(79, 47) * M(47, 70)
      M(79, 70) = M(79, 70) - temp
C     Lower part.
      temp = M(80, 47) * M(47, 70)
      M(80, 70) = M(80, 70) - temp
C     Lower part.
      temp = M(88, 47) * M(47, 70)
      M(88, 70) = M(88, 70) - temp
C     Lower part.
      temp = M(89, 47) * M(47, 70)
      M(89, 70) = M(89, 70) - temp
C     Upper part.
      M(70, 77) = M(70, 77) / M(70, 70)
C     Upper part.
      temp = M(70, 26) * M(26, 80)
      temp = temp + M(70, 27) * M(27, 80)
      temp = temp + M(70, 30) * M(30, 80)
      temp = temp + M(70, 35) * M(35, 80)
      temp = temp + M(70, 43) * M(43, 80)
      temp = temp + M(70, 59) * M(59, 80)
      temp = temp + M(70, 60) * M(60, 80)
      temp = temp + M(70, 62) * M(62, 80)
      temp = temp + M(70, 65) * M(65, 80)
      M(70, 80) = ( M(70, 80) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 59) * M(59, 82)
      temp = temp + M(70, 60) * M(60, 82)
      temp = temp + M(70, 62) * M(62, 82)
      temp = temp + M(70, 65) * M(65, 82)
      M(70, 82) = ( M(70, 82) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 43) * M(43, 84)
      temp = temp + M(70, 59) * M(59, 84)
      temp = temp + M(70, 60) * M(60, 84)
      temp = temp + M(70, 62) * M(62, 84)
      temp = temp + M(70, 65) * M(65, 84)
      M(70, 84) = ( M(70, 84) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 43) * M(43, 85)
      temp = temp + M(70, 59) * M(59, 85)
      temp = temp + M(70, 60) * M(60, 85)
      temp = temp + M(70, 62) * M(62, 85)
      temp = temp + M(70, 65) * M(65, 85)
      M(70, 85) = ( M(70, 85) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 65) * M(65, 86)
      M(70, 86) = ( M(70, 86) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 26) * M(26, 87)
      temp = temp + M(70, 27) * M(27, 87)
      temp = temp + M(70, 30) * M(30, 87)
      temp = temp + M(70, 35) * M(35, 87)
      temp = temp + M(70, 43) * M(43, 87)
      temp = temp + M(70, 59) * M(59, 87)
      temp = temp + M(70, 60) * M(60, 87)
      temp = temp + M(70, 62) * M(62, 87)
      temp = temp + M(70, 65) * M(65, 87)
      M(70, 87) = ( M(70, 87) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 59) * M(59, 88)
      temp = temp + M(70, 60) * M(60, 88)
      temp = temp + M(70, 62) * M(62, 88)
      temp = temp + M(70, 65) * M(65, 88)
      M(70, 88) = ( M(70, 88) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 59) * M(59, 89)
      temp = temp + M(70, 60) * M(60, 89)
      temp = temp + M(70, 62) * M(62, 89)
      temp = temp + M(70, 65) * M(65, 89)
      M(70, 89) = ( M(70, 89) - temp ) / M(70, 70)

C     Upper part.
      M(71, 76) = M(71, 76) / M(71, 71)
C     Upper part.
      temp = M(71, 70) * M(70, 77)
      M(71, 77) = ( M(71, 77) - temp ) / M(71, 71)
C     Upper part.
      M(71, 78) = M(71, 78) / M(71, 71)
C     Upper part.
      temp = M(71, 30) * M(30, 80)
      temp = temp + M(71, 53) * M(53, 80)
      temp = temp + M(71, 54) * M(54, 80)
      temp = temp + M(71, 56) * M(56, 80)
      temp = temp + M(71, 57) * M(57, 80)
      temp = temp + M(71, 58) * M(58, 80)
      temp = temp + M(71, 59) * M(59, 80)
      temp = temp + M(71, 60) * M(60, 80)
      temp = temp + M(71, 61) * M(61, 80)
      temp = temp + M(71, 62) * M(62, 80)
      temp = temp + M(71, 63) * M(63, 80)
      temp = temp + M(71, 64) * M(64, 80)
      temp = temp + M(71, 65) * M(65, 80)
      temp = temp + M(71, 68) * M(68, 80)
      temp = temp + M(71, 70) * M(70, 80)
      M(71, 80) = ( M(71, 80) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 53) * M(53, 82)
      temp = temp + M(71, 54) * M(54, 82)
      temp = temp + M(71, 56) * M(56, 82)
      temp = temp + M(71, 57) * M(57, 82)
      temp = temp + M(71, 58) * M(58, 82)
      temp = temp + M(71, 59) * M(59, 82)
      temp = temp + M(71, 60) * M(60, 82)
      temp = temp + M(71, 61) * M(61, 82)
      temp = temp + M(71, 62) * M(62, 82)
      temp = temp + M(71, 63) * M(63, 82)
      temp = temp + M(71, 64) * M(64, 82)
      temp = temp + M(71, 65) * M(65, 82)
      temp = temp + M(71, 68) * M(68, 82)
      temp = temp + M(71, 70) * M(70, 82)
      M(71, 82) = ( M(71, 82) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 54) * M(54, 84)
      temp = temp + M(71, 58) * M(58, 84)
      temp = temp + M(71, 59) * M(59, 84)
      temp = temp + M(71, 60) * M(60, 84)
      temp = temp + M(71, 61) * M(61, 84)
      temp = temp + M(71, 62) * M(62, 84)
      temp = temp + M(71, 63) * M(63, 84)
      temp = temp + M(71, 64) * M(64, 84)
      temp = temp + M(71, 65) * M(65, 84)
      temp = temp + M(71, 68) * M(68, 84)
      temp = temp + M(71, 70) * M(70, 84)
      M(71, 84) = ( M(71, 84) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 53) * M(53, 85)
      temp = temp + M(71, 54) * M(54, 85)
      temp = temp + M(71, 56) * M(56, 85)
      temp = temp + M(71, 57) * M(57, 85)
      temp = temp + M(71, 58) * M(58, 85)
      temp = temp + M(71, 59) * M(59, 85)
      temp = temp + M(71, 60) * M(60, 85)
      temp = temp + M(71, 61) * M(61, 85)
      temp = temp + M(71, 62) * M(62, 85)
      temp = temp + M(71, 63) * M(63, 85)
      temp = temp + M(71, 64) * M(64, 85)
      temp = temp + M(71, 65) * M(65, 85)
      temp = temp + M(71, 68) * M(68, 85)
      temp = temp + M(71, 70) * M(70, 85)
      M(71, 85) = ( M(71, 85) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 65) * M(65, 86)
      temp = temp + M(71, 68) * M(68, 86)
      temp = temp + M(71, 70) * M(70, 86)
      M(71, 86) = ( M(71, 86) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 30) * M(30, 87)
      temp = temp + M(71, 53) * M(53, 87)
      temp = temp + M(71, 54) * M(54, 87)
      temp = temp + M(71, 56) * M(56, 87)
      temp = temp + M(71, 57) * M(57, 87)
      temp = temp + M(71, 58) * M(58, 87)
      temp = temp + M(71, 59) * M(59, 87)
      temp = temp + M(71, 60) * M(60, 87)
      temp = temp + M(71, 61) * M(61, 87)
      temp = temp + M(71, 62) * M(62, 87)
      temp = temp + M(71, 63) * M(63, 87)
      temp = temp + M(71, 64) * M(64, 87)
      temp = temp + M(71, 65) * M(65, 87)
      temp = temp + M(71, 68) * M(68, 87)
      temp = temp + M(71, 70) * M(70, 87)
      M(71, 87) = ( M(71, 87) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 53) * M(53, 88)
      temp = temp + M(71, 54) * M(54, 88)
      temp = temp + M(71, 56) * M(56, 88)
      temp = temp + M(71, 57) * M(57, 88)
      temp = temp + M(71, 58) * M(58, 88)
      temp = temp + M(71, 59) * M(59, 88)
      temp = temp + M(71, 60) * M(60, 88)
      temp = temp + M(71, 61) * M(61, 88)
      temp = temp + M(71, 62) * M(62, 88)
      temp = temp + M(71, 63) * M(63, 88)
      temp = temp + M(71, 64) * M(64, 88)
      temp = temp + M(71, 65) * M(65, 88)
      temp = temp + M(71, 68) * M(68, 88)
      temp = temp + M(71, 70) * M(70, 88)
      M(71, 88) = ( M(71, 88) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 53) * M(53, 89)
      temp = temp + M(71, 54) * M(54, 89)
      temp = temp + M(71, 56) * M(56, 89)
      temp = temp + M(71, 57) * M(57, 89)
      temp = temp + M(71, 58) * M(58, 89)
      temp = temp + M(71, 59) * M(59, 89)
      temp = temp + M(71, 60) * M(60, 89)
      temp = temp + M(71, 61) * M(61, 89)
      temp = temp + M(71, 62) * M(62, 89)
      temp = temp + M(71, 63) * M(63, 89)
      temp = temp + M(71, 64) * M(64, 89)
      temp = temp + M(71, 65) * M(65, 89)
      temp = temp + M(71, 68) * M(68, 89)
      temp = temp + M(71, 70) * M(70, 89)
      M(71, 89) = ( M(71, 89) - temp ) / M(71, 71)

C     Lower part.
      temp = M(80, 67) * M(67, 72)
      M(80, 72) = M(80, 72) - temp
C     Lower part.
      temp = M(88, 67) * M(67, 72)
      M(88, 72) = M(88, 72) - temp
C     Upper part.
      M(72, 76) = M(72, 76) / M(72, 72)
C     Upper part.
      temp = M(72, 70) * M(70, 77)
      M(72, 77) = ( M(72, 77) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 80)
      temp = temp + M(72, 42) * M(42, 80)
      temp = temp + M(72, 45) * M(45, 80)
      temp = temp + M(72, 47) * M(47, 80)
      temp = temp + M(72, 48) * M(48, 80)
      temp = temp + M(72, 51) * M(51, 80)
      temp = temp + M(72, 54) * M(54, 80)
      temp = temp + M(72, 59) * M(59, 80)
      temp = temp + M(72, 65) * M(65, 80)
      temp = temp + M(72, 70) * M(70, 80)
      M(72, 80) = ( M(72, 80) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 82)
      temp = temp + M(72, 42) * M(42, 82)
      temp = temp + M(72, 47) * M(47, 82)
      temp = temp + M(72, 51) * M(51, 82)
      temp = temp + M(72, 54) * M(54, 82)
      temp = temp + M(72, 59) * M(59, 82)
      temp = temp + M(72, 65) * M(65, 82)
      temp = temp + M(72, 70) * M(70, 82)
      M(72, 82) = ( M(72, 82) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 84)
      temp = temp + M(72, 42) * M(42, 84)
      temp = temp + M(72, 45) * M(45, 84)
      temp = temp + M(72, 48) * M(48, 84)
      temp = temp + M(72, 51) * M(51, 84)
      temp = temp + M(72, 54) * M(54, 84)
      temp = temp + M(72, 59) * M(59, 84)
      temp = temp + M(72, 65) * M(65, 84)
      temp = temp + M(72, 70) * M(70, 84)
      M(72, 84) = ( M(72, 84) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 85)
      temp = temp + M(72, 42) * M(42, 85)
      temp = temp + M(72, 51) * M(51, 85)
      temp = temp + M(72, 54) * M(54, 85)
      temp = temp + M(72, 59) * M(59, 85)
      temp = temp + M(72, 65) * M(65, 85)
      temp = temp + M(72, 70) * M(70, 85)
      M(72, 85) = ( M(72, 85) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 48) * M(48, 86)
      temp = temp + M(72, 65) * M(65, 86)
      temp = temp + M(72, 70) * M(70, 86)
      M(72, 86) = ( M(72, 86) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 87)
      temp = temp + M(72, 42) * M(42, 87)
      temp = temp + M(72, 45) * M(45, 87)
      temp = temp + M(72, 48) * M(48, 87)
      temp = temp + M(72, 51) * M(51, 87)
      temp = temp + M(72, 54) * M(54, 87)
      temp = temp + M(72, 59) * M(59, 87)
      temp = temp + M(72, 65) * M(65, 87)
      temp = temp + M(72, 70) * M(70, 87)
      M(72, 87) = ( M(72, 87) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 88)
      temp = temp + M(72, 42) * M(42, 88)
      temp = temp + M(72, 45) * M(45, 88)
      temp = temp + M(72, 51) * M(51, 88)
      temp = temp + M(72, 54) * M(54, 88)
      temp = temp + M(72, 59) * M(59, 88)
      temp = temp + M(72, 65) * M(65, 88)
      temp = temp + M(72, 70) * M(70, 88)
      M(72, 88) = ( M(72, 88) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 40) * M(40, 89)
      temp = temp + M(72, 42) * M(42, 89)
      temp = temp + M(72, 51) * M(51, 89)
      temp = temp + M(72, 54) * M(54, 89)
      temp = temp + M(72, 59) * M(59, 89)
      temp = temp + M(72, 65) * M(65, 89)
      temp = temp + M(72, 70) * M(70, 89)
      M(72, 89) = ( M(72, 89) - temp ) / M(72, 72)

C     Upper part.
      M(73, 75) = M(73, 75) / M(73, 73)
C     Upper part.
      M(73, 76) = M(73, 76) / M(73, 73)
C     Upper part.
      temp = M(73, 70) * M(70, 77)
      M(73, 77) = ( M(73, 77) - temp ) / M(73, 73)
C     Upper part.
      M(73, 78) = M(73, 78) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 80)
      temp = temp + M(73, 42) * M(42, 80)
      temp = temp + M(73, 45) * M(45, 80)
      temp = temp + M(73, 51) * M(51, 80)
      temp = temp + M(73, 52) * M(52, 80)
      temp = temp + M(73, 53) * M(53, 80)
      temp = temp + M(73, 56) * M(56, 80)
      temp = temp + M(73, 57) * M(57, 80)
      temp = temp + M(73, 58) * M(58, 80)
      temp = temp + M(73, 59) * M(59, 80)
      temp = temp + M(73, 61) * M(61, 80)
      temp = temp + M(73, 65) * M(65, 80)
      temp = temp + M(73, 68) * M(68, 80)
      temp = temp + M(73, 69) * M(69, 80)
      temp = temp + M(73, 70) * M(70, 80)
      M(73, 80) = ( M(73, 80) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 82)
      temp = temp + M(73, 42) * M(42, 82)
      temp = temp + M(73, 51) * M(51, 82)
      temp = temp + M(73, 52) * M(52, 82)
      temp = temp + M(73, 53) * M(53, 82)
      temp = temp + M(73, 56) * M(56, 82)
      temp = temp + M(73, 57) * M(57, 82)
      temp = temp + M(73, 58) * M(58, 82)
      temp = temp + M(73, 59) * M(59, 82)
      temp = temp + M(73, 61) * M(61, 82)
      temp = temp + M(73, 65) * M(65, 82)
      temp = temp + M(73, 68) * M(68, 82)
      temp = temp + M(73, 69) * M(69, 82)
      temp = temp + M(73, 70) * M(70, 82)
      M(73, 82) = ( M(73, 82) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 84)
      temp = temp + M(73, 42) * M(42, 84)
      temp = temp + M(73, 45) * M(45, 84)
      temp = temp + M(73, 51) * M(51, 84)
      temp = temp + M(73, 58) * M(58, 84)
      temp = temp + M(73, 59) * M(59, 84)
      temp = temp + M(73, 61) * M(61, 84)
      temp = temp + M(73, 65) * M(65, 84)
      temp = temp + M(73, 68) * M(68, 84)
      temp = temp + M(73, 69) * M(69, 84)
      temp = temp + M(73, 70) * M(70, 84)
      M(73, 84) = ( M(73, 84) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 85)
      temp = temp + M(73, 42) * M(42, 85)
      temp = temp + M(73, 51) * M(51, 85)
      temp = temp + M(73, 52) * M(52, 85)
      temp = temp + M(73, 53) * M(53, 85)
      temp = temp + M(73, 56) * M(56, 85)
      temp = temp + M(73, 57) * M(57, 85)
      temp = temp + M(73, 58) * M(58, 85)
      temp = temp + M(73, 59) * M(59, 85)
      temp = temp + M(73, 61) * M(61, 85)
      temp = temp + M(73, 65) * M(65, 85)
      temp = temp + M(73, 68) * M(68, 85)
      temp = temp + M(73, 69) * M(69, 85)
      temp = temp + M(73, 70) * M(70, 85)
      M(73, 85) = ( M(73, 85) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 65) * M(65, 86)
      temp = temp + M(73, 68) * M(68, 86)
      temp = temp + M(73, 69) * M(69, 86)
      temp = temp + M(73, 70) * M(70, 86)
      M(73, 86) = ( M(73, 86) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 87)
      temp = temp + M(73, 42) * M(42, 87)
      temp = temp + M(73, 45) * M(45, 87)
      temp = temp + M(73, 51) * M(51, 87)
      temp = temp + M(73, 52) * M(52, 87)
      temp = temp + M(73, 53) * M(53, 87)
      temp = temp + M(73, 56) * M(56, 87)
      temp = temp + M(73, 57) * M(57, 87)
      temp = temp + M(73, 58) * M(58, 87)
      temp = temp + M(73, 59) * M(59, 87)
      temp = temp + M(73, 61) * M(61, 87)
      temp = temp + M(73, 65) * M(65, 87)
      temp = temp + M(73, 68) * M(68, 87)
      temp = temp + M(73, 69) * M(69, 87)
      temp = temp + M(73, 70) * M(70, 87)
      M(73, 87) = ( M(73, 87) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 88)
      temp = temp + M(73, 42) * M(42, 88)
      temp = temp + M(73, 45) * M(45, 88)
      temp = temp + M(73, 51) * M(51, 88)
      temp = temp + M(73, 52) * M(52, 88)
      temp = temp + M(73, 53) * M(53, 88)
      temp = temp + M(73, 56) * M(56, 88)
      temp = temp + M(73, 57) * M(57, 88)
      temp = temp + M(73, 58) * M(58, 88)
      temp = temp + M(73, 59) * M(59, 88)
      temp = temp + M(73, 61) * M(61, 88)
      temp = temp + M(73, 65) * M(65, 88)
      temp = temp + M(73, 68) * M(68, 88)
      temp = temp + M(73, 69) * M(69, 88)
      temp = temp + M(73, 70) * M(70, 88)
      M(73, 88) = ( M(73, 88) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 89)
      temp = temp + M(73, 42) * M(42, 89)
      temp = temp + M(73, 51) * M(51, 89)
      temp = temp + M(73, 52) * M(52, 89)
      temp = temp + M(73, 53) * M(53, 89)
      temp = temp + M(73, 56) * M(56, 89)
      temp = temp + M(73, 57) * M(57, 89)
      temp = temp + M(73, 58) * M(58, 89)
      temp = temp + M(73, 59) * M(59, 89)
      temp = temp + M(73, 61) * M(61, 89)
      temp = temp + M(73, 65) * M(65, 89)
      temp = temp + M(73, 68) * M(68, 89)
      temp = temp + M(73, 69) * M(69, 89)
      temp = temp + M(73, 70) * M(70, 89)
      M(73, 89) = ( M(73, 89) - temp ) / M(73, 73)

C     Upper part.
      temp = M(74, 66) * M(66, 76)
      temp = temp + M(74, 72) * M(72, 76)
      M(74, 76) = ( M(74, 76) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 72) * M(72, 77)
      M(74, 77) = ( M(74, 77) - temp ) / M(74, 74)
C     Upper part.
      M(74, 79) = M(74, 79) / M(74, 74)
C     Upper part.
      temp = M(74, 45) * M(45, 80)
      temp = temp + M(74, 54) * M(54, 80)
      temp = temp + M(74, 59) * M(59, 80)
      temp = temp + M(74, 65) * M(65, 80)
      temp = temp + M(74, 66) * M(66, 80)
      temp = temp + M(74, 72) * M(72, 80)
      M(74, 80) = ( M(74, 80) - temp ) / M(74, 74)
C     Upper part.
      M(74, 81) = M(74, 81) / M(74, 74)
C     Upper part.
      temp = M(74, 54) * M(54, 82)
      temp = temp + M(74, 59) * M(59, 82)
      temp = temp + M(74, 65) * M(65, 82)
      temp = temp + M(74, 66) * M(66, 82)
      temp = temp + M(74, 72) * M(72, 82)
      M(74, 82) = ( M(74, 82) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 17) * M(17, 84)
      temp = temp + M(74, 45) * M(45, 84)
      temp = temp + M(74, 54) * M(54, 84)
      temp = temp + M(74, 59) * M(59, 84)
      temp = temp + M(74, 65) * M(65, 84)
      temp = temp + M(74, 66) * M(66, 84)
      temp = temp + M(74, 72) * M(72, 84)
      M(74, 84) = ( M(74, 84) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 54) * M(54, 85)
      temp = temp + M(74, 59) * M(59, 85)
      temp = temp + M(74, 65) * M(65, 85)
      temp = temp + M(74, 66) * M(66, 85)
      temp = temp + M(74, 72) * M(72, 85)
      M(74, 85) = ( M(74, 85) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 65) * M(65, 86)
      temp = temp + M(74, 66) * M(66, 86)
      temp = temp + M(74, 72) * M(72, 86)
      M(74, 86) = ( M(74, 86) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 17) * M(17, 87)
      temp = temp + M(74, 45) * M(45, 87)
      temp = temp + M(74, 54) * M(54, 87)
      temp = temp + M(74, 59) * M(59, 87)
      temp = temp + M(74, 65) * M(65, 87)
      temp = temp + M(74, 66) * M(66, 87)
      temp = temp + M(74, 72) * M(72, 87)
      M(74, 87) = ( M(74, 87) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 45) * M(45, 88)
      temp = temp + M(74, 54) * M(54, 88)
      temp = temp + M(74, 59) * M(59, 88)
      temp = temp + M(74, 65) * M(65, 88)
      temp = temp + M(74, 66) * M(66, 88)
      temp = temp + M(74, 72) * M(72, 88)
      M(74, 88) = ( M(74, 88) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 54) * M(54, 89)
      temp = temp + M(74, 59) * M(59, 89)
      temp = temp + M(74, 65) * M(65, 89)
      temp = temp + M(74, 66) * M(66, 89)
      temp = temp + M(74, 72) * M(72, 89)
      M(74, 89) = ( M(74, 89) - temp ) / M(74, 74)

C     Lower part.
      temp = M(75, 73) * M(73, 75)
      M(75, 75) = M(75, 75) - temp
C     Lower part.
      temp = M(76, 73) * M(73, 75)
      M(76, 75) = M(76, 75) - temp
C     Lower part.
      temp = M(77, 73) * M(73, 75)
      M(77, 75) = M(77, 75) - temp
C     Lower part.
      temp = M(80, 73) * M(73, 75)
      M(80, 75) = M(80, 75) - temp
C     Lower part.
      temp = M(81, 73) * M(73, 75)
      M(81, 75) = M(81, 75) - temp
C     Lower part.
      temp = M(88, 73) * M(73, 75)
      M(88, 75) = M(88, 75) - temp
C     Upper part.
      temp = M(75, 73) * M(73, 76)
      M(75, 76) = ( M(75, 76) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 70) * M(70, 77)
      temp = temp + M(75, 73) * M(73, 77)
      M(75, 77) = ( M(75, 77) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 73) * M(73, 78)
      M(75, 78) = ( M(75, 78) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 7) * M(7, 80)
      temp = temp + M(75, 8) * M(8, 80)
      temp = temp + M(75, 26) * M(26, 80)
      temp = temp + M(75, 35) * M(35, 80)
      temp = temp + M(75, 38) * M(38, 80)
      temp = temp + M(75, 43) * M(43, 80)
      temp = temp + M(75, 45) * M(45, 80)
      temp = temp + M(75, 48) * M(48, 80)
      temp = temp + M(75, 50) * M(50, 80)
      temp = temp + M(75, 53) * M(53, 80)
      temp = temp + M(75, 54) * M(54, 80)
      temp = temp + M(75, 57) * M(57, 80)
      temp = temp + M(75, 59) * M(59, 80)
      temp = temp + M(75, 65) * M(65, 80)
      temp = temp + M(75, 70) * M(70, 80)
      temp = temp + M(75, 73) * M(73, 80)
      M(75, 80) = ( M(75, 80) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 53) * M(53, 82)
      temp = temp + M(75, 54) * M(54, 82)
      temp = temp + M(75, 57) * M(57, 82)
      temp = temp + M(75, 59) * M(59, 82)
      temp = temp + M(75, 65) * M(65, 82)
      temp = temp + M(75, 70) * M(70, 82)
      temp = temp + M(75, 73) * M(73, 82)
      M(75, 82) = ( M(75, 82) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 43) * M(43, 84)
      temp = temp + M(75, 45) * M(45, 84)
      temp = temp + M(75, 48) * M(48, 84)
      temp = temp + M(75, 50) * M(50, 84)
      temp = temp + M(75, 54) * M(54, 84)
      temp = temp + M(75, 59) * M(59, 84)
      temp = temp + M(75, 65) * M(65, 84)
      temp = temp + M(75, 70) * M(70, 84)
      temp = temp + M(75, 73) * M(73, 84)
      M(75, 84) = ( M(75, 84) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 43) * M(43, 85)
      temp = temp + M(75, 53) * M(53, 85)
      temp = temp + M(75, 54) * M(54, 85)
      temp = temp + M(75, 57) * M(57, 85)
      temp = temp + M(75, 59) * M(59, 85)
      temp = temp + M(75, 65) * M(65, 85)
      temp = temp + M(75, 70) * M(70, 85)
      temp = temp + M(75, 73) * M(73, 85)
      M(75, 85) = ( M(75, 85) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 48) * M(48, 86)
      temp = temp + M(75, 50) * M(50, 86)
      temp = temp + M(75, 65) * M(65, 86)
      temp = temp + M(75, 70) * M(70, 86)
      temp = temp + M(75, 73) * M(73, 86)
      M(75, 86) = ( M(75, 86) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 26) * M(26, 87)
      temp = temp + M(75, 35) * M(35, 87)
      temp = temp + M(75, 43) * M(43, 87)
      temp = temp + M(75, 45) * M(45, 87)
      temp = temp + M(75, 48) * M(48, 87)
      temp = temp + M(75, 50) * M(50, 87)
      temp = temp + M(75, 53) * M(53, 87)
      temp = temp + M(75, 54) * M(54, 87)
      temp = temp + M(75, 57) * M(57, 87)
      temp = temp + M(75, 59) * M(59, 87)
      temp = temp + M(75, 65) * M(65, 87)
      temp = temp + M(75, 70) * M(70, 87)
      temp = temp + M(75, 73) * M(73, 87)
      M(75, 87) = ( M(75, 87) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 38) * M(38, 88)
      temp = temp + M(75, 45) * M(45, 88)
      temp = temp + M(75, 53) * M(53, 88)
      temp = temp + M(75, 54) * M(54, 88)
      temp = temp + M(75, 57) * M(57, 88)
      temp = temp + M(75, 59) * M(59, 88)
      temp = temp + M(75, 65) * M(65, 88)
      temp = temp + M(75, 70) * M(70, 88)
      temp = temp + M(75, 73) * M(73, 88)
      M(75, 88) = ( M(75, 88) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 38) * M(38, 89)
      temp = temp + M(75, 50) * M(50, 89)
      temp = temp + M(75, 53) * M(53, 89)
      temp = temp + M(75, 54) * M(54, 89)
      temp = temp + M(75, 57) * M(57, 89)
      temp = temp + M(75, 59) * M(59, 89)
      temp = temp + M(75, 65) * M(65, 89)
      temp = temp + M(75, 70) * M(70, 89)
      temp = temp + M(75, 73) * M(73, 89)
      M(75, 89) = ( M(75, 89) - temp ) / M(75, 75)

C     Lower part.
      temp = M(76, 73) * M(73, 76)
      temp = temp + M(76, 75) * M(75, 76)
      M(76, 76) = M(76, 76) - temp
C     Lower part.
      temp = M(77, 73) * M(73, 76)
      temp = temp + M(77, 75) * M(75, 76)
      M(77, 76) = M(77, 76) - temp
C     Lower part.
      temp = M(79, 66) * M(66, 76)
      temp = temp + M(79, 75) * M(75, 76)
      M(79, 76) = M(79, 76) - temp
C     Lower part.
      temp = M(80, 66) * M(66, 76)
      temp = temp + M(80, 67) * M(67, 76)
      temp = temp + M(80, 72) * M(72, 76)
      temp = temp + M(80, 73) * M(73, 76)
      temp = temp + M(80, 74) * M(74, 76)
      temp = temp + M(80, 75) * M(75, 76)
      M(80, 76) = M(80, 76) - temp
C     Lower part.
      temp = M(81, 73) * M(73, 76)
      temp = temp + M(81, 75) * M(75, 76)
      M(81, 76) = M(81, 76) - temp
C     Lower part.
      temp = M(82, 75) * M(75, 76)
      M(82, 76) = M(82, 76) - temp
C     Lower part.
      temp = M(84, 74) * M(74, 76)
      temp = temp + M(84, 75) * M(75, 76)
      M(84, 76) = M(84, 76) - temp
C     Lower part.
      temp = M(85, 75) * M(75, 76)
      M(85, 76) = M(85, 76) - temp
C     Lower part.
      temp = M(87, 66) * M(66, 76)
      temp = temp + M(87, 72) * M(72, 76)
      temp = temp + M(87, 74) * M(74, 76)
      temp = temp + M(87, 75) * M(75, 76)
      M(87, 76) = M(87, 76) - temp
C     Lower part.
      temp = M(88, 66) * M(66, 76)
      temp = temp + M(88, 67) * M(67, 76)
      temp = temp + M(88, 72) * M(72, 76)
      temp = temp + M(88, 73) * M(73, 76)
      temp = temp + M(88, 75) * M(75, 76)
      M(88, 76) = M(88, 76) - temp
C     Lower part.
      temp = M(89, 72) * M(72, 76)
      temp = temp + M(89, 75) * M(75, 76)
      M(89, 76) = M(89, 76) - temp
C     Upper part.
      temp = M(76, 73) * M(73, 77)
      temp = temp + M(76, 75) * M(75, 77)
      M(76, 77) = ( M(76, 77) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 78)
      temp = temp + M(76, 75) * M(75, 78)
      M(76, 78) = ( M(76, 78) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 4) * M(4, 80)
      temp = temp + M(76, 73) * M(73, 80)
      temp = temp + M(76, 75) * M(75, 80)
      M(76, 80) = ( M(76, 80) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 82)
      temp = temp + M(76, 75) * M(75, 82)
      M(76, 82) = ( M(76, 82) - temp ) / M(76, 76)
C     Upper part.
      M(76, 83) = M(76, 83) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 84)
      temp = temp + M(76, 75) * M(75, 84)
      M(76, 84) = ( M(76, 84) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 85)
      temp = temp + M(76, 75) * M(75, 85)
      M(76, 85) = ( M(76, 85) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 86)
      temp = temp + M(76, 75) * M(75, 86)
      M(76, 86) = ( M(76, 86) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 87)
      temp = temp + M(76, 75) * M(75, 87)
      M(76, 87) = ( M(76, 87) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 88)
      temp = temp + M(76, 75) * M(75, 88)
      M(76, 88) = ( M(76, 88) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 73) * M(73, 89)
      temp = temp + M(76, 75) * M(75, 89)
      M(76, 89) = ( M(76, 89) - temp ) / M(76, 76)

C     Lower part.
      temp = M(77, 70) * M(70, 77)
      temp = temp + M(77, 73) * M(73, 77)
      temp = temp + M(77, 75) * M(75, 77)
      temp = temp + M(77, 76) * M(76, 77)
      M(77, 77) = M(77, 77) - temp
C     Lower part.
      temp = M(78, 76) * M(76, 77)
      M(78, 77) = M(78, 77) - temp
C     Lower part.
      temp = M(79, 70) * M(70, 77)
      temp = temp + M(79, 75) * M(75, 77)
      temp = temp + M(79, 76) * M(76, 77)
      M(79, 77) = M(79, 77) - temp
C     Lower part.
      temp = M(80, 70) * M(70, 77)
      temp = temp + M(80, 72) * M(72, 77)
      temp = temp + M(80, 73) * M(73, 77)
      temp = temp + M(80, 74) * M(74, 77)
      temp = temp + M(80, 75) * M(75, 77)
      temp = temp + M(80, 76) * M(76, 77)
      M(80, 77) = M(80, 77) - temp
C     Lower part.
      temp = M(81, 70) * M(70, 77)
      temp = temp + M(81, 73) * M(73, 77)
      temp = temp + M(81, 75) * M(75, 77)
      temp = temp + M(81, 76) * M(76, 77)
      M(81, 77) = M(81, 77) - temp
C     Lower part.
      temp = M(82, 70) * M(70, 77)
      temp = temp + M(82, 75) * M(75, 77)
      temp = temp + M(82, 76) * M(76, 77)
      M(82, 77) = M(82, 77) - temp
C     Lower part.
      temp = M(83, 76) * M(76, 77)
      M(83, 77) = M(83, 77) - temp
C     Lower part.
      temp = M(84, 70) * M(70, 77)
      temp = temp + M(84, 74) * M(74, 77)
      temp = temp + M(84, 75) * M(75, 77)
      temp = temp + M(84, 76) * M(76, 77)
      M(84, 77) = M(84, 77) - temp
C     Lower part.
      temp = M(85, 70) * M(70, 77)
      temp = temp + M(85, 75) * M(75, 77)
      temp = temp + M(85, 76) * M(76, 77)
      M(85, 77) = M(85, 77) - temp
C     Lower part.
      temp = M(87, 70) * M(70, 77)
      temp = temp + M(87, 72) * M(72, 77)
      temp = temp + M(87, 74) * M(74, 77)
      temp = temp + M(87, 75) * M(75, 77)
      temp = temp + M(87, 76) * M(76, 77)
      M(87, 77) = M(87, 77) - temp
C     Lower part.
      temp = M(88, 70) * M(70, 77)
      temp = temp + M(88, 72) * M(72, 77)
      temp = temp + M(88, 73) * M(73, 77)
      temp = temp + M(88, 75) * M(75, 77)
      temp = temp + M(88, 76) * M(76, 77)
      M(88, 77) = M(88, 77) - temp
C     Lower part.
      temp = M(89, 70) * M(70, 77)
      temp = temp + M(89, 72) * M(72, 77)
      temp = temp + M(89, 75) * M(75, 77)
      temp = temp + M(89, 76) * M(76, 77)
      M(89, 77) = M(89, 77) - temp
C     Upper part.
      temp = M(77, 73) * M(73, 78)
      temp = temp + M(77, 75) * M(75, 78)
      temp = temp + M(77, 76) * M(76, 78)
      M(77, 78) = ( M(77, 78) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 5) * M(5, 80)
      temp = temp + M(77, 18) * M(18, 80)
      temp = temp + M(77, 27) * M(27, 80)
      temp = temp + M(77, 53) * M(53, 80)
      temp = temp + M(77, 54) * M(54, 80)
      temp = temp + M(77, 57) * M(57, 80)
      temp = temp + M(77, 59) * M(59, 80)
      temp = temp + M(77, 60) * M(60, 80)
      temp = temp + M(77, 61) * M(61, 80)
      temp = temp + M(77, 62) * M(62, 80)
      temp = temp + M(77, 63) * M(63, 80)
      temp = temp + M(77, 64) * M(64, 80)
      temp = temp + M(77, 65) * M(65, 80)
      temp = temp + M(77, 68) * M(68, 80)
      temp = temp + M(77, 69) * M(69, 80)
      temp = temp + M(77, 70) * M(70, 80)
      temp = temp + M(77, 73) * M(73, 80)
      temp = temp + M(77, 75) * M(75, 80)
      temp = temp + M(77, 76) * M(76, 80)
      M(77, 80) = ( M(77, 80) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 53) * M(53, 82)
      temp = temp + M(77, 54) * M(54, 82)
      temp = temp + M(77, 57) * M(57, 82)
      temp = temp + M(77, 59) * M(59, 82)
      temp = temp + M(77, 60) * M(60, 82)
      temp = temp + M(77, 61) * M(61, 82)
      temp = temp + M(77, 62) * M(62, 82)
      temp = temp + M(77, 63) * M(63, 82)
      temp = temp + M(77, 64) * M(64, 82)
      temp = temp + M(77, 65) * M(65, 82)
      temp = temp + M(77, 68) * M(68, 82)
      temp = temp + M(77, 69) * M(69, 82)
      temp = temp + M(77, 70) * M(70, 82)
      temp = temp + M(77, 73) * M(73, 82)
      temp = temp + M(77, 75) * M(75, 82)
      temp = temp + M(77, 76) * M(76, 82)
      M(77, 82) = ( M(77, 82) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 76) * M(76, 83)
      M(77, 83) = ( M(77, 83) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 54) * M(54, 84)
      temp = temp + M(77, 59) * M(59, 84)
      temp = temp + M(77, 60) * M(60, 84)
      temp = temp + M(77, 61) * M(61, 84)
      temp = temp + M(77, 62) * M(62, 84)
      temp = temp + M(77, 63) * M(63, 84)
      temp = temp + M(77, 64) * M(64, 84)
      temp = temp + M(77, 65) * M(65, 84)
      temp = temp + M(77, 68) * M(68, 84)
      temp = temp + M(77, 69) * M(69, 84)
      temp = temp + M(77, 70) * M(70, 84)
      temp = temp + M(77, 73) * M(73, 84)
      temp = temp + M(77, 75) * M(75, 84)
      temp = temp + M(77, 76) * M(76, 84)
      M(77, 84) = ( M(77, 84) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 53) * M(53, 85)
      temp = temp + M(77, 54) * M(54, 85)
      temp = temp + M(77, 57) * M(57, 85)
      temp = temp + M(77, 59) * M(59, 85)
      temp = temp + M(77, 60) * M(60, 85)
      temp = temp + M(77, 61) * M(61, 85)
      temp = temp + M(77, 62) * M(62, 85)
      temp = temp + M(77, 63) * M(63, 85)
      temp = temp + M(77, 64) * M(64, 85)
      temp = temp + M(77, 65) * M(65, 85)
      temp = temp + M(77, 68) * M(68, 85)
      temp = temp + M(77, 69) * M(69, 85)
      temp = temp + M(77, 70) * M(70, 85)
      temp = temp + M(77, 73) * M(73, 85)
      temp = temp + M(77, 75) * M(75, 85)
      temp = temp + M(77, 76) * M(76, 85)
      M(77, 85) = ( M(77, 85) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 65) * M(65, 86)
      temp = temp + M(77, 68) * M(68, 86)
      temp = temp + M(77, 69) * M(69, 86)
      temp = temp + M(77, 70) * M(70, 86)
      temp = temp + M(77, 73) * M(73, 86)
      temp = temp + M(77, 75) * M(75, 86)
      temp = temp + M(77, 76) * M(76, 86)
      M(77, 86) = ( M(77, 86) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 27) * M(27, 87)
      temp = temp + M(77, 53) * M(53, 87)
      temp = temp + M(77, 54) * M(54, 87)
      temp = temp + M(77, 57) * M(57, 87)
      temp = temp + M(77, 59) * M(59, 87)
      temp = temp + M(77, 60) * M(60, 87)
      temp = temp + M(77, 61) * M(61, 87)
      temp = temp + M(77, 62) * M(62, 87)
      temp = temp + M(77, 63) * M(63, 87)
      temp = temp + M(77, 64) * M(64, 87)
      temp = temp + M(77, 65) * M(65, 87)
      temp = temp + M(77, 68) * M(68, 87)
      temp = temp + M(77, 69) * M(69, 87)
      temp = temp + M(77, 70) * M(70, 87)
      temp = temp + M(77, 73) * M(73, 87)
      temp = temp + M(77, 75) * M(75, 87)
      temp = temp + M(77, 76) * M(76, 87)
      M(77, 87) = ( M(77, 87) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 53) * M(53, 88)
      temp = temp + M(77, 54) * M(54, 88)
      temp = temp + M(77, 57) * M(57, 88)
      temp = temp + M(77, 59) * M(59, 88)
      temp = temp + M(77, 60) * M(60, 88)
      temp = temp + M(77, 61) * M(61, 88)
      temp = temp + M(77, 62) * M(62, 88)
      temp = temp + M(77, 63) * M(63, 88)
      temp = temp + M(77, 64) * M(64, 88)
      temp = temp + M(77, 65) * M(65, 88)
      temp = temp + M(77, 68) * M(68, 88)
      temp = temp + M(77, 69) * M(69, 88)
      temp = temp + M(77, 70) * M(70, 88)
      temp = temp + M(77, 73) * M(73, 88)
      temp = temp + M(77, 75) * M(75, 88)
      temp = temp + M(77, 76) * M(76, 88)
      M(77, 88) = ( M(77, 88) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 53) * M(53, 89)
      temp = temp + M(77, 54) * M(54, 89)
      temp = temp + M(77, 57) * M(57, 89)
      temp = temp + M(77, 59) * M(59, 89)
      temp = temp + M(77, 60) * M(60, 89)
      temp = temp + M(77, 61) * M(61, 89)
      temp = temp + M(77, 62) * M(62, 89)
      temp = temp + M(77, 63) * M(63, 89)
      temp = temp + M(77, 64) * M(64, 89)
      temp = temp + M(77, 65) * M(65, 89)
      temp = temp + M(77, 68) * M(68, 89)
      temp = temp + M(77, 69) * M(69, 89)
      temp = temp + M(77, 70) * M(70, 89)
      temp = temp + M(77, 73) * M(73, 89)
      temp = temp + M(77, 75) * M(75, 89)
      temp = temp + M(77, 76) * M(76, 89)
      M(77, 89) = ( M(77, 89) - temp ) / M(77, 77)

C     Lower part.
      temp = M(78, 76) * M(76, 78)
      temp = temp + M(78, 77) * M(77, 78)
      M(78, 78) = M(78, 78) - temp
C     Lower part.
      temp = M(79, 75) * M(75, 78)
      temp = temp + M(79, 76) * M(76, 78)
      temp = temp + M(79, 77) * M(77, 78)
      M(79, 78) = M(79, 78) - temp
C     Lower part.
      temp = M(80, 73) * M(73, 78)
      temp = temp + M(80, 75) * M(75, 78)
      temp = temp + M(80, 76) * M(76, 78)
      temp = temp + M(80, 77) * M(77, 78)
      M(80, 78) = M(80, 78) - temp
C     Lower part.
      temp = M(81, 73) * M(73, 78)
      temp = temp + M(81, 75) * M(75, 78)
      temp = temp + M(81, 76) * M(76, 78)
      temp = temp + M(81, 77) * M(77, 78)
      M(81, 78) = M(81, 78) - temp
C     Lower part.
      temp = M(82, 75) * M(75, 78)
      temp = temp + M(82, 76) * M(76, 78)
      temp = temp + M(82, 77) * M(77, 78)
      M(82, 78) = M(82, 78) - temp
C     Lower part.
      temp = M(83, 76) * M(76, 78)
      temp = temp + M(83, 77) * M(77, 78)
      M(83, 78) = M(83, 78) - temp
C     Lower part.
      temp = M(84, 75) * M(75, 78)
      temp = temp + M(84, 76) * M(76, 78)
      temp = temp + M(84, 77) * M(77, 78)
      M(84, 78) = M(84, 78) - temp
C     Lower part.
      temp = M(85, 75) * M(75, 78)
      temp = temp + M(85, 76) * M(76, 78)
      temp = temp + M(85, 77) * M(77, 78)
      M(85, 78) = M(85, 78) - temp
C     Lower part.
      temp = M(87, 75) * M(75, 78)
      temp = temp + M(87, 76) * M(76, 78)
      temp = temp + M(87, 77) * M(77, 78)
      M(87, 78) = M(87, 78) - temp
C     Lower part.
      temp = M(88, 73) * M(73, 78)
      temp = temp + M(88, 75) * M(75, 78)
      temp = temp + M(88, 76) * M(76, 78)
      temp = temp + M(88, 77) * M(77, 78)
      M(88, 78) = M(88, 78) - temp
C     Lower part.
      temp = M(89, 75) * M(75, 78)
      temp = temp + M(89, 76) * M(76, 78)
      temp = temp + M(89, 77) * M(77, 78)
      M(89, 78) = M(89, 78) - temp
C     Upper part.
      temp = M(78, 27) * M(27, 80)
      temp = temp + M(78, 30) * M(30, 80)
      temp = temp + M(78, 34) * M(34, 80)
      temp = temp + M(78, 53) * M(53, 80)
      temp = temp + M(78, 57) * M(57, 80)
      temp = temp + M(78, 60) * M(60, 80)
      temp = temp + M(78, 62) * M(62, 80)
      temp = temp + M(78, 65) * M(65, 80)
      temp = temp + M(78, 76) * M(76, 80)
      temp = temp + M(78, 77) * M(77, 80)
      M(78, 80) = ( M(78, 80) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 53) * M(53, 82)
      temp = temp + M(78, 57) * M(57, 82)
      temp = temp + M(78, 60) * M(60, 82)
      temp = temp + M(78, 62) * M(62, 82)
      temp = temp + M(78, 65) * M(65, 82)
      temp = temp + M(78, 76) * M(76, 82)
      temp = temp + M(78, 77) * M(77, 82)
      M(78, 82) = ( M(78, 82) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 76) * M(76, 83)
      temp = temp + M(78, 77) * M(77, 83)
      M(78, 83) = ( M(78, 83) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 60) * M(60, 84)
      temp = temp + M(78, 62) * M(62, 84)
      temp = temp + M(78, 65) * M(65, 84)
      temp = temp + M(78, 76) * M(76, 84)
      temp = temp + M(78, 77) * M(77, 84)
      M(78, 84) = ( M(78, 84) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 53) * M(53, 85)
      temp = temp + M(78, 57) * M(57, 85)
      temp = temp + M(78, 60) * M(60, 85)
      temp = temp + M(78, 62) * M(62, 85)
      temp = temp + M(78, 65) * M(65, 85)
      temp = temp + M(78, 76) * M(76, 85)
      temp = temp + M(78, 77) * M(77, 85)
      M(78, 85) = ( M(78, 85) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 65) * M(65, 86)
      temp = temp + M(78, 76) * M(76, 86)
      temp = temp + M(78, 77) * M(77, 86)
      M(78, 86) = ( M(78, 86) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 27) * M(27, 87)
      temp = temp + M(78, 30) * M(30, 87)
      temp = temp + M(78, 53) * M(53, 87)
      temp = temp + M(78, 57) * M(57, 87)
      temp = temp + M(78, 60) * M(60, 87)
      temp = temp + M(78, 62) * M(62, 87)
      temp = temp + M(78, 65) * M(65, 87)
      temp = temp + M(78, 76) * M(76, 87)
      temp = temp + M(78, 77) * M(77, 87)
      M(78, 87) = ( M(78, 87) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 53) * M(53, 88)
      temp = temp + M(78, 57) * M(57, 88)
      temp = temp + M(78, 60) * M(60, 88)
      temp = temp + M(78, 62) * M(62, 88)
      temp = temp + M(78, 65) * M(65, 88)
      temp = temp + M(78, 76) * M(76, 88)
      temp = temp + M(78, 77) * M(77, 88)
      M(78, 88) = ( M(78, 88) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 53) * M(53, 89)
      temp = temp + M(78, 57) * M(57, 89)
      temp = temp + M(78, 60) * M(60, 89)
      temp = temp + M(78, 62) * M(62, 89)
      temp = temp + M(78, 65) * M(65, 89)
      temp = temp + M(78, 76) * M(76, 89)
      temp = temp + M(78, 77) * M(77, 89)
      M(78, 89) = ( M(78, 89) - temp ) / M(78, 78)

C     Lower part.
      temp = M(80, 67) * M(67, 79)
      temp = temp + M(80, 74) * M(74, 79)
      M(80, 79) = M(80, 79) - temp
C     Lower part.
      temp = M(84, 74) * M(74, 79)
      M(84, 79) = M(84, 79) - temp
C     Lower part.
      temp = M(87, 74) * M(74, 79)
      M(87, 79) = M(87, 79) - temp
C     Lower part.
      temp = M(88, 67) * M(67, 79)
      M(88, 79) = M(88, 79) - temp
C     Upper part.
      temp = M(79, 4) * M(4, 80)
      temp = temp + M(79, 21) * M(21, 80)
      temp = temp + M(79, 25) * M(25, 80)
      temp = temp + M(79, 26) * M(26, 80)
      temp = temp + M(79, 30) * M(30, 80)
      temp = temp + M(79, 35) * M(35, 80)
      temp = temp + M(79, 38) * M(38, 80)
      temp = temp + M(79, 40) * M(40, 80)
      temp = temp + M(79, 42) * M(42, 80)
      temp = temp + M(79, 43) * M(43, 80)
      temp = temp + M(79, 45) * M(45, 80)
      temp = temp + M(79, 47) * M(47, 80)
      temp = temp + M(79, 48) * M(48, 80)
      temp = temp + M(79, 50) * M(50, 80)
      temp = temp + M(79, 51) * M(51, 80)
      temp = temp + M(79, 52) * M(52, 80)
      temp = temp + M(79, 53) * M(53, 80)
      temp = temp + M(79, 54) * M(54, 80)
      temp = temp + M(79, 56) * M(56, 80)
      temp = temp + M(79, 57) * M(57, 80)
      temp = temp + M(79, 58) * M(58, 80)
      temp = temp + M(79, 59) * M(59, 80)
      temp = temp + M(79, 60) * M(60, 80)
      temp = temp + M(79, 61) * M(61, 80)
      temp = temp + M(79, 62) * M(62, 80)
      temp = temp + M(79, 63) * M(63, 80)
      temp = temp + M(79, 64) * M(64, 80)
      temp = temp + M(79, 65) * M(65, 80)
      temp = temp + M(79, 66) * M(66, 80)
      temp = temp + M(79, 68) * M(68, 80)
      temp = temp + M(79, 69) * M(69, 80)
      temp = temp + M(79, 70) * M(70, 80)
      temp = temp + M(79, 75) * M(75, 80)
      temp = temp + M(79, 76) * M(76, 80)
      temp = temp + M(79, 77) * M(77, 80)
      temp = temp + M(79, 78) * M(78, 80)
      M(79, 80) = ( M(79, 80) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 21) * M(21, 82)
      temp = temp + M(79, 40) * M(40, 82)
      temp = temp + M(79, 42) * M(42, 82)
      temp = temp + M(79, 47) * M(47, 82)
      temp = temp + M(79, 51) * M(51, 82)
      temp = temp + M(79, 52) * M(52, 82)
      temp = temp + M(79, 53) * M(53, 82)
      temp = temp + M(79, 54) * M(54, 82)
      temp = temp + M(79, 56) * M(56, 82)
      temp = temp + M(79, 57) * M(57, 82)
      temp = temp + M(79, 58) * M(58, 82)
      temp = temp + M(79, 59) * M(59, 82)
      temp = temp + M(79, 60) * M(60, 82)
      temp = temp + M(79, 61) * M(61, 82)
      temp = temp + M(79, 62) * M(62, 82)
      temp = temp + M(79, 63) * M(63, 82)
      temp = temp + M(79, 64) * M(64, 82)
      temp = temp + M(79, 65) * M(65, 82)
      temp = temp + M(79, 66) * M(66, 82)
      temp = temp + M(79, 68) * M(68, 82)
      temp = temp + M(79, 69) * M(69, 82)
      temp = temp + M(79, 70) * M(70, 82)
      temp = temp + M(79, 75) * M(75, 82)
      temp = temp + M(79, 76) * M(76, 82)
      temp = temp + M(79, 77) * M(77, 82)
      temp = temp + M(79, 78) * M(78, 82)
      M(79, 82) = ( M(79, 82) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 76) * M(76, 83)
      temp = temp + M(79, 77) * M(77, 83)
      temp = temp + M(79, 78) * M(78, 83)
      M(79, 83) = ( M(79, 83) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 40) * M(40, 84)
      temp = temp + M(79, 42) * M(42, 84)
      temp = temp + M(79, 43) * M(43, 84)
      temp = temp + M(79, 45) * M(45, 84)
      temp = temp + M(79, 48) * M(48, 84)
      temp = temp + M(79, 50) * M(50, 84)
      temp = temp + M(79, 51) * M(51, 84)
      temp = temp + M(79, 54) * M(54, 84)
      temp = temp + M(79, 58) * M(58, 84)
      temp = temp + M(79, 59) * M(59, 84)
      temp = temp + M(79, 60) * M(60, 84)
      temp = temp + M(79, 61) * M(61, 84)
      temp = temp + M(79, 62) * M(62, 84)
      temp = temp + M(79, 63) * M(63, 84)
      temp = temp + M(79, 64) * M(64, 84)
      temp = temp + M(79, 65) * M(65, 84)
      temp = temp + M(79, 66) * M(66, 84)
      temp = temp + M(79, 68) * M(68, 84)
      temp = temp + M(79, 69) * M(69, 84)
      temp = temp + M(79, 70) * M(70, 84)
      temp = temp + M(79, 75) * M(75, 84)
      temp = temp + M(79, 76) * M(76, 84)
      temp = temp + M(79, 77) * M(77, 84)
      temp = temp + M(79, 78) * M(78, 84)
      M(79, 84) = ( M(79, 84) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 40) * M(40, 85)
      temp = temp + M(79, 42) * M(42, 85)
      temp = temp + M(79, 43) * M(43, 85)
      temp = temp + M(79, 51) * M(51, 85)
      temp = temp + M(79, 52) * M(52, 85)
      temp = temp + M(79, 53) * M(53, 85)
      temp = temp + M(79, 54) * M(54, 85)
      temp = temp + M(79, 56) * M(56, 85)
      temp = temp + M(79, 57) * M(57, 85)
      temp = temp + M(79, 58) * M(58, 85)
      temp = temp + M(79, 59) * M(59, 85)
      temp = temp + M(79, 60) * M(60, 85)
      temp = temp + M(79, 61) * M(61, 85)
      temp = temp + M(79, 62) * M(62, 85)
      temp = temp + M(79, 63) * M(63, 85)
      temp = temp + M(79, 64) * M(64, 85)
      temp = temp + M(79, 65) * M(65, 85)
      temp = temp + M(79, 66) * M(66, 85)
      temp = temp + M(79, 68) * M(68, 85)
      temp = temp + M(79, 69) * M(69, 85)
      temp = temp + M(79, 70) * M(70, 85)
      temp = temp + M(79, 75) * M(75, 85)
      temp = temp + M(79, 76) * M(76, 85)
      temp = temp + M(79, 77) * M(77, 85)
      temp = temp + M(79, 78) * M(78, 85)
      M(79, 85) = ( M(79, 85) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 48) * M(48, 86)
      temp = temp + M(79, 50) * M(50, 86)
      temp = temp + M(79, 65) * M(65, 86)
      temp = temp + M(79, 66) * M(66, 86)
      temp = temp + M(79, 68) * M(68, 86)
      temp = temp + M(79, 69) * M(69, 86)
      temp = temp + M(79, 70) * M(70, 86)
      temp = temp + M(79, 75) * M(75, 86)
      temp = temp + M(79, 76) * M(76, 86)
      temp = temp + M(79, 77) * M(77, 86)
      temp = temp + M(79, 78) * M(78, 86)
      M(79, 86) = ( M(79, 86) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 25) * M(25, 87)
      temp = temp + M(79, 26) * M(26, 87)
      temp = temp + M(79, 30) * M(30, 87)
      temp = temp + M(79, 35) * M(35, 87)
      temp = temp + M(79, 40) * M(40, 87)
      temp = temp + M(79, 42) * M(42, 87)
      temp = temp + M(79, 43) * M(43, 87)
      temp = temp + M(79, 45) * M(45, 87)
      temp = temp + M(79, 48) * M(48, 87)
      temp = temp + M(79, 50) * M(50, 87)
      temp = temp + M(79, 51) * M(51, 87)
      temp = temp + M(79, 52) * M(52, 87)
      temp = temp + M(79, 53) * M(53, 87)
      temp = temp + M(79, 54) * M(54, 87)
      temp = temp + M(79, 56) * M(56, 87)
      temp = temp + M(79, 57) * M(57, 87)
      temp = temp + M(79, 58) * M(58, 87)
      temp = temp + M(79, 59) * M(59, 87)
      temp = temp + M(79, 60) * M(60, 87)
      temp = temp + M(79, 61) * M(61, 87)
      temp = temp + M(79, 62) * M(62, 87)
      temp = temp + M(79, 63) * M(63, 87)
      temp = temp + M(79, 64) * M(64, 87)
      temp = temp + M(79, 65) * M(65, 87)
      temp = temp + M(79, 66) * M(66, 87)
      temp = temp + M(79, 68) * M(68, 87)
      temp = temp + M(79, 69) * M(69, 87)
      temp = temp + M(79, 70) * M(70, 87)
      temp = temp + M(79, 75) * M(75, 87)
      temp = temp + M(79, 76) * M(76, 87)
      temp = temp + M(79, 77) * M(77, 87)
      temp = temp + M(79, 78) * M(78, 87)
      M(79, 87) = ( M(79, 87) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 21) * M(21, 88)
      temp = temp + M(79, 38) * M(38, 88)
      temp = temp + M(79, 40) * M(40, 88)
      temp = temp + M(79, 42) * M(42, 88)
      temp = temp + M(79, 45) * M(45, 88)
      temp = temp + M(79, 51) * M(51, 88)
      temp = temp + M(79, 52) * M(52, 88)
      temp = temp + M(79, 53) * M(53, 88)
      temp = temp + M(79, 54) * M(54, 88)
      temp = temp + M(79, 56) * M(56, 88)
      temp = temp + M(79, 57) * M(57, 88)
      temp = temp + M(79, 58) * M(58, 88)
      temp = temp + M(79, 59) * M(59, 88)
      temp = temp + M(79, 60) * M(60, 88)
      temp = temp + M(79, 61) * M(61, 88)
      temp = temp + M(79, 62) * M(62, 88)
      temp = temp + M(79, 63) * M(63, 88)
      temp = temp + M(79, 64) * M(64, 88)
      temp = temp + M(79, 65) * M(65, 88)
      temp = temp + M(79, 66) * M(66, 88)
      temp = temp + M(79, 68) * M(68, 88)
      temp = temp + M(79, 69) * M(69, 88)
      temp = temp + M(79, 70) * M(70, 88)
      temp = temp + M(79, 75) * M(75, 88)
      temp = temp + M(79, 76) * M(76, 88)
      temp = temp + M(79, 77) * M(77, 88)
      temp = temp + M(79, 78) * M(78, 88)
      M(79, 88) = ( M(79, 88) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 38) * M(38, 89)
      temp = temp + M(79, 40) * M(40, 89)
      temp = temp + M(79, 42) * M(42, 89)
      temp = temp + M(79, 50) * M(50, 89)
      temp = temp + M(79, 51) * M(51, 89)
      temp = temp + M(79, 52) * M(52, 89)
      temp = temp + M(79, 53) * M(53, 89)
      temp = temp + M(79, 54) * M(54, 89)
      temp = temp + M(79, 56) * M(56, 89)
      temp = temp + M(79, 57) * M(57, 89)
      temp = temp + M(79, 58) * M(58, 89)
      temp = temp + M(79, 59) * M(59, 89)
      temp = temp + M(79, 60) * M(60, 89)
      temp = temp + M(79, 61) * M(61, 89)
      temp = temp + M(79, 62) * M(62, 89)
      temp = temp + M(79, 63) * M(63, 89)
      temp = temp + M(79, 64) * M(64, 89)
      temp = temp + M(79, 65) * M(65, 89)
      temp = temp + M(79, 66) * M(66, 89)
      temp = temp + M(79, 68) * M(68, 89)
      temp = temp + M(79, 69) * M(69, 89)
      temp = temp + M(79, 70) * M(70, 89)
      temp = temp + M(79, 75) * M(75, 89)
      temp = temp + M(79, 76) * M(76, 89)
      temp = temp + M(79, 77) * M(77, 89)
      temp = temp + M(79, 78) * M(78, 89)
      M(79, 89) = ( M(79, 89) - temp ) / M(79, 79)

C     Lower part.
      temp = M(80, 3) * M(3, 80)
      temp = temp + M(80, 4) * M(4, 80)
      temp = temp + M(80, 5) * M(5, 80)
      temp = temp + M(80, 6) * M(6, 80)
      temp = temp + M(80, 7) * M(7, 80)
      temp = temp + M(80, 8) * M(8, 80)
      temp = temp + M(80, 11) * M(11, 80)
      temp = temp + M(80, 13) * M(13, 80)
      temp = temp + M(80, 14) * M(14, 80)
      temp = temp + M(80, 15) * M(15, 80)
      temp = temp + M(80, 18) * M(18, 80)
      temp = temp + M(80, 21) * M(21, 80)
      temp = temp + M(80, 22) * M(22, 80)
      temp = temp + M(80, 23) * M(23, 80)
      temp = temp + M(80, 24) * M(24, 80)
      temp = temp + M(80, 25) * M(25, 80)
      temp = temp + M(80, 26) * M(26, 80)
      temp = temp + M(80, 27) * M(27, 80)
      temp = temp + M(80, 30) * M(30, 80)
      temp = temp + M(80, 33) * M(33, 80)
      temp = temp + M(80, 34) * M(34, 80)
      temp = temp + M(80, 35) * M(35, 80)
      temp = temp + M(80, 36) * M(36, 80)
      temp = temp + M(80, 37) * M(37, 80)
      temp = temp + M(80, 38) * M(38, 80)
      temp = temp + M(80, 43) * M(43, 80)
      temp = temp + M(80, 44) * M(44, 80)
      temp = temp + M(80, 45) * M(45, 80)
      temp = temp + M(80, 47) * M(47, 80)
      temp = temp + M(80, 48) * M(48, 80)
      temp = temp + M(80, 50) * M(50, 80)
      temp = temp + M(80, 54) * M(54, 80)
      temp = temp + M(80, 59) * M(59, 80)
      temp = temp + M(80, 60) * M(60, 80)
      temp = temp + M(80, 62) * M(62, 80)
      temp = temp + M(80, 65) * M(65, 80)
      temp = temp + M(80, 66) * M(66, 80)
      temp = temp + M(80, 67) * M(67, 80)
      temp = temp + M(80, 70) * M(70, 80)
      temp = temp + M(80, 72) * M(72, 80)
      temp = temp + M(80, 73) * M(73, 80)
      temp = temp + M(80, 74) * M(74, 80)
      temp = temp + M(80, 75) * M(75, 80)
      temp = temp + M(80, 76) * M(76, 80)
      temp = temp + M(80, 77) * M(77, 80)
      temp = temp + M(80, 78) * M(78, 80)
      temp = temp + M(80, 79) * M(79, 80)
      M(80, 80) = M(80, 80) - temp
C     Lower part.
      temp = M(81, 4) * M(4, 80)
      temp = temp + M(81, 6) * M(6, 80)
      temp = temp + M(81, 18) * M(18, 80)
      temp = temp + M(81, 27) * M(27, 80)
      temp = temp + M(81, 43) * M(43, 80)
      temp = temp + M(81, 53) * M(53, 80)
      temp = temp + M(81, 54) * M(54, 80)
      temp = temp + M(81, 56) * M(56, 80)
      temp = temp + M(81, 57) * M(57, 80)
      temp = temp + M(81, 59) * M(59, 80)
      temp = temp + M(81, 60) * M(60, 80)
      temp = temp + M(81, 61) * M(61, 80)
      temp = temp + M(81, 62) * M(62, 80)
      temp = temp + M(81, 63) * M(63, 80)
      temp = temp + M(81, 64) * M(64, 80)
      temp = temp + M(81, 65) * M(65, 80)
      temp = temp + M(81, 68) * M(68, 80)
      temp = temp + M(81, 69) * M(69, 80)
      temp = temp + M(81, 70) * M(70, 80)
      temp = temp + M(81, 73) * M(73, 80)
      temp = temp + M(81, 75) * M(75, 80)
      temp = temp + M(81, 76) * M(76, 80)
      temp = temp + M(81, 77) * M(77, 80)
      temp = temp + M(81, 78) * M(78, 80)
      M(81, 80) = M(81, 80) - temp
C     Lower part.
      temp = M(82, 21) * M(21, 80)
      temp = temp + M(82, 26) * M(26, 80)
      temp = temp + M(82, 35) * M(35, 80)
      temp = temp + M(82, 37) * M(37, 80)
      temp = temp + M(82, 38) * M(38, 80)
      temp = temp + M(82, 40) * M(40, 80)
      temp = temp + M(82, 42) * M(42, 80)
      temp = temp + M(82, 43) * M(43, 80)
      temp = temp + M(82, 45) * M(45, 80)
      temp = temp + M(82, 51) * M(51, 80)
      temp = temp + M(82, 52) * M(52, 80)
      temp = temp + M(82, 53) * M(53, 80)
      temp = temp + M(82, 54) * M(54, 80)
      temp = temp + M(82, 56) * M(56, 80)
      temp = temp + M(82, 57) * M(57, 80)
      temp = temp + M(82, 58) * M(58, 80)
      temp = temp + M(82, 59) * M(59, 80)
      temp = temp + M(82, 60) * M(60, 80)
      temp = temp + M(82, 61) * M(61, 80)
      temp = temp + M(82, 62) * M(62, 80)
      temp = temp + M(82, 63) * M(63, 80)
      temp = temp + M(82, 64) * M(64, 80)
      temp = temp + M(82, 65) * M(65, 80)
      temp = temp + M(82, 68) * M(68, 80)
      temp = temp + M(82, 69) * M(69, 80)
      temp = temp + M(82, 70) * M(70, 80)
      temp = temp + M(82, 75) * M(75, 80)
      temp = temp + M(82, 76) * M(76, 80)
      temp = temp + M(82, 77) * M(77, 80)
      temp = temp + M(82, 78) * M(78, 80)
      M(82, 80) = M(82, 80) - temp
C     Lower part.
      temp = M(83, 39) * M(39, 80)
      temp = temp + M(83, 40) * M(40, 80)
      temp = temp + M(83, 45) * M(45, 80)
      temp = temp + M(83, 48) * M(48, 80)
      temp = temp + M(83, 51) * M(51, 80)
      temp = temp + M(83, 52) * M(52, 80)
      temp = temp + M(83, 53) * M(53, 80)
      temp = temp + M(83, 57) * M(57, 80)
      temp = temp + M(83, 58) * M(58, 80)
      temp = temp + M(83, 59) * M(59, 80)
      temp = temp + M(83, 63) * M(63, 80)
      temp = temp + M(83, 64) * M(64, 80)
      temp = temp + M(83, 65) * M(65, 80)
      temp = temp + M(83, 69) * M(69, 80)
      temp = temp + M(83, 76) * M(76, 80)
      temp = temp + M(83, 77) * M(77, 80)
      temp = temp + M(83, 78) * M(78, 80)
      M(83, 80) = M(83, 80) - temp
C     Lower part.
      temp = M(84, 22) * M(22, 80)
      temp = temp + M(84, 23) * M(23, 80)
      temp = temp + M(84, 24) * M(24, 80)
      temp = temp + M(84, 33) * M(33, 80)
      temp = temp + M(84, 36) * M(36, 80)
      temp = temp + M(84, 39) * M(39, 80)
      temp = temp + M(84, 40) * M(40, 80)
      temp = temp + M(84, 42) * M(42, 80)
      temp = temp + M(84, 43) * M(43, 80)
      temp = temp + M(84, 45) * M(45, 80)
      temp = temp + M(84, 48) * M(48, 80)
      temp = temp + M(84, 50) * M(50, 80)
      temp = temp + M(84, 51) * M(51, 80)
      temp = temp + M(84, 52) * M(52, 80)
      temp = temp + M(84, 53) * M(53, 80)
      temp = temp + M(84, 54) * M(54, 80)
      temp = temp + M(84, 56) * M(56, 80)
      temp = temp + M(84, 57) * M(57, 80)
      temp = temp + M(84, 58) * M(58, 80)
      temp = temp + M(84, 59) * M(59, 80)
      temp = temp + M(84, 61) * M(61, 80)
      temp = temp + M(84, 63) * M(63, 80)
      temp = temp + M(84, 64) * M(64, 80)
      temp = temp + M(84, 65) * M(65, 80)
      temp = temp + M(84, 68) * M(68, 80)
      temp = temp + M(84, 69) * M(69, 80)
      temp = temp + M(84, 70) * M(70, 80)
      temp = temp + M(84, 74) * M(74, 80)
      temp = temp + M(84, 75) * M(75, 80)
      temp = temp + M(84, 76) * M(76, 80)
      temp = temp + M(84, 77) * M(77, 80)
      temp = temp + M(84, 78) * M(78, 80)
      temp = temp + M(84, 79) * M(79, 80)
      M(84, 80) = M(84, 80) - temp
C     Lower part.
      temp = M(85, 33) * M(33, 80)
      temp = temp + M(85, 36) * M(36, 80)
      temp = temp + M(85, 40) * M(40, 80)
      temp = temp + M(85, 42) * M(42, 80)
      temp = temp + M(85, 43) * M(43, 80)
      temp = temp + M(85, 45) * M(45, 80)
      temp = temp + M(85, 51) * M(51, 80)
      temp = temp + M(85, 52) * M(52, 80)
      temp = temp + M(85, 53) * M(53, 80)
      temp = temp + M(85, 56) * M(56, 80)
      temp = temp + M(85, 57) * M(57, 80)
      temp = temp + M(85, 58) * M(58, 80)
      temp = temp + M(85, 59) * M(59, 80)
      temp = temp + M(85, 61) * M(61, 80)
      temp = temp + M(85, 63) * M(63, 80)
      temp = temp + M(85, 64) * M(64, 80)
      temp = temp + M(85, 65) * M(65, 80)
      temp = temp + M(85, 68) * M(68, 80)
      temp = temp + M(85, 69) * M(69, 80)
      temp = temp + M(85, 70) * M(70, 80)
      temp = temp + M(85, 75) * M(75, 80)
      temp = temp + M(85, 76) * M(76, 80)
      temp = temp + M(85, 77) * M(77, 80)
      temp = temp + M(85, 78) * M(78, 80)
      M(85, 80) = M(85, 80) - temp
C     Lower part.
      temp = M(86, 48) * M(48, 80)
      temp = temp + M(86, 54) * M(54, 80)
      temp = temp + M(86, 59) * M(59, 80)
      temp = temp + M(86, 65) * M(65, 80)
      M(86, 80) = M(86, 80) - temp
C     Lower part.
      temp = M(87, 24) * M(24, 80)
      temp = temp + M(87, 25) * M(25, 80)
      temp = temp + M(87, 26) * M(26, 80)
      temp = temp + M(87, 27) * M(27, 80)
      temp = temp + M(87, 30) * M(30, 80)
      temp = temp + M(87, 35) * M(35, 80)
      temp = temp + M(87, 40) * M(40, 80)
      temp = temp + M(87, 42) * M(42, 80)
      temp = temp + M(87, 43) * M(43, 80)
      temp = temp + M(87, 45) * M(45, 80)
      temp = temp + M(87, 48) * M(48, 80)
      temp = temp + M(87, 50) * M(50, 80)
      temp = temp + M(87, 51) * M(51, 80)
      temp = temp + M(87, 52) * M(52, 80)
      temp = temp + M(87, 53) * M(53, 80)
      temp = temp + M(87, 54) * M(54, 80)
      temp = temp + M(87, 56) * M(56, 80)
      temp = temp + M(87, 57) * M(57, 80)
      temp = temp + M(87, 58) * M(58, 80)
      temp = temp + M(87, 59) * M(59, 80)
      temp = temp + M(87, 60) * M(60, 80)
      temp = temp + M(87, 61) * M(61, 80)
      temp = temp + M(87, 62) * M(62, 80)
      temp = temp + M(87, 63) * M(63, 80)
      temp = temp + M(87, 64) * M(64, 80)
      temp = temp + M(87, 65) * M(65, 80)
      temp = temp + M(87, 66) * M(66, 80)
      temp = temp + M(87, 68) * M(68, 80)
      temp = temp + M(87, 69) * M(69, 80)
      temp = temp + M(87, 70) * M(70, 80)
      temp = temp + M(87, 72) * M(72, 80)
      temp = temp + M(87, 74) * M(74, 80)
      temp = temp + M(87, 75) * M(75, 80)
      temp = temp + M(87, 76) * M(76, 80)
      temp = temp + M(87, 77) * M(77, 80)
      temp = temp + M(87, 78) * M(78, 80)
      temp = temp + M(87, 79) * M(79, 80)
      M(87, 80) = M(87, 80) - temp
C     Lower part.
      temp = M(88, 3) * M(3, 80)
      temp = temp + M(88, 4) * M(4, 80)
      temp = temp + M(88, 5) * M(5, 80)
      temp = temp + M(88, 6) * M(6, 80)
      temp = temp + M(88, 7) * M(7, 80)
      temp = temp + M(88, 8) * M(8, 80)
      temp = temp + M(88, 18) * M(18, 80)
      temp = temp + M(88, 21) * M(21, 80)
      temp = temp + M(88, 22) * M(22, 80)
      temp = temp + M(88, 23) * M(23, 80)
      temp = temp + M(88, 24) * M(24, 80)
      temp = temp + M(88, 25) * M(25, 80)
      temp = temp + M(88, 26) * M(26, 80)
      temp = temp + M(88, 27) * M(27, 80)
      temp = temp + M(88, 30) * M(30, 80)
      temp = temp + M(88, 35) * M(35, 80)
      temp = temp + M(88, 36) * M(36, 80)
      temp = temp + M(88, 38) * M(38, 80)
      temp = temp + M(88, 39) * M(39, 80)
      temp = temp + M(88, 40) * M(40, 80)
      temp = temp + M(88, 42) * M(42, 80)
      temp = temp + M(88, 43) * M(43, 80)
      temp = temp + M(88, 44) * M(44, 80)
      temp = temp + M(88, 45) * M(45, 80)
      temp = temp + M(88, 47) * M(47, 80)
      temp = temp + M(88, 48) * M(48, 80)
      temp = temp + M(88, 51) * M(51, 80)
      temp = temp + M(88, 52) * M(52, 80)
      temp = temp + M(88, 53) * M(53, 80)
      temp = temp + M(88, 54) * M(54, 80)
      temp = temp + M(88, 56) * M(56, 80)
      temp = temp + M(88, 57) * M(57, 80)
      temp = temp + M(88, 58) * M(58, 80)
      temp = temp + M(88, 59) * M(59, 80)
      temp = temp + M(88, 60) * M(60, 80)
      temp = temp + M(88, 61) * M(61, 80)
      temp = temp + M(88, 62) * M(62, 80)
      temp = temp + M(88, 63) * M(63, 80)
      temp = temp + M(88, 64) * M(64, 80)
      temp = temp + M(88, 65) * M(65, 80)
      temp = temp + M(88, 66) * M(66, 80)
      temp = temp + M(88, 67) * M(67, 80)
      temp = temp + M(88, 68) * M(68, 80)
      temp = temp + M(88, 69) * M(69, 80)
      temp = temp + M(88, 70) * M(70, 80)
      temp = temp + M(88, 72) * M(72, 80)
      temp = temp + M(88, 73) * M(73, 80)
      temp = temp + M(88, 75) * M(75, 80)
      temp = temp + M(88, 76) * M(76, 80)
      temp = temp + M(88, 77) * M(77, 80)
      temp = temp + M(88, 78) * M(78, 80)
      temp = temp + M(88, 79) * M(79, 80)
      M(88, 80) = M(88, 80) - temp
C     Lower part.
      temp = M(89, 26) * M(26, 80)
      temp = temp + M(89, 35) * M(35, 80)
      temp = temp + M(89, 38) * M(38, 80)
      temp = temp + M(89, 40) * M(40, 80)
      temp = temp + M(89, 42) * M(42, 80)
      temp = temp + M(89, 43) * M(43, 80)
      temp = temp + M(89, 45) * M(45, 80)
      temp = temp + M(89, 47) * M(47, 80)
      temp = temp + M(89, 48) * M(48, 80)
      temp = temp + M(89, 50) * M(50, 80)
      temp = temp + M(89, 51) * M(51, 80)
      temp = temp + M(89, 52) * M(52, 80)
      temp = temp + M(89, 53) * M(53, 80)
      temp = temp + M(89, 54) * M(54, 80)
      temp = temp + M(89, 56) * M(56, 80)
      temp = temp + M(89, 57) * M(57, 80)
      temp = temp + M(89, 58) * M(58, 80)
      temp = temp + M(89, 59) * M(59, 80)
      temp = temp + M(89, 61) * M(61, 80)
      temp = temp + M(89, 63) * M(63, 80)
      temp = temp + M(89, 64) * M(64, 80)
      temp = temp + M(89, 65) * M(65, 80)
      temp = temp + M(89, 68) * M(68, 80)
      temp = temp + M(89, 69) * M(69, 80)
      temp = temp + M(89, 70) * M(70, 80)
      temp = temp + M(89, 72) * M(72, 80)
      temp = temp + M(89, 75) * M(75, 80)
      temp = temp + M(89, 76) * M(76, 80)
      temp = temp + M(89, 77) * M(77, 80)
      temp = temp + M(89, 78) * M(78, 80)
      M(89, 80) = M(89, 80) - temp
C     Upper part.
      temp = M(80, 67) * M(67, 81)
      temp = temp + M(80, 74) * M(74, 81)
      M(80, 81) = ( M(80, 81) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 21) * M(21, 82)
      temp = temp + M(80, 47) * M(47, 82)
      temp = temp + M(80, 54) * M(54, 82)
      temp = temp + M(80, 59) * M(59, 82)
      temp = temp + M(80, 60) * M(60, 82)
      temp = temp + M(80, 62) * M(62, 82)
      temp = temp + M(80, 65) * M(65, 82)
      temp = temp + M(80, 66) * M(66, 82)
      temp = temp + M(80, 67) * M(67, 82)
      temp = temp + M(80, 70) * M(70, 82)
      temp = temp + M(80, 72) * M(72, 82)
      temp = temp + M(80, 73) * M(73, 82)
      temp = temp + M(80, 74) * M(74, 82)
      temp = temp + M(80, 75) * M(75, 82)
      temp = temp + M(80, 76) * M(76, 82)
      temp = temp + M(80, 77) * M(77, 82)
      temp = temp + M(80, 78) * M(78, 82)
      temp = temp + M(80, 79) * M(79, 82)
      M(80, 82) = ( M(80, 82) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 76) * M(76, 83)
      temp = temp + M(80, 77) * M(77, 83)
      temp = temp + M(80, 78) * M(78, 83)
      temp = temp + M(80, 79) * M(79, 83)
      M(80, 83) = ( M(80, 83) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 22) * M(22, 84)
      temp = temp + M(80, 23) * M(23, 84)
      temp = temp + M(80, 24) * M(24, 84)
      temp = temp + M(80, 33) * M(33, 84)
      temp = temp + M(80, 36) * M(36, 84)
      temp = temp + M(80, 43) * M(43, 84)
      temp = temp + M(80, 44) * M(44, 84)
      temp = temp + M(80, 45) * M(45, 84)
      temp = temp + M(80, 48) * M(48, 84)
      temp = temp + M(80, 50) * M(50, 84)
      temp = temp + M(80, 54) * M(54, 84)
      temp = temp + M(80, 59) * M(59, 84)
      temp = temp + M(80, 60) * M(60, 84)
      temp = temp + M(80, 62) * M(62, 84)
      temp = temp + M(80, 65) * M(65, 84)
      temp = temp + M(80, 66) * M(66, 84)
      temp = temp + M(80, 67) * M(67, 84)
      temp = temp + M(80, 70) * M(70, 84)
      temp = temp + M(80, 72) * M(72, 84)
      temp = temp + M(80, 73) * M(73, 84)
      temp = temp + M(80, 74) * M(74, 84)
      temp = temp + M(80, 75) * M(75, 84)
      temp = temp + M(80, 76) * M(76, 84)
      temp = temp + M(80, 77) * M(77, 84)
      temp = temp + M(80, 78) * M(78, 84)
      temp = temp + M(80, 79) * M(79, 84)
      M(80, 84) = ( M(80, 84) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 33) * M(33, 85)
      temp = temp + M(80, 43) * M(43, 85)
      temp = temp + M(80, 44) * M(44, 85)
      temp = temp + M(80, 54) * M(54, 85)
      temp = temp + M(80, 59) * M(59, 85)
      temp = temp + M(80, 60) * M(60, 85)
      temp = temp + M(80, 62) * M(62, 85)
      temp = temp + M(80, 65) * M(65, 85)
      temp = temp + M(80, 66) * M(66, 85)
      temp = temp + M(80, 67) * M(67, 85)
      temp = temp + M(80, 70) * M(70, 85)
      temp = temp + M(80, 72) * M(72, 85)
      temp = temp + M(80, 73) * M(73, 85)
      temp = temp + M(80, 74) * M(74, 85)
      temp = temp + M(80, 75) * M(75, 85)
      temp = temp + M(80, 76) * M(76, 85)
      temp = temp + M(80, 77) * M(77, 85)
      temp = temp + M(80, 78) * M(78, 85)
      temp = temp + M(80, 79) * M(79, 85)
      M(80, 85) = ( M(80, 85) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 48) * M(48, 86)
      temp = temp + M(80, 50) * M(50, 86)
      temp = temp + M(80, 65) * M(65, 86)
      temp = temp + M(80, 66) * M(66, 86)
      temp = temp + M(80, 67) * M(67, 86)
      temp = temp + M(80, 70) * M(70, 86)
      temp = temp + M(80, 72) * M(72, 86)
      temp = temp + M(80, 73) * M(73, 86)
      temp = temp + M(80, 74) * M(74, 86)
      temp = temp + M(80, 75) * M(75, 86)
      temp = temp + M(80, 76) * M(76, 86)
      temp = temp + M(80, 77) * M(77, 86)
      temp = temp + M(80, 78) * M(78, 86)
      temp = temp + M(80, 79) * M(79, 86)
      M(80, 86) = ( M(80, 86) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 25) * M(25, 87)
      temp = temp + M(80, 26) * M(26, 87)
      temp = temp + M(80, 27) * M(27, 87)
      temp = temp + M(80, 30) * M(30, 87)
      temp = temp + M(80, 35) * M(35, 87)
      temp = temp + M(80, 43) * M(43, 87)
      temp = temp + M(80, 44) * M(44, 87)
      temp = temp + M(80, 45) * M(45, 87)
      temp = temp + M(80, 48) * M(48, 87)
      temp = temp + M(80, 50) * M(50, 87)
      temp = temp + M(80, 54) * M(54, 87)
      temp = temp + M(80, 59) * M(59, 87)
      temp = temp + M(80, 60) * M(60, 87)
      temp = temp + M(80, 62) * M(62, 87)
      temp = temp + M(80, 65) * M(65, 87)
      temp = temp + M(80, 66) * M(66, 87)
      temp = temp + M(80, 67) * M(67, 87)
      temp = temp + M(80, 70) * M(70, 87)
      temp = temp + M(80, 72) * M(72, 87)
      temp = temp + M(80, 73) * M(73, 87)
      temp = temp + M(80, 74) * M(74, 87)
      temp = temp + M(80, 75) * M(75, 87)
      temp = temp + M(80, 76) * M(76, 87)
      temp = temp + M(80, 77) * M(77, 87)
      temp = temp + M(80, 78) * M(78, 87)
      temp = temp + M(80, 79) * M(79, 87)
      M(80, 87) = ( M(80, 87) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 21) * M(21, 88)
      temp = temp + M(80, 24) * M(24, 88)
      temp = temp + M(80, 38) * M(38, 88)
      temp = temp + M(80, 44) * M(44, 88)
      temp = temp + M(80, 45) * M(45, 88)
      temp = temp + M(80, 54) * M(54, 88)
      temp = temp + M(80, 59) * M(59, 88)
      temp = temp + M(80, 60) * M(60, 88)
      temp = temp + M(80, 62) * M(62, 88)
      temp = temp + M(80, 65) * M(65, 88)
      temp = temp + M(80, 66) * M(66, 88)
      temp = temp + M(80, 67) * M(67, 88)
      temp = temp + M(80, 70) * M(70, 88)
      temp = temp + M(80, 72) * M(72, 88)
      temp = temp + M(80, 73) * M(73, 88)
      temp = temp + M(80, 74) * M(74, 88)
      temp = temp + M(80, 75) * M(75, 88)
      temp = temp + M(80, 76) * M(76, 88)
      temp = temp + M(80, 77) * M(77, 88)
      temp = temp + M(80, 78) * M(78, 88)
      temp = temp + M(80, 79) * M(79, 88)
      M(80, 88) = ( M(80, 88) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 38) * M(38, 89)
      temp = temp + M(80, 50) * M(50, 89)
      temp = temp + M(80, 54) * M(54, 89)
      temp = temp + M(80, 59) * M(59, 89)
      temp = temp + M(80, 60) * M(60, 89)
      temp = temp + M(80, 62) * M(62, 89)
      temp = temp + M(80, 65) * M(65, 89)
      temp = temp + M(80, 66) * M(66, 89)
      temp = temp + M(80, 67) * M(67, 89)
      temp = temp + M(80, 70) * M(70, 89)
      temp = temp + M(80, 72) * M(72, 89)
      temp = temp + M(80, 73) * M(73, 89)
      temp = temp + M(80, 74) * M(74, 89)
      temp = temp + M(80, 75) * M(75, 89)
      temp = temp + M(80, 76) * M(76, 89)
      temp = temp + M(80, 77) * M(77, 89)
      temp = temp + M(80, 78) * M(78, 89)
      temp = temp + M(80, 79) * M(79, 89)
      M(80, 89) = ( M(80, 89) - temp ) / M(80, 80)

C     Lower part.
      temp = M(81, 80) * M(80, 81)
      M(81, 81) = M(81, 81) - temp
C     Lower part.
      temp = M(82, 80) * M(80, 81)
      M(82, 81) = M(82, 81) - temp
C     Lower part.
      temp = M(83, 80) * M(80, 81)
      M(83, 81) = M(83, 81) - temp
C     Lower part.
      temp = M(84, 74) * M(74, 81)
      temp = temp + M(84, 80) * M(80, 81)
      M(84, 81) = M(84, 81) - temp
C     Lower part.
      temp = M(85, 80) * M(80, 81)
      M(85, 81) = M(85, 81) - temp
C     Lower part.
      temp = M(86, 80) * M(80, 81)
      M(86, 81) = M(86, 81) - temp
C     Lower part.
      temp = M(87, 74) * M(74, 81)
      temp = temp + M(87, 80) * M(80, 81)
      M(87, 81) = M(87, 81) - temp
C     Lower part.
      temp = M(88, 67) * M(67, 81)
      temp = temp + M(88, 80) * M(80, 81)
      M(88, 81) = M(88, 81) - temp
C     Lower part.
      temp = M(89, 80) * M(80, 81)
      M(89, 81) = M(89, 81) - temp
C     Upper part.
      temp = M(81, 53) * M(53, 82)
      temp = temp + M(81, 54) * M(54, 82)
      temp = temp + M(81, 56) * M(56, 82)
      temp = temp + M(81, 57) * M(57, 82)
      temp = temp + M(81, 59) * M(59, 82)
      temp = temp + M(81, 60) * M(60, 82)
      temp = temp + M(81, 61) * M(61, 82)
      temp = temp + M(81, 62) * M(62, 82)
      temp = temp + M(81, 63) * M(63, 82)
      temp = temp + M(81, 64) * M(64, 82)
      temp = temp + M(81, 65) * M(65, 82)
      temp = temp + M(81, 68) * M(68, 82)
      temp = temp + M(81, 69) * M(69, 82)
      temp = temp + M(81, 70) * M(70, 82)
      temp = temp + M(81, 73) * M(73, 82)
      temp = temp + M(81, 75) * M(75, 82)
      temp = temp + M(81, 76) * M(76, 82)
      temp = temp + M(81, 77) * M(77, 82)
      temp = temp + M(81, 78) * M(78, 82)
      temp = temp + M(81, 80) * M(80, 82)
      M(81, 82) = ( M(81, 82) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 76) * M(76, 83)
      temp = temp + M(81, 77) * M(77, 83)
      temp = temp + M(81, 78) * M(78, 83)
      temp = temp + M(81, 80) * M(80, 83)
      M(81, 83) = ( M(81, 83) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 43) * M(43, 84)
      temp = temp + M(81, 54) * M(54, 84)
      temp = temp + M(81, 59) * M(59, 84)
      temp = temp + M(81, 60) * M(60, 84)
      temp = temp + M(81, 61) * M(61, 84)
      temp = temp + M(81, 62) * M(62, 84)
      temp = temp + M(81, 63) * M(63, 84)
      temp = temp + M(81, 64) * M(64, 84)
      temp = temp + M(81, 65) * M(65, 84)
      temp = temp + M(81, 68) * M(68, 84)
      temp = temp + M(81, 69) * M(69, 84)
      temp = temp + M(81, 70) * M(70, 84)
      temp = temp + M(81, 73) * M(73, 84)
      temp = temp + M(81, 75) * M(75, 84)
      temp = temp + M(81, 76) * M(76, 84)
      temp = temp + M(81, 77) * M(77, 84)
      temp = temp + M(81, 78) * M(78, 84)
      temp = temp + M(81, 80) * M(80, 84)
      M(81, 84) = ( M(81, 84) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 43) * M(43, 85)
      temp = temp + M(81, 53) * M(53, 85)
      temp = temp + M(81, 54) * M(54, 85)
      temp = temp + M(81, 56) * M(56, 85)
      temp = temp + M(81, 57) * M(57, 85)
      temp = temp + M(81, 59) * M(59, 85)
      temp = temp + M(81, 60) * M(60, 85)
      temp = temp + M(81, 61) * M(61, 85)
      temp = temp + M(81, 62) * M(62, 85)
      temp = temp + M(81, 63) * M(63, 85)
      temp = temp + M(81, 64) * M(64, 85)
      temp = temp + M(81, 65) * M(65, 85)
      temp = temp + M(81, 68) * M(68, 85)
      temp = temp + M(81, 69) * M(69, 85)
      temp = temp + M(81, 70) * M(70, 85)
      temp = temp + M(81, 73) * M(73, 85)
      temp = temp + M(81, 75) * M(75, 85)
      temp = temp + M(81, 76) * M(76, 85)
      temp = temp + M(81, 77) * M(77, 85)
      temp = temp + M(81, 78) * M(78, 85)
      temp = temp + M(81, 80) * M(80, 85)
      M(81, 85) = ( M(81, 85) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 65) * M(65, 86)
      temp = temp + M(81, 68) * M(68, 86)
      temp = temp + M(81, 69) * M(69, 86)
      temp = temp + M(81, 70) * M(70, 86)
      temp = temp + M(81, 73) * M(73, 86)
      temp = temp + M(81, 75) * M(75, 86)
      temp = temp + M(81, 76) * M(76, 86)
      temp = temp + M(81, 77) * M(77, 86)
      temp = temp + M(81, 78) * M(78, 86)
      temp = temp + M(81, 80) * M(80, 86)
      M(81, 86) = ( M(81, 86) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 27) * M(27, 87)
      temp = temp + M(81, 43) * M(43, 87)
      temp = temp + M(81, 53) * M(53, 87)
      temp = temp + M(81, 54) * M(54, 87)
      temp = temp + M(81, 56) * M(56, 87)
      temp = temp + M(81, 57) * M(57, 87)
      temp = temp + M(81, 59) * M(59, 87)
      temp = temp + M(81, 60) * M(60, 87)
      temp = temp + M(81, 61) * M(61, 87)
      temp = temp + M(81, 62) * M(62, 87)
      temp = temp + M(81, 63) * M(63, 87)
      temp = temp + M(81, 64) * M(64, 87)
      temp = temp + M(81, 65) * M(65, 87)
      temp = temp + M(81, 68) * M(68, 87)
      temp = temp + M(81, 69) * M(69, 87)
      temp = temp + M(81, 70) * M(70, 87)
      temp = temp + M(81, 73) * M(73, 87)
      temp = temp + M(81, 75) * M(75, 87)
      temp = temp + M(81, 76) * M(76, 87)
      temp = temp + M(81, 77) * M(77, 87)
      temp = temp + M(81, 78) * M(78, 87)
      temp = temp + M(81, 80) * M(80, 87)
      M(81, 87) = ( M(81, 87) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 53) * M(53, 88)
      temp = temp + M(81, 54) * M(54, 88)
      temp = temp + M(81, 56) * M(56, 88)
      temp = temp + M(81, 57) * M(57, 88)
      temp = temp + M(81, 59) * M(59, 88)
      temp = temp + M(81, 60) * M(60, 88)
      temp = temp + M(81, 61) * M(61, 88)
      temp = temp + M(81, 62) * M(62, 88)
      temp = temp + M(81, 63) * M(63, 88)
      temp = temp + M(81, 64) * M(64, 88)
      temp = temp + M(81, 65) * M(65, 88)
      temp = temp + M(81, 68) * M(68, 88)
      temp = temp + M(81, 69) * M(69, 88)
      temp = temp + M(81, 70) * M(70, 88)
      temp = temp + M(81, 73) * M(73, 88)
      temp = temp + M(81, 75) * M(75, 88)
      temp = temp + M(81, 76) * M(76, 88)
      temp = temp + M(81, 77) * M(77, 88)
      temp = temp + M(81, 78) * M(78, 88)
      temp = temp + M(81, 80) * M(80, 88)
      M(81, 88) = ( M(81, 88) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 53) * M(53, 89)
      temp = temp + M(81, 54) * M(54, 89)
      temp = temp + M(81, 56) * M(56, 89)
      temp = temp + M(81, 57) * M(57, 89)
      temp = temp + M(81, 59) * M(59, 89)
      temp = temp + M(81, 60) * M(60, 89)
      temp = temp + M(81, 61) * M(61, 89)
      temp = temp + M(81, 62) * M(62, 89)
      temp = temp + M(81, 63) * M(63, 89)
      temp = temp + M(81, 64) * M(64, 89)
      temp = temp + M(81, 65) * M(65, 89)
      temp = temp + M(81, 68) * M(68, 89)
      temp = temp + M(81, 69) * M(69, 89)
      temp = temp + M(81, 70) * M(70, 89)
      temp = temp + M(81, 73) * M(73, 89)
      temp = temp + M(81, 75) * M(75, 89)
      temp = temp + M(81, 76) * M(76, 89)
      temp = temp + M(81, 77) * M(77, 89)
      temp = temp + M(81, 78) * M(78, 89)
      temp = temp + M(81, 80) * M(80, 89)
      M(81, 89) = ( M(81, 89) - temp ) / M(81, 81)

C     Lower part.
      temp = M(82, 21) * M(21, 82)
      temp = temp + M(82, 40) * M(40, 82)
      temp = temp + M(82, 42) * M(42, 82)
      temp = temp + M(82, 51) * M(51, 82)
      temp = temp + M(82, 52) * M(52, 82)
      temp = temp + M(82, 53) * M(53, 82)
      temp = temp + M(82, 54) * M(54, 82)
      temp = temp + M(82, 56) * M(56, 82)
      temp = temp + M(82, 57) * M(57, 82)
      temp = temp + M(82, 58) * M(58, 82)
      temp = temp + M(82, 59) * M(59, 82)
      temp = temp + M(82, 60) * M(60, 82)
      temp = temp + M(82, 61) * M(61, 82)
      temp = temp + M(82, 62) * M(62, 82)
      temp = temp + M(82, 63) * M(63, 82)
      temp = temp + M(82, 64) * M(64, 82)
      temp = temp + M(82, 65) * M(65, 82)
      temp = temp + M(82, 68) * M(68, 82)
      temp = temp + M(82, 69) * M(69, 82)
      temp = temp + M(82, 70) * M(70, 82)
      temp = temp + M(82, 75) * M(75, 82)
      temp = temp + M(82, 76) * M(76, 82)
      temp = temp + M(82, 77) * M(77, 82)
      temp = temp + M(82, 78) * M(78, 82)
      temp = temp + M(82, 80) * M(80, 82)
      temp = temp + M(82, 81) * M(81, 82)
      M(82, 82) = M(82, 82) - temp
C     Lower part.
      temp = M(83, 40) * M(40, 82)
      temp = temp + M(83, 51) * M(51, 82)
      temp = temp + M(83, 52) * M(52, 82)
      temp = temp + M(83, 53) * M(53, 82)
      temp = temp + M(83, 57) * M(57, 82)
      temp = temp + M(83, 58) * M(58, 82)
      temp = temp + M(83, 59) * M(59, 82)
      temp = temp + M(83, 63) * M(63, 82)
      temp = temp + M(83, 64) * M(64, 82)
      temp = temp + M(83, 65) * M(65, 82)
      temp = temp + M(83, 69) * M(69, 82)
      temp = temp + M(83, 76) * M(76, 82)
      temp = temp + M(83, 77) * M(77, 82)
      temp = temp + M(83, 78) * M(78, 82)
      temp = temp + M(83, 80) * M(80, 82)
      temp = temp + M(83, 81) * M(81, 82)
      M(83, 82) = M(83, 82) - temp
C     Lower part.
      temp = M(84, 40) * M(40, 82)
      temp = temp + M(84, 42) * M(42, 82)
      temp = temp + M(84, 51) * M(51, 82)
      temp = temp + M(84, 52) * M(52, 82)
      temp = temp + M(84, 53) * M(53, 82)
      temp = temp + M(84, 54) * M(54, 82)
      temp = temp + M(84, 56) * M(56, 82)
      temp = temp + M(84, 57) * M(57, 82)
      temp = temp + M(84, 58) * M(58, 82)
      temp = temp + M(84, 59) * M(59, 82)
      temp = temp + M(84, 61) * M(61, 82)
      temp = temp + M(84, 63) * M(63, 82)
      temp = temp + M(84, 64) * M(64, 82)
      temp = temp + M(84, 65) * M(65, 82)
      temp = temp + M(84, 68) * M(68, 82)
      temp = temp + M(84, 69) * M(69, 82)
      temp = temp + M(84, 70) * M(70, 82)
      temp = temp + M(84, 74) * M(74, 82)
      temp = temp + M(84, 75) * M(75, 82)
      temp = temp + M(84, 76) * M(76, 82)
      temp = temp + M(84, 77) * M(77, 82)
      temp = temp + M(84, 78) * M(78, 82)
      temp = temp + M(84, 79) * M(79, 82)
      temp = temp + M(84, 80) * M(80, 82)
      temp = temp + M(84, 81) * M(81, 82)
      M(84, 82) = M(84, 82) - temp
C     Lower part.
      temp = M(85, 40) * M(40, 82)
      temp = temp + M(85, 42) * M(42, 82)
      temp = temp + M(85, 51) * M(51, 82)
      temp = temp + M(85, 52) * M(52, 82)
      temp = temp + M(85, 53) * M(53, 82)
      temp = temp + M(85, 56) * M(56, 82)
      temp = temp + M(85, 57) * M(57, 82)
      temp = temp + M(85, 58) * M(58, 82)
      temp = temp + M(85, 59) * M(59, 82)
      temp = temp + M(85, 61) * M(61, 82)
      temp = temp + M(85, 63) * M(63, 82)
      temp = temp + M(85, 64) * M(64, 82)
      temp = temp + M(85, 65) * M(65, 82)
      temp = temp + M(85, 68) * M(68, 82)
      temp = temp + M(85, 69) * M(69, 82)
      temp = temp + M(85, 70) * M(70, 82)
      temp = temp + M(85, 75) * M(75, 82)
      temp = temp + M(85, 76) * M(76, 82)
      temp = temp + M(85, 77) * M(77, 82)
      temp = temp + M(85, 78) * M(78, 82)
      temp = temp + M(85, 80) * M(80, 82)
      temp = temp + M(85, 81) * M(81, 82)
      M(85, 82) = M(85, 82) - temp
C     Lower part.
      temp = M(86, 54) * M(54, 82)
      temp = temp + M(86, 59) * M(59, 82)
      temp = temp + M(86, 65) * M(65, 82)
      temp = temp + M(86, 80) * M(80, 82)
      temp = temp + M(86, 81) * M(81, 82)
      M(86, 82) = M(86, 82) - temp
C     Lower part.
      temp = M(87, 40) * M(40, 82)
      temp = temp + M(87, 42) * M(42, 82)
      temp = temp + M(87, 51) * M(51, 82)
      temp = temp + M(87, 52) * M(52, 82)
      temp = temp + M(87, 53) * M(53, 82)
      temp = temp + M(87, 54) * M(54, 82)
      temp = temp + M(87, 56) * M(56, 82)
      temp = temp + M(87, 57) * M(57, 82)
      temp = temp + M(87, 58) * M(58, 82)
      temp = temp + M(87, 59) * M(59, 82)
      temp = temp + M(87, 60) * M(60, 82)
      temp = temp + M(87, 61) * M(61, 82)
      temp = temp + M(87, 62) * M(62, 82)
      temp = temp + M(87, 63) * M(63, 82)
      temp = temp + M(87, 64) * M(64, 82)
      temp = temp + M(87, 65) * M(65, 82)
      temp = temp + M(87, 66) * M(66, 82)
      temp = temp + M(87, 68) * M(68, 82)
      temp = temp + M(87, 69) * M(69, 82)
      temp = temp + M(87, 70) * M(70, 82)
      temp = temp + M(87, 72) * M(72, 82)
      temp = temp + M(87, 74) * M(74, 82)
      temp = temp + M(87, 75) * M(75, 82)
      temp = temp + M(87, 76) * M(76, 82)
      temp = temp + M(87, 77) * M(77, 82)
      temp = temp + M(87, 78) * M(78, 82)
      temp = temp + M(87, 79) * M(79, 82)
      temp = temp + M(87, 80) * M(80, 82)
      temp = temp + M(87, 81) * M(81, 82)
      M(87, 82) = M(87, 82) - temp
C     Lower part.
      temp = M(88, 21) * M(21, 82)
      temp = temp + M(88, 40) * M(40, 82)
      temp = temp + M(88, 42) * M(42, 82)
      temp = temp + M(88, 47) * M(47, 82)
      temp = temp + M(88, 51) * M(51, 82)
      temp = temp + M(88, 52) * M(52, 82)
      temp = temp + M(88, 53) * M(53, 82)
      temp = temp + M(88, 54) * M(54, 82)
      temp = temp + M(88, 56) * M(56, 82)
      temp = temp + M(88, 57) * M(57, 82)
      temp = temp + M(88, 58) * M(58, 82)
      temp = temp + M(88, 59) * M(59, 82)
      temp = temp + M(88, 60) * M(60, 82)
      temp = temp + M(88, 61) * M(61, 82)
      temp = temp + M(88, 62) * M(62, 82)
      temp = temp + M(88, 63) * M(63, 82)
      temp = temp + M(88, 64) * M(64, 82)
      temp = temp + M(88, 65) * M(65, 82)
      temp = temp + M(88, 66) * M(66, 82)
      temp = temp + M(88, 67) * M(67, 82)
      temp = temp + M(88, 68) * M(68, 82)
      temp = temp + M(88, 69) * M(69, 82)
      temp = temp + M(88, 70) * M(70, 82)
      temp = temp + M(88, 72) * M(72, 82)
      temp = temp + M(88, 73) * M(73, 82)
      temp = temp + M(88, 75) * M(75, 82)
      temp = temp + M(88, 76) * M(76, 82)
      temp = temp + M(88, 77) * M(77, 82)
      temp = temp + M(88, 78) * M(78, 82)
      temp = temp + M(88, 79) * M(79, 82)
      temp = temp + M(88, 80) * M(80, 82)
      temp = temp + M(88, 81) * M(81, 82)
      M(88, 82) = M(88, 82) - temp
C     Lower part.
      temp = M(89, 40) * M(40, 82)
      temp = temp + M(89, 42) * M(42, 82)
      temp = temp + M(89, 47) * M(47, 82)
      temp = temp + M(89, 51) * M(51, 82)
      temp = temp + M(89, 52) * M(52, 82)
      temp = temp + M(89, 53) * M(53, 82)
      temp = temp + M(89, 54) * M(54, 82)
      temp = temp + M(89, 56) * M(56, 82)
      temp = temp + M(89, 57) * M(57, 82)
      temp = temp + M(89, 58) * M(58, 82)
      temp = temp + M(89, 59) * M(59, 82)
      temp = temp + M(89, 61) * M(61, 82)
      temp = temp + M(89, 63) * M(63, 82)
      temp = temp + M(89, 64) * M(64, 82)
      temp = temp + M(89, 65) * M(65, 82)
      temp = temp + M(89, 68) * M(68, 82)
      temp = temp + M(89, 69) * M(69, 82)
      temp = temp + M(89, 70) * M(70, 82)
      temp = temp + M(89, 72) * M(72, 82)
      temp = temp + M(89, 75) * M(75, 82)
      temp = temp + M(89, 76) * M(76, 82)
      temp = temp + M(89, 77) * M(77, 82)
      temp = temp + M(89, 78) * M(78, 82)
      temp = temp + M(89, 80) * M(80, 82)
      temp = temp + M(89, 81) * M(81, 82)
      M(89, 82) = M(89, 82) - temp
C     Upper part.
      temp = M(82, 76) * M(76, 83)
      temp = temp + M(82, 77) * M(77, 83)
      temp = temp + M(82, 78) * M(78, 83)
      temp = temp + M(82, 80) * M(80, 83)
      temp = temp + M(82, 81) * M(81, 83)
      M(82, 83) = ( M(82, 83) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 40) * M(40, 84)
      temp = temp + M(82, 42) * M(42, 84)
      temp = temp + M(82, 43) * M(43, 84)
      temp = temp + M(82, 45) * M(45, 84)
      temp = temp + M(82, 51) * M(51, 84)
      temp = temp + M(82, 54) * M(54, 84)
      temp = temp + M(82, 58) * M(58, 84)
      temp = temp + M(82, 59) * M(59, 84)
      temp = temp + M(82, 60) * M(60, 84)
      temp = temp + M(82, 61) * M(61, 84)
      temp = temp + M(82, 62) * M(62, 84)
      temp = temp + M(82, 63) * M(63, 84)
      temp = temp + M(82, 64) * M(64, 84)
      temp = temp + M(82, 65) * M(65, 84)
      temp = temp + M(82, 68) * M(68, 84)
      temp = temp + M(82, 69) * M(69, 84)
      temp = temp + M(82, 70) * M(70, 84)
      temp = temp + M(82, 75) * M(75, 84)
      temp = temp + M(82, 76) * M(76, 84)
      temp = temp + M(82, 77) * M(77, 84)
      temp = temp + M(82, 78) * M(78, 84)
      temp = temp + M(82, 80) * M(80, 84)
      temp = temp + M(82, 81) * M(81, 84)
      M(82, 84) = ( M(82, 84) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 40) * M(40, 85)
      temp = temp + M(82, 42) * M(42, 85)
      temp = temp + M(82, 43) * M(43, 85)
      temp = temp + M(82, 51) * M(51, 85)
      temp = temp + M(82, 52) * M(52, 85)
      temp = temp + M(82, 53) * M(53, 85)
      temp = temp + M(82, 54) * M(54, 85)
      temp = temp + M(82, 56) * M(56, 85)
      temp = temp + M(82, 57) * M(57, 85)
      temp = temp + M(82, 58) * M(58, 85)
      temp = temp + M(82, 59) * M(59, 85)
      temp = temp + M(82, 60) * M(60, 85)
      temp = temp + M(82, 61) * M(61, 85)
      temp = temp + M(82, 62) * M(62, 85)
      temp = temp + M(82, 63) * M(63, 85)
      temp = temp + M(82, 64) * M(64, 85)
      temp = temp + M(82, 65) * M(65, 85)
      temp = temp + M(82, 68) * M(68, 85)
      temp = temp + M(82, 69) * M(69, 85)
      temp = temp + M(82, 70) * M(70, 85)
      temp = temp + M(82, 75) * M(75, 85)
      temp = temp + M(82, 76) * M(76, 85)
      temp = temp + M(82, 77) * M(77, 85)
      temp = temp + M(82, 78) * M(78, 85)
      temp = temp + M(82, 80) * M(80, 85)
      temp = temp + M(82, 81) * M(81, 85)
      M(82, 85) = ( M(82, 85) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 65) * M(65, 86)
      temp = temp + M(82, 68) * M(68, 86)
      temp = temp + M(82, 69) * M(69, 86)
      temp = temp + M(82, 70) * M(70, 86)
      temp = temp + M(82, 75) * M(75, 86)
      temp = temp + M(82, 76) * M(76, 86)
      temp = temp + M(82, 77) * M(77, 86)
      temp = temp + M(82, 78) * M(78, 86)
      temp = temp + M(82, 80) * M(80, 86)
      temp = temp + M(82, 81) * M(81, 86)
      M(82, 86) = ( M(82, 86) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 26) * M(26, 87)
      temp = temp + M(82, 35) * M(35, 87)
      temp = temp + M(82, 40) * M(40, 87)
      temp = temp + M(82, 42) * M(42, 87)
      temp = temp + M(82, 43) * M(43, 87)
      temp = temp + M(82, 45) * M(45, 87)
      temp = temp + M(82, 51) * M(51, 87)
      temp = temp + M(82, 52) * M(52, 87)
      temp = temp + M(82, 53) * M(53, 87)
      temp = temp + M(82, 54) * M(54, 87)
      temp = temp + M(82, 56) * M(56, 87)
      temp = temp + M(82, 57) * M(57, 87)
      temp = temp + M(82, 58) * M(58, 87)
      temp = temp + M(82, 59) * M(59, 87)
      temp = temp + M(82, 60) * M(60, 87)
      temp = temp + M(82, 61) * M(61, 87)
      temp = temp + M(82, 62) * M(62, 87)
      temp = temp + M(82, 63) * M(63, 87)
      temp = temp + M(82, 64) * M(64, 87)
      temp = temp + M(82, 65) * M(65, 87)
      temp = temp + M(82, 68) * M(68, 87)
      temp = temp + M(82, 69) * M(69, 87)
      temp = temp + M(82, 70) * M(70, 87)
      temp = temp + M(82, 75) * M(75, 87)
      temp = temp + M(82, 76) * M(76, 87)
      temp = temp + M(82, 77) * M(77, 87)
      temp = temp + M(82, 78) * M(78, 87)
      temp = temp + M(82, 80) * M(80, 87)
      temp = temp + M(82, 81) * M(81, 87)
      M(82, 87) = ( M(82, 87) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 21) * M(21, 88)
      temp = temp + M(82, 38) * M(38, 88)
      temp = temp + M(82, 40) * M(40, 88)
      temp = temp + M(82, 42) * M(42, 88)
      temp = temp + M(82, 45) * M(45, 88)
      temp = temp + M(82, 51) * M(51, 88)
      temp = temp + M(82, 52) * M(52, 88)
      temp = temp + M(82, 53) * M(53, 88)
      temp = temp + M(82, 54) * M(54, 88)
      temp = temp + M(82, 56) * M(56, 88)
      temp = temp + M(82, 57) * M(57, 88)
      temp = temp + M(82, 58) * M(58, 88)
      temp = temp + M(82, 59) * M(59, 88)
      temp = temp + M(82, 60) * M(60, 88)
      temp = temp + M(82, 61) * M(61, 88)
      temp = temp + M(82, 62) * M(62, 88)
      temp = temp + M(82, 63) * M(63, 88)
      temp = temp + M(82, 64) * M(64, 88)
      temp = temp + M(82, 65) * M(65, 88)
      temp = temp + M(82, 68) * M(68, 88)
      temp = temp + M(82, 69) * M(69, 88)
      temp = temp + M(82, 70) * M(70, 88)
      temp = temp + M(82, 75) * M(75, 88)
      temp = temp + M(82, 76) * M(76, 88)
      temp = temp + M(82, 77) * M(77, 88)
      temp = temp + M(82, 78) * M(78, 88)
      temp = temp + M(82, 80) * M(80, 88)
      temp = temp + M(82, 81) * M(81, 88)
      M(82, 88) = ( M(82, 88) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 38) * M(38, 89)
      temp = temp + M(82, 40) * M(40, 89)
      temp = temp + M(82, 42) * M(42, 89)
      temp = temp + M(82, 51) * M(51, 89)
      temp = temp + M(82, 52) * M(52, 89)
      temp = temp + M(82, 53) * M(53, 89)
      temp = temp + M(82, 54) * M(54, 89)
      temp = temp + M(82, 56) * M(56, 89)
      temp = temp + M(82, 57) * M(57, 89)
      temp = temp + M(82, 58) * M(58, 89)
      temp = temp + M(82, 59) * M(59, 89)
      temp = temp + M(82, 60) * M(60, 89)
      temp = temp + M(82, 61) * M(61, 89)
      temp = temp + M(82, 62) * M(62, 89)
      temp = temp + M(82, 63) * M(63, 89)
      temp = temp + M(82, 64) * M(64, 89)
      temp = temp + M(82, 65) * M(65, 89)
      temp = temp + M(82, 68) * M(68, 89)
      temp = temp + M(82, 69) * M(69, 89)
      temp = temp + M(82, 70) * M(70, 89)
      temp = temp + M(82, 75) * M(75, 89)
      temp = temp + M(82, 76) * M(76, 89)
      temp = temp + M(82, 77) * M(77, 89)
      temp = temp + M(82, 78) * M(78, 89)
      temp = temp + M(82, 80) * M(80, 89)
      temp = temp + M(82, 81) * M(81, 89)
      M(82, 89) = ( M(82, 89) - temp ) / M(82, 82)

C     Lower part.
      temp = M(83, 76) * M(76, 83)
      temp = temp + M(83, 77) * M(77, 83)
      temp = temp + M(83, 78) * M(78, 83)
      temp = temp + M(83, 80) * M(80, 83)
      temp = temp + M(83, 81) * M(81, 83)
      temp = temp + M(83, 82) * M(82, 83)
      M(83, 83) = M(83, 83) - temp
C     Lower part.
      temp = M(84, 76) * M(76, 83)
      temp = temp + M(84, 77) * M(77, 83)
      temp = temp + M(84, 78) * M(78, 83)
      temp = temp + M(84, 79) * M(79, 83)
      temp = temp + M(84, 80) * M(80, 83)
      temp = temp + M(84, 81) * M(81, 83)
      temp = temp + M(84, 82) * M(82, 83)
      M(84, 83) = M(84, 83) - temp
C     Lower part.
      temp = M(85, 76) * M(76, 83)
      temp = temp + M(85, 77) * M(77, 83)
      temp = temp + M(85, 78) * M(78, 83)
      temp = temp + M(85, 80) * M(80, 83)
      temp = temp + M(85, 81) * M(81, 83)
      temp = temp + M(85, 82) * M(82, 83)
      M(85, 83) = M(85, 83) - temp
C     Lower part.
      temp = M(86, 80) * M(80, 83)
      temp = temp + M(86, 81) * M(81, 83)
      temp = temp + M(86, 82) * M(82, 83)
      M(86, 83) = M(86, 83) - temp
C     Lower part.
      temp = M(87, 76) * M(76, 83)
      temp = temp + M(87, 77) * M(77, 83)
      temp = temp + M(87, 78) * M(78, 83)
      temp = temp + M(87, 79) * M(79, 83)
      temp = temp + M(87, 80) * M(80, 83)
      temp = temp + M(87, 81) * M(81, 83)
      temp = temp + M(87, 82) * M(82, 83)
      M(87, 83) = M(87, 83) - temp
C     Lower part.
      temp = M(88, 76) * M(76, 83)
      temp = temp + M(88, 77) * M(77, 83)
      temp = temp + M(88, 78) * M(78, 83)
      temp = temp + M(88, 79) * M(79, 83)
      temp = temp + M(88, 80) * M(80, 83)
      temp = temp + M(88, 81) * M(81, 83)
      temp = temp + M(88, 82) * M(82, 83)
      M(88, 83) = M(88, 83) - temp
C     Lower part.
      temp = M(89, 76) * M(76, 83)
      temp = temp + M(89, 77) * M(77, 83)
      temp = temp + M(89, 78) * M(78, 83)
      temp = temp + M(89, 80) * M(80, 83)
      temp = temp + M(89, 81) * M(81, 83)
      temp = temp + M(89, 82) * M(82, 83)
      M(89, 83) = M(89, 83) - temp
C     Upper part.
      temp = M(83, 39) * M(39, 84)
      temp = temp + M(83, 40) * M(40, 84)
      temp = temp + M(83, 45) * M(45, 84)
      temp = temp + M(83, 48) * M(48, 84)
      temp = temp + M(83, 51) * M(51, 84)
      temp = temp + M(83, 58) * M(58, 84)
      temp = temp + M(83, 59) * M(59, 84)
      temp = temp + M(83, 63) * M(63, 84)
      temp = temp + M(83, 64) * M(64, 84)
      temp = temp + M(83, 65) * M(65, 84)
      temp = temp + M(83, 69) * M(69, 84)
      temp = temp + M(83, 76) * M(76, 84)
      temp = temp + M(83, 77) * M(77, 84)
      temp = temp + M(83, 78) * M(78, 84)
      temp = temp + M(83, 80) * M(80, 84)
      temp = temp + M(83, 81) * M(81, 84)
      temp = temp + M(83, 82) * M(82, 84)
      M(83, 84) = ( M(83, 84) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 40) * M(40, 85)
      temp = temp + M(83, 51) * M(51, 85)
      temp = temp + M(83, 52) * M(52, 85)
      temp = temp + M(83, 53) * M(53, 85)
      temp = temp + M(83, 57) * M(57, 85)
      temp = temp + M(83, 58) * M(58, 85)
      temp = temp + M(83, 59) * M(59, 85)
      temp = temp + M(83, 63) * M(63, 85)
      temp = temp + M(83, 64) * M(64, 85)
      temp = temp + M(83, 65) * M(65, 85)
      temp = temp + M(83, 69) * M(69, 85)
      temp = temp + M(83, 76) * M(76, 85)
      temp = temp + M(83, 77) * M(77, 85)
      temp = temp + M(83, 78) * M(78, 85)
      temp = temp + M(83, 80) * M(80, 85)
      temp = temp + M(83, 81) * M(81, 85)
      temp = temp + M(83, 82) * M(82, 85)
      M(83, 85) = ( M(83, 85) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 48) * M(48, 86)
      temp = temp + M(83, 65) * M(65, 86)
      temp = temp + M(83, 69) * M(69, 86)
      temp = temp + M(83, 76) * M(76, 86)
      temp = temp + M(83, 77) * M(77, 86)
      temp = temp + M(83, 78) * M(78, 86)
      temp = temp + M(83, 80) * M(80, 86)
      temp = temp + M(83, 81) * M(81, 86)
      temp = temp + M(83, 82) * M(82, 86)
      M(83, 86) = ( M(83, 86) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 39) * M(39, 87)
      temp = temp + M(83, 40) * M(40, 87)
      temp = temp + M(83, 45) * M(45, 87)
      temp = temp + M(83, 48) * M(48, 87)
      temp = temp + M(83, 51) * M(51, 87)
      temp = temp + M(83, 52) * M(52, 87)
      temp = temp + M(83, 53) * M(53, 87)
      temp = temp + M(83, 57) * M(57, 87)
      temp = temp + M(83, 58) * M(58, 87)
      temp = temp + M(83, 59) * M(59, 87)
      temp = temp + M(83, 63) * M(63, 87)
      temp = temp + M(83, 64) * M(64, 87)
      temp = temp + M(83, 65) * M(65, 87)
      temp = temp + M(83, 69) * M(69, 87)
      temp = temp + M(83, 76) * M(76, 87)
      temp = temp + M(83, 77) * M(77, 87)
      temp = temp + M(83, 78) * M(78, 87)
      temp = temp + M(83, 80) * M(80, 87)
      temp = temp + M(83, 81) * M(81, 87)
      temp = temp + M(83, 82) * M(82, 87)
      M(83, 87) = ( M(83, 87) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 39) * M(39, 88)
      temp = temp + M(83, 40) * M(40, 88)
      temp = temp + M(83, 45) * M(45, 88)
      temp = temp + M(83, 51) * M(51, 88)
      temp = temp + M(83, 52) * M(52, 88)
      temp = temp + M(83, 53) * M(53, 88)
      temp = temp + M(83, 57) * M(57, 88)
      temp = temp + M(83, 58) * M(58, 88)
      temp = temp + M(83, 59) * M(59, 88)
      temp = temp + M(83, 63) * M(63, 88)
      temp = temp + M(83, 64) * M(64, 88)
      temp = temp + M(83, 65) * M(65, 88)
      temp = temp + M(83, 69) * M(69, 88)
      temp = temp + M(83, 76) * M(76, 88)
      temp = temp + M(83, 77) * M(77, 88)
      temp = temp + M(83, 78) * M(78, 88)
      temp = temp + M(83, 80) * M(80, 88)
      temp = temp + M(83, 81) * M(81, 88)
      temp = temp + M(83, 82) * M(82, 88)
      M(83, 88) = ( M(83, 88) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 40) * M(40, 89)
      temp = temp + M(83, 51) * M(51, 89)
      temp = temp + M(83, 52) * M(52, 89)
      temp = temp + M(83, 53) * M(53, 89)
      temp = temp + M(83, 57) * M(57, 89)
      temp = temp + M(83, 58) * M(58, 89)
      temp = temp + M(83, 59) * M(59, 89)
      temp = temp + M(83, 63) * M(63, 89)
      temp = temp + M(83, 64) * M(64, 89)
      temp = temp + M(83, 65) * M(65, 89)
      temp = temp + M(83, 69) * M(69, 89)
      temp = temp + M(83, 76) * M(76, 89)
      temp = temp + M(83, 77) * M(77, 89)
      temp = temp + M(83, 78) * M(78, 89)
      temp = temp + M(83, 80) * M(80, 89)
      temp = temp + M(83, 81) * M(81, 89)
      temp = temp + M(83, 82) * M(82, 89)
      M(83, 89) = ( M(83, 89) - temp ) / M(83, 83)

C     Lower part.
      temp = M(84, 17) * M(17, 84)
      temp = temp + M(84, 22) * M(22, 84)
      temp = temp + M(84, 23) * M(23, 84)
      temp = temp + M(84, 24) * M(24, 84)
      temp = temp + M(84, 33) * M(33, 84)
      temp = temp + M(84, 36) * M(36, 84)
      temp = temp + M(84, 39) * M(39, 84)
      temp = temp + M(84, 40) * M(40, 84)
      temp = temp + M(84, 42) * M(42, 84)
      temp = temp + M(84, 43) * M(43, 84)
      temp = temp + M(84, 45) * M(45, 84)
      temp = temp + M(84, 48) * M(48, 84)
      temp = temp + M(84, 50) * M(50, 84)
      temp = temp + M(84, 51) * M(51, 84)
      temp = temp + M(84, 54) * M(54, 84)
      temp = temp + M(84, 58) * M(58, 84)
      temp = temp + M(84, 59) * M(59, 84)
      temp = temp + M(84, 61) * M(61, 84)
      temp = temp + M(84, 63) * M(63, 84)
      temp = temp + M(84, 64) * M(64, 84)
      temp = temp + M(84, 65) * M(65, 84)
      temp = temp + M(84, 68) * M(68, 84)
      temp = temp + M(84, 69) * M(69, 84)
      temp = temp + M(84, 70) * M(70, 84)
      temp = temp + M(84, 74) * M(74, 84)
      temp = temp + M(84, 75) * M(75, 84)
      temp = temp + M(84, 76) * M(76, 84)
      temp = temp + M(84, 77) * M(77, 84)
      temp = temp + M(84, 78) * M(78, 84)
      temp = temp + M(84, 79) * M(79, 84)
      temp = temp + M(84, 80) * M(80, 84)
      temp = temp + M(84, 81) * M(81, 84)
      temp = temp + M(84, 82) * M(82, 84)
      temp = temp + M(84, 83) * M(83, 84)
      M(84, 84) = M(84, 84) - temp
C     Lower part.
      temp = M(85, 33) * M(33, 84)
      temp = temp + M(85, 36) * M(36, 84)
      temp = temp + M(85, 40) * M(40, 84)
      temp = temp + M(85, 42) * M(42, 84)
      temp = temp + M(85, 43) * M(43, 84)
      temp = temp + M(85, 45) * M(45, 84)
      temp = temp + M(85, 51) * M(51, 84)
      temp = temp + M(85, 58) * M(58, 84)
      temp = temp + M(85, 59) * M(59, 84)
      temp = temp + M(85, 61) * M(61, 84)
      temp = temp + M(85, 63) * M(63, 84)
      temp = temp + M(85, 64) * M(64, 84)
      temp = temp + M(85, 65) * M(65, 84)
      temp = temp + M(85, 68) * M(68, 84)
      temp = temp + M(85, 69) * M(69, 84)
      temp = temp + M(85, 70) * M(70, 84)
      temp = temp + M(85, 75) * M(75, 84)
      temp = temp + M(85, 76) * M(76, 84)
      temp = temp + M(85, 77) * M(77, 84)
      temp = temp + M(85, 78) * M(78, 84)
      temp = temp + M(85, 80) * M(80, 84)
      temp = temp + M(85, 81) * M(81, 84)
      temp = temp + M(85, 82) * M(82, 84)
      temp = temp + M(85, 83) * M(83, 84)
      M(85, 84) = M(85, 84) - temp
C     Lower part.
      temp = M(86, 48) * M(48, 84)
      temp = temp + M(86, 54) * M(54, 84)
      temp = temp + M(86, 59) * M(59, 84)
      temp = temp + M(86, 65) * M(65, 84)
      temp = temp + M(86, 80) * M(80, 84)
      temp = temp + M(86, 81) * M(81, 84)
      temp = temp + M(86, 82) * M(82, 84)
      temp = temp + M(86, 83) * M(83, 84)
      M(86, 84) = M(86, 84) - temp
C     Lower part.
      temp = M(87, 17) * M(17, 84)
      temp = temp + M(87, 24) * M(24, 84)
      temp = temp + M(87, 40) * M(40, 84)
      temp = temp + M(87, 42) * M(42, 84)
      temp = temp + M(87, 43) * M(43, 84)
      temp = temp + M(87, 45) * M(45, 84)
      temp = temp + M(87, 48) * M(48, 84)
      temp = temp + M(87, 50) * M(50, 84)
      temp = temp + M(87, 51) * M(51, 84)
      temp = temp + M(87, 54) * M(54, 84)
      temp = temp + M(87, 58) * M(58, 84)
      temp = temp + M(87, 59) * M(59, 84)
      temp = temp + M(87, 60) * M(60, 84)
      temp = temp + M(87, 61) * M(61, 84)
      temp = temp + M(87, 62) * M(62, 84)
      temp = temp + M(87, 63) * M(63, 84)
      temp = temp + M(87, 64) * M(64, 84)
      temp = temp + M(87, 65) * M(65, 84)
      temp = temp + M(87, 66) * M(66, 84)
      temp = temp + M(87, 68) * M(68, 84)
      temp = temp + M(87, 69) * M(69, 84)
      temp = temp + M(87, 70) * M(70, 84)
      temp = temp + M(87, 72) * M(72, 84)
      temp = temp + M(87, 74) * M(74, 84)
      temp = temp + M(87, 75) * M(75, 84)
      temp = temp + M(87, 76) * M(76, 84)
      temp = temp + M(87, 77) * M(77, 84)
      temp = temp + M(87, 78) * M(78, 84)
      temp = temp + M(87, 79) * M(79, 84)
      temp = temp + M(87, 80) * M(80, 84)
      temp = temp + M(87, 81) * M(81, 84)
      temp = temp + M(87, 82) * M(82, 84)
      temp = temp + M(87, 83) * M(83, 84)
      M(87, 84) = M(87, 84) - temp
C     Lower part.
      temp = M(88, 22) * M(22, 84)
      temp = temp + M(88, 23) * M(23, 84)
      temp = temp + M(88, 24) * M(24, 84)
      temp = temp + M(88, 36) * M(36, 84)
      temp = temp + M(88, 39) * M(39, 84)
      temp = temp + M(88, 40) * M(40, 84)
      temp = temp + M(88, 42) * M(42, 84)
      temp = temp + M(88, 43) * M(43, 84)
      temp = temp + M(88, 44) * M(44, 84)
      temp = temp + M(88, 45) * M(45, 84)
      temp = temp + M(88, 48) * M(48, 84)
      temp = temp + M(88, 51) * M(51, 84)
      temp = temp + M(88, 54) * M(54, 84)
      temp = temp + M(88, 58) * M(58, 84)
      temp = temp + M(88, 59) * M(59, 84)
      temp = temp + M(88, 60) * M(60, 84)
      temp = temp + M(88, 61) * M(61, 84)
      temp = temp + M(88, 62) * M(62, 84)
      temp = temp + M(88, 63) * M(63, 84)
      temp = temp + M(88, 64) * M(64, 84)
      temp = temp + M(88, 65) * M(65, 84)
      temp = temp + M(88, 66) * M(66, 84)
      temp = temp + M(88, 67) * M(67, 84)
      temp = temp + M(88, 68) * M(68, 84)
      temp = temp + M(88, 69) * M(69, 84)
      temp = temp + M(88, 70) * M(70, 84)
      temp = temp + M(88, 72) * M(72, 84)
      temp = temp + M(88, 73) * M(73, 84)
      temp = temp + M(88, 75) * M(75, 84)
      temp = temp + M(88, 76) * M(76, 84)
      temp = temp + M(88, 77) * M(77, 84)
      temp = temp + M(88, 78) * M(78, 84)
      temp = temp + M(88, 79) * M(79, 84)
      temp = temp + M(88, 80) * M(80, 84)
      temp = temp + M(88, 81) * M(81, 84)
      temp = temp + M(88, 82) * M(82, 84)
      temp = temp + M(88, 83) * M(83, 84)
      M(88, 84) = M(88, 84) - temp
C     Lower part.
      temp = M(89, 40) * M(40, 84)
      temp = temp + M(89, 42) * M(42, 84)
      temp = temp + M(89, 43) * M(43, 84)
      temp = temp + M(89, 45) * M(45, 84)
      temp = temp + M(89, 48) * M(48, 84)
      temp = temp + M(89, 50) * M(50, 84)
      temp = temp + M(89, 51) * M(51, 84)
      temp = temp + M(89, 54) * M(54, 84)
      temp = temp + M(89, 58) * M(58, 84)
      temp = temp + M(89, 59) * M(59, 84)
      temp = temp + M(89, 61) * M(61, 84)
      temp = temp + M(89, 63) * M(63, 84)
      temp = temp + M(89, 64) * M(64, 84)
      temp = temp + M(89, 65) * M(65, 84)
      temp = temp + M(89, 68) * M(68, 84)
      temp = temp + M(89, 69) * M(69, 84)
      temp = temp + M(89, 70) * M(70, 84)
      temp = temp + M(89, 72) * M(72, 84)
      temp = temp + M(89, 75) * M(75, 84)
      temp = temp + M(89, 76) * M(76, 84)
      temp = temp + M(89, 77) * M(77, 84)
      temp = temp + M(89, 78) * M(78, 84)
      temp = temp + M(89, 80) * M(80, 84)
      temp = temp + M(89, 81) * M(81, 84)
      temp = temp + M(89, 82) * M(82, 84)
      temp = temp + M(89, 83) * M(83, 84)
      M(89, 84) = M(89, 84) - temp
C     Upper part.
      temp = M(84, 33) * M(33, 85)
      temp = temp + M(84, 40) * M(40, 85)
      temp = temp + M(84, 42) * M(42, 85)
      temp = temp + M(84, 43) * M(43, 85)
      temp = temp + M(84, 51) * M(51, 85)
      temp = temp + M(84, 52) * M(52, 85)
      temp = temp + M(84, 53) * M(53, 85)
      temp = temp + M(84, 54) * M(54, 85)
      temp = temp + M(84, 56) * M(56, 85)
      temp = temp + M(84, 57) * M(57, 85)
      temp = temp + M(84, 58) * M(58, 85)
      temp = temp + M(84, 59) * M(59, 85)
      temp = temp + M(84, 61) * M(61, 85)
      temp = temp + M(84, 63) * M(63, 85)
      temp = temp + M(84, 64) * M(64, 85)
      temp = temp + M(84, 65) * M(65, 85)
      temp = temp + M(84, 68) * M(68, 85)
      temp = temp + M(84, 69) * M(69, 85)
      temp = temp + M(84, 70) * M(70, 85)
      temp = temp + M(84, 74) * M(74, 85)
      temp = temp + M(84, 75) * M(75, 85)
      temp = temp + M(84, 76) * M(76, 85)
      temp = temp + M(84, 77) * M(77, 85)
      temp = temp + M(84, 78) * M(78, 85)
      temp = temp + M(84, 79) * M(79, 85)
      temp = temp + M(84, 80) * M(80, 85)
      temp = temp + M(84, 81) * M(81, 85)
      temp = temp + M(84, 82) * M(82, 85)
      temp = temp + M(84, 83) * M(83, 85)
      M(84, 85) = ( M(84, 85) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 48) * M(48, 86)
      temp = temp + M(84, 50) * M(50, 86)
      temp = temp + M(84, 65) * M(65, 86)
      temp = temp + M(84, 68) * M(68, 86)
      temp = temp + M(84, 69) * M(69, 86)
      temp = temp + M(84, 70) * M(70, 86)
      temp = temp + M(84, 74) * M(74, 86)
      temp = temp + M(84, 75) * M(75, 86)
      temp = temp + M(84, 76) * M(76, 86)
      temp = temp + M(84, 77) * M(77, 86)
      temp = temp + M(84, 78) * M(78, 86)
      temp = temp + M(84, 79) * M(79, 86)
      temp = temp + M(84, 80) * M(80, 86)
      temp = temp + M(84, 81) * M(81, 86)
      temp = temp + M(84, 82) * M(82, 86)
      temp = temp + M(84, 83) * M(83, 86)
      M(84, 86) = ( M(84, 86) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 17) * M(17, 87)
      temp = temp + M(84, 39) * M(39, 87)
      temp = temp + M(84, 40) * M(40, 87)
      temp = temp + M(84, 42) * M(42, 87)
      temp = temp + M(84, 43) * M(43, 87)
      temp = temp + M(84, 45) * M(45, 87)
      temp = temp + M(84, 48) * M(48, 87)
      temp = temp + M(84, 50) * M(50, 87)
      temp = temp + M(84, 51) * M(51, 87)
      temp = temp + M(84, 52) * M(52, 87)
      temp = temp + M(84, 53) * M(53, 87)
      temp = temp + M(84, 54) * M(54, 87)
      temp = temp + M(84, 56) * M(56, 87)
      temp = temp + M(84, 57) * M(57, 87)
      temp = temp + M(84, 58) * M(58, 87)
      temp = temp + M(84, 59) * M(59, 87)
      temp = temp + M(84, 61) * M(61, 87)
      temp = temp + M(84, 63) * M(63, 87)
      temp = temp + M(84, 64) * M(64, 87)
      temp = temp + M(84, 65) * M(65, 87)
      temp = temp + M(84, 68) * M(68, 87)
      temp = temp + M(84, 69) * M(69, 87)
      temp = temp + M(84, 70) * M(70, 87)
      temp = temp + M(84, 74) * M(74, 87)
      temp = temp + M(84, 75) * M(75, 87)
      temp = temp + M(84, 76) * M(76, 87)
      temp = temp + M(84, 77) * M(77, 87)
      temp = temp + M(84, 78) * M(78, 87)
      temp = temp + M(84, 79) * M(79, 87)
      temp = temp + M(84, 80) * M(80, 87)
      temp = temp + M(84, 81) * M(81, 87)
      temp = temp + M(84, 82) * M(82, 87)
      temp = temp + M(84, 83) * M(83, 87)
      M(84, 87) = ( M(84, 87) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 24) * M(24, 88)
      temp = temp + M(84, 39) * M(39, 88)
      temp = temp + M(84, 40) * M(40, 88)
      temp = temp + M(84, 42) * M(42, 88)
      temp = temp + M(84, 45) * M(45, 88)
      temp = temp + M(84, 51) * M(51, 88)
      temp = temp + M(84, 52) * M(52, 88)
      temp = temp + M(84, 53) * M(53, 88)
      temp = temp + M(84, 54) * M(54, 88)
      temp = temp + M(84, 56) * M(56, 88)
      temp = temp + M(84, 57) * M(57, 88)
      temp = temp + M(84, 58) * M(58, 88)
      temp = temp + M(84, 59) * M(59, 88)
      temp = temp + M(84, 61) * M(61, 88)
      temp = temp + M(84, 63) * M(63, 88)
      temp = temp + M(84, 64) * M(64, 88)
      temp = temp + M(84, 65) * M(65, 88)
      temp = temp + M(84, 68) * M(68, 88)
      temp = temp + M(84, 69) * M(69, 88)
      temp = temp + M(84, 70) * M(70, 88)
      temp = temp + M(84, 74) * M(74, 88)
      temp = temp + M(84, 75) * M(75, 88)
      temp = temp + M(84, 76) * M(76, 88)
      temp = temp + M(84, 77) * M(77, 88)
      temp = temp + M(84, 78) * M(78, 88)
      temp = temp + M(84, 79) * M(79, 88)
      temp = temp + M(84, 80) * M(80, 88)
      temp = temp + M(84, 81) * M(81, 88)
      temp = temp + M(84, 82) * M(82, 88)
      temp = temp + M(84, 83) * M(83, 88)
      M(84, 88) = ( M(84, 88) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 40) * M(40, 89)
      temp = temp + M(84, 42) * M(42, 89)
      temp = temp + M(84, 50) * M(50, 89)
      temp = temp + M(84, 51) * M(51, 89)
      temp = temp + M(84, 52) * M(52, 89)
      temp = temp + M(84, 53) * M(53, 89)
      temp = temp + M(84, 54) * M(54, 89)
      temp = temp + M(84, 56) * M(56, 89)
      temp = temp + M(84, 57) * M(57, 89)
      temp = temp + M(84, 58) * M(58, 89)
      temp = temp + M(84, 59) * M(59, 89)
      temp = temp + M(84, 61) * M(61, 89)
      temp = temp + M(84, 63) * M(63, 89)
      temp = temp + M(84, 64) * M(64, 89)
      temp = temp + M(84, 65) * M(65, 89)
      temp = temp + M(84, 68) * M(68, 89)
      temp = temp + M(84, 69) * M(69, 89)
      temp = temp + M(84, 70) * M(70, 89)
      temp = temp + M(84, 74) * M(74, 89)
      temp = temp + M(84, 75) * M(75, 89)
      temp = temp + M(84, 76) * M(76, 89)
      temp = temp + M(84, 77) * M(77, 89)
      temp = temp + M(84, 78) * M(78, 89)
      temp = temp + M(84, 79) * M(79, 89)
      temp = temp + M(84, 80) * M(80, 89)
      temp = temp + M(84, 81) * M(81, 89)
      temp = temp + M(84, 82) * M(82, 89)
      temp = temp + M(84, 83) * M(83, 89)
      M(84, 89) = ( M(84, 89) - temp ) / M(84, 84)

C     Lower part.
      temp = M(85, 33) * M(33, 85)
      temp = temp + M(85, 40) * M(40, 85)
      temp = temp + M(85, 42) * M(42, 85)
      temp = temp + M(85, 43) * M(43, 85)
      temp = temp + M(85, 51) * M(51, 85)
      temp = temp + M(85, 52) * M(52, 85)
      temp = temp + M(85, 53) * M(53, 85)
      temp = temp + M(85, 56) * M(56, 85)
      temp = temp + M(85, 57) * M(57, 85)
      temp = temp + M(85, 58) * M(58, 85)
      temp = temp + M(85, 59) * M(59, 85)
      temp = temp + M(85, 61) * M(61, 85)
      temp = temp + M(85, 63) * M(63, 85)
      temp = temp + M(85, 64) * M(64, 85)
      temp = temp + M(85, 65) * M(65, 85)
      temp = temp + M(85, 68) * M(68, 85)
      temp = temp + M(85, 69) * M(69, 85)
      temp = temp + M(85, 70) * M(70, 85)
      temp = temp + M(85, 75) * M(75, 85)
      temp = temp + M(85, 76) * M(76, 85)
      temp = temp + M(85, 77) * M(77, 85)
      temp = temp + M(85, 78) * M(78, 85)
      temp = temp + M(85, 80) * M(80, 85)
      temp = temp + M(85, 81) * M(81, 85)
      temp = temp + M(85, 82) * M(82, 85)
      temp = temp + M(85, 83) * M(83, 85)
      temp = temp + M(85, 84) * M(84, 85)
      M(85, 85) = M(85, 85) - temp
C     Lower part.
      temp = M(86, 54) * M(54, 85)
      temp = temp + M(86, 59) * M(59, 85)
      temp = temp + M(86, 65) * M(65, 85)
      temp = temp + M(86, 80) * M(80, 85)
      temp = temp + M(86, 81) * M(81, 85)
      temp = temp + M(86, 82) * M(82, 85)
      temp = temp + M(86, 83) * M(83, 85)
      temp = temp + M(86, 84) * M(84, 85)
      M(86, 85) = M(86, 85) - temp
C     Lower part.
      temp = M(87, 40) * M(40, 85)
      temp = temp + M(87, 42) * M(42, 85)
      temp = temp + M(87, 43) * M(43, 85)
      temp = temp + M(87, 51) * M(51, 85)
      temp = temp + M(87, 52) * M(52, 85)
      temp = temp + M(87, 53) * M(53, 85)
      temp = temp + M(87, 54) * M(54, 85)
      temp = temp + M(87, 56) * M(56, 85)
      temp = temp + M(87, 57) * M(57, 85)
      temp = temp + M(87, 58) * M(58, 85)
      temp = temp + M(87, 59) * M(59, 85)
      temp = temp + M(87, 60) * M(60, 85)
      temp = temp + M(87, 61) * M(61, 85)
      temp = temp + M(87, 62) * M(62, 85)
      temp = temp + M(87, 63) * M(63, 85)
      temp = temp + M(87, 64) * M(64, 85)
      temp = temp + M(87, 65) * M(65, 85)
      temp = temp + M(87, 66) * M(66, 85)
      temp = temp + M(87, 68) * M(68, 85)
      temp = temp + M(87, 69) * M(69, 85)
      temp = temp + M(87, 70) * M(70, 85)
      temp = temp + M(87, 72) * M(72, 85)
      temp = temp + M(87, 74) * M(74, 85)
      temp = temp + M(87, 75) * M(75, 85)
      temp = temp + M(87, 76) * M(76, 85)
      temp = temp + M(87, 77) * M(77, 85)
      temp = temp + M(87, 78) * M(78, 85)
      temp = temp + M(87, 79) * M(79, 85)
      temp = temp + M(87, 80) * M(80, 85)
      temp = temp + M(87, 81) * M(81, 85)
      temp = temp + M(87, 82) * M(82, 85)
      temp = temp + M(87, 83) * M(83, 85)
      temp = temp + M(87, 84) * M(84, 85)
      M(87, 85) = M(87, 85) - temp
C     Lower part.
      temp = M(88, 40) * M(40, 85)
      temp = temp + M(88, 42) * M(42, 85)
      temp = temp + M(88, 43) * M(43, 85)
      temp = temp + M(88, 44) * M(44, 85)
      temp = temp + M(88, 51) * M(51, 85)
      temp = temp + M(88, 52) * M(52, 85)
      temp = temp + M(88, 53) * M(53, 85)
      temp = temp + M(88, 54) * M(54, 85)
      temp = temp + M(88, 56) * M(56, 85)
      temp = temp + M(88, 57) * M(57, 85)
      temp = temp + M(88, 58) * M(58, 85)
      temp = temp + M(88, 59) * M(59, 85)
      temp = temp + M(88, 60) * M(60, 85)
      temp = temp + M(88, 61) * M(61, 85)
      temp = temp + M(88, 62) * M(62, 85)
      temp = temp + M(88, 63) * M(63, 85)
      temp = temp + M(88, 64) * M(64, 85)
      temp = temp + M(88, 65) * M(65, 85)
      temp = temp + M(88, 66) * M(66, 85)
      temp = temp + M(88, 67) * M(67, 85)
      temp = temp + M(88, 68) * M(68, 85)
      temp = temp + M(88, 69) * M(69, 85)
      temp = temp + M(88, 70) * M(70, 85)
      temp = temp + M(88, 72) * M(72, 85)
      temp = temp + M(88, 73) * M(73, 85)
      temp = temp + M(88, 75) * M(75, 85)
      temp = temp + M(88, 76) * M(76, 85)
      temp = temp + M(88, 77) * M(77, 85)
      temp = temp + M(88, 78) * M(78, 85)
      temp = temp + M(88, 79) * M(79, 85)
      temp = temp + M(88, 80) * M(80, 85)
      temp = temp + M(88, 81) * M(81, 85)
      temp = temp + M(88, 82) * M(82, 85)
      temp = temp + M(88, 83) * M(83, 85)
      temp = temp + M(88, 84) * M(84, 85)
      M(88, 85) = M(88, 85) - temp
C     Lower part.
      temp = M(89, 40) * M(40, 85)
      temp = temp + M(89, 42) * M(42, 85)
      temp = temp + M(89, 43) * M(43, 85)
      temp = temp + M(89, 51) * M(51, 85)
      temp = temp + M(89, 52) * M(52, 85)
      temp = temp + M(89, 53) * M(53, 85)
      temp = temp + M(89, 54) * M(54, 85)
      temp = temp + M(89, 56) * M(56, 85)
      temp = temp + M(89, 57) * M(57, 85)
      temp = temp + M(89, 58) * M(58, 85)
      temp = temp + M(89, 59) * M(59, 85)
      temp = temp + M(89, 61) * M(61, 85)
      temp = temp + M(89, 63) * M(63, 85)
      temp = temp + M(89, 64) * M(64, 85)
      temp = temp + M(89, 65) * M(65, 85)
      temp = temp + M(89, 68) * M(68, 85)
      temp = temp + M(89, 69) * M(69, 85)
      temp = temp + M(89, 70) * M(70, 85)
      temp = temp + M(89, 72) * M(72, 85)
      temp = temp + M(89, 75) * M(75, 85)
      temp = temp + M(89, 76) * M(76, 85)
      temp = temp + M(89, 77) * M(77, 85)
      temp = temp + M(89, 78) * M(78, 85)
      temp = temp + M(89, 80) * M(80, 85)
      temp = temp + M(89, 81) * M(81, 85)
      temp = temp + M(89, 82) * M(82, 85)
      temp = temp + M(89, 83) * M(83, 85)
      temp = temp + M(89, 84) * M(84, 85)
      M(89, 85) = M(89, 85) - temp
C     Upper part.
      temp = M(85, 65) * M(65, 86)
      temp = temp + M(85, 68) * M(68, 86)
      temp = temp + M(85, 69) * M(69, 86)
      temp = temp + M(85, 70) * M(70, 86)
      temp = temp + M(85, 75) * M(75, 86)
      temp = temp + M(85, 76) * M(76, 86)
      temp = temp + M(85, 77) * M(77, 86)
      temp = temp + M(85, 78) * M(78, 86)
      temp = temp + M(85, 80) * M(80, 86)
      temp = temp + M(85, 81) * M(81, 86)
      temp = temp + M(85, 82) * M(82, 86)
      temp = temp + M(85, 83) * M(83, 86)
      temp = temp + M(85, 84) * M(84, 86)
      M(85, 86) = ( M(85, 86) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 40) * M(40, 87)
      temp = temp + M(85, 42) * M(42, 87)
      temp = temp + M(85, 43) * M(43, 87)
      temp = temp + M(85, 45) * M(45, 87)
      temp = temp + M(85, 51) * M(51, 87)
      temp = temp + M(85, 52) * M(52, 87)
      temp = temp + M(85, 53) * M(53, 87)
      temp = temp + M(85, 56) * M(56, 87)
      temp = temp + M(85, 57) * M(57, 87)
      temp = temp + M(85, 58) * M(58, 87)
      temp = temp + M(85, 59) * M(59, 87)
      temp = temp + M(85, 61) * M(61, 87)
      temp = temp + M(85, 63) * M(63, 87)
      temp = temp + M(85, 64) * M(64, 87)
      temp = temp + M(85, 65) * M(65, 87)
      temp = temp + M(85, 68) * M(68, 87)
      temp = temp + M(85, 69) * M(69, 87)
      temp = temp + M(85, 70) * M(70, 87)
      temp = temp + M(85, 75) * M(75, 87)
      temp = temp + M(85, 76) * M(76, 87)
      temp = temp + M(85, 77) * M(77, 87)
      temp = temp + M(85, 78) * M(78, 87)
      temp = temp + M(85, 80) * M(80, 87)
      temp = temp + M(85, 81) * M(81, 87)
      temp = temp + M(85, 82) * M(82, 87)
      temp = temp + M(85, 83) * M(83, 87)
      temp = temp + M(85, 84) * M(84, 87)
      M(85, 87) = ( M(85, 87) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 40) * M(40, 88)
      temp = temp + M(85, 42) * M(42, 88)
      temp = temp + M(85, 45) * M(45, 88)
      temp = temp + M(85, 51) * M(51, 88)
      temp = temp + M(85, 52) * M(52, 88)
      temp = temp + M(85, 53) * M(53, 88)
      temp = temp + M(85, 56) * M(56, 88)
      temp = temp + M(85, 57) * M(57, 88)
      temp = temp + M(85, 58) * M(58, 88)
      temp = temp + M(85, 59) * M(59, 88)
      temp = temp + M(85, 61) * M(61, 88)
      temp = temp + M(85, 63) * M(63, 88)
      temp = temp + M(85, 64) * M(64, 88)
      temp = temp + M(85, 65) * M(65, 88)
      temp = temp + M(85, 68) * M(68, 88)
      temp = temp + M(85, 69) * M(69, 88)
      temp = temp + M(85, 70) * M(70, 88)
      temp = temp + M(85, 75) * M(75, 88)
      temp = temp + M(85, 76) * M(76, 88)
      temp = temp + M(85, 77) * M(77, 88)
      temp = temp + M(85, 78) * M(78, 88)
      temp = temp + M(85, 80) * M(80, 88)
      temp = temp + M(85, 81) * M(81, 88)
      temp = temp + M(85, 82) * M(82, 88)
      temp = temp + M(85, 83) * M(83, 88)
      temp = temp + M(85, 84) * M(84, 88)
      M(85, 88) = ( M(85, 88) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 40) * M(40, 89)
      temp = temp + M(85, 42) * M(42, 89)
      temp = temp + M(85, 51) * M(51, 89)
      temp = temp + M(85, 52) * M(52, 89)
      temp = temp + M(85, 53) * M(53, 89)
      temp = temp + M(85, 56) * M(56, 89)
      temp = temp + M(85, 57) * M(57, 89)
      temp = temp + M(85, 58) * M(58, 89)
      temp = temp + M(85, 59) * M(59, 89)
      temp = temp + M(85, 61) * M(61, 89)
      temp = temp + M(85, 63) * M(63, 89)
      temp = temp + M(85, 64) * M(64, 89)
      temp = temp + M(85, 65) * M(65, 89)
      temp = temp + M(85, 68) * M(68, 89)
      temp = temp + M(85, 69) * M(69, 89)
      temp = temp + M(85, 70) * M(70, 89)
      temp = temp + M(85, 75) * M(75, 89)
      temp = temp + M(85, 76) * M(76, 89)
      temp = temp + M(85, 77) * M(77, 89)
      temp = temp + M(85, 78) * M(78, 89)
      temp = temp + M(85, 80) * M(80, 89)
      temp = temp + M(85, 81) * M(81, 89)
      temp = temp + M(85, 82) * M(82, 89)
      temp = temp + M(85, 83) * M(83, 89)
      temp = temp + M(85, 84) * M(84, 89)
      M(85, 89) = ( M(85, 89) - temp ) / M(85, 85)

C     Lower part.
      temp = M(86, 48) * M(48, 86)
      temp = temp + M(86, 65) * M(65, 86)
      temp = temp + M(86, 80) * M(80, 86)
      temp = temp + M(86, 81) * M(81, 86)
      temp = temp + M(86, 82) * M(82, 86)
      temp = temp + M(86, 83) * M(83, 86)
      temp = temp + M(86, 84) * M(84, 86)
      temp = temp + M(86, 85) * M(85, 86)
      M(86, 86) = M(86, 86) - temp
C     Lower part.
      temp = M(87, 48) * M(48, 86)
      temp = temp + M(87, 50) * M(50, 86)
      temp = temp + M(87, 65) * M(65, 86)
      temp = temp + M(87, 66) * M(66, 86)
      temp = temp + M(87, 68) * M(68, 86)
      temp = temp + M(87, 69) * M(69, 86)
      temp = temp + M(87, 70) * M(70, 86)
      temp = temp + M(87, 72) * M(72, 86)
      temp = temp + M(87, 74) * M(74, 86)
      temp = temp + M(87, 75) * M(75, 86)
      temp = temp + M(87, 76) * M(76, 86)
      temp = temp + M(87, 77) * M(77, 86)
      temp = temp + M(87, 78) * M(78, 86)
      temp = temp + M(87, 79) * M(79, 86)
      temp = temp + M(87, 80) * M(80, 86)
      temp = temp + M(87, 81) * M(81, 86)
      temp = temp + M(87, 82) * M(82, 86)
      temp = temp + M(87, 83) * M(83, 86)
      temp = temp + M(87, 84) * M(84, 86)
      temp = temp + M(87, 85) * M(85, 86)
      M(87, 86) = M(87, 86) - temp
C     Lower part.
      temp = M(88, 48) * M(48, 86)
      temp = temp + M(88, 65) * M(65, 86)
      temp = temp + M(88, 66) * M(66, 86)
      temp = temp + M(88, 67) * M(67, 86)
      temp = temp + M(88, 68) * M(68, 86)
      temp = temp + M(88, 69) * M(69, 86)
      temp = temp + M(88, 70) * M(70, 86)
      temp = temp + M(88, 72) * M(72, 86)
      temp = temp + M(88, 73) * M(73, 86)
      temp = temp + M(88, 75) * M(75, 86)
      temp = temp + M(88, 76) * M(76, 86)
      temp = temp + M(88, 77) * M(77, 86)
      temp = temp + M(88, 78) * M(78, 86)
      temp = temp + M(88, 79) * M(79, 86)
      temp = temp + M(88, 80) * M(80, 86)
      temp = temp + M(88, 81) * M(81, 86)
      temp = temp + M(88, 82) * M(82, 86)
      temp = temp + M(88, 83) * M(83, 86)
      temp = temp + M(88, 84) * M(84, 86)
      temp = temp + M(88, 85) * M(85, 86)
      M(88, 86) = M(88, 86) - temp
C     Lower part.
      temp = M(89, 48) * M(48, 86)
      temp = temp + M(89, 50) * M(50, 86)
      temp = temp + M(89, 65) * M(65, 86)
      temp = temp + M(89, 68) * M(68, 86)
      temp = temp + M(89, 69) * M(69, 86)
      temp = temp + M(89, 70) * M(70, 86)
      temp = temp + M(89, 72) * M(72, 86)
      temp = temp + M(89, 75) * M(75, 86)
      temp = temp + M(89, 76) * M(76, 86)
      temp = temp + M(89, 77) * M(77, 86)
      temp = temp + M(89, 78) * M(78, 86)
      temp = temp + M(89, 80) * M(80, 86)
      temp = temp + M(89, 81) * M(81, 86)
      temp = temp + M(89, 82) * M(82, 86)
      temp = temp + M(89, 83) * M(83, 86)
      temp = temp + M(89, 84) * M(84, 86)
      temp = temp + M(89, 85) * M(85, 86)
      M(89, 86) = M(89, 86) - temp
C     Upper part.
      temp = M(86, 48) * M(48, 87)
      temp = temp + M(86, 54) * M(54, 87)
      temp = temp + M(86, 59) * M(59, 87)
      temp = temp + M(86, 65) * M(65, 87)
      temp = temp + M(86, 80) * M(80, 87)
      temp = temp + M(86, 81) * M(81, 87)
      temp = temp + M(86, 82) * M(82, 87)
      temp = temp + M(86, 83) * M(83, 87)
      temp = temp + M(86, 84) * M(84, 87)
      temp = temp + M(86, 85) * M(85, 87)
      M(86, 87) = ( M(86, 87) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 54) * M(54, 88)
      temp = temp + M(86, 59) * M(59, 88)
      temp = temp + M(86, 65) * M(65, 88)
      temp = temp + M(86, 80) * M(80, 88)
      temp = temp + M(86, 81) * M(81, 88)
      temp = temp + M(86, 82) * M(82, 88)
      temp = temp + M(86, 83) * M(83, 88)
      temp = temp + M(86, 84) * M(84, 88)
      temp = temp + M(86, 85) * M(85, 88)
      M(86, 88) = ( M(86, 88) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 54) * M(54, 89)
      temp = temp + M(86, 59) * M(59, 89)
      temp = temp + M(86, 65) * M(65, 89)
      temp = temp + M(86, 80) * M(80, 89)
      temp = temp + M(86, 81) * M(81, 89)
      temp = temp + M(86, 82) * M(82, 89)
      temp = temp + M(86, 83) * M(83, 89)
      temp = temp + M(86, 84) * M(84, 89)
      temp = temp + M(86, 85) * M(85, 89)
      M(86, 89) = ( M(86, 89) - temp ) / M(86, 86)

C     Lower part.
      temp = M(87, 17) * M(17, 87)
      temp = temp + M(87, 25) * M(25, 87)
      temp = temp + M(87, 26) * M(26, 87)
      temp = temp + M(87, 27) * M(27, 87)
      temp = temp + M(87, 30) * M(30, 87)
      temp = temp + M(87, 35) * M(35, 87)
      temp = temp + M(87, 40) * M(40, 87)
      temp = temp + M(87, 42) * M(42, 87)
      temp = temp + M(87, 43) * M(43, 87)
      temp = temp + M(87, 45) * M(45, 87)
      temp = temp + M(87, 48) * M(48, 87)
      temp = temp + M(87, 50) * M(50, 87)
      temp = temp + M(87, 51) * M(51, 87)
      temp = temp + M(87, 52) * M(52, 87)
      temp = temp + M(87, 53) * M(53, 87)
      temp = temp + M(87, 54) * M(54, 87)
      temp = temp + M(87, 56) * M(56, 87)
      temp = temp + M(87, 57) * M(57, 87)
      temp = temp + M(87, 58) * M(58, 87)
      temp = temp + M(87, 59) * M(59, 87)
      temp = temp + M(87, 60) * M(60, 87)
      temp = temp + M(87, 61) * M(61, 87)
      temp = temp + M(87, 62) * M(62, 87)
      temp = temp + M(87, 63) * M(63, 87)
      temp = temp + M(87, 64) * M(64, 87)
      temp = temp + M(87, 65) * M(65, 87)
      temp = temp + M(87, 66) * M(66, 87)
      temp = temp + M(87, 68) * M(68, 87)
      temp = temp + M(87, 69) * M(69, 87)
      temp = temp + M(87, 70) * M(70, 87)
      temp = temp + M(87, 72) * M(72, 87)
      temp = temp + M(87, 74) * M(74, 87)
      temp = temp + M(87, 75) * M(75, 87)
      temp = temp + M(87, 76) * M(76, 87)
      temp = temp + M(87, 77) * M(77, 87)
      temp = temp + M(87, 78) * M(78, 87)
      temp = temp + M(87, 79) * M(79, 87)
      temp = temp + M(87, 80) * M(80, 87)
      temp = temp + M(87, 81) * M(81, 87)
      temp = temp + M(87, 82) * M(82, 87)
      temp = temp + M(87, 83) * M(83, 87)
      temp = temp + M(87, 84) * M(84, 87)
      temp = temp + M(87, 85) * M(85, 87)
      temp = temp + M(87, 86) * M(86, 87)
      M(87, 87) = M(87, 87) - temp
C     Lower part.
      temp = M(88, 25) * M(25, 87)
      temp = temp + M(88, 26) * M(26, 87)
      temp = temp + M(88, 27) * M(27, 87)
      temp = temp + M(88, 30) * M(30, 87)
      temp = temp + M(88, 35) * M(35, 87)
      temp = temp + M(88, 39) * M(39, 87)
      temp = temp + M(88, 40) * M(40, 87)
      temp = temp + M(88, 42) * M(42, 87)
      temp = temp + M(88, 43) * M(43, 87)
      temp = temp + M(88, 44) * M(44, 87)
      temp = temp + M(88, 45) * M(45, 87)
      temp = temp + M(88, 48) * M(48, 87)
      temp = temp + M(88, 51) * M(51, 87)
      temp = temp + M(88, 52) * M(52, 87)
      temp = temp + M(88, 53) * M(53, 87)
      temp = temp + M(88, 54) * M(54, 87)
      temp = temp + M(88, 56) * M(56, 87)
      temp = temp + M(88, 57) * M(57, 87)
      temp = temp + M(88, 58) * M(58, 87)
      temp = temp + M(88, 59) * M(59, 87)
      temp = temp + M(88, 60) * M(60, 87)
      temp = temp + M(88, 61) * M(61, 87)
      temp = temp + M(88, 62) * M(62, 87)
      temp = temp + M(88, 63) * M(63, 87)
      temp = temp + M(88, 64) * M(64, 87)
      temp = temp + M(88, 65) * M(65, 87)
      temp = temp + M(88, 66) * M(66, 87)
      temp = temp + M(88, 67) * M(67, 87)
      temp = temp + M(88, 68) * M(68, 87)
      temp = temp + M(88, 69) * M(69, 87)
      temp = temp + M(88, 70) * M(70, 87)
      temp = temp + M(88, 72) * M(72, 87)
      temp = temp + M(88, 73) * M(73, 87)
      temp = temp + M(88, 75) * M(75, 87)
      temp = temp + M(88, 76) * M(76, 87)
      temp = temp + M(88, 77) * M(77, 87)
      temp = temp + M(88, 78) * M(78, 87)
      temp = temp + M(88, 79) * M(79, 87)
      temp = temp + M(88, 80) * M(80, 87)
      temp = temp + M(88, 81) * M(81, 87)
      temp = temp + M(88, 82) * M(82, 87)
      temp = temp + M(88, 83) * M(83, 87)
      temp = temp + M(88, 84) * M(84, 87)
      temp = temp + M(88, 85) * M(85, 87)
      temp = temp + M(88, 86) * M(86, 87)
      M(88, 87) = M(88, 87) - temp
C     Lower part.
      temp = M(89, 26) * M(26, 87)
      temp = temp + M(89, 35) * M(35, 87)
      temp = temp + M(89, 40) * M(40, 87)
      temp = temp + M(89, 42) * M(42, 87)
      temp = temp + M(89, 43) * M(43, 87)
      temp = temp + M(89, 45) * M(45, 87)
      temp = temp + M(89, 48) * M(48, 87)
      temp = temp + M(89, 50) * M(50, 87)
      temp = temp + M(89, 51) * M(51, 87)
      temp = temp + M(89, 52) * M(52, 87)
      temp = temp + M(89, 53) * M(53, 87)
      temp = temp + M(89, 54) * M(54, 87)
      temp = temp + M(89, 56) * M(56, 87)
      temp = temp + M(89, 57) * M(57, 87)
      temp = temp + M(89, 58) * M(58, 87)
      temp = temp + M(89, 59) * M(59, 87)
      temp = temp + M(89, 61) * M(61, 87)
      temp = temp + M(89, 63) * M(63, 87)
      temp = temp + M(89, 64) * M(64, 87)
      temp = temp + M(89, 65) * M(65, 87)
      temp = temp + M(89, 68) * M(68, 87)
      temp = temp + M(89, 69) * M(69, 87)
      temp = temp + M(89, 70) * M(70, 87)
      temp = temp + M(89, 72) * M(72, 87)
      temp = temp + M(89, 75) * M(75, 87)
      temp = temp + M(89, 76) * M(76, 87)
      temp = temp + M(89, 77) * M(77, 87)
      temp = temp + M(89, 78) * M(78, 87)
      temp = temp + M(89, 80) * M(80, 87)
      temp = temp + M(89, 81) * M(81, 87)
      temp = temp + M(89, 82) * M(82, 87)
      temp = temp + M(89, 83) * M(83, 87)
      temp = temp + M(89, 84) * M(84, 87)
      temp = temp + M(89, 85) * M(85, 87)
      temp = temp + M(89, 86) * M(86, 87)
      M(89, 87) = M(89, 87) - temp
C     Upper part.
      temp = M(87, 24) * M(24, 88)
      temp = temp + M(87, 40) * M(40, 88)
      temp = temp + M(87, 42) * M(42, 88)
      temp = temp + M(87, 45) * M(45, 88)
      temp = temp + M(87, 51) * M(51, 88)
      temp = temp + M(87, 52) * M(52, 88)
      temp = temp + M(87, 53) * M(53, 88)
      temp = temp + M(87, 54) * M(54, 88)
      temp = temp + M(87, 56) * M(56, 88)
      temp = temp + M(87, 57) * M(57, 88)
      temp = temp + M(87, 58) * M(58, 88)
      temp = temp + M(87, 59) * M(59, 88)
      temp = temp + M(87, 60) * M(60, 88)
      temp = temp + M(87, 61) * M(61, 88)
      temp = temp + M(87, 62) * M(62, 88)
      temp = temp + M(87, 63) * M(63, 88)
      temp = temp + M(87, 64) * M(64, 88)
      temp = temp + M(87, 65) * M(65, 88)
      temp = temp + M(87, 66) * M(66, 88)
      temp = temp + M(87, 68) * M(68, 88)
      temp = temp + M(87, 69) * M(69, 88)
      temp = temp + M(87, 70) * M(70, 88)
      temp = temp + M(87, 72) * M(72, 88)
      temp = temp + M(87, 74) * M(74, 88)
      temp = temp + M(87, 75) * M(75, 88)
      temp = temp + M(87, 76) * M(76, 88)
      temp = temp + M(87, 77) * M(77, 88)
      temp = temp + M(87, 78) * M(78, 88)
      temp = temp + M(87, 79) * M(79, 88)
      temp = temp + M(87, 80) * M(80, 88)
      temp = temp + M(87, 81) * M(81, 88)
      temp = temp + M(87, 82) * M(82, 88)
      temp = temp + M(87, 83) * M(83, 88)
      temp = temp + M(87, 84) * M(84, 88)
      temp = temp + M(87, 85) * M(85, 88)
      temp = temp + M(87, 86) * M(86, 88)
      M(87, 88) = ( M(87, 88) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 40) * M(40, 89)
      temp = temp + M(87, 42) * M(42, 89)
      temp = temp + M(87, 50) * M(50, 89)
      temp = temp + M(87, 51) * M(51, 89)
      temp = temp + M(87, 52) * M(52, 89)
      temp = temp + M(87, 53) * M(53, 89)
      temp = temp + M(87, 54) * M(54, 89)
      temp = temp + M(87, 56) * M(56, 89)
      temp = temp + M(87, 57) * M(57, 89)
      temp = temp + M(87, 58) * M(58, 89)
      temp = temp + M(87, 59) * M(59, 89)
      temp = temp + M(87, 60) * M(60, 89)
      temp = temp + M(87, 61) * M(61, 89)
      temp = temp + M(87, 62) * M(62, 89)
      temp = temp + M(87, 63) * M(63, 89)
      temp = temp + M(87, 64) * M(64, 89)
      temp = temp + M(87, 65) * M(65, 89)
      temp = temp + M(87, 66) * M(66, 89)
      temp = temp + M(87, 68) * M(68, 89)
      temp = temp + M(87, 69) * M(69, 89)
      temp = temp + M(87, 70) * M(70, 89)
      temp = temp + M(87, 72) * M(72, 89)
      temp = temp + M(87, 74) * M(74, 89)
      temp = temp + M(87, 75) * M(75, 89)
      temp = temp + M(87, 76) * M(76, 89)
      temp = temp + M(87, 77) * M(77, 89)
      temp = temp + M(87, 78) * M(78, 89)
      temp = temp + M(87, 79) * M(79, 89)
      temp = temp + M(87, 80) * M(80, 89)
      temp = temp + M(87, 81) * M(81, 89)
      temp = temp + M(87, 82) * M(82, 89)
      temp = temp + M(87, 83) * M(83, 89)
      temp = temp + M(87, 84) * M(84, 89)
      temp = temp + M(87, 85) * M(85, 89)
      temp = temp + M(87, 86) * M(86, 89)
      M(87, 89) = ( M(87, 89) - temp ) / M(87, 87)

C     Lower part.
      temp = M(88, 21) * M(21, 88)
      temp = temp + M(88, 24) * M(24, 88)
      temp = temp + M(88, 38) * M(38, 88)
      temp = temp + M(88, 39) * M(39, 88)
      temp = temp + M(88, 40) * M(40, 88)
      temp = temp + M(88, 42) * M(42, 88)
      temp = temp + M(88, 44) * M(44, 88)
      temp = temp + M(88, 45) * M(45, 88)
      temp = temp + M(88, 51) * M(51, 88)
      temp = temp + M(88, 52) * M(52, 88)
      temp = temp + M(88, 53) * M(53, 88)
      temp = temp + M(88, 54) * M(54, 88)
      temp = temp + M(88, 56) * M(56, 88)
      temp = temp + M(88, 57) * M(57, 88)
      temp = temp + M(88, 58) * M(58, 88)
      temp = temp + M(88, 59) * M(59, 88)
      temp = temp + M(88, 60) * M(60, 88)
      temp = temp + M(88, 61) * M(61, 88)
      temp = temp + M(88, 62) * M(62, 88)
      temp = temp + M(88, 63) * M(63, 88)
      temp = temp + M(88, 64) * M(64, 88)
      temp = temp + M(88, 65) * M(65, 88)
      temp = temp + M(88, 66) * M(66, 88)
      temp = temp + M(88, 67) * M(67, 88)
      temp = temp + M(88, 68) * M(68, 88)
      temp = temp + M(88, 69) * M(69, 88)
      temp = temp + M(88, 70) * M(70, 88)
      temp = temp + M(88, 72) * M(72, 88)
      temp = temp + M(88, 73) * M(73, 88)
      temp = temp + M(88, 75) * M(75, 88)
      temp = temp + M(88, 76) * M(76, 88)
      temp = temp + M(88, 77) * M(77, 88)
      temp = temp + M(88, 78) * M(78, 88)
      temp = temp + M(88, 79) * M(79, 88)
      temp = temp + M(88, 80) * M(80, 88)
      temp = temp + M(88, 81) * M(81, 88)
      temp = temp + M(88, 82) * M(82, 88)
      temp = temp + M(88, 83) * M(83, 88)
      temp = temp + M(88, 84) * M(84, 88)
      temp = temp + M(88, 85) * M(85, 88)
      temp = temp + M(88, 86) * M(86, 88)
      temp = temp + M(88, 87) * M(87, 88)
      M(88, 88) = M(88, 88) - temp
C     Lower part.
      temp = M(89, 38) * M(38, 88)
      temp = temp + M(89, 40) * M(40, 88)
      temp = temp + M(89, 42) * M(42, 88)
      temp = temp + M(89, 45) * M(45, 88)
      temp = temp + M(89, 51) * M(51, 88)
      temp = temp + M(89, 52) * M(52, 88)
      temp = temp + M(89, 53) * M(53, 88)
      temp = temp + M(89, 54) * M(54, 88)
      temp = temp + M(89, 56) * M(56, 88)
      temp = temp + M(89, 57) * M(57, 88)
      temp = temp + M(89, 58) * M(58, 88)
      temp = temp + M(89, 59) * M(59, 88)
      temp = temp + M(89, 61) * M(61, 88)
      temp = temp + M(89, 63) * M(63, 88)
      temp = temp + M(89, 64) * M(64, 88)
      temp = temp + M(89, 65) * M(65, 88)
      temp = temp + M(89, 68) * M(68, 88)
      temp = temp + M(89, 69) * M(69, 88)
      temp = temp + M(89, 70) * M(70, 88)
      temp = temp + M(89, 72) * M(72, 88)
      temp = temp + M(89, 75) * M(75, 88)
      temp = temp + M(89, 76) * M(76, 88)
      temp = temp + M(89, 77) * M(77, 88)
      temp = temp + M(89, 78) * M(78, 88)
      temp = temp + M(89, 80) * M(80, 88)
      temp = temp + M(89, 81) * M(81, 88)
      temp = temp + M(89, 82) * M(82, 88)
      temp = temp + M(89, 83) * M(83, 88)
      temp = temp + M(89, 84) * M(84, 88)
      temp = temp + M(89, 85) * M(85, 88)
      temp = temp + M(89, 86) * M(86, 88)
      temp = temp + M(89, 87) * M(87, 88)
      M(89, 88) = M(89, 88) - temp
C     Upper part.
      temp = M(88, 38) * M(38, 89)
      temp = temp + M(88, 40) * M(40, 89)
      temp = temp + M(88, 42) * M(42, 89)
      temp = temp + M(88, 51) * M(51, 89)
      temp = temp + M(88, 52) * M(52, 89)
      temp = temp + M(88, 53) * M(53, 89)
      temp = temp + M(88, 54) * M(54, 89)
      temp = temp + M(88, 56) * M(56, 89)
      temp = temp + M(88, 57) * M(57, 89)
      temp = temp + M(88, 58) * M(58, 89)
      temp = temp + M(88, 59) * M(59, 89)
      temp = temp + M(88, 60) * M(60, 89)
      temp = temp + M(88, 61) * M(61, 89)
      temp = temp + M(88, 62) * M(62, 89)
      temp = temp + M(88, 63) * M(63, 89)
      temp = temp + M(88, 64) * M(64, 89)
      temp = temp + M(88, 65) * M(65, 89)
      temp = temp + M(88, 66) * M(66, 89)
      temp = temp + M(88, 67) * M(67, 89)
      temp = temp + M(88, 68) * M(68, 89)
      temp = temp + M(88, 69) * M(69, 89)
      temp = temp + M(88, 70) * M(70, 89)
      temp = temp + M(88, 72) * M(72, 89)
      temp = temp + M(88, 73) * M(73, 89)
      temp = temp + M(88, 75) * M(75, 89)
      temp = temp + M(88, 76) * M(76, 89)
      temp = temp + M(88, 77) * M(77, 89)
      temp = temp + M(88, 78) * M(78, 89)
      temp = temp + M(88, 79) * M(79, 89)
      temp = temp + M(88, 80) * M(80, 89)
      temp = temp + M(88, 81) * M(81, 89)
      temp = temp + M(88, 82) * M(82, 89)
      temp = temp + M(88, 83) * M(83, 89)
      temp = temp + M(88, 84) * M(84, 89)
      temp = temp + M(88, 85) * M(85, 89)
      temp = temp + M(88, 86) * M(86, 89)
      temp = temp + M(88, 87) * M(87, 89)
      M(88, 89) = ( M(88, 89) - temp ) / M(88, 88)

C     Lower part.
      temp = M(89, 38) * M(38, 89)
      temp = temp + M(89, 40) * M(40, 89)
      temp = temp + M(89, 42) * M(42, 89)
      temp = temp + M(89, 50) * M(50, 89)
      temp = temp + M(89, 51) * M(51, 89)
      temp = temp + M(89, 52) * M(52, 89)
      temp = temp + M(89, 53) * M(53, 89)
      temp = temp + M(89, 54) * M(54, 89)
      temp = temp + M(89, 56) * M(56, 89)
      temp = temp + M(89, 57) * M(57, 89)
      temp = temp + M(89, 58) * M(58, 89)
      temp = temp + M(89, 59) * M(59, 89)
      temp = temp + M(89, 61) * M(61, 89)
      temp = temp + M(89, 63) * M(63, 89)
      temp = temp + M(89, 64) * M(64, 89)
      temp = temp + M(89, 65) * M(65, 89)
      temp = temp + M(89, 68) * M(68, 89)
      temp = temp + M(89, 69) * M(69, 89)
      temp = temp + M(89, 70) * M(70, 89)
      temp = temp + M(89, 72) * M(72, 89)
      temp = temp + M(89, 75) * M(75, 89)
      temp = temp + M(89, 76) * M(76, 89)
      temp = temp + M(89, 77) * M(77, 89)
      temp = temp + M(89, 78) * M(78, 89)
      temp = temp + M(89, 80) * M(80, 89)
      temp = temp + M(89, 81) * M(81, 89)
      temp = temp + M(89, 82) * M(82, 89)
      temp = temp + M(89, 83) * M(83, 89)
      temp = temp + M(89, 84) * M(84, 89)
      temp = temp + M(89, 85) * M(85, 89)
      temp = temp + M(89, 86) * M(86, 89)
      temp = temp + M(89, 87) * M(87, 89)
      temp = temp + M(89, 88) * M(88, 89)
      M(89, 89) = M(89, 89) - temp


      END
