C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc(ns,nr,y,convers_factor,
     $                     convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM_AEC            
C     Species: _ciRACM_AEC         
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
 
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo

      call dratedc(ns,nr,rk,conc,dw)
 
      JacC( 43, 84) = JacC( 43, 84) + dw(  1, 84)
      JacC( 84, 84) = JacC( 84, 84) - dw(  1, 84)
      JacC( 85, 84) = JacC( 85, 84) + dw(  1, 84)
      JacC(  9, 65) = JacC(  9, 65) + dw(  2, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw(  2, 65)
      JacC( 43, 65) = JacC( 43, 65) + dw(  3, 65)
      JacC( 65, 65) = JacC( 65, 65) - dw(  3, 65)
      JacC( 33, 33) = JacC( 33, 33) - dw(  4, 33)
      JacC( 80, 33) = JacC( 80, 33) + dw(  4, 33)
      JacC( 85, 33) = JacC( 85, 33) + dw(  4, 33)
      JacC( 74, 74) = JacC( 74, 74) - dw(  5, 74)
      JacC( 80, 74) = JacC( 80, 74) + dw(  5, 74)
      JacC( 84, 74) = JacC( 84, 74) + dw(  5, 74)
      JacC( 24, 24) = JacC( 24, 24) - dw(  6, 24)
      JacC( 80, 24) = JacC( 80, 24)+ 0.3500000000000000D+00*dw(  6, 24)
      JacC( 84, 24) = JacC( 84, 24)+ 0.6500000000000000D+00*dw(  6, 24)
      JacC( 87, 24) = JacC( 87, 24)+ 0.3500000000000000D+00*dw(  6, 24)
      JacC( 88, 24) = JacC( 88, 24)+ 0.6500000000000000D+00*dw(  6, 24)
      JacC( 85, 87) = JacC( 85, 87) + dw(  7, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw(  7, 87)
      JacC( 43, 87) = JacC( 43, 87) + dw(  8, 87)
      JacC( 84, 87) = JacC( 84, 87) + dw(  8, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw(  8, 87)
      JacC( 44, 44) = JacC( 44, 44) - dw(  9, 44)
      JacC( 80, 44) = JacC( 80, 44)+ 0.2000000000000000D+01*dw(  9, 44)
      JacC( 67, 79) = JacC( 67, 79) + dw( 10, 79)
      JacC( 79, 79) = JacC( 79, 79) - dw( 10, 79)
      JacC( 67, 79) = JacC( 67, 79) + dw( 11, 79)
      JacC( 79, 79) = JacC( 79, 79) - dw( 11, 79)
      JacC( 88, 79) = JacC( 88, 79)+ 0.2000000000000000D+01*dw( 11, 79)
      JacC( 67, 81) = JacC( 67, 81) + dw( 12, 81)
      JacC( 81, 81) = JacC( 81, 81) - dw( 12, 81)
      JacC( 82, 81) = JacC( 82, 81) + dw( 12, 81)
      JacC( 88, 81) = JacC( 88, 81) + dw( 12, 81)
      JacC( 21, 21) = JacC( 21, 21) - dw( 13, 21)
      JacC( 79, 21) = JacC( 79, 21) + dw( 13, 21)
      JacC( 80, 21) = JacC( 80, 21) + dw( 13, 21)
      JacC( 88, 21) = JacC( 88, 21) + dw( 13, 21)
      JacC( 73, 73) = JacC( 73, 73) - dw( 14, 73)
      JacC( 80, 73) = JacC( 80, 73) + dw( 14, 73)
      JacC( 81, 73) = JacC( 81, 73) + dw( 14, 73)
      JacC( 88, 73) = JacC( 88, 73) + dw( 14, 73)
      JacC( 38, 38) = JacC( 38, 38) - dw( 15, 38)
      JacC( 80, 38) = JacC( 80, 38) + dw( 15, 38)
      JacC( 82, 38) = JacC( 82, 38) + dw( 15, 38)
      JacC( 77, 77) = JacC( 77, 77) - dw( 16, 77)
      JacC( 78, 77) = JacC( 78, 77) + dw( 16, 77)
      JacC( 89, 77) = JacC( 89, 77) + dw( 16, 77)
      JacC( 66, 66) = JacC( 66, 66) - dw( 17, 66)
      JacC( 67, 66) = JacC( 67, 66)+ 0.1870000000000000D+01*dw( 17, 66)
      JacC( 79, 66) = JacC( 79, 66)+ 0.1300000000000000D+00*dw( 17, 66)
      JacC( 66, 66) = JacC( 66, 66) - dw( 18, 66)
      JacC( 67, 66) = JacC( 67, 66)+ 0.1550000000000000D+01*dw( 18, 66)
      JacC( 79, 66) = JacC( 79, 66)+ 0.4500000000000000D+00*dw( 18, 66)
      JacC( 88, 66) = JacC( 88, 66)+ 0.8000000000000000D+00*dw( 18, 66)
      JacC( 67, 72) = JacC( 67, 72) + dw( 19, 72)
      JacC( 72, 72) = JacC( 72, 72) - dw( 19, 72)
      JacC( 88, 72) = JacC( 88, 72) + dw( 19, 72)
      JacC( 89, 72) = JacC( 89, 72) + dw( 19, 72)
      JacC( 54, 54) = JacC( 54, 54) - dw( 20, 54)
      JacC( 86, 54) = JacC( 86, 54) + dw( 20, 54)
      JacC( 88, 54) = JacC( 88, 54) + dw( 20, 54)
      JacC( 77, 83) = JacC( 77, 83)+ 0.8000000000000000D+00*dw( 21, 83)
      JacC( 81, 83) = JacC( 81, 83)+ 0.2000000000000000D+00*dw( 21, 83)
      JacC( 83, 83) = JacC( 83, 83) - dw( 21, 83)
      JacC( 84, 83) = JacC( 84, 83) + dw( 21, 83)
      JacC( 88, 83) = JacC( 88, 83) + dw( 21, 83)
      JacC( 59, 59) = JacC( 59, 59) - dw( 22, 59)
      JacC( 67, 59) = JacC( 67, 59) + dw( 22, 59)
      JacC( 79, 59) = JacC( 79, 59) + dw( 22, 59)
      JacC( 88, 59) = JacC( 88, 59) + dw( 22, 59)
      JacC( 89, 59) = JacC( 89, 59) + dw( 22, 59)
      JacC( 47, 47) = JacC( 47, 47) - dw( 23, 47)
      JacC( 79, 47) = JacC( 79, 47) + dw( 23, 47)
      JacC( 88, 47) = JacC( 88, 47) + dw( 23, 47)
      JacC( 89, 47) = JacC( 89, 47) + dw( 23, 47)
      JacC( 43, 43) = JacC( 43, 43) - dw( 24, 43)
      JacC( 65, 43) = JacC( 65, 43) + dw( 24, 43)
      JacC( 43, 43) = JacC( 43, 43) - dw( 25, 43)
      JacC( 43, 65) = JacC( 43, 65) - dw( 25, 65)
      JacC( 65, 43) = JacC( 65, 43) - dw( 25, 43)
      JacC( 65, 65) = JacC( 65, 65) - dw( 25, 65)
      JacC(  9,  9) = JacC(  9,  9) - dw( 26,  9)
      JacC( 43,  9) = JacC( 43,  9) + dw( 26,  9)
      JacC(  9,  9) = JacC(  9,  9) - dw( 27,  9)
      JacC( 43,  9) = JacC( 43,  9) + dw( 27,  9)
      JacC(  9,  9) = JacC(  9,  9) - dw( 28,  9)
      JacC( 80,  9) = JacC( 80,  9)+ 0.2000000000000000D+01*dw( 28,  9)
      JacC( 65, 65) = JacC( 65, 65) - dw( 29, 65)
      JacC( 65, 80) = JacC( 65, 80) - dw( 29, 80)
      JacC( 80, 65) = JacC( 80, 65) - dw( 29, 65)
      JacC( 80, 80) = JacC( 80, 80) - dw( 29, 80)
      JacC( 88, 65) = JacC( 88, 65) + dw( 29, 65)
      JacC( 88, 80) = JacC( 88, 80) + dw( 29, 80)
      JacC( 65, 65) = JacC( 65, 65) - dw( 30, 65)
      JacC( 65, 88) = JacC( 65, 88) - dw( 30, 88)
      JacC( 80, 65) = JacC( 80, 65) + dw( 30, 65)
      JacC( 80, 88) = JacC( 80, 88) + dw( 30, 88)
      JacC( 88, 65) = JacC( 88, 65) - dw( 30, 65)
      JacC( 88, 88) = JacC( 88, 88) - dw( 30, 88)
      JacC( 80, 80) = JacC( 80, 80) - dw( 31, 80)
      JacC( 80, 88) = JacC( 80, 88) - dw( 31, 88)
      JacC( 88, 80) = JacC( 88, 80) - dw( 31, 80)
      JacC( 88, 88) = JacC( 88, 88) - dw( 31, 88)
      JacC( 44, 44) = JacC( 44, 44) - dw( 32, 44)
      JacC( 44, 80) = JacC( 44, 80) - dw( 32, 80)
      JacC( 80, 44) = JacC( 80, 44) - dw( 32, 44)
      JacC( 80, 80) = JacC( 80, 80) - dw( 32, 80)
      JacC( 88, 44) = JacC( 88, 44) + dw( 32, 44)
      JacC( 88, 80) = JacC( 88, 80) + dw( 32, 80)
      JacC( 44, 88) = JacC( 44, 88) + dw( 33, 88)
      JacC( 44, 88) = JacC( 44, 88) + dw( 33, 88)
      JacC( 88, 88) = JacC( 88, 88)- 0.2000000000000000D+01*dw( 33, 88)
      JacC( 88, 88) = JacC( 88, 88)- 0.2000000000000000D+01*dw( 33, 88)
      JacC( 44, 88) = JacC( 44, 88) + dw( 34, 88)
      JacC( 44, 88) = JacC( 44, 88) + dw( 34, 88)
      JacC( 88, 88) = JacC( 88, 88)- 0.2000000000000000D+01*dw( 34, 88)
      JacC( 88, 88) = JacC( 88, 88)- 0.2000000000000000D+01*dw( 34, 88)
      JacC( 43, 43) = JacC( 43, 43) - dw( 35, 43)
      JacC( 43, 85) = JacC( 43, 85) - dw( 35, 85)
      JacC( 84, 43) = JacC( 84, 43) + dw( 35, 43)
      JacC( 84, 85) = JacC( 84, 85) + dw( 35, 85)
      JacC( 85, 43) = JacC( 85, 43) - dw( 35, 43)
      JacC( 85, 85) = JacC( 85, 85) - dw( 35, 85)
      JacC( 43, 43) = JacC( 43, 43) - dw( 36, 43)
      JacC( 43, 84) = JacC( 43, 84) - dw( 36, 84)
      JacC( 84, 43) = JacC( 84, 43) - dw( 36, 43)
      JacC( 84, 84) = JacC( 84, 84) - dw( 36, 84)
      JacC( 85, 43) = JacC( 85, 43) + dw( 36, 43)
      JacC( 85, 84) = JacC( 85, 84) + dw( 36, 84)
      JacC( 43, 43) = JacC( 43, 43) - dw( 37, 43)
      JacC( 43, 84) = JacC( 43, 84) - dw( 37, 84)
      JacC( 84, 43) = JacC( 84, 43) - dw( 37, 43)
      JacC( 84, 84) = JacC( 84, 84) - dw( 37, 84)
      JacC( 87, 43) = JacC( 87, 43) + dw( 37, 43)
      JacC( 87, 84) = JacC( 87, 84) + dw( 37, 84)
      JacC( 33, 80) = JacC( 33, 80) + dw( 38, 80)
      JacC( 33, 85) = JacC( 33, 85) + dw( 38, 85)
      JacC( 80, 80) = JacC( 80, 80) - dw( 38, 80)
      JacC( 80, 85) = JacC( 80, 85) - dw( 38, 85)
      JacC( 85, 80) = JacC( 85, 80) - dw( 38, 80)
      JacC( 85, 85) = JacC( 85, 85) - dw( 38, 85)
      JacC( 74, 80) = JacC( 74, 80) + dw( 39, 80)
      JacC( 74, 84) = JacC( 74, 84) + dw( 39, 84)
      JacC( 80, 80) = JacC( 80, 80) - dw( 39, 80)
      JacC( 80, 84) = JacC( 80, 84) - dw( 39, 84)
      JacC( 84, 80) = JacC( 84, 80) - dw( 39, 80)
      JacC( 84, 84) = JacC( 84, 84) - dw( 39, 84)
      JacC( 80, 80) = JacC( 80, 80) - dw( 40, 80)
      JacC( 80, 87) = JacC( 80, 87) - dw( 40, 87)
      JacC( 84, 80) = JacC( 84, 80) + dw( 40, 80)
      JacC( 84, 87) = JacC( 84, 87) + dw( 40, 87)
      JacC( 87, 80) = JacC( 87, 80) - dw( 40, 80)
      JacC( 87, 87) = JacC( 87, 87) - dw( 40, 87)
      JacC( 88, 80) = JacC( 88, 80) + dw( 40, 80)
      JacC( 88, 87) = JacC( 88, 87) + dw( 40, 87)
      JacC( 80, 88) = JacC( 80, 88) + dw( 41, 88)
      JacC( 80, 85) = JacC( 80, 85) + dw( 41, 85)
      JacC( 84, 88) = JacC( 84, 88) + dw( 41, 88)
      JacC( 84, 85) = JacC( 84, 85) + dw( 41, 85)
      JacC( 85, 88) = JacC( 85, 88) - dw( 41, 88)
      JacC( 85, 85) = JacC( 85, 85) - dw( 41, 85)
      JacC( 88, 88) = JacC( 88, 88) - dw( 41, 88)
      JacC( 88, 85) = JacC( 88, 85) - dw( 41, 85)
      JacC( 24, 88) = JacC( 24, 88) + dw( 42, 88)
      JacC( 24, 84) = JacC( 24, 84) + dw( 42, 84)
      JacC( 84, 88) = JacC( 84, 88) - dw( 42, 88)
      JacC( 84, 84) = JacC( 84, 84) - dw( 42, 84)
      JacC( 88, 88) = JacC( 88, 88) - dw( 42, 88)
      JacC( 88, 84) = JacC( 88, 84) - dw( 42, 84)
      JacC( 24, 24) = JacC( 24, 24) - dw( 43, 24)
      JacC( 84, 24) = JacC( 84, 24) + dw( 43, 24)
      JacC( 88, 24) = JacC( 88, 24) + dw( 43, 24)
      JacC( 74, 88) = JacC( 74, 88)+ 0.3000000000000000D+00*dw( 44, 88)
      JacC( 74, 87) = JacC( 74, 87)+ 0.3000000000000000D+00*dw( 44, 87)
      JacC( 80, 88) = JacC( 80, 88)+ 0.7000000000000000D+00*dw( 44, 88)
      JacC( 80, 87) = JacC( 80, 87)+ 0.7000000000000000D+00*dw( 44, 87)
      JacC( 84, 88) = JacC( 84, 88)+ 0.7000000000000000D+00*dw( 44, 88)
      JacC( 84, 87) = JacC( 84, 87)+ 0.7000000000000000D+00*dw( 44, 87)
      JacC( 87, 88) = JacC( 87, 88) - dw( 44, 88)
      JacC( 87, 87) = JacC( 87, 87) - dw( 44, 87)
      JacC( 88, 88) = JacC( 88, 88) - dw( 44, 88)
      JacC( 88, 87) = JacC( 88, 87) - dw( 44, 87)
      JacC( 33, 80) = JacC( 33, 80) - dw( 45, 80)
      JacC( 33, 33) = JacC( 33, 33) - dw( 45, 33)
      JacC( 80, 80) = JacC( 80, 80) - dw( 45, 80)
      JacC( 80, 33) = JacC( 80, 33) - dw( 45, 33)
      JacC( 84, 80) = JacC( 84, 80) + dw( 45, 80)
      JacC( 84, 33) = JacC( 84, 33) + dw( 45, 33)
      JacC( 74, 80) = JacC( 74, 80) - dw( 46, 80)
      JacC( 74, 74) = JacC( 74, 74) - dw( 46, 74)
      JacC( 80, 80) = JacC( 80, 80) - dw( 46, 80)
      JacC( 80, 74) = JacC( 80, 74) - dw( 46, 74)
      JacC( 87, 80) = JacC( 87, 80) + dw( 46, 80)
      JacC( 87, 74) = JacC( 87, 74) + dw( 46, 74)
      JacC( 24, 80) = JacC( 24, 80) - dw( 47, 80)
      JacC( 24, 24) = JacC( 24, 24) - dw( 47, 24)
      JacC( 80, 80) = JacC( 80, 80) - dw( 47, 80)
      JacC( 80, 24) = JacC( 80, 24) - dw( 47, 24)
      JacC( 84, 80) = JacC( 84, 80) + dw( 47, 80)
      JacC( 84, 24) = JacC( 84, 24) + dw( 47, 24)
      JacC( 65, 65) = JacC( 65, 65) - dw( 48, 65)
      JacC( 65, 85) = JacC( 65, 85) - dw( 48, 85)
      JacC( 84, 65) = JacC( 84, 65) + dw( 48, 65)
      JacC( 84, 85) = JacC( 84, 85) + dw( 48, 85)
      JacC( 85, 65) = JacC( 85, 65) - dw( 48, 65)
      JacC( 85, 85) = JacC( 85, 85) - dw( 48, 85)
      JacC( 65, 65) = JacC( 65, 65) - dw( 49, 65)
      JacC( 65, 84) = JacC( 65, 84) - dw( 49, 84)
      JacC( 84, 65) = JacC( 84, 65) - dw( 49, 65)
      JacC( 84, 84) = JacC( 84, 84) - dw( 49, 84)
      JacC( 87, 65) = JacC( 87, 65) + dw( 49, 65)
      JacC( 87, 84) = JacC( 87, 84) + dw( 49, 84)
      JacC( 84, 85) = JacC( 84, 85)+ 0.2000000000000000D+01*dw( 50, 85)
      JacC( 84, 85) = JacC( 84, 85)+ 0.2000000000000000D+01*dw( 50, 85)
      JacC( 85, 85) = JacC( 85, 85)- 0.2000000000000000D+01*dw( 50, 85)
      JacC( 85, 85) = JacC( 85, 85)- 0.2000000000000000D+01*dw( 50, 85)
      JacC( 84, 87) = JacC( 84, 87)+ 0.2000000000000000D+01*dw( 51, 87)
      JacC( 84, 85) = JacC( 84, 85)+ 0.2000000000000000D+01*dw( 51, 85)
      JacC( 85, 87) = JacC( 85, 87) - dw( 51, 87)
      JacC( 85, 85) = JacC( 85, 85) - dw( 51, 85)
      JacC( 87, 87) = JacC( 87, 87) - dw( 51, 87)
      JacC( 87, 85) = JacC( 87, 85) - dw( 51, 85)
      JacC( 85, 87) = JacC( 85, 87) + dw( 52, 87)
      JacC( 85, 84) = JacC( 85, 84) + dw( 52, 84)
      JacC( 87, 87) = JacC( 87, 87) - dw( 52, 87)
      JacC( 87, 84) = JacC( 87, 84) - dw( 52, 84)
      JacC( 17, 87) = JacC( 17, 87) + dw( 53, 87)
      JacC( 17, 84) = JacC( 17, 84) + dw( 53, 84)
      JacC( 84, 87) = JacC( 84, 87) - dw( 53, 87)
      JacC( 84, 84) = JacC( 84, 84) - dw( 53, 84)
      JacC( 87, 87) = JacC( 87, 87) - dw( 53, 87)
      JacC( 87, 84) = JacC( 87, 84) - dw( 53, 84)
      JacC( 17, 17) = JacC( 17, 17) - dw( 54, 17)
      JacC( 84, 17) = JacC( 84, 17) + dw( 54, 17)
      JacC( 87, 17) = JacC( 87, 17) + dw( 54, 17)
      JacC( 84, 87) = JacC( 84, 87)+ 0.2000000000000000D+01*dw( 55, 87)
      JacC( 84, 87) = JacC( 84, 87)+ 0.2000000000000000D+01*dw( 55, 87)
      JacC( 87, 87) = JacC( 87, 87)- 0.2000000000000000D+01*dw( 55, 87)
      JacC( 87, 87) = JacC( 87, 87)- 0.2000000000000000D+01*dw( 55, 87)
      JacC( 80, 80) = JacC( 80, 80) - dw( 56, 80)
      JacC( 88, 80) = JacC( 88, 80) + dw( 56, 80)
      JacC(  3, 80) = JacC(  3, 80) - dw( 57, 80)
      JacC(  3,  3) = JacC(  3,  3) - dw( 57,  3)
      JacC( 10, 80) = JacC( 10, 80) + dw( 57, 80)
      JacC( 10,  3) = JacC( 10,  3) + dw( 57,  3)
      JacC( 80, 80) = JacC( 80, 80) - dw( 57, 80)
      JacC( 80,  3) = JacC( 80,  3) - dw( 57,  3)
      JacC( 88, 80) = JacC( 88, 80) + dw( 57, 80)
      JacC( 88,  3) = JacC( 88,  3) + dw( 57,  3)
      JacC( 67, 67) = JacC( 67, 67) - dw( 58, 67)
      JacC( 67, 80) = JacC( 67, 80) - dw( 58, 80)
      JacC( 80, 67) = JacC( 80, 67) - dw( 58, 67)
      JacC( 80, 80) = JacC( 80, 80) - dw( 58, 80)
      JacC( 88, 67) = JacC( 88, 67) + dw( 58, 67)
      JacC( 88, 80) = JacC( 88, 80) + dw( 58, 80)
      JacC( 35, 35) = JacC( 35, 35) - dw( 59, 35)
      JacC( 35, 43) = JacC( 35, 43) - dw( 59, 43)
      JacC( 43, 35) = JacC( 43, 35) - dw( 59, 35)
      JacC( 43, 43) = JacC( 43, 43) - dw( 59, 43)
      JacC( 54, 35) = JacC( 54, 35)+ 0.1300000000000000D+00*dw( 59, 35)
      JacC( 54, 43) = JacC( 54, 43)+ 0.1300000000000000D+00*dw( 59, 43)
      JacC( 60, 35) = JacC( 60, 35)+ 0.8600000000000000D+00*dw( 59, 35)
      JacC( 60, 43) = JacC( 60, 43)+ 0.8600000000000000D+00*dw( 59, 43)
      JacC( 67, 35) = JacC( 67, 35)+ 0.1000000000000000D-01*dw( 59, 35)
      JacC( 67, 43) = JacC( 67, 43)+ 0.1000000000000000D-01*dw( 59, 43)
      JacC( 75, 35) = JacC( 75, 35)+ 0.1500000000000000D+00*dw( 59, 35)
      JacC( 75, 43) = JacC( 75, 43)+ 0.1500000000000000D+00*dw( 59, 43)
      JacC( 79, 35) = JacC( 79, 35)+ 0.5000000000000000D-01*dw( 59, 35)
      JacC( 79, 43) = JacC( 79, 43)+ 0.5000000000000000D-01*dw( 59, 43)
      JacC( 80, 35) = JacC( 80, 35)+ 0.2000000000000000D-01*dw( 59, 35)
      JacC( 80, 43) = JacC( 80, 43)+ 0.2000000000000000D-01*dw( 59, 43)
      JacC( 88, 35) = JacC( 88, 35)+ 0.2800000000000000D+00*dw( 59, 35)
      JacC( 88, 43) = JacC( 88, 43)+ 0.2800000000000000D+00*dw( 59, 43)
      JacC( 43, 59) = JacC( 43, 59) - dw( 60, 59)
      JacC( 43, 43) = JacC( 43, 43) - dw( 60, 43)
      JacC( 59, 59) = JacC( 59, 59) - dw( 60, 59)
      JacC( 59, 43) = JacC( 59, 43) - dw( 60, 43)
      JacC( 81, 59) = JacC( 81, 59) + dw( 60, 59)
      JacC( 81, 43) = JacC( 81, 43) + dw( 60, 43)
      JacC( 37, 37) = JacC( 37, 37) - dw( 61, 37)
      JacC( 37, 80) = JacC( 37, 80) - dw( 61, 80)
      JacC( 80, 37) = JacC( 80, 37) - dw( 61, 37)
      JacC( 80, 80) = JacC( 80, 80) - dw( 61, 80)
      JacC( 82, 37) = JacC( 82, 37) + dw( 61, 37)
      JacC( 82, 80) = JacC( 82, 80) + dw( 61, 80)
      JacC( 34, 34) = JacC( 34, 34) - dw( 62, 34)
      JacC( 34, 80) = JacC( 34, 80) - dw( 62, 80)
      JacC( 78, 34) = JacC( 78, 34) + dw( 62, 34)
      JacC( 78, 80) = JacC( 78, 80) + dw( 62, 80)
      JacC( 80, 34) = JacC( 80, 34) - dw( 62, 34)
      JacC( 80, 80) = JacC( 80, 80) - dw( 62, 80)
      JacC(  4,  4) = JacC(  4,  4) - dw( 63,  4)
      JacC(  4, 80) = JacC(  4, 80) - dw( 63, 80)
      JacC( 49,  4) = JacC( 49,  4)+ 0.3600000000000000D-01*dw( 63,  4)
      JacC( 49, 80) = JacC( 49, 80)+ 0.3600000000000000D-01*dw( 63, 80)
      JacC( 66,  4) = JacC( 66,  4)+ 0.3600000000000000D-01*dw( 63,  4)
      JacC( 66, 80) = JacC( 66, 80)+ 0.3600000000000000D-01*dw( 63, 80)
      JacC( 67,  4) = JacC( 67,  4)+ 0.3600000000000000D-01*dw( 63,  4)
      JacC( 67, 80) = JacC( 67, 80)+ 0.3600000000000000D-01*dw( 63, 80)
      JacC( 76,  4) = JacC( 76,  4)+ 0.5830000000000000D+00*dw( 63,  4)
      JacC( 76, 80) = JacC( 76, 80)+ 0.5830000000000000D+00*dw( 63, 80)
      JacC( 79,  4) = JacC( 79,  4)+ 0.1000000000000000D-01*dw( 63,  4)
      JacC( 79, 80) = JacC( 79, 80)+ 0.1000000000000000D-01*dw( 63, 80)
      JacC( 80,  4) = JacC( 80,  4)- 0.9640000000000000D+00*dw( 63,  4)
      JacC( 80, 80) = JacC( 80, 80)- 0.9640000000000000D+00*dw( 63, 80)
      JacC( 81,  4) = JacC( 81,  4)+ 0.3350000000000000D+00*dw( 63,  4)
      JacC( 81, 80) = JacC( 81, 80)+ 0.3350000000000000D+00*dw( 63, 80)
      JacC( 88,  4) = JacC( 88,  4)+ 0.3810000000000000D+00*dw( 63,  4)
      JacC( 88, 80) = JacC( 88, 80)+ 0.3810000000000000D+00*dw( 63, 80)
      JacC(  5,  5) = JacC(  5,  5) - dw( 64,  5)
      JacC(  5, 80) = JacC(  5, 80) - dw( 64, 80)
      JacC( 53,  5) = JacC( 53,  5)+ 0.7500000000000000D+00*dw( 64,  5)
      JacC( 53, 80) = JacC( 53, 80)+ 0.7500000000000000D+00*dw( 64, 80)
      JacC( 77,  5) = JacC( 77,  5)+ 0.2500000000000000D+00*dw( 64,  5)
      JacC( 77, 80) = JacC( 77, 80)+ 0.2500000000000000D+00*dw( 64, 80)
      JacC( 80,  5) = JacC( 80,  5) - dw( 64,  5)
      JacC( 80, 80) = JacC( 80, 80) - dw( 64, 80)
      JacC( 88,  5) = JacC( 88,  5)+ 0.2500000000000000D+00*dw( 64,  5)
      JacC( 88, 80) = JacC( 88, 80)+ 0.2500000000000000D+00*dw( 64, 80)
      JacC(  6,  6) = JacC(  6,  6) - dw( 65,  6)
      JacC(  6, 80) = JacC(  6, 80) - dw( 65, 80)
      JacC( 47,  6) = JacC( 47,  6)+ 0.2400000000000000D-01*dw( 65,  6)
      JacC( 47, 80) = JacC( 47, 80)+ 0.2400000000000000D-01*dw( 65, 80)
      JacC( 55,  6) = JacC( 55,  6)+ 0.4800000000000000D-01*dw( 65,  6)
      JacC( 55, 80) = JacC( 55, 80)+ 0.4800000000000000D-01*dw( 65, 80)
      JacC( 57,  6) = JacC( 57,  6)+ 0.9510000000000000D+00*dw( 65,  6)
      JacC( 57, 80) = JacC( 57, 80)+ 0.9510000000000000D+00*dw( 65, 80)
      JacC( 80,  6) = JacC( 80,  6) - dw( 65,  6)
      JacC( 80, 80) = JacC( 80, 80) - dw( 65, 80)
      JacC( 81,  6) = JacC( 81,  6)+ 0.2500000000000000D-01*dw( 65,  6)
      JacC( 81, 80) = JacC( 81, 80)+ 0.2500000000000000D-01*dw( 65, 80)
      JacC( 88,  6) = JacC( 88,  6)+ 0.4900000000000000D-01*dw( 65,  6)
      JacC( 88, 80) = JacC( 88, 80)+ 0.4900000000000000D-01*dw( 65, 80)
      JacC( 25, 25) = JacC( 25, 25) - dw( 66, 25)
      JacC( 25, 80) = JacC( 25, 80) - dw( 66, 80)
      JacC( 56, 25) = JacC( 56, 25) + dw( 66, 25)
      JacC( 56, 80) = JacC( 56, 80) + dw( 66, 80)
      JacC( 80, 25) = JacC( 80, 25) - dw( 66, 25)
      JacC( 80, 80) = JacC( 80, 80) - dw( 66, 80)
      JacC( 55, 60) = JacC( 55, 60)+ 0.1600000000000000D-02*dw( 67, 60)
      JacC( 55, 80) = JacC( 55, 80)+ 0.1600000000000000D-02*dw( 67, 80)
      JacC( 60, 60) = JacC( 60, 60) - dw( 67, 60)
      JacC( 60, 80) = JacC( 60, 80) - dw( 67, 80)
      JacC( 61, 60) = JacC( 61, 60) + dw( 67, 60)
      JacC( 61, 80) = JacC( 61, 80) + dw( 67, 80)
      JacC( 80, 60) = JacC( 80, 60) - dw( 67, 60)
      JacC( 80, 80) = JacC( 80, 80) - dw( 67, 80)
      JacC( 55, 62) = JacC( 55, 62)+ 0.3040000000000000D-02*dw( 68, 62)
      JacC( 55, 80) = JacC( 55, 80)+ 0.3040000000000000D-02*dw( 68, 80)
      JacC( 62, 62) = JacC( 62, 62) - dw( 68, 62)
      JacC( 62, 80) = JacC( 62, 80) - dw( 68, 80)
      JacC( 68, 62) = JacC( 68, 62) + dw( 68, 62)
      JacC( 68, 80) = JacC( 68, 80) + dw( 68, 80)
      JacC( 80, 62) = JacC( 80, 62) - dw( 68, 62)
      JacC( 80, 80) = JacC( 80, 80) - dw( 68, 80)
      JacC( 26, 26) = JacC( 26, 26) - dw( 69, 26)
      JacC( 26, 80) = JacC( 26, 80) - dw( 69, 80)
      JacC( 58, 26) = JacC( 58, 26) + dw( 69, 26)
      JacC( 58, 80) = JacC( 58, 80) + dw( 69, 80)
      JacC( 80, 26) = JacC( 80, 26) - dw( 69, 26)
      JacC( 80, 80) = JacC( 80, 80) - dw( 69, 80)
      JacC( 19, 35) = JacC( 19, 35)+ 0.2320000000000000D+00*dw( 70, 35)
      JacC( 19, 80) = JacC( 19, 80)+ 0.2320000000000000D+00*dw( 70, 80)
      JacC( 20, 35) = JacC( 20, 35)+ 0.2880000000000000D-01*dw( 70, 35)
      JacC( 20, 80) = JacC( 20, 80)+ 0.2880000000000000D-01*dw( 70, 80)
      JacC( 35, 35) = JacC( 35, 35) - dw( 70, 35)
      JacC( 35, 80) = JacC( 35, 80) - dw( 70, 80)
      JacC( 58, 35) = JacC( 58, 35) + dw( 70, 35)
      JacC( 58, 80) = JacC( 58, 80) + dw( 70, 80)
      JacC( 59, 35) = JacC( 59, 35)+ 0.2300000000000000D+00*dw( 70, 35)
      JacC( 59, 80) = JacC( 59, 80)+ 0.2300000000000000D+00*dw( 70, 80)
      JacC( 79, 35) = JacC( 79, 35)+ 0.6200000000000000D+00*dw( 70, 35)
      JacC( 79, 80) = JacC( 79, 80)+ 0.6200000000000000D+00*dw( 70, 80)
      JacC( 80, 35) = JacC( 80, 35) - dw( 70, 35)
      JacC( 80, 80) = JacC( 80, 80) - dw( 70, 80)
      JacC( 27, 27) = JacC( 27, 27) - dw( 71, 27)
      JacC( 27, 80) = JacC( 27, 80) - dw( 71, 80)
      JacC( 28, 27) = JacC( 28, 27)+ 0.7639000000000000D-01*dw( 71, 27)
      JacC( 28, 80) = JacC( 28, 80)+ 0.7639000000000000D-01*dw( 71, 80)
      JacC( 31, 27) = JacC( 31, 27)+ 0.1642000000000000D+00*dw( 71, 27)
      JacC( 31, 80) = JacC( 31, 80)+ 0.1642000000000000D+00*dw( 71, 80)
      JacC( 32, 27) = JacC( 32, 27)+ 0.1169000000000000D+00*dw( 71, 27)
      JacC( 32, 80) = JacC( 32, 80)+ 0.1169000000000000D+00*dw( 71, 80)
      JacC( 69, 27) = JacC( 69, 27) + dw( 71, 27)
      JacC( 69, 80) = JacC( 69, 80) + dw( 71, 80)
      JacC( 80, 27) = JacC( 80, 27) - dw( 71, 27)
      JacC( 80, 80) = JacC( 80, 80) - dw( 71, 80)
      JacC( 28, 30) = JacC( 28, 30)+ 0.3100000000000000D-02*dw( 72, 30)
      JacC( 28, 80) = JacC( 28, 80)+ 0.3100000000000000D-02*dw( 72, 80)
      JacC( 29, 30) = JacC( 29, 30)+ 0.2330000000000000D-01*dw( 72, 30)
      JacC( 29, 80) = JacC( 29, 80)+ 0.2330000000000000D-01*dw( 72, 80)
      JacC( 30, 30) = JacC( 30, 30) - dw( 72, 30)
      JacC( 30, 80) = JacC( 30, 80) - dw( 72, 80)
      JacC( 31, 30) = JacC( 31, 30)+ 0.4064000000000000D+00*dw( 72, 30)
      JacC( 31, 80) = JacC( 31, 80)+ 0.4064000000000000D+00*dw( 72, 80)
      JacC( 32, 30) = JacC( 32, 30)+ 0.1731000000000000D+00*dw( 72, 30)
      JacC( 32, 80) = JacC( 32, 80)+ 0.1731000000000000D+00*dw( 72, 80)
      JacC( 52, 30) = JacC( 52, 30) + dw( 72, 30)
      JacC( 52, 80) = JacC( 52, 80) + dw( 72, 80)
      JacC( 80, 30) = JacC( 80, 30) - dw( 72, 30)
      JacC( 80, 80) = JacC( 80, 80) - dw( 72, 80)
      JacC(  7,  7) = JacC(  7,  7) - dw( 73,  7)
      JacC(  7, 80) = JacC(  7, 80) - dw( 73, 80)
      JacC( 22,  7) = JacC( 22,  7)+ 0.9000000000000000D+00*dw( 73,  7)
      JacC( 22, 80) = JacC( 22, 80)+ 0.9000000000000000D+00*dw( 73, 80)
      JacC( 75,  7) = JacC( 75,  7)+ 0.1000000000000000D+00*dw( 73,  7)
      JacC( 75, 80) = JacC( 75, 80)+ 0.1000000000000000D+00*dw( 73, 80)
      JacC( 80,  7) = JacC( 80,  7) - dw( 73,  7)
      JacC( 80, 80) = JacC( 80, 80) - dw( 73, 80)
      JacC( 88,  7) = JacC( 88,  7)+ 0.1000000000000000D+00*dw( 73,  7)
      JacC( 88, 80) = JacC( 88, 80)+ 0.1000000000000000D+00*dw( 73, 80)
      JacC(  8,  8) = JacC(  8,  8) - dw( 74,  8)
      JacC(  8, 80) = JacC(  8, 80) - dw( 74, 80)
      JacC( 23,  8) = JacC( 23,  8)+ 0.9000000000000000D+00*dw( 74,  8)
      JacC( 23, 80) = JacC( 23, 80)+ 0.9000000000000000D+00*dw( 74, 80)
      JacC( 75,  8) = JacC( 75,  8)+ 0.1000000000000000D+00*dw( 74,  8)
      JacC( 75, 80) = JacC( 75, 80)+ 0.1000000000000000D+00*dw( 74, 80)
      JacC( 80,  8) = JacC( 80,  8) - dw( 74,  8)
      JacC( 80, 80) = JacC( 80, 80) - dw( 74, 80)
      JacC( 88,  8) = JacC( 88,  8)+ 0.1000000000000000D+00*dw( 74,  8)
      JacC( 88, 80) = JacC( 88, 80)+ 0.1000000000000000D+00*dw( 74, 80)
      JacC( 36, 45) = JacC( 36, 45)+ 0.8500000000000000D+00*dw( 75, 45)
      JacC( 36, 80) = JacC( 36, 80)+ 0.8500000000000000D+00*dw( 75, 80)
      JacC( 39, 45) = JacC( 39, 45)+ 0.1000000000000000D+00*dw( 75, 45)
      JacC( 39, 80) = JacC( 39, 80)+ 0.1000000000000000D+00*dw( 75, 80)
      JacC( 45, 45) = JacC( 45, 45) - dw( 75, 45)
      JacC( 45, 80) = JacC( 45, 80) - dw( 75, 80)
      JacC( 46, 45) = JacC( 46, 45)+ 0.9000000000000000D-01*dw( 75, 45)
      JacC( 46, 80) = JacC( 46, 80)+ 0.9000000000000000D-01*dw( 75, 80)
      JacC( 55, 45) = JacC( 55, 45)+ 0.1400000000000000D-01*dw( 75, 45)
      JacC( 55, 80) = JacC( 55, 80)+ 0.1400000000000000D-01*dw( 75, 80)
      JacC( 75, 45) = JacC( 75, 45)+ 0.5000000000000000D-01*dw( 75, 45)
      JacC( 75, 80) = JacC( 75, 80)+ 0.5000000000000000D-01*dw( 75, 80)
      JacC( 80, 45) = JacC( 80, 45) - dw( 75, 45)
      JacC( 80, 80) = JacC( 80, 80) - dw( 75, 80)
      JacC( 88, 45) = JacC( 88, 45)+ 0.5000000000000000D-01*dw( 75, 45)
      JacC( 88, 80) = JacC( 88, 80)+ 0.5000000000000000D-01*dw( 75, 80)
      JacC( 67, 79) = JacC( 67, 79) + dw( 76, 79)
      JacC( 67, 80) = JacC( 67, 80) + dw( 76, 80)
      JacC( 79, 79) = JacC( 79, 79) - dw( 76, 79)
      JacC( 79, 80) = JacC( 79, 80) - dw( 76, 80)
      JacC( 80, 79) = JacC( 80, 79) - dw( 76, 79)
      JacC( 80, 80) = JacC( 80, 80) - dw( 76, 80)
      JacC( 88, 79) = JacC( 88, 79) + dw( 76, 79)
      JacC( 88, 80) = JacC( 88, 80) + dw( 76, 80)
      JacC( 80, 81) = JacC( 80, 81) - dw( 77, 81)
      JacC( 80, 80) = JacC( 80, 80) - dw( 77, 80)
      JacC( 81, 81) = JacC( 81, 81) - dw( 77, 81)
      JacC( 81, 80) = JacC( 81, 80) - dw( 77, 80)
      JacC( 89, 81) = JacC( 89, 81) + dw( 77, 81)
      JacC( 89, 80) = JacC( 89, 80) + dw( 77, 80)
      JacC( 70, 77) = JacC( 70, 77) + dw( 78, 77)
      JacC( 70, 80) = JacC( 70, 80) + dw( 78, 80)
      JacC( 77, 77) = JacC( 77, 77) - dw( 78, 77)
      JacC( 77, 80) = JacC( 77, 80) - dw( 78, 80)
      JacC( 80, 77) = JacC( 80, 77) - dw( 78, 77)
      JacC( 80, 80) = JacC( 80, 80) - dw( 78, 80)
      JacC( 47, 47) = JacC( 47, 47) - dw( 79, 47)
      JacC( 47, 80) = JacC( 47, 80) - dw( 79, 80)
      JacC( 72, 47) = JacC( 72, 47) + dw( 79, 47)
      JacC( 72, 80) = JacC( 72, 80) + dw( 79, 80)
      JacC( 80, 47) = JacC( 80, 47) - dw( 79, 47)
      JacC( 80, 80) = JacC( 80, 80) - dw( 79, 80)
      JacC( 88, 47) = JacC( 88, 47) + dw( 79, 47)
      JacC( 88, 80) = JacC( 88, 80) + dw( 79, 80)
      JacC( 66, 66) = JacC( 66, 66) - dw( 80, 66)
      JacC( 66, 80) = JacC( 66, 80) - dw( 80, 80)
      JacC( 67, 66) = JacC( 67, 66)+ 0.2000000000000000D+01*dw( 80, 66)
      JacC( 67, 80) = JacC( 67, 80)+ 0.2000000000000000D+01*dw( 80, 80)
      JacC( 80, 66) = JacC( 80, 66) - dw( 80, 66)
      JacC( 80, 80) = JacC( 80, 80) - dw( 80, 80)
      JacC( 88, 66) = JacC( 88, 66) + dw( 80, 66)
      JacC( 88, 80) = JacC( 88, 80) + dw( 80, 80)
      JacC( 67, 72) = JacC( 67, 72) + dw( 81, 72)
      JacC( 67, 80) = JacC( 67, 80) + dw( 81, 80)
      JacC( 72, 72) = JacC( 72, 72) - dw( 81, 72)
      JacC( 72, 80) = JacC( 72, 80) - dw( 81, 80)
      JacC( 80, 72) = JacC( 80, 72) - dw( 81, 72)
      JacC( 80, 80) = JacC( 80, 80) - dw( 81, 80)
      JacC( 89, 72) = JacC( 89, 72) + dw( 81, 72)
      JacC( 89, 80) = JacC( 89, 80) + dw( 81, 80)
      JacC( 47, 59) = JacC( 47, 59)+ 0.4100000000000000D+00*dw( 82, 59)
      JacC( 47, 80) = JacC( 47, 80)+ 0.4100000000000000D+00*dw( 82, 80)
      JacC( 59, 59) = JacC( 59, 59) - dw( 82, 59)
      JacC( 59, 80) = JacC( 59, 80) - dw( 82, 80)
      JacC( 67, 59) = JacC( 67, 59)+ 0.4100000000000000D+00*dw( 82, 59)
      JacC( 67, 80) = JacC( 67, 80)+ 0.4100000000000000D+00*dw( 82, 80)
      JacC( 72, 59) = JacC( 72, 59)+ 0.8000000000000000D-01*dw( 82, 59)
      JacC( 72, 80) = JacC( 72, 80)+ 0.8000000000000000D-01*dw( 82, 80)
      JacC( 75, 59) = JacC( 75, 59)+ 0.4900000000000000D+00*dw( 82, 59)
      JacC( 75, 80) = JacC( 75, 80)+ 0.4900000000000000D+00*dw( 82, 80)
      JacC( 79, 59) = JacC( 79, 59)+ 0.8000000000000000D-01*dw( 82, 59)
      JacC( 79, 80) = JacC( 79, 80)+ 0.8000000000000000D-01*dw( 82, 80)
      JacC( 80, 59) = JacC( 80, 59) - dw( 82, 59)
      JacC( 80, 80) = JacC( 80, 80) - dw( 82, 80)
      JacC( 86, 59) = JacC( 86, 59)+ 0.5100000000000000D+00*dw( 82, 59)
      JacC( 86, 80) = JacC( 86, 80)+ 0.5100000000000000D+00*dw( 82, 80)
      JacC( 88, 59) = JacC( 88, 59)+ 0.4900000000000000D+00*dw( 82, 59)
      JacC( 88, 80) = JacC( 88, 80)+ 0.4900000000000000D+00*dw( 82, 80)
      JacC( 18, 80) = JacC( 18, 80)+ 0.3500000000000000D+00*dw( 83, 80)
      JacC( 18, 54) = JacC( 18, 54)+ 0.3500000000000000D+00*dw( 83, 54)
      JacC( 54, 80) = JacC( 54, 80) - dw( 83, 80)
      JacC( 54, 54) = JacC( 54, 54) - dw( 83, 54)
      JacC( 66, 80) = JacC( 66, 80)+ 0.1500000000000000D+00*dw( 83, 80)
      JacC( 66, 54) = JacC( 66, 54)+ 0.1500000000000000D+00*dw( 83, 54)
      JacC( 72, 80) = JacC( 72, 80)+ 0.1500000000000000D+00*dw( 83, 80)
      JacC( 72, 54) = JacC( 72, 54)+ 0.1500000000000000D+00*dw( 83, 54)
      JacC( 75, 80) = JacC( 75, 80)+ 0.5000000000000000D+00*dw( 83, 80)
      JacC( 75, 54) = JacC( 75, 54)+ 0.5000000000000000D+00*dw( 83, 54)
      JacC( 80, 80) = JacC( 80, 80) - dw( 83, 80)
      JacC( 80, 54) = JacC( 80, 54) - dw( 83, 54)
      JacC( 86, 80) = JacC( 86, 80)+ 0.5000000000000000D+00*dw( 83, 80)
      JacC( 86, 54) = JacC( 86, 54)+ 0.5000000000000000D+00*dw( 83, 54)
      JacC( 88, 80) = JacC( 88, 80)+ 0.5000000000000000D+00*dw( 83, 80)
      JacC( 88, 54) = JacC( 88, 54)+ 0.5000000000000000D+00*dw( 83, 54)
      JacC( 18, 80) = JacC( 18, 80) - dw( 84, 80)
      JacC( 18, 18) = JacC( 18, 18) - dw( 84, 18)
      JacC( 77, 80) = JacC( 77, 80)+ 0.1200000000000000D+00*dw( 84, 80)
      JacC( 77, 18) = JacC( 77, 18)+ 0.1200000000000000D+00*dw( 84, 18)
      JacC( 80, 80) = JacC( 80, 80) - dw( 84, 80)
      JacC( 80, 18) = JacC( 80, 18) - dw( 84, 18)
      JacC( 81, 80) = JacC( 81, 80)+ 0.8800000000000000D+00*dw( 84, 80)
      JacC( 81, 18) = JacC( 81, 18)+ 0.8800000000000000D+00*dw( 84, 18)
      JacC( 88, 80) = JacC( 88, 80) + dw( 84, 80)
      JacC( 88, 18) = JacC( 88, 18) + dw( 84, 18)
      JacC( 21, 21) = JacC( 21, 21) - dw( 85, 21)
      JacC( 21, 80) = JacC( 21, 80) - dw( 85, 80)
      JacC( 79, 21) = JacC( 79, 21)+ 0.3500000000000000D+00*dw( 85, 21)
      JacC( 79, 80) = JacC( 79, 80)+ 0.3500000000000000D+00*dw( 85, 80)
      JacC( 80, 21) = JacC( 80, 21)- 0.6500000000000000D+00*dw( 85, 21)
      JacC( 80, 80) = JacC( 80, 80)- 0.6500000000000000D+00*dw( 85, 80)
      JacC( 82, 21) = JacC( 82, 21)+ 0.6500000000000000D+00*dw( 85, 21)
      JacC( 82, 80) = JacC( 82, 80)+ 0.6500000000000000D+00*dw( 85, 80)
      JacC( 73, 73) = JacC( 73, 73) - dw( 86, 73)
      JacC( 73, 80) = JacC( 73, 80) - dw( 86, 80)
      JacC( 75, 73) = JacC( 75, 73)+ 0.7000000000000001D-01*dw( 86, 73)
      JacC( 75, 80) = JacC( 75, 80)+ 0.7000000000000001D-01*dw( 86, 80)
      JacC( 76, 73) = JacC( 76, 73)+ 0.4400000000000000D+00*dw( 86, 73)
      JacC( 76, 80) = JacC( 76, 80)+ 0.4400000000000000D+00*dw( 86, 80)
      JacC( 77, 73) = JacC( 77, 73)+ 0.4100000000000000D+00*dw( 86, 73)
      JacC( 77, 80) = JacC( 77, 80)+ 0.4100000000000000D+00*dw( 86, 80)
      JacC( 80, 73) = JacC( 80, 73)- 0.5100000000000000D+00*dw( 86, 73)
      JacC( 80, 80) = JacC( 80, 80)- 0.5100000000000000D+00*dw( 86, 80)
      JacC( 81, 73) = JacC( 81, 73)+ 0.8000000000000000D-01*dw( 86, 73)
      JacC( 81, 80) = JacC( 81, 80)+ 0.8000000000000000D-01*dw( 86, 80)
      JacC( 38, 38) = JacC( 38, 38) - dw( 87, 38)
      JacC( 38, 80) = JacC( 38, 80) - dw( 87, 80)
      JacC( 75, 38) = JacC( 75, 38)+ 0.3500000000000000D+00*dw( 87, 38)
      JacC( 75, 80) = JacC( 75, 80)+ 0.3500000000000000D+00*dw( 87, 80)
      JacC( 79, 38) = JacC( 79, 38)+ 0.3500000000000000D+00*dw( 87, 38)
      JacC( 79, 80) = JacC( 79, 80)+ 0.3500000000000000D+00*dw( 87, 80)
      JacC( 80, 38) = JacC( 80, 38) - dw( 87, 38)
      JacC( 80, 80) = JacC( 80, 80) - dw( 87, 80)
      JacC( 88, 38) = JacC( 88, 38)+ 0.3500000000000000D+00*dw( 87, 38)
      JacC( 88, 80) = JacC( 88, 80)+ 0.3500000000000000D+00*dw( 87, 80)
      JacC( 89, 38) = JacC( 89, 38)+ 0.6500000000000000D+00*dw( 87, 38)
      JacC( 89, 80) = JacC( 89, 80)+ 0.6500000000000000D+00*dw( 87, 80)
      JacC( 50, 50) = JacC( 50, 50) - dw( 88, 50)
      JacC( 50, 80) = JacC( 50, 80) - dw( 88, 80)
      JacC( 75, 50) = JacC( 75, 50) + dw( 88, 50)
      JacC( 75, 80) = JacC( 75, 80) + dw( 88, 80)
      JacC( 79, 50) = JacC( 79, 50) + dw( 88, 50)
      JacC( 79, 80) = JacC( 79, 80) + dw( 88, 80)
      JacC( 80, 50) = JacC( 80, 50) - dw( 88, 50)
      JacC( 80, 80) = JacC( 80, 80) - dw( 88, 80)
      JacC( 87, 50) = JacC( 87, 50) + dw( 88, 50)
      JacC( 87, 80) = JacC( 87, 80) + dw( 88, 80)
      JacC( 47, 48) = JacC( 47, 48)+ 0.6000000000000000D+00*dw( 89, 48)
      JacC( 47, 80) = JacC( 47, 80)+ 0.6000000000000000D+00*dw( 89, 80)
      JacC( 48, 48) = JacC( 48, 48) - dw( 89, 48)
      JacC( 48, 80) = JacC( 48, 80) - dw( 89, 80)
      JacC( 50, 48) = JacC( 50, 48)+ 0.4000000000000000D+00*dw( 89, 48)
      JacC( 50, 80) = JacC( 50, 80)+ 0.4000000000000000D+00*dw( 89, 80)
      JacC( 75, 48) = JacC( 75, 48) + dw( 89, 48)
      JacC( 75, 80) = JacC( 75, 80) + dw( 89, 80)
      JacC( 79, 48) = JacC( 79, 48)+ 0.4000000000000000D+00*dw( 89, 48)
      JacC( 79, 80) = JacC( 79, 80)+ 0.4000000000000000D+00*dw( 89, 80)
      JacC( 80, 48) = JacC( 80, 48) - dw( 89, 48)
      JacC( 80, 80) = JacC( 80, 80) - dw( 89, 80)
      JacC( 87, 48) = JacC( 87, 48)+ 0.6000000000000000D+00*dw( 89, 48)
      JacC( 87, 80) = JacC( 87, 80)+ 0.6000000000000000D+00*dw( 89, 80)
      JacC( 88, 48) = JacC( 88, 48)+ 0.4000000000000000D+00*dw( 89, 48)
      JacC( 88, 80) = JacC( 88, 80)+ 0.4000000000000000D+00*dw( 89, 80)
      JacC( 76, 83) = JacC( 76, 83) + dw( 90, 83)
      JacC( 76, 80) = JacC( 76, 80) + dw( 90, 80)
      JacC( 80, 83) = JacC( 80, 83) - dw( 90, 83)
      JacC( 80, 80) = JacC( 80, 80) - dw( 90, 80)
      JacC( 83, 83) = JacC( 83, 83) - dw( 90, 83)
      JacC( 83, 80) = JacC( 83, 80) - dw( 90, 80)
      JacC( 84, 83) = JacC( 84, 83) + dw( 90, 83)
      JacC( 84, 80) = JacC( 84, 80) + dw( 90, 80)
      JacC( 67, 79) = JacC( 67, 79) + dw( 91, 79)
      JacC( 67, 87) = JacC( 67, 87) + dw( 91, 87)
      JacC( 74, 79) = JacC( 74, 79) + dw( 91, 79)
      JacC( 74, 87) = JacC( 74, 87) + dw( 91, 87)
      JacC( 79, 79) = JacC( 79, 79) - dw( 91, 79)
      JacC( 79, 87) = JacC( 79, 87) - dw( 91, 87)
      JacC( 87, 79) = JacC( 87, 79) - dw( 91, 79)
      JacC( 87, 87) = JacC( 87, 87) - dw( 91, 87)
      JacC( 88, 79) = JacC( 88, 79) + dw( 91, 79)
      JacC( 88, 87) = JacC( 88, 87) + dw( 91, 87)
      JacC( 74, 81) = JacC( 74, 81) + dw( 92, 81)
      JacC( 74, 87) = JacC( 74, 87) + dw( 92, 87)
      JacC( 81, 81) = JacC( 81, 81) - dw( 92, 81)
      JacC( 81, 87) = JacC( 81, 87) - dw( 92, 87)
      JacC( 87, 81) = JacC( 87, 81) - dw( 92, 81)
      JacC( 87, 87) = JacC( 87, 87) - dw( 92, 87)
      JacC( 89, 81) = JacC( 89, 81) + dw( 92, 81)
      JacC( 89, 87) = JacC( 89, 87) + dw( 92, 87)
      JacC( 66, 66) = JacC( 66, 66) - dw( 93, 66)
      JacC( 66, 87) = JacC( 66, 87) - dw( 93, 87)
      JacC( 67, 66) = JacC( 67, 66)+ 0.2000000000000000D+01*dw( 93, 66)
      JacC( 67, 87) = JacC( 67, 87)+ 0.2000000000000000D+01*dw( 93, 87)
      JacC( 74, 66) = JacC( 74, 66) + dw( 93, 66)
      JacC( 74, 87) = JacC( 74, 87) + dw( 93, 87)
      JacC( 87, 66) = JacC( 87, 66) - dw( 93, 66)
      JacC( 87, 87) = JacC( 87, 87) - dw( 93, 87)
      JacC( 88, 66) = JacC( 88, 66) + dw( 93, 66)
      JacC( 88, 87) = JacC( 88, 87) + dw( 93, 87)
      JacC( 67, 72) = JacC( 67, 72) + dw( 94, 72)
      JacC( 67, 87) = JacC( 67, 87) + dw( 94, 87)
      JacC( 72, 72) = JacC( 72, 72) - dw( 94, 72)
      JacC( 72, 87) = JacC( 72, 87) - dw( 94, 87)
      JacC( 74, 72) = JacC( 74, 72) + dw( 94, 72)
      JacC( 74, 87) = JacC( 74, 87) + dw( 94, 87)
      JacC( 87, 72) = JacC( 87, 72) - dw( 94, 72)
      JacC( 87, 87) = JacC( 87, 87) - dw( 94, 87)
      JacC( 89, 72) = JacC( 89, 72) + dw( 94, 72)
      JacC( 89, 87) = JacC( 89, 87) + dw( 94, 87)
      JacC( 59, 59) = JacC( 59, 59) - dw( 95, 59)
      JacC( 59, 87) = JacC( 59, 87) - dw( 95, 87)
      JacC( 64, 59) = JacC( 64, 59)+ 0.8000000000000000D+00*dw( 95, 59)
      JacC( 64, 87) = JacC( 64, 87)+ 0.8000000000000000D+00*dw( 95, 87)
      JacC( 67, 59) = JacC( 67, 59)+ 0.8000000000000000D+00*dw( 95, 59)
      JacC( 67, 87) = JacC( 67, 87)+ 0.8000000000000000D+00*dw( 95, 87)
      JacC( 74, 59) = JacC( 74, 59)+ 0.2000000000000000D+00*dw( 95, 59)
      JacC( 74, 87) = JacC( 74, 87)+ 0.2000000000000000D+00*dw( 95, 87)
      JacC( 86, 59) = JacC( 86, 59)+ 0.2000000000000000D+00*dw( 95, 59)
      JacC( 86, 87) = JacC( 86, 87)+ 0.2000000000000000D+00*dw( 95, 87)
      JacC( 87, 59) = JacC( 87, 59) - dw( 95, 59)
      JacC( 87, 87) = JacC( 87, 87) - dw( 95, 87)
      JacC( 54, 54) = JacC( 54, 54) - dw( 96, 54)
      JacC( 54, 87) = JacC( 54, 87) - dw( 96, 87)
      JacC( 66, 54) = JacC( 66, 54)+ 0.2500000000000000D+00*dw( 96, 54)
      JacC( 66, 87) = JacC( 66, 87)+ 0.2500000000000000D+00*dw( 96, 87)
      JacC( 72, 54) = JacC( 72, 54)+ 0.2500000000000000D+00*dw( 96, 54)
      JacC( 72, 87) = JacC( 72, 87)+ 0.2500000000000000D+00*dw( 96, 87)
      JacC( 74, 54) = JacC( 74, 54)+ 0.5000000000000000D+00*dw( 96, 54)
      JacC( 74, 87) = JacC( 74, 87)+ 0.5000000000000000D+00*dw( 96, 87)
      JacC( 75, 54) = JacC( 75, 54)+ 0.5000000000000000D+00*dw( 96, 54)
      JacC( 75, 87) = JacC( 75, 87)+ 0.5000000000000000D+00*dw( 96, 87)
      JacC( 77, 54) = JacC( 77, 54)+ 0.3000000000000000D-01*dw( 96, 54)
      JacC( 77, 87) = JacC( 77, 87)+ 0.3000000000000000D-01*dw( 96, 87)
      JacC( 81, 54) = JacC( 81, 54)+ 0.2500000000000000D+00*dw( 96, 54)
      JacC( 81, 87) = JacC( 81, 87)+ 0.2500000000000000D+00*dw( 96, 87)
      JacC( 84, 54) = JacC( 84, 54)+ 0.5000000000000000D+00*dw( 96, 54)
      JacC( 84, 87) = JacC( 84, 87)+ 0.5000000000000000D+00*dw( 96, 87)
      JacC( 86, 54) = JacC( 86, 54)+ 0.5000000000000000D+00*dw( 96, 54)
      JacC( 86, 87) = JacC( 86, 87)+ 0.5000000000000000D+00*dw( 96, 87)
      JacC( 87, 54) = JacC( 87, 54) - dw( 96, 54)
      JacC( 87, 87) = JacC( 87, 87) - dw( 96, 87)
      JacC( 88, 54) = JacC( 88, 54)+ 0.5000000000000000D+00*dw( 96, 54)
      JacC( 88, 87) = JacC( 88, 87)+ 0.5000000000000000D+00*dw( 96, 87)
      JacC( 39, 45) = JacC( 39, 45) + dw( 97, 45)
      JacC( 39, 87) = JacC( 39, 87) + dw( 97, 87)
      JacC( 45, 45) = JacC( 45, 45) - dw( 97, 45)
      JacC( 45, 87) = JacC( 45, 87) - dw( 97, 87)
      JacC( 46, 45) = JacC( 46, 45)+ 0.1200000000000000D+00*dw( 97, 45)
      JacC( 46, 87) = JacC( 46, 87)+ 0.1200000000000000D+00*dw( 97, 87)
      JacC( 55, 45) = JacC( 55, 45)+ 0.4000000000000000D-01*dw( 97, 45)
      JacC( 55, 87) = JacC( 55, 87)+ 0.4000000000000000D-01*dw( 97, 87)
      JacC( 74, 45) = JacC( 74, 45) + dw( 97, 45)
      JacC( 74, 87) = JacC( 74, 87) + dw( 97, 87)
      JacC( 87, 45) = JacC( 87, 45) - dw( 97, 45)
      JacC( 87, 87) = JacC( 87, 87) - dw( 97, 87)
      JacC( 25, 25) = JacC( 25, 25) - dw( 98, 25)
      JacC( 25, 87) = JacC( 25, 87) - dw( 98, 87)
      JacC( 63, 25) = JacC( 63, 25)+ 0.2000000000000000D+00*dw( 98, 25)
      JacC( 63, 87) = JacC( 63, 87)+ 0.2000000000000000D+00*dw( 98, 87)
      JacC( 64, 25) = JacC( 64, 25)+ 0.8000000000000000D+00*dw( 98, 25)
      JacC( 64, 87) = JacC( 64, 87)+ 0.8000000000000000D+00*dw( 98, 87)
      JacC( 87, 25) = JacC( 87, 25) - dw( 98, 25)
      JacC( 87, 87) = JacC( 87, 87) - dw( 98, 87)
      JacC( 55, 60) = JacC( 55, 60)+ 0.1600000000000000D-02*dw( 99, 60)
      JacC( 55, 87) = JacC( 55, 87)+ 0.1600000000000000D-02*dw( 99, 87)
      JacC( 60, 60) = JacC( 60, 60) - dw( 99, 60)
      JacC( 60, 87) = JacC( 60, 87) - dw( 99, 87)
      JacC( 63, 60) = JacC( 63, 60)+ 0.5700000000000000D+00*dw( 99, 60)
      JacC( 63, 87) = JacC( 63, 87)+ 0.5700000000000000D+00*dw( 99, 87)
      JacC( 64, 60) = JacC( 64, 60)+ 0.4300000000000000D+00*dw( 99, 60)
      JacC( 64, 87) = JacC( 64, 87)+ 0.4300000000000000D+00*dw( 99, 87)
      JacC( 87, 60) = JacC( 87, 60) - dw( 99, 60)
      JacC( 87, 87) = JacC( 87, 87) - dw( 99, 87)
      JacC( 55, 62) = JacC( 55, 62)+ 0.3040000000000000D-02*dw(100, 62)
      JacC( 55, 87) = JacC( 55, 87)+ 0.3040000000000000D-02*dw(100, 87)
      JacC( 62, 62) = JacC( 62, 62) - dw(100, 62)
      JacC( 62, 87) = JacC( 62, 87) - dw(100, 87)
      JacC( 63, 62) = JacC( 63, 62)+ 0.8900000000000000D+00*dw(100, 62)
      JacC( 63, 87) = JacC( 63, 87)+ 0.8900000000000000D+00*dw(100, 87)
      JacC( 64, 62) = JacC( 64, 62)+ 0.1100000000000000D+00*dw(100, 62)
      JacC( 64, 87) = JacC( 64, 87)+ 0.1100000000000000D+00*dw(100, 87)
      JacC( 87, 62) = JacC( 87, 62) - dw(100, 62)
      JacC( 87, 87) = JacC( 87, 87) - dw(100, 87)
      JacC( 26, 26) = JacC( 26, 26) - dw(101, 26)
      JacC( 26, 87) = JacC( 26, 87) - dw(101, 87)
      JacC( 59, 26) = JacC( 59, 26)+ 0.9000000000000000D+00*dw(101, 26)
      JacC( 59, 87) = JacC( 59, 87)+ 0.9000000000000000D+00*dw(101, 87)
      JacC( 63, 26) = JacC( 63, 26)+ 0.1000000000000000D+00*dw(101, 26)
      JacC( 63, 87) = JacC( 63, 87)+ 0.1000000000000000D+00*dw(101, 87)
      JacC( 64, 26) = JacC( 64, 26)+ 0.9000000000000000D+00*dw(101, 26)
      JacC( 64, 87) = JacC( 64, 87)+ 0.9000000000000000D+00*dw(101, 87)
      JacC( 87, 26) = JacC( 87, 26) - dw(101, 26)
      JacC( 87, 87) = JacC( 87, 87) - dw(101, 87)
      JacC( 35, 35) = JacC( 35, 35) - dw(102, 35)
      JacC( 35, 87) = JacC( 35, 87) - dw(102, 87)
      JacC( 59, 35) = JacC( 59, 35)+ 0.9000000000000000D+00*dw(102, 35)
      JacC( 59, 87) = JacC( 59, 87)+ 0.9000000000000000D+00*dw(102, 87)
      JacC( 63, 35) = JacC( 63, 35)+ 0.1000000000000000D+00*dw(102, 35)
      JacC( 63, 87) = JacC( 63, 87)+ 0.1000000000000000D+00*dw(102, 87)
      JacC( 64, 35) = JacC( 64, 35)+ 0.9000000000000000D+00*dw(102, 35)
      JacC( 64, 87) = JacC( 64, 87)+ 0.9000000000000000D+00*dw(102, 87)
      JacC( 87, 35) = JacC( 87, 35) - dw(102, 35)
      JacC( 87, 87) = JacC( 87, 87) - dw(102, 87)
      JacC( 27, 27) = JacC( 27, 27) - dw(103, 27)
      JacC( 27, 87) = JacC( 27, 87) - dw(103, 87)
      JacC( 29, 27) = JacC( 29, 27)+ 0.8000000000000000D+00*dw(103, 27)
      JacC( 29, 87) = JacC( 29, 87)+ 0.8000000000000000D+00*dw(103, 87)
      JacC( 63, 27) = JacC( 63, 27)+ 0.9000000000000000D+00*dw(103, 27)
      JacC( 63, 87) = JacC( 63, 87)+ 0.9000000000000000D+00*dw(103, 87)
      JacC( 64, 27) = JacC( 64, 27)+ 0.1000000000000000D+00*dw(103, 27)
      JacC( 64, 87) = JacC( 64, 87)+ 0.1000000000000000D+00*dw(103, 87)
      JacC( 87, 27) = JacC( 87, 27) - dw(103, 27)
      JacC( 87, 87) = JacC( 87, 87) - dw(103, 87)
      JacC( 30, 30) = JacC( 30, 30) - dw(104, 30)
      JacC( 30, 87) = JacC( 30, 87) - dw(104, 87)
      JacC( 31, 30) = JacC( 31, 30)+ 0.3076000000000000D+00*dw(104, 30)
      JacC( 31, 87) = JacC( 31, 87)+ 0.3076000000000000D+00*dw(104, 87)
      JacC( 32, 30) = JacC( 32, 30)+ 0.2050000000000000D-01*dw(104, 30)
      JacC( 32, 87) = JacC( 32, 87)+ 0.2050000000000000D-01*dw(104, 87)
      JacC( 63, 30) = JacC( 63, 30)+ 0.8700000000000000D+00*dw(104, 30)
      JacC( 63, 87) = JacC( 63, 87)+ 0.8700000000000000D+00*dw(104, 87)
      JacC( 64, 30) = JacC( 64, 30)+ 0.1300000000000000D+00*dw(104, 30)
      JacC( 64, 87) = JacC( 64, 87)+ 0.1300000000000000D+00*dw(104, 87)
      JacC( 87, 30) = JacC( 87, 30) - dw(104, 30)
      JacC( 87, 87) = JacC( 87, 87) - dw(104, 87)
      JacC( 48, 48) = JacC( 48, 48) - dw(105, 48)
      JacC( 48, 87) = JacC( 48, 87) - dw(105, 87)
      JacC( 50, 48) = JacC( 50, 48)+ 0.4000000000000000D+00*dw(105, 48)
      JacC( 50, 87) = JacC( 50, 87)+ 0.4000000000000000D+00*dw(105, 87)
      JacC( 75, 48) = JacC( 75, 48) + dw(105, 48)
      JacC( 75, 87) = JacC( 75, 87) + dw(105, 87)
      JacC( 79, 48) = JacC( 79, 48)+ 0.4000000000000000D+00*dw(105, 48)
      JacC( 79, 87) = JacC( 79, 87)+ 0.4000000000000000D+00*dw(105, 87)
      JacC( 83, 48) = JacC( 83, 48)+ 0.6000000000000000D+00*dw(105, 48)
      JacC( 83, 87) = JacC( 83, 87)+ 0.6000000000000000D+00*dw(105, 87)
      JacC( 84, 48) = JacC( 84, 48)+ 0.4000000000000000D+00*dw(105, 48)
      JacC( 84, 87) = JacC( 84, 87)+ 0.4000000000000000D+00*dw(105, 87)
      JacC( 87, 48) = JacC( 87, 48)- 0.4000000000000000D+00*dw(105, 48)
      JacC( 87, 87) = JacC( 87, 87)- 0.4000000000000000D+00*dw(105, 87)
      JacC( 25, 25) = JacC( 25, 25) - dw(106, 25)
      JacC( 25, 65) = JacC( 25, 65) - dw(106, 65)
      JacC( 49, 25) = JacC( 49, 25)+ 0.3700000000000000D+00*dw(106, 25)
      JacC( 49, 65) = JacC( 49, 65)+ 0.3700000000000000D+00*dw(106, 65)
      JacC( 65, 25) = JacC( 65, 25) - dw(106, 25)
      JacC( 65, 65) = JacC( 65, 65) - dw(106, 65)
      JacC( 67, 25) = JacC( 67, 25)+ 0.4300000000000000D+00*dw(106, 25)
      JacC( 67, 65) = JacC( 67, 65)+ 0.4300000000000000D+00*dw(106, 65)
      JacC( 79, 25) = JacC( 79, 25) + dw(106, 25)
      JacC( 79, 65) = JacC( 79, 65) + dw(106, 65)
      JacC( 80, 25) = JacC( 80, 25)+ 0.1200000000000000D+00*dw(106, 25)
      JacC( 80, 65) = JacC( 80, 65)+ 0.1200000000000000D+00*dw(106, 65)
      JacC( 88, 25) = JacC( 88, 25)+ 0.2600000000000000D+00*dw(106, 25)
      JacC( 88, 65) = JacC( 88, 65)+ 0.2600000000000000D+00*dw(106, 65)
      JacC( 34, 60) = JacC( 34, 60)+ 0.3000000000000000D-01*dw(107, 60)
      JacC( 34, 65) = JacC( 34, 65)+ 0.3000000000000000D-01*dw(107, 65)
      JacC( 37, 60) = JacC( 37, 60)+ 0.6000000000000000D-01*dw(107, 60)
      JacC( 37, 65) = JacC( 37, 65)+ 0.6000000000000000D-01*dw(107, 65)
      JacC( 44, 60) = JacC( 44, 60)+ 0.6000000000000000D-02*dw(107, 60)
      JacC( 44, 65) = JacC( 44, 65)+ 0.6000000000000000D-02*dw(107, 65)
      JacC( 49, 60) = JacC( 49, 60)+ 0.1400000000000000D+00*dw(107, 60)
      JacC( 49, 65) = JacC( 49, 65)+ 0.1400000000000000D+00*dw(107, 65)
      JacC( 55, 60) = JacC( 55, 60)+ 0.1600000000000000D-02*dw(107, 60)
      JacC( 55, 65) = JacC( 55, 65)+ 0.1600000000000000D-02*dw(107, 65)
      JacC( 60, 60) = JacC( 60, 60) - dw(107, 60)
      JacC( 60, 65) = JacC( 60, 65) - dw(107, 65)
      JacC( 65, 60) = JacC( 65, 60) - dw(107, 60)
      JacC( 65, 65) = JacC( 65, 65) - dw(107, 65)
      JacC( 67, 60) = JacC( 67, 60)+ 0.3700000000000000D+00*dw(107, 60)
      JacC( 67, 65) = JacC( 67, 65)+ 0.3700000000000000D+00*dw(107, 65)
      JacC( 70, 60) = JacC( 70, 60)+ 0.3000000000000000D-01*dw(107, 60)
      JacC( 70, 65) = JacC( 70, 65)+ 0.3000000000000000D-01*dw(107, 65)
      JacC( 71, 60) = JacC( 71, 60)+ 0.1000000000000000D+00*dw(107, 60)
      JacC( 71, 65) = JacC( 71, 65)+ 0.1000000000000000D+00*dw(107, 65)
      JacC( 77, 60) = JacC( 77, 60)+ 0.3000000000000000D-01*dw(107, 60)
      JacC( 77, 65) = JacC( 77, 65)+ 0.3000000000000000D-01*dw(107, 65)
      JacC( 78, 60) = JacC( 78, 60)+ 0.1000000000000000D+00*dw(107, 60)
      JacC( 78, 65) = JacC( 78, 65)+ 0.1000000000000000D+00*dw(107, 65)
      JacC( 79, 60) = JacC( 79, 60)+ 0.6400000000000000D+00*dw(107, 60)
      JacC( 79, 65) = JacC( 79, 65)+ 0.6400000000000000D+00*dw(107, 65)
      JacC( 80, 60) = JacC( 80, 60)+ 0.4000000000000000D+00*dw(107, 60)
      JacC( 80, 65) = JacC( 80, 65)+ 0.4000000000000000D+00*dw(107, 65)
      JacC( 81, 60) = JacC( 81, 60)+ 0.4400000000000000D+00*dw(107, 60)
      JacC( 81, 65) = JacC( 81, 65)+ 0.4400000000000000D+00*dw(107, 65)
      JacC( 82, 60) = JacC( 82, 60)+ 0.1900000000000000D+00*dw(107, 60)
      JacC( 82, 65) = JacC( 82, 65)+ 0.1900000000000000D+00*dw(107, 65)
      JacC( 88, 60) = JacC( 88, 60)+ 0.2500000000000000D+00*dw(107, 60)
      JacC( 88, 65) = JacC( 88, 65)+ 0.2500000000000000D+00*dw(107, 65)
      JacC( 34, 62) = JacC( 34, 62)+ 0.6000000000000000D-01*dw(108, 62)
      JacC( 34, 65) = JacC( 34, 65)+ 0.6000000000000000D-01*dw(108, 65)
      JacC( 37, 62) = JacC( 37, 62)+ 0.7000000000000001D-01*dw(108, 62)
      JacC( 37, 65) = JacC( 37, 65)+ 0.7000000000000001D-01*dw(108, 65)
      JacC( 44, 62) = JacC( 44, 62)+ 0.1100000000000000D-01*dw(108, 62)
      JacC( 44, 65) = JacC( 44, 65)+ 0.1100000000000000D-01*dw(108, 65)
      JacC( 55, 62) = JacC( 55, 62)+ 0.3040000000000000D-02*dw(108, 62)
      JacC( 55, 65) = JacC( 55, 65)+ 0.3040000000000000D-02*dw(108, 65)
      JacC( 62, 62) = JacC( 62, 62) - dw(108, 62)
      JacC( 62, 65) = JacC( 62, 65) - dw(108, 65)
      JacC( 65, 62) = JacC( 65, 62) - dw(108, 62)
      JacC( 65, 65) = JacC( 65, 65) - dw(108, 65)
      JacC( 67, 62) = JacC( 67, 62)+ 0.3000000000000000D+00*dw(108, 62)
      JacC( 67, 65) = JacC( 67, 65)+ 0.3000000000000000D+00*dw(108, 65)
      JacC( 70, 62) = JacC( 70, 62)+ 0.1200000000000000D+00*dw(108, 62)
      JacC( 70, 65) = JacC( 70, 65)+ 0.1200000000000000D+00*dw(108, 65)
      JacC( 71, 62) = JacC( 71, 62)+ 0.1400000000000000D+00*dw(108, 62)
      JacC( 71, 65) = JacC( 71, 65)+ 0.1400000000000000D+00*dw(108, 65)
      JacC( 77, 62) = JacC( 77, 62)+ 0.1600000000000000D+00*dw(108, 62)
      JacC( 77, 65) = JacC( 77, 65)+ 0.1600000000000000D+00*dw(108, 65)
      JacC( 78, 62) = JacC( 78, 62)+ 0.1800000000000000D+00*dw(108, 62)
      JacC( 78, 65) = JacC( 78, 65)+ 0.1800000000000000D+00*dw(108, 65)
      JacC( 79, 62) = JacC( 79, 62)+ 0.2000000000000000D-01*dw(108, 62)
      JacC( 79, 65) = JacC( 79, 65)+ 0.2000000000000000D-01*dw(108, 65)
      JacC( 80, 62) = JacC( 80, 62)+ 0.6300000000000000D+00*dw(108, 62)
      JacC( 80, 65) = JacC( 80, 65)+ 0.6300000000000000D+00*dw(108, 65)
      JacC( 81, 62) = JacC( 81, 62)+ 0.9900000000000000D+00*dw(108, 62)
      JacC( 81, 65) = JacC( 81, 65)+ 0.9900000000000000D+00*dw(108, 65)
      JacC( 82, 62) = JacC( 82, 62)+ 0.2300000000000000D+00*dw(108, 62)
      JacC( 82, 65) = JacC( 82, 65)+ 0.2300000000000000D+00*dw(108, 65)
      JacC( 88, 62) = JacC( 88, 62)+ 0.2200000000000000D+00*dw(108, 62)
      JacC( 88, 65) = JacC( 88, 65)+ 0.2200000000000000D+00*dw(108, 65)
      JacC( 26, 26) = JacC( 26, 26) - dw(109, 26)
      JacC( 26, 65) = JacC( 26, 65) - dw(109, 65)
      JacC( 43, 26) = JacC( 43, 26)+ 0.9000000000000000D-01*dw(109, 26)
      JacC( 43, 65) = JacC( 43, 65)+ 0.9000000000000000D-01*dw(109, 65)
      JacC( 44, 26) = JacC( 44, 26)+ 0.1000000000000000D-02*dw(109, 26)
      JacC( 44, 65) = JacC( 44, 65)+ 0.1000000000000000D-02*dw(109, 65)
      JacC( 49, 26) = JacC( 49, 26)+ 0.1500000000000000D+00*dw(109, 26)
      JacC( 49, 65) = JacC( 49, 65)+ 0.1500000000000000D+00*dw(109, 65)
      JacC( 59, 26) = JacC( 59, 26)+ 0.3900000000000000D+00*dw(109, 26)
      JacC( 59, 65) = JacC( 59, 65)+ 0.3900000000000000D+00*dw(109, 65)
      JacC( 60, 26) = JacC( 60, 26)+ 0.3500000000000000D+00*dw(109, 26)
      JacC( 60, 65) = JacC( 60, 65)+ 0.3500000000000000D+00*dw(109, 65)
      JacC( 65, 26) = JacC( 65, 26) - dw(109, 26)
      JacC( 65, 65) = JacC( 65, 65) - dw(109, 65)
      JacC( 67, 26) = JacC( 67, 26)+ 0.3600000000000000D+00*dw(109, 26)
      JacC( 67, 65) = JacC( 67, 65)+ 0.3600000000000000D+00*dw(109, 65)
      JacC( 70, 26) = JacC( 70, 26)+ 0.2000000000000000D-01*dw(109, 26)
      JacC( 70, 65) = JacC( 70, 65)+ 0.2000000000000000D-01*dw(109, 65)
      JacC( 75, 26) = JacC( 75, 26)+ 0.1300000000000000D+00*dw(109, 26)
      JacC( 75, 65) = JacC( 75, 65)+ 0.1300000000000000D+00*dw(109, 65)
      JacC( 79, 26) = JacC( 79, 26)+ 0.9000000000000000D+00*dw(109, 26)
      JacC( 79, 65) = JacC( 79, 65)+ 0.9000000000000000D+00*dw(109, 65)
      JacC( 80, 26) = JacC( 80, 26)+ 0.2800000000000000D+00*dw(109, 26)
      JacC( 80, 65) = JacC( 80, 65)+ 0.2800000000000000D+00*dw(109, 65)
      JacC( 82, 26) = JacC( 82, 26)+ 0.3000000000000000D-01*dw(109, 26)
      JacC( 82, 65) = JacC( 82, 65)+ 0.3000000000000000D-01*dw(109, 65)
      JacC( 88, 26) = JacC( 88, 26)+ 0.3000000000000000D+00*dw(109, 26)
      JacC( 88, 65) = JacC( 88, 65)+ 0.3000000000000000D+00*dw(109, 65)
      JacC( 89, 26) = JacC( 89, 26)+ 0.1500000000000000D+00*dw(109, 26)
      JacC( 89, 65) = JacC( 89, 65)+ 0.1500000000000000D+00*dw(109, 65)
      JacC( 35, 35) = JacC( 35, 35) - dw(110, 35)
      JacC( 35, 65) = JacC( 35, 65) - dw(110, 65)
      JacC( 43, 35) = JacC( 43, 35)+ 0.9000000000000000D-01*dw(110, 35)
      JacC( 43, 65) = JacC( 43, 65)+ 0.9000000000000000D-01*dw(110, 65)
      JacC( 44, 35) = JacC( 44, 35)+ 0.1000000000000000D-02*dw(110, 35)
      JacC( 44, 65) = JacC( 44, 65)+ 0.1000000000000000D-02*dw(110, 65)
      JacC( 49, 35) = JacC( 49, 35)+ 0.1500000000000000D+00*dw(110, 35)
      JacC( 49, 65) = JacC( 49, 65)+ 0.1500000000000000D+00*dw(110, 65)
      JacC( 59, 35) = JacC( 59, 35)+ 0.3900000000000000D+00*dw(110, 35)
      JacC( 59, 65) = JacC( 59, 65)+ 0.3900000000000000D+00*dw(110, 65)
      JacC( 60, 35) = JacC( 60, 35)+ 0.3500000000000000D+00*dw(110, 35)
      JacC( 60, 65) = JacC( 60, 65)+ 0.3500000000000000D+00*dw(110, 65)
      JacC( 65, 35) = JacC( 65, 35) - dw(110, 35)
      JacC( 65, 65) = JacC( 65, 65) - dw(110, 65)
      JacC( 67, 35) = JacC( 67, 35)+ 0.3600000000000000D+00*dw(110, 35)
      JacC( 67, 65) = JacC( 67, 65)+ 0.3600000000000000D+00*dw(110, 65)
      JacC( 70, 35) = JacC( 70, 35)+ 0.2000000000000000D-01*dw(110, 35)
      JacC( 70, 65) = JacC( 70, 65)+ 0.2000000000000000D-01*dw(110, 65)
      JacC( 75, 35) = JacC( 75, 35)+ 0.1300000000000000D+00*dw(110, 35)
      JacC( 75, 65) = JacC( 75, 65)+ 0.1300000000000000D+00*dw(110, 65)
      JacC( 79, 35) = JacC( 79, 35)+ 0.9000000000000000D+00*dw(110, 35)
      JacC( 79, 65) = JacC( 79, 65)+ 0.9000000000000000D+00*dw(110, 65)
      JacC( 80, 35) = JacC( 80, 35)+ 0.2800000000000000D+00*dw(110, 35)
      JacC( 80, 65) = JacC( 80, 65)+ 0.2800000000000000D+00*dw(110, 65)
      JacC( 82, 35) = JacC( 82, 35)+ 0.3000000000000000D-01*dw(110, 35)
      JacC( 82, 65) = JacC( 82, 65)+ 0.3000000000000000D-01*dw(110, 65)
      JacC( 88, 35) = JacC( 88, 35)+ 0.3000000000000000D+00*dw(110, 35)
      JacC( 88, 65) = JacC( 88, 65)+ 0.3000000000000000D+00*dw(110, 65)
      JacC( 89, 35) = JacC( 89, 35)+ 0.1500000000000000D+00*dw(110, 35)
      JacC( 89, 65) = JacC( 89, 65)+ 0.1500000000000000D+00*dw(110, 65)
      JacC( 27, 27) = JacC( 27, 27) - dw(111, 27)
      JacC( 27, 65) = JacC( 27, 65) - dw(111, 65)
      JacC( 28, 27) = JacC( 28, 27)+ 0.4410000000000000D-01*dw(111, 27)
      JacC( 28, 65) = JacC( 28, 65)+ 0.4410000000000000D-01*dw(111, 65)
      JacC( 31, 27) = JacC( 31, 27)+ 0.1269000000000000D+00*dw(111, 27)
      JacC( 31, 65) = JacC( 31, 65)+ 0.1269000000000000D+00*dw(111, 65)
      JacC( 32, 27) = JacC( 32, 27)+ 0.1423000000000000D+00*dw(111, 27)
      JacC( 32, 65) = JacC( 32, 65)+ 0.1423000000000000D+00*dw(111, 65)
      JacC( 44, 27) = JacC( 44, 27)+ 0.2000000000000000D-01*dw(111, 27)
      JacC( 44, 65) = JacC( 44, 65)+ 0.2000000000000000D-01*dw(111, 65)
      JacC( 65, 27) = JacC( 65, 27) - dw(111, 27)
      JacC( 65, 65) = JacC( 65, 65) - dw(111, 65)
      JacC( 67, 27) = JacC( 67, 27)+ 0.1400000000000000D+00*dw(111, 27)
      JacC( 67, 65) = JacC( 67, 65)+ 0.1400000000000000D+00*dw(111, 65)
      JacC( 70, 27) = JacC( 70, 27)+ 0.4200000000000000D+00*dw(111, 27)
      JacC( 70, 65) = JacC( 70, 65)+ 0.4200000000000000D+00*dw(111, 65)
      JacC( 77, 27) = JacC( 77, 27)+ 0.5300000000000000D+00*dw(111, 27)
      JacC( 77, 65) = JacC( 77, 65)+ 0.5300000000000000D+00*dw(111, 65)
      JacC( 78, 27) = JacC( 78, 27)+ 0.2000000000000000D+00*dw(111, 27)
      JacC( 78, 65) = JacC( 78, 65)+ 0.2000000000000000D+00*dw(111, 65)
      JacC( 80, 27) = JacC( 80, 27)+ 0.8500000000000000D+00*dw(111, 27)
      JacC( 80, 65) = JacC( 80, 65)+ 0.8500000000000000D+00*dw(111, 65)
      JacC( 81, 27) = JacC( 81, 27)+ 0.6500000000000000D+00*dw(111, 27)
      JacC( 81, 65) = JacC( 81, 65)+ 0.6500000000000000D+00*dw(111, 65)
      JacC( 88, 27) = JacC( 88, 27)+ 0.1000000000000000D+00*dw(111, 27)
      JacC( 88, 65) = JacC( 88, 65)+ 0.1000000000000000D+00*dw(111, 65)
      JacC( 30, 30) = JacC( 30, 30) - dw(112, 30)
      JacC( 30, 65) = JacC( 30, 65) - dw(112, 65)
      JacC( 31, 30) = JacC( 31, 30)+ 0.1980000000000000D+00*dw(112, 30)
      JacC( 31, 65) = JacC( 31, 65)+ 0.1980000000000000D+00*dw(112, 65)
      JacC( 32, 30) = JacC( 32, 30)+ 0.9350000000000000D-01*dw(112, 30)
      JacC( 32, 65) = JacC( 32, 65)+ 0.9350000000000000D-01*dw(112, 65)
      JacC( 44, 30) = JacC( 44, 30)+ 0.2000000000000000D-01*dw(112, 30)
      JacC( 44, 65) = JacC( 44, 65)+ 0.2000000000000000D-01*dw(112, 65)
      JacC( 49, 30) = JacC( 49, 30)+ 0.1000000000000000D-01*dw(112, 30)
      JacC( 49, 65) = JacC( 49, 65)+ 0.1000000000000000D-01*dw(112, 65)
      JacC( 59, 30) = JacC( 59, 30)+ 0.7900000000000000D+00*dw(112, 30)
      JacC( 59, 65) = JacC( 59, 65)+ 0.7900000000000000D+00*dw(112, 65)
      JacC( 60, 30) = JacC( 60, 30)+ 0.4600000000000000D+00*dw(112, 30)
      JacC( 60, 65) = JacC( 60, 65)+ 0.4600000000000000D+00*dw(112, 65)
      JacC( 65, 30) = JacC( 65, 30) - dw(112, 30)
      JacC( 65, 65) = JacC( 65, 65) - dw(112, 65)
      JacC( 67, 30) = JacC( 67, 30)+ 0.1400000000000000D+00*dw(112, 30)
      JacC( 67, 65) = JacC( 67, 65)+ 0.1400000000000000D+00*dw(112, 65)
      JacC( 70, 30) = JacC( 70, 30)+ 0.4200000000000000D+00*dw(112, 30)
      JacC( 70, 65) = JacC( 70, 65)+ 0.4200000000000000D+00*dw(112, 65)
      JacC( 71, 30) = JacC( 71, 30)+ 0.7000000000000001D-01*dw(112, 30)
      JacC( 71, 65) = JacC( 71, 65)+ 0.7000000000000001D-01*dw(112, 65)
      JacC( 78, 30) = JacC( 78, 30)+ 0.1600000000000000D+00*dw(112, 30)
      JacC( 78, 65) = JacC( 78, 65)+ 0.1600000000000000D+00*dw(112, 65)
      JacC( 79, 30) = JacC( 79, 30)+ 0.4000000000000000D-01*dw(112, 30)
      JacC( 79, 65) = JacC( 79, 65)+ 0.4000000000000000D-01*dw(112, 65)
      JacC( 80, 30) = JacC( 80, 30)+ 0.8500000000000000D+00*dw(112, 30)
      JacC( 80, 65) = JacC( 80, 65)+ 0.8500000000000000D+00*dw(112, 65)
      JacC( 88, 30) = JacC( 88, 30)+ 0.1000000000000000D+00*dw(112, 30)
      JacC( 88, 65) = JacC( 88, 65)+ 0.1000000000000000D+00*dw(112, 65)
      JacC( 49, 59) = JacC( 49, 59)+ 0.2200000000000000D+00*dw(113, 59)
      JacC( 49, 65) = JacC( 49, 65)+ 0.2200000000000000D+00*dw(113, 65)
      JacC( 59, 59) = JacC( 59, 59) - dw(113, 59)
      JacC( 59, 65) = JacC( 59, 65) - dw(113, 65)
      JacC( 65, 59) = JacC( 65, 59) - dw(113, 59)
      JacC( 65, 65) = JacC( 65, 65) - dw(113, 65)
      JacC( 67, 59) = JacC( 67, 59)+ 0.5400000000000000D+00*dw(113, 59)
      JacC( 67, 65) = JacC( 67, 65)+ 0.5400000000000000D+00*dw(113, 65)
      JacC( 71, 59) = JacC( 71, 59)+ 0.1300000000000000D+00*dw(113, 59)
      JacC( 71, 65) = JacC( 71, 65)+ 0.1300000000000000D+00*dw(113, 65)
      JacC( 72, 59) = JacC( 72, 59)+ 0.6000000000000000D+00*dw(113, 59)
      JacC( 72, 65) = JacC( 72, 65)+ 0.6000000000000000D+00*dw(113, 65)
      JacC( 73, 59) = JacC( 73, 59)+ 0.1300000000000000D+00*dw(113, 59)
      JacC( 73, 65) = JacC( 73, 65)+ 0.1300000000000000D+00*dw(113, 65)
      JacC( 79, 59) = JacC( 79, 59)+ 0.4000000000000000D+00*dw(113, 59)
      JacC( 79, 65) = JacC( 79, 65)+ 0.4000000000000000D+00*dw(113, 65)
      JacC( 80, 59) = JacC( 80, 59)+ 0.7000000000000001D-01*dw(113, 59)
      JacC( 80, 65) = JacC( 80, 65)+ 0.7000000000000001D-01*dw(113, 65)
      JacC( 88, 59) = JacC( 88, 59)+ 0.2900000000000000D+00*dw(113, 59)
      JacC( 88, 65) = JacC( 88, 65)+ 0.2900000000000000D+00*dw(113, 65)
      JacC( 89, 59) = JacC( 89, 59)+ 0.1300000000000000D+00*dw(113, 59)
      JacC( 89, 65) = JacC( 89, 65)+ 0.1300000000000000D+00*dw(113, 65)
      JacC( 38, 54) = JacC( 38, 54)+ 0.1100000000000000D+00*dw(114, 54)
      JacC( 38, 65) = JacC( 38, 65)+ 0.1100000000000000D+00*dw(114, 65)
      JacC( 49, 54) = JacC( 49, 54)+ 0.1100000000000000D+00*dw(114, 54)
      JacC( 49, 65) = JacC( 49, 65)+ 0.1100000000000000D+00*dw(114, 65)
      JacC( 54, 54) = JacC( 54, 54) - dw(114, 54)
      JacC( 54, 65) = JacC( 54, 65) - dw(114, 65)
      JacC( 65, 54) = JacC( 65, 54) - dw(114, 54)
      JacC( 65, 65) = JacC( 65, 65) - dw(114, 65)
      JacC( 66, 54) = JacC( 66, 54)+ 0.5000000000000000D+00*dw(114, 54)
      JacC( 66, 65) = JacC( 66, 65)+ 0.5000000000000000D+00*dw(114, 65)
      JacC( 67, 54) = JacC( 67, 54)+ 0.6600000000000000D+00*dw(114, 54)
      JacC( 67, 65) = JacC( 67, 65)+ 0.6600000000000000D+00*dw(114, 65)
      JacC( 71, 54) = JacC( 71, 54)+ 0.2100000000000000D+00*dw(114, 54)
      JacC( 71, 65) = JacC( 71, 65)+ 0.2100000000000000D+00*dw(114, 65)
      JacC( 72, 54) = JacC( 72, 54)+ 0.6200000000000000D+00*dw(114, 54)
      JacC( 72, 65) = JacC( 72, 65)+ 0.6200000000000000D+00*dw(114, 65)
      JacC( 80, 54) = JacC( 80, 54)+ 0.2100000000000000D+00*dw(114, 54)
      JacC( 80, 65) = JacC( 80, 65)+ 0.2100000000000000D+00*dw(114, 65)
      JacC( 81, 54) = JacC( 81, 54)+ 0.1600000000000000D+00*dw(114, 54)
      JacC( 81, 65) = JacC( 81, 65)+ 0.1600000000000000D+00*dw(114, 65)
      JacC( 88, 54) = JacC( 88, 54)+ 0.2900000000000000D+00*dw(114, 54)
      JacC( 88, 65) = JacC( 88, 65)+ 0.2900000000000000D+00*dw(114, 65)
      JacC( 89, 54) = JacC( 89, 54)+ 0.2800000000000000D+00*dw(114, 54)
      JacC( 89, 65) = JacC( 89, 65)+ 0.2800000000000000D+00*dw(114, 65)
      JacC( 48, 48) = JacC( 48, 48) - dw(115, 48)
      JacC( 48, 65) = JacC( 48, 65) - dw(115, 65)
      JacC( 49, 48) = JacC( 49, 48)+ 0.1100000000000000D+00*dw(115, 48)
      JacC( 49, 65) = JacC( 49, 65)+ 0.1100000000000000D+00*dw(115, 65)
      JacC( 50, 48) = JacC( 50, 48)+ 0.3000000000000000D+00*dw(115, 48)
      JacC( 50, 65) = JacC( 50, 65)+ 0.3000000000000000D+00*dw(115, 65)
      JacC( 65, 48) = JacC( 65, 48) - dw(115, 48)
      JacC( 65, 65) = JacC( 65, 65) - dw(115, 65)
      JacC( 67, 48) = JacC( 67, 48)+ 0.1300000000000000D+00*dw(115, 48)
      JacC( 67, 65) = JacC( 67, 65)+ 0.1300000000000000D+00*dw(115, 65)
      JacC( 79, 48) = JacC( 79, 48)+ 0.7000000000000000D+00*dw(115, 48)
      JacC( 79, 65) = JacC( 79, 65)+ 0.7000000000000000D+00*dw(115, 65)
      JacC( 80, 48) = JacC( 80, 48)+ 0.3600000000000000D-01*dw(115, 48)
      JacC( 80, 65) = JacC( 80, 65)+ 0.3600000000000000D-01*dw(115, 65)
      JacC( 84, 48) = JacC( 84, 48)+ 0.7000000000000000D+00*dw(115, 48)
      JacC( 84, 65) = JacC( 84, 65)+ 0.7000000000000000D+00*dw(115, 65)
      JacC( 88, 48) = JacC( 88, 48)+ 0.8000000000000000D-01*dw(115, 48)
      JacC( 88, 65) = JacC( 88, 65)+ 0.8000000000000000D-01*dw(115, 65)
      JacC( 89, 48) = JacC( 89, 48)+ 0.7000000000000000D+00*dw(115, 48)
      JacC( 89, 65) = JacC( 89, 65)+ 0.7000000000000000D+00*dw(115, 65)
      JacC( 39, 39) = JacC( 39, 39) - dw(116, 39)
      JacC( 39, 84) = JacC( 39, 84) - dw(116, 84)
      JacC( 45, 39) = JacC( 45, 39)+ 0.1000000000000000D+00*dw(116, 39)
      JacC( 45, 84) = JacC( 45, 84)+ 0.1000000000000000D+00*dw(116, 84)
      JacC( 83, 39) = JacC( 83, 39) + dw(116, 39)
      JacC( 83, 84) = JacC( 83, 84) + dw(116, 84)
      JacC( 84, 39) = JacC( 84, 39) - dw(116, 39)
      JacC( 84, 84) = JacC( 84, 84) - dw(116, 84)
      JacC( 39, 39) = JacC( 39, 39) - dw(117, 39)
      JacC( 39, 88) = JacC( 39, 88) - dw(117, 88)
      JacC( 45, 39) = JacC( 45, 39) + dw(117, 39)
      JacC( 45, 88) = JacC( 45, 88) + dw(117, 88)
      JacC( 88, 39) = JacC( 88, 39) - dw(117, 39)
      JacC( 88, 88) = JacC( 88, 88) - dw(117, 88)
      JacC( 22, 22) = JacC( 22, 22) - dw(118, 22)
      JacC( 22, 84) = JacC( 22, 84) - dw(118, 84)
      JacC( 33, 22) = JacC( 33, 22) + dw(118, 22)
      JacC( 33, 84) = JacC( 33, 84) + dw(118, 84)
      JacC( 45, 22) = JacC( 45, 22) + dw(118, 22)
      JacC( 45, 84) = JacC( 45, 84) + dw(118, 84)
      JacC( 84, 22) = JacC( 84, 22) - dw(118, 22)
      JacC( 84, 84) = JacC( 84, 84) - dw(118, 84)
      JacC( 22, 22) = JacC( 22, 22) - dw(119, 22)
      JacC( 40, 22) = JacC( 40, 22)+ 0.9800000000000000D+00*dw(119, 22)
      JacC( 45, 22) = JacC( 45, 22)+ 0.2000000000000000D-01*dw(119, 22)
      JacC( 88, 22) = JacC( 88, 22)+ 0.2000000000000000D-01*dw(119, 22)
      JacC( 22, 22) = JacC( 22, 22) - dw(120, 22)
      JacC( 22, 65) = JacC( 22, 65) - dw(120, 65)
      JacC( 45, 22) = JacC( 45, 22) + dw(120, 22)
      JacC( 45, 65) = JacC( 45, 65) + dw(120, 65)
      JacC( 65, 22) = JacC( 65, 22) - dw(120, 22)
      JacC( 65, 65) = JacC( 65, 65) - dw(120, 65)
      JacC( 80, 22) = JacC( 80, 22) + dw(120, 22)
      JacC( 80, 65) = JacC( 80, 65) + dw(120, 65)
      JacC( 23, 23) = JacC( 23, 23) - dw(121, 23)
      JacC( 23, 84) = JacC( 23, 84) - dw(121, 84)
      JacC( 33, 23) = JacC( 33, 23) + dw(121, 23)
      JacC( 33, 84) = JacC( 33, 84) + dw(121, 84)
      JacC( 45, 23) = JacC( 45, 23) + dw(121, 23)
      JacC( 45, 84) = JacC( 45, 84) + dw(121, 84)
      JacC( 84, 23) = JacC( 84, 23) - dw(121, 23)
      JacC( 84, 84) = JacC( 84, 84) - dw(121, 84)
      JacC( 23, 23) = JacC( 23, 23) - dw(122, 23)
      JacC( 45, 23) = JacC( 45, 23)+ 0.2000000000000000D-01*dw(122, 23)
      JacC( 51, 23) = JacC( 51, 23)+ 0.9800000000000000D+00*dw(122, 23)
      JacC( 88, 23) = JacC( 88, 23)+ 0.2000000000000000D-01*dw(122, 23)
      JacC( 23, 23) = JacC( 23, 23) - dw(123, 23)
      JacC( 23, 65) = JacC( 23, 65) - dw(123, 65)
      JacC( 45, 23) = JacC( 45, 23) + dw(123, 23)
      JacC( 45, 65) = JacC( 45, 65) + dw(123, 65)
      JacC( 65, 23) = JacC( 65, 23) - dw(123, 23)
      JacC( 65, 65) = JacC( 65, 65) - dw(123, 65)
      JacC( 80, 23) = JacC( 80, 23) + dw(123, 23)
      JacC( 80, 65) = JacC( 80, 65) + dw(123, 65)
      JacC( 33, 36) = JacC( 33, 36) + dw(124, 36)
      JacC( 33, 84) = JacC( 33, 84) + dw(124, 84)
      JacC( 36, 36) = JacC( 36, 36) - dw(124, 36)
      JacC( 36, 84) = JacC( 36, 84) - dw(124, 84)
      JacC( 45, 36) = JacC( 45, 36) + dw(124, 36)
      JacC( 45, 84) = JacC( 45, 84) + dw(124, 84)
      JacC( 84, 36) = JacC( 84, 36) - dw(124, 36)
      JacC( 84, 84) = JacC( 84, 84) - dw(124, 84)
      JacC( 36, 36) = JacC( 36, 36) - dw(125, 36)
      JacC( 42, 36) = JacC( 42, 36)+ 0.9800000000000000D+00*dw(125, 36)
      JacC( 45, 36) = JacC( 45, 36)+ 0.2000000000000000D-01*dw(125, 36)
      JacC( 88, 36) = JacC( 88, 36)+ 0.2000000000000000D-01*dw(125, 36)
      JacC( 36, 36) = JacC( 36, 36) - dw(126, 36)
      JacC( 36, 65) = JacC( 36, 65) - dw(126, 65)
      JacC( 45, 36) = JacC( 45, 36) + dw(126, 36)
      JacC( 45, 65) = JacC( 45, 65) + dw(126, 65)
      JacC( 65, 36) = JacC( 65, 36) - dw(126, 36)
      JacC( 65, 65) = JacC( 65, 65) - dw(126, 65)
      JacC( 80, 36) = JacC( 80, 36) + dw(126, 36)
      JacC( 80, 65) = JacC( 80, 65) + dw(126, 65)
      JacC( 50, 89) = JacC( 50, 89) + dw(127, 89)
      JacC( 50, 84) = JacC( 50, 84) + dw(127, 84)
      JacC( 84, 89) = JacC( 84, 89) - dw(127, 89)
      JacC( 84, 84) = JacC( 84, 84) - dw(127, 84)
      JacC( 89, 89) = JacC( 89, 89) - dw(127, 89)
      JacC( 89, 84) = JacC( 89, 84) - dw(127, 84)
      JacC( 50, 50) = JacC( 50, 50) - dw(128, 50)
      JacC( 84, 50) = JacC( 84, 50) + dw(128, 50)
      JacC( 89, 50) = JacC( 89, 50) + dw(128, 50)
      JacC( 48, 86) = JacC( 48, 86) + dw(129, 86)
      JacC( 48, 84) = JacC( 48, 84) + dw(129, 84)
      JacC( 84, 86) = JacC( 84, 86) - dw(129, 86)
      JacC( 84, 84) = JacC( 84, 84) - dw(129, 84)
      JacC( 86, 86) = JacC( 86, 86) - dw(129, 86)
      JacC( 86, 84) = JacC( 86, 84) - dw(129, 84)
      JacC( 48, 48) = JacC( 48, 48) - dw(130, 48)
      JacC( 84, 48) = JacC( 84, 48) + dw(130, 48)
      JacC( 86, 48) = JacC( 86, 48) + dw(130, 48)
      JacC( 79, 82) = JacC( 79, 82) + dw(131, 82)
      JacC( 79, 85) = JacC( 79, 85) + dw(131, 85)
      JacC( 82, 82) = JacC( 82, 82) - dw(131, 82)
      JacC( 82, 85) = JacC( 82, 85) - dw(131, 85)
      JacC( 84, 82) = JacC( 84, 82) + dw(131, 82)
      JacC( 84, 85) = JacC( 84, 85) + dw(131, 85)
      JacC( 85, 82) = JacC( 85, 82) - dw(131, 82)
      JacC( 85, 85) = JacC( 85, 85) - dw(131, 85)
      JacC( 88, 82) = JacC( 88, 82) + dw(131, 82)
      JacC( 88, 85) = JacC( 88, 85) + dw(131, 85)
      JacC( 78, 78) = JacC( 78, 78) - dw(132, 78)
      JacC( 78, 85) = JacC( 78, 85) - dw(132, 85)
      JacC( 81, 78) = JacC( 81, 78) + dw(132, 78)
      JacC( 81, 85) = JacC( 81, 85) + dw(132, 85)
      JacC( 84, 78) = JacC( 84, 78) + dw(132, 78)
      JacC( 84, 85) = JacC( 84, 85) + dw(132, 85)
      JacC( 85, 78) = JacC( 85, 78) - dw(132, 78)
      JacC( 85, 85) = JacC( 85, 85) - dw(132, 85)
      JacC( 88, 78) = JacC( 88, 78) + dw(132, 78)
      JacC( 88, 85) = JacC( 88, 85) + dw(132, 85)
      JacC( 66, 76) = JacC( 66, 76)+ 0.6300000000000000D-01*dw(133, 76)
      JacC( 66, 85) = JacC( 66, 85)+ 0.6300000000000000D-01*dw(133, 85)
      JacC( 75, 76) = JacC( 75, 76)+ 0.4800000000000000D-01*dw(133, 76)
      JacC( 75, 85) = JacC( 75, 85)+ 0.4800000000000000D-01*dw(133, 85)
      JacC( 76, 76) = JacC( 76, 76) - dw(133, 76)
      JacC( 76, 85) = JacC( 76, 85) - dw(133, 85)
      JacC( 77, 76) = JacC( 77, 76)+ 0.6230000000000000D+00*dw(133, 76)
      JacC( 77, 85) = JacC( 77, 85)+ 0.6230000000000000D+00*dw(133, 85)
      JacC( 78, 76) = JacC( 78, 76)+ 0.4800000000000000D-01*dw(133, 76)
      JacC( 78, 85) = JacC( 78, 85)+ 0.4800000000000000D-01*dw(133, 85)
      JacC( 79, 76) = JacC( 79, 76)+ 0.4700000000000000D-01*dw(133, 76)
      JacC( 79, 85) = JacC( 79, 85)+ 0.4700000000000000D-01*dw(133, 85)
      JacC( 81, 76) = JacC( 81, 76)+ 0.2330000000000000D+00*dw(133, 76)
      JacC( 81, 85) = JacC( 81, 85)+ 0.2330000000000000D+00*dw(133, 85)
      JacC( 82, 76) = JacC( 82, 76)+ 0.1500000000000000D+00*dw(133, 76)
      JacC( 82, 85) = JacC( 82, 85)+ 0.1500000000000000D+00*dw(133, 85)
      JacC( 83, 76) = JacC( 83, 76)+ 0.5900000000000000D-01*dw(133, 76)
      JacC( 83, 85) = JacC( 83, 85)+ 0.5900000000000000D-01*dw(133, 85)
      JacC( 84, 76) = JacC( 84, 76)+ 0.9409999999999999D+00*dw(133, 76)
      JacC( 84, 85) = JacC( 84, 85)+ 0.9409999999999999D+00*dw(133, 85)
      JacC( 85, 76) = JacC( 85, 76) - dw(133, 76)
      JacC( 85, 85) = JacC( 85, 85) - dw(133, 85)
      JacC( 88, 76) = JacC( 88, 76)+ 0.7420000000000000D+00*dw(133, 76)
      JacC( 88, 85) = JacC( 88, 85)+ 0.7420000000000000D+00*dw(133, 85)
      JacC( 53, 53) = JacC( 53, 53) - dw(134, 53)
      JacC( 53, 85) = JacC( 53, 85) - dw(134, 85)
      JacC( 75, 53) = JacC( 75, 53)+ 0.3340000000000000D+00*dw(134, 53)
      JacC( 75, 85) = JacC( 75, 85)+ 0.3340000000000000D+00*dw(134, 85)
      JacC( 77, 53) = JacC( 77, 53)+ 0.7220000000000000D+00*dw(134, 53)
      JacC( 77, 85) = JacC( 77, 85)+ 0.7220000000000000D+00*dw(134, 85)
      JacC( 78, 53) = JacC( 78, 53)+ 0.2450000000000000D+00*dw(134, 53)
      JacC( 78, 85) = JacC( 78, 85)+ 0.2450000000000000D+00*dw(134, 85)
      JacC( 79, 53) = JacC( 79, 53)+ 0.2100000000000000D-01*dw(134, 53)
      JacC( 79, 85) = JacC( 79, 85)+ 0.2100000000000000D-01*dw(134, 85)
      JacC( 81, 53) = JacC( 81, 53)+ 0.2110000000000000D+00*dw(134, 53)
      JacC( 81, 85) = JacC( 81, 85)+ 0.2110000000000000D+00*dw(134, 85)
      JacC( 82, 53) = JacC( 82, 53)+ 0.3100000000000000D-01*dw(134, 53)
      JacC( 82, 85) = JacC( 82, 85)+ 0.3100000000000000D-01*dw(134, 85)
      JacC( 83, 53) = JacC( 83, 53)+ 0.1240000000000000D+00*dw(134, 53)
      JacC( 83, 85) = JacC( 83, 85)+ 0.1240000000000000D+00*dw(134, 85)
      JacC( 84, 53) = JacC( 84, 53)+ 0.8760000000000000D+00*dw(134, 53)
      JacC( 84, 85) = JacC( 84, 85)+ 0.8760000000000000D+00*dw(134, 85)
      JacC( 85, 53) = JacC( 85, 53) - dw(134, 53)
      JacC( 85, 85) = JacC( 85, 85) - dw(134, 85)
      JacC( 88, 53) = JacC( 88, 53)+ 0.5990000000000000D+00*dw(134, 53)
      JacC( 88, 85) = JacC( 88, 85)+ 0.5990000000000000D+00*dw(134, 85)
      JacC( 57, 57) = JacC( 57, 57) - dw(135, 57)
      JacC( 57, 85) = JacC( 57, 85) - dw(135, 85)
      JacC( 75, 57) = JacC( 75, 57)+ 0.4160000000000000D+00*dw(135, 57)
      JacC( 75, 85) = JacC( 75, 85)+ 0.4160000000000000D+00*dw(135, 85)
      JacC( 77, 57) = JacC( 77, 57)+ 0.6420000000000000D+00*dw(135, 57)
      JacC( 77, 85) = JacC( 77, 85)+ 0.6420000000000000D+00*dw(135, 85)
      JacC( 78, 57) = JacC( 78, 57)+ 0.1330000000000000D+00*dw(135, 57)
      JacC( 78, 85) = JacC( 78, 85)+ 0.1330000000000000D+00*dw(135, 85)
      JacC( 81, 57) = JacC( 81, 57)+ 0.1500000000000000D+00*dw(135, 57)
      JacC( 81, 85) = JacC( 81, 85)+ 0.1500000000000000D+00*dw(135, 85)
      JacC( 83, 57) = JacC( 83, 57)+ 0.2610000000000000D+00*dw(135, 57)
      JacC( 83, 85) = JacC( 83, 85)+ 0.2610000000000000D+00*dw(135, 85)
      JacC( 84, 57) = JacC( 84, 57)+ 0.7390000000000000D+00*dw(135, 57)
      JacC( 84, 85) = JacC( 84, 85)+ 0.7390000000000000D+00*dw(135, 85)
      JacC( 85, 57) = JacC( 85, 57) - dw(135, 57)
      JacC( 85, 85) = JacC( 85, 85) - dw(135, 85)
      JacC( 88, 57) = JacC( 88, 57)+ 0.6060000000000000D+00*dw(135, 57)
      JacC( 88, 85) = JacC( 88, 85)+ 0.6060000000000000D+00*dw(135, 85)
      JacC( 56, 56) = JacC( 56, 56) - dw(136, 56)
      JacC( 56, 85) = JacC( 56, 85) - dw(136, 85)
      JacC( 79, 56) = JacC( 79, 56)+ 0.1600000000000000D+01*dw(136, 56)
      JacC( 79, 85) = JacC( 79, 85)+ 0.1600000000000000D+01*dw(136, 85)
      JacC( 81, 56) = JacC( 81, 56)+ 0.2000000000000000D+00*dw(136, 56)
      JacC( 81, 85) = JacC( 81, 85)+ 0.2000000000000000D+00*dw(136, 85)
      JacC( 84, 56) = JacC( 84, 56) + dw(136, 56)
      JacC( 84, 85) = JacC( 84, 85) + dw(136, 85)
      JacC( 85, 56) = JacC( 85, 56) - dw(136, 56)
      JacC( 85, 85) = JacC( 85, 85) - dw(136, 85)
      JacC( 88, 56) = JacC( 88, 56) + dw(136, 56)
      JacC( 88, 85) = JacC( 88, 85) + dw(136, 85)
      JacC( 61, 61) = JacC( 61, 61) - dw(137, 61)
      JacC( 61, 85) = JacC( 61, 85) - dw(137, 85)
      JacC( 77, 61) = JacC( 77, 61)+ 0.6000000000000000D-01*dw(137, 61)
      JacC( 77, 85) = JacC( 77, 85)+ 0.6000000000000000D-01*dw(137, 85)
      JacC( 79, 61) = JacC( 79, 61) + dw(137, 61)
      JacC( 79, 85) = JacC( 79, 85) + dw(137, 85)
      JacC( 81, 61) = JacC( 81, 61)+ 0.9399999999999999D+00*dw(137, 61)
      JacC( 81, 85) = JacC( 81, 85)+ 0.9399999999999999D+00*dw(137, 85)
      JacC( 84, 61) = JacC( 84, 61) + dw(137, 61)
      JacC( 84, 85) = JacC( 84, 85) + dw(137, 85)
      JacC( 85, 61) = JacC( 85, 61) - dw(137, 61)
      JacC( 85, 85) = JacC( 85, 85) - dw(137, 85)
      JacC( 88, 61) = JacC( 88, 61) + dw(137, 61)
      JacC( 88, 85) = JacC( 88, 85) + dw(137, 85)
      JacC( 68, 68) = JacC( 68, 68) - dw(138, 68)
      JacC( 68, 85) = JacC( 68, 85) - dw(138, 85)
      JacC( 77, 68) = JacC( 77, 68)+ 0.2900000000000000D+00*dw(138, 68)
      JacC( 77, 85) = JacC( 77, 85)+ 0.2900000000000000D+00*dw(138, 85)
      JacC( 81, 68) = JacC( 81, 68)+ 0.1710000000000000D+01*dw(138, 68)
      JacC( 81, 85) = JacC( 81, 85)+ 0.1710000000000000D+01*dw(138, 85)
      JacC( 84, 68) = JacC( 84, 68) + dw(138, 68)
      JacC( 84, 85) = JacC( 84, 85) + dw(138, 85)
      JacC( 85, 68) = JacC( 85, 68) - dw(138, 68)
      JacC( 85, 85) = JacC( 85, 85) - dw(138, 85)
      JacC( 88, 68) = JacC( 88, 68) + dw(138, 68)
      JacC( 88, 85) = JacC( 88, 85) + dw(138, 85)
      JacC( 58, 58) = JacC( 58, 58) - dw(139, 58)
      JacC( 58, 85) = JacC( 58, 85) - dw(139, 85)
      JacC( 59, 58) = JacC( 59, 58)+ 0.4460000000000000D+00*dw(139, 58)
      JacC( 59, 85) = JacC( 59, 85)+ 0.4460000000000000D+00*dw(139, 85)
      JacC( 60, 58) = JacC( 60, 58)+ 0.3540000000000000D+00*dw(139, 58)
      JacC( 60, 85) = JacC( 60, 85)+ 0.3540000000000000D+00*dw(139, 85)
      JacC( 79, 58) = JacC( 79, 58)+ 0.6060000000000000D+00*dw(139, 58)
      JacC( 79, 85) = JacC( 79, 85)+ 0.6060000000000000D+00*dw(139, 85)
      JacC( 83, 58) = JacC( 83, 58)+ 0.1530000000000000D+00*dw(139, 58)
      JacC( 83, 85) = JacC( 83, 85)+ 0.1530000000000000D+00*dw(139, 85)
      JacC( 84, 58) = JacC( 84, 58)+ 0.8470000000000000D+00*dw(139, 58)
      JacC( 84, 85) = JacC( 84, 85)+ 0.8470000000000000D+00*dw(139, 85)
      JacC( 85, 58) = JacC( 85, 58) - dw(139, 58)
      JacC( 85, 85) = JacC( 85, 85) - dw(139, 85)
      JacC( 88, 58) = JacC( 88, 58)+ 0.8470000000000000D+00*dw(139, 58)
      JacC( 88, 85) = JacC( 88, 85)+ 0.8470000000000000D+00*dw(139, 85)
      JacC( 69, 69) = JacC( 69, 69) - dw(140, 69)
      JacC( 69, 85) = JacC( 69, 85) - dw(140, 85)
      JacC( 77, 69) = JacC( 77, 69)+ 0.8000000000000000D+00*dw(140, 69)
      JacC( 77, 85) = JacC( 77, 85)+ 0.8000000000000000D+00*dw(140, 85)
      JacC( 81, 69) = JacC( 81, 69)+ 0.8000000000000000D+00*dw(140, 69)
      JacC( 81, 85) = JacC( 81, 85)+ 0.8000000000000000D+00*dw(140, 85)
      JacC( 83, 69) = JacC( 83, 69)+ 0.2000000000000000D+00*dw(140, 69)
      JacC( 83, 85) = JacC( 83, 85)+ 0.2000000000000000D+00*dw(140, 85)
      JacC( 84, 69) = JacC( 84, 69)+ 0.8000000000000000D+00*dw(140, 69)
      JacC( 84, 85) = JacC( 84, 85)+ 0.8000000000000000D+00*dw(140, 85)
      JacC( 85, 69) = JacC( 85, 69) - dw(140, 69)
      JacC( 85, 85) = JacC( 85, 85) - dw(140, 85)
      JacC( 88, 69) = JacC( 88, 69)+ 0.8000000000000000D+00*dw(140, 69)
      JacC( 88, 85) = JacC( 88, 85)+ 0.8000000000000000D+00*dw(140, 85)
      JacC( 52, 52) = JacC( 52, 52) - dw(141, 52)
      JacC( 52, 85) = JacC( 52, 85) - dw(141, 85)
      JacC( 59, 52) = JacC( 59, 52)+ 0.4000000000000000D+00*dw(141, 52)
      JacC( 59, 85) = JacC( 59, 85)+ 0.4000000000000000D+00*dw(141, 85)
      JacC( 62, 52) = JacC( 62, 52)+ 0.2500000000000000D+00*dw(141, 52)
      JacC( 62, 85) = JacC( 62, 85)+ 0.2500000000000000D+00*dw(141, 85)
      JacC( 79, 52) = JacC( 79, 52)+ 0.2500000000000000D+00*dw(141, 52)
      JacC( 79, 85) = JacC( 79, 85)+ 0.2500000000000000D+00*dw(141, 85)
      JacC( 83, 52) = JacC( 83, 52)+ 0.3500000000000000D+00*dw(141, 52)
      JacC( 83, 85) = JacC( 83, 85)+ 0.3500000000000000D+00*dw(141, 85)
      JacC( 84, 52) = JacC( 84, 52)+ 0.6500000000000000D+00*dw(141, 52)
      JacC( 84, 85) = JacC( 84, 85)+ 0.6500000000000000D+00*dw(141, 85)
      JacC( 85, 52) = JacC( 85, 52) - dw(141, 52)
      JacC( 85, 85) = JacC( 85, 85) - dw(141, 85)
      JacC( 88, 52) = JacC( 88, 52)+ 0.6500000000000000D+00*dw(141, 52)
      JacC( 88, 85) = JacC( 88, 85)+ 0.6500000000000000D+00*dw(141, 85)
      JacC( 40, 40) = JacC( 40, 40) - dw(142, 40)
      JacC( 40, 85) = JacC( 40, 85) - dw(142, 85)
      JacC( 46, 40) = JacC( 46, 40)+ 0.9500000000000000D-01*dw(142, 40)
      JacC( 46, 85) = JacC( 46, 85)+ 0.9500000000000000D-01*dw(142, 85)
      JacC( 54, 40) = JacC( 54, 40)+ 0.5000000000000000D+00*dw(142, 40)
      JacC( 54, 85) = JacC( 54, 85)+ 0.5000000000000000D+00*dw(142, 85)
      JacC( 55, 40) = JacC( 55, 40)+ 0.1500000000000000D-01*dw(142, 40)
      JacC( 55, 85) = JacC( 55, 85)+ 0.1500000000000000D-01*dw(142, 85)
      JacC( 66, 40) = JacC( 66, 40)+ 0.1200000000000000D+01*dw(142, 40)
      JacC( 66, 85) = JacC( 66, 85)+ 0.1200000000000000D+01*dw(142, 85)
      JacC( 72, 40) = JacC( 72, 40)+ 0.6500000000000000D+00*dw(142, 40)
      JacC( 72, 85) = JacC( 72, 85)+ 0.6500000000000000D+00*dw(142, 85)
      JacC( 83, 40) = JacC( 83, 40)+ 0.5000000000000000D-01*dw(142, 40)
      JacC( 83, 85) = JacC( 83, 85)+ 0.5000000000000000D-01*dw(142, 85)
      JacC( 84, 40) = JacC( 84, 40)+ 0.9500000000000000D+00*dw(142, 40)
      JacC( 84, 85) = JacC( 84, 85)+ 0.9500000000000000D+00*dw(142, 85)
      JacC( 85, 40) = JacC( 85, 40) - dw(142, 40)
      JacC( 85, 85) = JacC( 85, 85) - dw(142, 85)
      JacC( 88, 40) = JacC( 88, 40)+ 0.9500000000000000D+00*dw(142, 40)
      JacC( 88, 85) = JacC( 88, 85)+ 0.9500000000000000D+00*dw(142, 85)
      JacC( 46, 51) = JacC( 46, 51)+ 0.1000000000000000D+00*dw(143, 51)
      JacC( 46, 85) = JacC( 46, 85)+ 0.1000000000000000D+00*dw(143, 85)
      JacC( 51, 51) = JacC( 51, 51) - dw(143, 51)
      JacC( 51, 85) = JacC( 51, 85) - dw(143, 85)
      JacC( 54, 51) = JacC( 54, 51)+ 0.9500000000000000D+00*dw(143, 51)
      JacC( 54, 85) = JacC( 54, 85)+ 0.9500000000000000D+00*dw(143, 85)
      JacC( 55, 51) = JacC( 55, 51)+ 0.7000000000000000D-02*dw(143, 51)
      JacC( 55, 85) = JacC( 55, 85)+ 0.7000000000000000D-02*dw(143, 85)
      JacC( 66, 51) = JacC( 66, 51)+ 0.3500000000000000D+00*dw(143, 51)
      JacC( 66, 85) = JacC( 66, 85)+ 0.3500000000000000D+00*dw(143, 85)
      JacC( 72, 51) = JacC( 72, 51)+ 0.6000000000000000D+00*dw(143, 51)
      JacC( 72, 85) = JacC( 72, 85)+ 0.6000000000000000D+00*dw(143, 85)
      JacC( 83, 51) = JacC( 83, 51)+ 0.5000000000000000D-01*dw(143, 51)
      JacC( 83, 85) = JacC( 83, 85)+ 0.5000000000000000D-01*dw(143, 85)
      JacC( 84, 51) = JacC( 84, 51)+ 0.9500000000000000D+00*dw(143, 51)
      JacC( 84, 85) = JacC( 84, 85)+ 0.9500000000000000D+00*dw(143, 85)
      JacC( 85, 51) = JacC( 85, 51) - dw(143, 51)
      JacC( 85, 85) = JacC( 85, 85) - dw(143, 85)
      JacC( 88, 51) = JacC( 88, 51)+ 0.9500000000000000D+00*dw(143, 51)
      JacC( 88, 85) = JacC( 88, 85)+ 0.9500000000000000D+00*dw(143, 85)
      JacC( 42, 42) = JacC( 42, 42) - dw(144, 42)
      JacC( 42, 85) = JacC( 42, 85) - dw(144, 85)
      JacC( 66, 42) = JacC( 66, 42) + dw(144, 42)
      JacC( 66, 85) = JacC( 66, 85) + dw(144, 85)
      JacC( 72, 42) = JacC( 72, 42) + dw(144, 42)
      JacC( 72, 85) = JacC( 72, 85) + dw(144, 85)
      JacC( 84, 42) = JacC( 84, 42) + dw(144, 42)
      JacC( 84, 85) = JacC( 84, 85) + dw(144, 85)
      JacC( 85, 42) = JacC( 85, 42) - dw(144, 42)
      JacC( 85, 85) = JacC( 85, 85) - dw(144, 85)
      JacC( 88, 42) = JacC( 88, 42) + dw(144, 42)
      JacC( 88, 85) = JacC( 88, 85) + dw(144, 85)
      JacC( 82, 89) = JacC( 82, 89) + dw(145, 89)
      JacC( 82, 85) = JacC( 82, 85) + dw(145, 85)
      JacC( 84, 89) = JacC( 84, 89) + dw(145, 89)
      JacC( 84, 85) = JacC( 84, 85) + dw(145, 85)
      JacC( 85, 89) = JacC( 85, 89) - dw(145, 89)
      JacC( 85, 85) = JacC( 85, 85) - dw(145, 85)
      JacC( 89, 89) = JacC( 89, 89) - dw(145, 89)
      JacC( 89, 85) = JacC( 89, 85) - dw(145, 85)
      JacC( 79, 86) = JacC( 79, 86) + dw(146, 86)
      JacC( 79, 85) = JacC( 79, 85) + dw(146, 85)
      JacC( 84, 86) = JacC( 84, 86) + dw(146, 86)
      JacC( 84, 85) = JacC( 84, 85) + dw(146, 85)
      JacC( 85, 86) = JacC( 85, 86) - dw(146, 86)
      JacC( 85, 85) = JacC( 85, 85) - dw(146, 85)
      JacC( 86, 86) = JacC( 86, 86) - dw(146, 86)
      JacC( 86, 85) = JacC( 86, 85) - dw(146, 85)
      JacC( 89, 86) = JacC( 89, 86) + dw(146, 86)
      JacC( 89, 85) = JacC( 89, 85) + dw(146, 85)
      JacC( 70, 70) = JacC( 70, 70) - dw(147, 70)
      JacC( 70, 85) = JacC( 70, 85) - dw(147, 85)
      JacC( 72, 70) = JacC( 72, 70)+ 0.5400000000000000D+00*dw(147, 70)
      JacC( 72, 85) = JacC( 72, 85)+ 0.5400000000000000D+00*dw(147, 85)
      JacC( 75, 70) = JacC( 75, 70)+ 0.1600000000000000D+00*dw(147, 70)
      JacC( 75, 85) = JacC( 75, 85)+ 0.1600000000000000D+00*dw(147, 85)
      JacC( 81, 70) = JacC( 81, 70)+ 0.4600000000000000D+00*dw(147, 70)
      JacC( 81, 85) = JacC( 81, 85)+ 0.4600000000000000D+00*dw(147, 85)
      JacC( 84, 70) = JacC( 84, 70) + dw(147, 70)
      JacC( 84, 85) = JacC( 84, 85) + dw(147, 85)
      JacC( 85, 70) = JacC( 85, 70) - dw(147, 70)
      JacC( 85, 85) = JacC( 85, 85) - dw(147, 85)
      JacC( 88, 70) = JacC( 88, 70)+ 0.7700000000000000D+00*dw(147, 70)
      JacC( 88, 85) = JacC( 88, 85)+ 0.7700000000000000D+00*dw(147, 85)
      JacC( 89, 70) = JacC( 89, 70)+ 0.2300000000000000D+00*dw(147, 70)
      JacC( 89, 85) = JacC( 89, 85)+ 0.2300000000000000D+00*dw(147, 85)
      JacC( 64, 64) = JacC( 64, 64) - dw(148, 64)
      JacC( 64, 85) = JacC( 64, 85) - dw(148, 85)
      JacC( 83, 64) = JacC( 83, 64) + dw(148, 64)
      JacC( 83, 85) = JacC( 83, 85) + dw(148, 85)
      JacC( 84, 64) = JacC( 84, 64) + dw(148, 64)
      JacC( 84, 85) = JacC( 84, 85) + dw(148, 85)
      JacC( 85, 64) = JacC( 85, 64) - dw(148, 64)
      JacC( 85, 85) = JacC( 85, 85) - dw(148, 85)
      JacC( 88, 64) = JacC( 88, 64) + dw(148, 64)
      JacC( 88, 85) = JacC( 88, 85) + dw(148, 85)
      JacC( 63, 63) = JacC( 63, 63) - dw(149, 63)
      JacC( 63, 85) = JacC( 63, 85) - dw(149, 85)
      JacC( 77, 63) = JacC( 77, 63)+ 0.4640000000000000D+00*dw(149, 63)
      JacC( 77, 85) = JacC( 77, 85)+ 0.4640000000000000D+00*dw(149, 85)
      JacC( 79, 63) = JacC( 79, 63)+ 0.2870000000000000D+00*dw(149, 63)
      JacC( 79, 85) = JacC( 79, 85)+ 0.2870000000000000D+00*dw(149, 85)
      JacC( 81, 63) = JacC( 81, 63)+ 0.1240000000000000D+01*dw(149, 63)
      JacC( 81, 85) = JacC( 81, 85)+ 0.1240000000000000D+01*dw(149, 85)
      JacC( 84, 63) = JacC( 84, 63)+ 0.2000000000000000D+01*dw(149, 63)
      JacC( 84, 85) = JacC( 84, 85)+ 0.2000000000000000D+01*dw(149, 85)
      JacC( 85, 63) = JacC( 85, 63) - dw(149, 63)
      JacC( 85, 85) = JacC( 85, 85) - dw(149, 85)
      JacC( 21, 82) = JacC( 21, 82) + dw(150, 82)
      JacC( 21, 88) = JacC( 21, 88) + dw(150, 88)
      JacC( 82, 82) = JacC( 82, 82) - dw(150, 82)
      JacC( 82, 88) = JacC( 82, 88) - dw(150, 88)
      JacC( 88, 82) = JacC( 88, 82) - dw(150, 82)
      JacC( 88, 88) = JacC( 88, 88) - dw(150, 88)
      JacC( 73, 78) = JacC( 73, 78) + dw(151, 78)
      JacC( 73, 88) = JacC( 73, 88) + dw(151, 88)
      JacC( 78, 78) = JacC( 78, 78) - dw(151, 78)
      JacC( 78, 88) = JacC( 78, 88) - dw(151, 88)
      JacC( 88, 78) = JacC( 88, 78) - dw(151, 78)
      JacC( 88, 88) = JacC( 88, 88) - dw(151, 88)
      JacC( 73, 76) = JacC( 73, 76) + dw(152, 76)
      JacC( 73, 88) = JacC( 73, 88) + dw(152, 88)
      JacC( 76, 76) = JacC( 76, 76) - dw(152, 76)
      JacC( 76, 88) = JacC( 76, 88) - dw(152, 88)
      JacC( 88, 76) = JacC( 88, 76) - dw(152, 76)
      JacC( 88, 88) = JacC( 88, 88) - dw(152, 88)
      JacC( 53, 53) = JacC( 53, 53) - dw(153, 53)
      JacC( 53, 88) = JacC( 53, 88) - dw(153, 88)
      JacC( 73, 53) = JacC( 73, 53) + dw(153, 53)
      JacC( 73, 88) = JacC( 73, 88) + dw(153, 88)
      JacC( 88, 53) = JacC( 88, 53) - dw(153, 53)
      JacC( 88, 88) = JacC( 88, 88) - dw(153, 88)
      JacC( 57, 57) = JacC( 57, 57) - dw(154, 57)
      JacC( 57, 88) = JacC( 57, 88) - dw(154, 88)
      JacC( 73, 57) = JacC( 73, 57) + dw(154, 57)
      JacC( 73, 88) = JacC( 73, 88) + dw(154, 88)
      JacC( 88, 57) = JacC( 88, 57) - dw(154, 57)
      JacC( 88, 88) = JacC( 88, 88) - dw(154, 88)
      JacC( 56, 56) = JacC( 56, 56) - dw(155, 56)
      JacC( 56, 88) = JacC( 56, 88) - dw(155, 88)
      JacC( 73, 56) = JacC( 73, 56) + dw(155, 56)
      JacC( 73, 88) = JacC( 73, 88) + dw(155, 88)
      JacC( 88, 56) = JacC( 88, 56) - dw(155, 56)
      JacC( 88, 88) = JacC( 88, 88) - dw(155, 88)
      JacC( 61, 61) = JacC( 61, 61) - dw(156, 61)
      JacC( 61, 88) = JacC( 61, 88) - dw(156, 88)
      JacC( 73, 61) = JacC( 73, 61) + dw(156, 61)
      JacC( 73, 88) = JacC( 73, 88) + dw(156, 88)
      JacC( 88, 61) = JacC( 88, 61) - dw(156, 61)
      JacC( 88, 88) = JacC( 88, 88) - dw(156, 88)
      JacC( 68, 68) = JacC( 68, 68) - dw(157, 68)
      JacC( 68, 88) = JacC( 68, 88) - dw(157, 88)
      JacC( 73, 68) = JacC( 73, 68) + dw(157, 68)
      JacC( 73, 88) = JacC( 73, 88) + dw(157, 88)
      JacC( 88, 68) = JacC( 88, 68) - dw(157, 68)
      JacC( 88, 88) = JacC( 88, 88) - dw(157, 88)
      JacC( 58, 58) = JacC( 58, 58) - dw(158, 58)
      JacC( 58, 88) = JacC( 58, 88) - dw(158, 88)
      JacC( 73, 58) = JacC( 73, 58) + dw(158, 58)
      JacC( 73, 88) = JacC( 73, 88) + dw(158, 88)
      JacC( 88, 58) = JacC( 88, 58) - dw(158, 58)
      JacC( 88, 88) = JacC( 88, 88) - dw(158, 88)
      JacC( 69, 69) = JacC( 69, 69) - dw(159, 69)
      JacC( 69, 88) = JacC( 69, 88) - dw(159, 88)
      JacC( 73, 69) = JacC( 73, 69) + dw(159, 69)
      JacC( 73, 88) = JacC( 73, 88) + dw(159, 88)
      JacC( 88, 69) = JacC( 88, 69) - dw(159, 69)
      JacC( 88, 88) = JacC( 88, 88) - dw(159, 88)
      JacC( 52, 52) = JacC( 52, 52) - dw(160, 52)
      JacC( 52, 88) = JacC( 52, 88) - dw(160, 88)
      JacC( 73, 52) = JacC( 73, 52) + dw(160, 52)
      JacC( 73, 88) = JacC( 73, 88) + dw(160, 88)
      JacC( 88, 52) = JacC( 88, 52) - dw(160, 52)
      JacC( 88, 88) = JacC( 88, 88) - dw(160, 88)
      JacC( 40, 40) = JacC( 40, 40) - dw(161, 40)
      JacC( 40, 88) = JacC( 40, 88) - dw(161, 88)
      JacC( 41, 40) = JacC( 41, 40)+ 0.2200000000000000D+00*dw(161, 40)
      JacC( 41, 88) = JacC( 41, 88)+ 0.2200000000000000D+00*dw(161, 88)
      JacC( 73, 40) = JacC( 73, 40) + dw(161, 40)
      JacC( 73, 88) = JacC( 73, 88) + dw(161, 88)
      JacC( 88, 40) = JacC( 88, 40) - dw(161, 40)
      JacC( 88, 88) = JacC( 88, 88) - dw(161, 88)
      JacC( 41, 51) = JacC( 41, 51)+ 0.2200000000000000D+00*dw(162, 51)
      JacC( 41, 88) = JacC( 41, 88)+ 0.2200000000000000D+00*dw(162, 88)
      JacC( 51, 51) = JacC( 51, 51) - dw(162, 51)
      JacC( 51, 88) = JacC( 51, 88) - dw(162, 88)
      JacC( 73, 51) = JacC( 73, 51) + dw(162, 51)
      JacC( 73, 88) = JacC( 73, 88) + dw(162, 88)
      JacC( 88, 51) = JacC( 88, 51) - dw(162, 51)
      JacC( 88, 88) = JacC( 88, 88) - dw(162, 88)
      JacC( 42, 42) = JacC( 42, 42) - dw(163, 42)
      JacC( 42, 88) = JacC( 42, 88) - dw(163, 88)
      JacC( 73, 42) = JacC( 73, 42) + dw(163, 42)
      JacC( 73, 88) = JacC( 73, 88) + dw(163, 88)
      JacC( 88, 42) = JacC( 88, 42) - dw(163, 42)
      JacC( 88, 88) = JacC( 88, 88) - dw(163, 88)
      JacC( 38, 89) = JacC( 38, 89) + dw(164, 89)
      JacC( 38, 88) = JacC( 38, 88) + dw(164, 88)
      JacC( 88, 89) = JacC( 88, 89) - dw(164, 89)
      JacC( 88, 88) = JacC( 88, 88) - dw(164, 88)
      JacC( 89, 89) = JacC( 89, 89) - dw(164, 89)
      JacC( 89, 88) = JacC( 89, 88) - dw(164, 88)
      JacC( 65, 89) = JacC( 65, 89) + dw(165, 89)
      JacC( 65, 88) = JacC( 65, 88) + dw(165, 88)
      JacC( 71, 89) = JacC( 71, 89) + dw(165, 89)
      JacC( 71, 88) = JacC( 71, 88) + dw(165, 88)
      JacC( 88, 89) = JacC( 88, 89) - dw(165, 89)
      JacC( 88, 88) = JacC( 88, 88) - dw(165, 88)
      JacC( 89, 89) = JacC( 89, 89) - dw(165, 89)
      JacC( 89, 88) = JacC( 89, 88) - dw(165, 88)
      JacC( 73, 86) = JacC( 73, 86) + dw(166, 86)
      JacC( 73, 88) = JacC( 73, 88) + dw(166, 88)
      JacC( 86, 86) = JacC( 86, 86) - dw(166, 86)
      JacC( 86, 88) = JacC( 86, 88) - dw(166, 88)
      JacC( 88, 86) = JacC( 88, 86) - dw(166, 86)
      JacC( 88, 88) = JacC( 88, 88) - dw(166, 88)
      JacC( 65, 86) = JacC( 65, 86) + dw(167, 86)
      JacC( 65, 88) = JacC( 65, 88) + dw(167, 88)
      JacC( 71, 86) = JacC( 71, 86) + dw(167, 86)
      JacC( 71, 88) = JacC( 71, 88) + dw(167, 88)
      JacC( 86, 86) = JacC( 86, 86) - dw(167, 86)
      JacC( 86, 88) = JacC( 86, 88) - dw(167, 88)
      JacC( 88, 86) = JacC( 88, 86) - dw(167, 86)
      JacC( 88, 88) = JacC( 88, 88) - dw(167, 88)
      JacC( 70, 70) = JacC( 70, 70) - dw(168, 70)
      JacC( 70, 88) = JacC( 70, 88) - dw(168, 88)
      JacC( 73, 70) = JacC( 73, 70) + dw(168, 70)
      JacC( 73, 88) = JacC( 73, 88) + dw(168, 88)
      JacC( 88, 70) = JacC( 88, 70) - dw(168, 70)
      JacC( 88, 88) = JacC( 88, 88) - dw(168, 88)
      JacC( 64, 64) = JacC( 64, 64) - dw(169, 64)
      JacC( 64, 88) = JacC( 64, 88) - dw(169, 88)
      JacC( 83, 64) = JacC( 83, 64) + dw(169, 64)
      JacC( 83, 88) = JacC( 83, 88) + dw(169, 88)
      JacC( 88, 64) = JacC( 88, 64) - dw(169, 64)
      JacC( 88, 88) = JacC( 88, 88) - dw(169, 88)
      JacC( 63, 63) = JacC( 63, 63) - dw(170, 63)
      JacC( 63, 88) = JacC( 63, 88) - dw(170, 88)
      JacC( 83, 63) = JacC( 83, 63) + dw(170, 63)
      JacC( 83, 88) = JacC( 83, 88) + dw(170, 88)
      JacC( 88, 63) = JacC( 88, 63) - dw(170, 63)
      JacC( 88, 88) = JacC( 88, 88) - dw(170, 88)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1330000000000000D+01*dw(171, 82)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1330000000000000D+01*dw(171, 82)
      JacC( 82, 82) = JacC( 82, 82)- 0.2000000000000000D+01*dw(171, 82)
      JacC( 82, 82) = JacC( 82, 82)- 0.2000000000000000D+01*dw(171, 82)
      JacC( 88, 82) = JacC( 88, 82)+ 0.6600000000000000D+00*dw(171, 82)
      JacC( 88, 82) = JacC( 88, 82)+ 0.6600000000000000D+00*dw(171, 82)
      JacC( 78, 78) = JacC( 78, 78) - dw(172, 78)
      JacC( 78, 82) = JacC( 78, 82) - dw(172, 82)
      JacC( 79, 78) = JacC( 79, 78)+ 0.7500000000000000D+00*dw(172, 78)
      JacC( 79, 82) = JacC( 79, 82)+ 0.7500000000000000D+00*dw(172, 82)
      JacC( 81, 78) = JacC( 81, 78)+ 0.7500000000000000D+00*dw(172, 78)
      JacC( 81, 82) = JacC( 81, 82)+ 0.7500000000000000D+00*dw(172, 82)
      JacC( 82, 78) = JacC( 82, 78) - dw(172, 78)
      JacC( 82, 82) = JacC( 82, 82) - dw(172, 82)
      JacC( 88, 78) = JacC( 88, 78) + dw(172, 78)
      JacC( 88, 82) = JacC( 88, 82) + dw(172, 82)
      JacC( 66, 76) = JacC( 66, 76)+ 0.1190000000000000D+00*dw(173, 76)
      JacC( 66, 82) = JacC( 66, 82)+ 0.1190000000000000D+00*dw(173, 82)
      JacC( 72, 76) = JacC( 72, 76)+ 0.5000000000000000D-02*dw(173, 76)
      JacC( 72, 82) = JacC( 72, 82)+ 0.5000000000000000D-02*dw(173, 82)
      JacC( 75, 76) = JacC( 75, 76)+ 0.8500000000000001D-01*dw(173, 76)
      JacC( 75, 82) = JacC( 75, 82)+ 0.8500000000000001D-01*dw(173, 82)
      JacC( 76, 76) = JacC( 76, 76) - dw(173, 76)
      JacC( 76, 82) = JacC( 76, 82) - dw(173, 82)
      JacC( 77, 76) = JacC( 77, 76)+ 0.1800000000000000D-01*dw(173, 76)
      JacC( 77, 82) = JacC( 77, 82)+ 0.1800000000000000D-01*dw(173, 82)
      JacC( 79, 76) = JacC( 79, 76)+ 0.8100000000000001D+00*dw(173, 76)
      JacC( 79, 82) = JacC( 79, 82)+ 0.8100000000000001D+00*dw(173, 82)
      JacC( 81, 76) = JacC( 81, 76)+ 0.5800000000000000D+00*dw(173, 76)
      JacC( 81, 82) = JacC( 81, 82)+ 0.5800000000000000D+00*dw(173, 82)
      JacC( 82, 76) = JacC( 82, 76)- 0.9930000000000000D+00*dw(173, 76)
      JacC( 82, 82) = JacC( 82, 82)- 0.9930000000000000D+00*dw(173, 82)
      JacC( 88, 76) = JacC( 88, 76)+ 0.9920000000000000D+00*dw(173, 76)
      JacC( 88, 82) = JacC( 88, 82)+ 0.9920000000000000D+00*dw(173, 82)
      JacC( 53, 53) = JacC( 53, 53) - dw(174, 53)
      JacC( 53, 82) = JacC( 53, 82) - dw(174, 82)
      JacC( 75, 53) = JacC( 75, 53)+ 0.2450000000000000D+00*dw(174, 53)
      JacC( 75, 82) = JacC( 75, 82)+ 0.2450000000000000D+00*dw(174, 82)
      JacC( 77, 53) = JacC( 77, 53)+ 0.2400000000000000D+00*dw(174, 53)
      JacC( 77, 82) = JacC( 77, 82)+ 0.2400000000000000D+00*dw(174, 82)
      JacC( 78, 53) = JacC( 78, 53)+ 0.1400000000000000D-01*dw(174, 53)
      JacC( 78, 82) = JacC( 78, 82)+ 0.1400000000000000D-01*dw(174, 82)
      JacC( 79, 53) = JacC( 79, 53)+ 0.8290000000000000D+00*dw(174, 53)
      JacC( 79, 82) = JacC( 79, 82)+ 0.8290000000000000D+00*dw(174, 82)
      JacC( 81, 53) = JacC( 81, 53)+ 0.5230000000000000D+00*dw(174, 53)
      JacC( 81, 82) = JacC( 81, 82)+ 0.5230000000000000D+00*dw(174, 82)
      JacC( 82, 53) = JacC( 82, 53)- 0.9510000000000000D+00*dw(174, 53)
      JacC( 82, 82) = JacC( 82, 82)- 0.9510000000000000D+00*dw(174, 82)
      JacC( 88, 53) = JacC( 88, 53)+ 0.9460000000000000D+00*dw(174, 53)
      JacC( 88, 82) = JacC( 88, 82)+ 0.9460000000000000D+00*dw(174, 82)
      JacC( 57, 57) = JacC( 57, 57) - dw(175, 57)
      JacC( 57, 82) = JacC( 57, 82) - dw(175, 82)
      JacC( 75, 57) = JacC( 75, 57)+ 0.3220000000000000D+00*dw(175, 57)
      JacC( 75, 82) = JacC( 75, 82)+ 0.3220000000000000D+00*dw(175, 82)
      JacC( 77, 57) = JacC( 77, 57)+ 0.4190000000000000D+00*dw(175, 57)
      JacC( 77, 82) = JacC( 77, 82)+ 0.4190000000000000D+00*dw(175, 82)
      JacC( 78, 57) = JacC( 78, 57)+ 0.1300000000000000D-01*dw(175, 57)
      JacC( 78, 82) = JacC( 78, 82)+ 0.1300000000000000D-01*dw(175, 82)
      JacC( 79, 57) = JacC( 79, 57)+ 0.7530000000000000D+00*dw(175, 57)
      JacC( 79, 82) = JacC( 79, 82)+ 0.7530000000000000D+00*dw(175, 82)
      JacC( 81, 57) = JacC( 81, 57)+ 0.4110000000000000D+00*dw(175, 57)
      JacC( 81, 82) = JacC( 81, 82)+ 0.4110000000000000D+00*dw(175, 82)
      JacC( 82, 57) = JacC( 82, 57) - dw(175, 57)
      JacC( 82, 82) = JacC( 82, 82) - dw(175, 82)
      JacC( 88, 57) = JacC( 88, 57)+ 0.9930000000000000D+00*dw(175, 57)
      JacC( 88, 82) = JacC( 88, 82)+ 0.9930000000000000D+00*dw(175, 82)
      JacC( 56, 56) = JacC( 56, 56) - dw(176, 56)
      JacC( 56, 82) = JacC( 56, 82) - dw(176, 82)
      JacC( 79, 56) = JacC( 79, 56)+ 0.1550000000000000D+01*dw(176, 56)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1550000000000000D+01*dw(176, 82)
      JacC( 81, 56) = JacC( 81, 56)+ 0.3500000000000000D+00*dw(176, 56)
      JacC( 81, 82) = JacC( 81, 82)+ 0.3500000000000000D+00*dw(176, 82)
      JacC( 82, 56) = JacC( 82, 56) - dw(176, 56)
      JacC( 82, 82) = JacC( 82, 82) - dw(176, 82)
      JacC( 88, 56) = JacC( 88, 56) + dw(176, 56)
      JacC( 88, 82) = JacC( 88, 82) + dw(176, 82)
      JacC( 61, 61) = JacC( 61, 61) - dw(177, 61)
      JacC( 61, 82) = JacC( 61, 82) - dw(177, 82)
      JacC( 77, 61) = JacC( 77, 61)+ 0.8100000000000000D-01*dw(177, 61)
      JacC( 77, 82) = JacC( 77, 82)+ 0.8100000000000000D-01*dw(177, 82)
      JacC( 79, 61) = JacC( 79, 61)+ 0.1250000000000000D+01*dw(177, 61)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1250000000000000D+01*dw(177, 82)
      JacC( 81, 61) = JacC( 81, 61)+ 0.6690000000000000D+00*dw(177, 61)
      JacC( 81, 82) = JacC( 81, 82)+ 0.6690000000000000D+00*dw(177, 82)
      JacC( 82, 61) = JacC( 82, 61) - dw(177, 61)
      JacC( 82, 82) = JacC( 82, 82) - dw(177, 82)
      JacC( 88, 61) = JacC( 88, 61) + dw(177, 61)
      JacC( 88, 82) = JacC( 88, 82) + dw(177, 82)
      JacC( 68, 68) = JacC( 68, 68) - dw(178, 68)
      JacC( 68, 82) = JacC( 68, 82) - dw(178, 82)
      JacC( 77, 68) = JacC( 77, 68)+ 0.3130000000000000D+00*dw(178, 68)
      JacC( 77, 82) = JacC( 77, 82)+ 0.3130000000000000D+00*dw(178, 82)
      JacC( 79, 68) = JacC( 79, 68)+ 0.7550000000000000D+00*dw(178, 68)
      JacC( 79, 82) = JacC( 79, 82)+ 0.7550000000000000D+00*dw(178, 82)
      JacC( 81, 68) = JacC( 81, 68)+ 0.9320000000000001D+00*dw(178, 68)
      JacC( 81, 82) = JacC( 81, 82)+ 0.9320000000000001D+00*dw(178, 82)
      JacC( 82, 68) = JacC( 82, 68) - dw(178, 68)
      JacC( 82, 82) = JacC( 82, 82) - dw(178, 82)
      JacC( 88, 68) = JacC( 88, 68) + dw(178, 68)
      JacC( 88, 82) = JacC( 88, 82) + dw(178, 82)
      JacC( 58, 58) = JacC( 58, 58) - dw(179, 58)
      JacC( 58, 82) = JacC( 58, 82) - dw(179, 82)
      JacC( 59, 58) = JacC( 59, 58)+ 0.5500000000000000D+00*dw(179, 58)
      JacC( 59, 82) = JacC( 59, 82)+ 0.5500000000000000D+00*dw(179, 82)
      JacC( 60, 58) = JacC( 60, 58)+ 0.3700000000000000D+00*dw(179, 58)
      JacC( 60, 82) = JacC( 60, 82)+ 0.3700000000000000D+00*dw(179, 82)
      JacC( 62, 58) = JacC( 62, 58)+ 0.8000000000000000D-01*dw(179, 58)
      JacC( 62, 82) = JacC( 62, 82)+ 0.8000000000000000D-01*dw(179, 82)
      JacC( 79, 58) = JacC( 79, 58)+ 0.1090000000000000D+01*dw(179, 58)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1090000000000000D+01*dw(179, 82)
      JacC( 82, 58) = JacC( 82, 58) - dw(179, 58)
      JacC( 82, 82) = JacC( 82, 82) - dw(179, 82)
      JacC( 88, 58) = JacC( 88, 58) + dw(179, 58)
      JacC( 88, 82) = JacC( 88, 82) + dw(179, 82)
      JacC( 69, 69) = JacC( 69, 69) - dw(180, 69)
      JacC( 69, 82) = JacC( 69, 82) - dw(180, 82)
      JacC( 77, 69) = JacC( 77, 69) + dw(180, 69)
      JacC( 77, 82) = JacC( 77, 82) + dw(180, 82)
      JacC( 79, 69) = JacC( 79, 69) + dw(180, 69)
      JacC( 79, 82) = JacC( 79, 82) + dw(180, 82)
      JacC( 81, 69) = JacC( 81, 69) + dw(180, 69)
      JacC( 81, 82) = JacC( 81, 82) + dw(180, 82)
      JacC( 82, 69) = JacC( 82, 69) - dw(180, 69)
      JacC( 82, 82) = JacC( 82, 82) - dw(180, 82)
      JacC( 88, 69) = JacC( 88, 69)+ 0.2000000000000000D+01*dw(180, 69)
      JacC( 88, 82) = JacC( 88, 82)+ 0.2000000000000000D+01*dw(180, 82)
      JacC( 52, 52) = JacC( 52, 52) - dw(181, 52)
      JacC( 52, 82) = JacC( 52, 82) - dw(181, 82)
      JacC( 59, 52) = JacC( 59, 52)+ 0.6000000000000000D+00*dw(181, 52)
      JacC( 59, 82) = JacC( 59, 82)+ 0.6000000000000000D+00*dw(181, 82)
      JacC( 62, 52) = JacC( 62, 52)+ 0.4000000000000000D+00*dw(181, 52)
      JacC( 62, 82) = JacC( 62, 82)+ 0.4000000000000000D+00*dw(181, 82)
      JacC( 79, 52) = JacC( 79, 52)+ 0.1400000000000000D+01*dw(181, 52)
      JacC( 79, 82) = JacC( 79, 82)+ 0.1400000000000000D+01*dw(181, 82)
      JacC( 82, 52) = JacC( 82, 52) - dw(181, 52)
      JacC( 82, 82) = JacC( 82, 82) - dw(181, 82)
      JacC( 88, 52) = JacC( 88, 52)+ 0.2000000000000000D+01*dw(181, 52)
      JacC( 88, 82) = JacC( 88, 82)+ 0.2000000000000000D+01*dw(181, 82)
      JacC( 40, 40) = JacC( 40, 40) - dw(182, 40)
      JacC( 40, 82) = JacC( 40, 82) - dw(182, 82)
      JacC( 41, 40) = JacC( 41, 40)+ 0.2200000000000000D+00*dw(182, 40)
      JacC( 41, 82) = JacC( 41, 82)+ 0.2200000000000000D+00*dw(182, 82)
      JacC( 54, 40) = JacC( 54, 40) + dw(182, 40)
      JacC( 54, 82) = JacC( 54, 82) + dw(182, 82)
      JacC( 66, 40) = JacC( 66, 40)+ 0.6500000000000000D+00*dw(182, 40)
      JacC( 66, 82) = JacC( 66, 82)+ 0.6500000000000000D+00*dw(182, 82)
      JacC( 72, 40) = JacC( 72, 40)+ 0.3500000000000000D+00*dw(182, 40)
      JacC( 72, 82) = JacC( 72, 82)+ 0.3500000000000000D+00*dw(182, 82)
      JacC( 79, 40) = JacC( 79, 40) + dw(182, 40)
      JacC( 79, 82) = JacC( 79, 82) + dw(182, 82)
      JacC( 82, 40) = JacC( 82, 40) - dw(182, 40)
      JacC( 82, 82) = JacC( 82, 82) - dw(182, 82)
      JacC( 88, 40) = JacC( 88, 40) + dw(182, 40)
      JacC( 88, 82) = JacC( 88, 82) + dw(182, 82)
      JacC( 41, 51) = JacC( 41, 51)+ 0.2200000000000000D+00*dw(183, 51)
      JacC( 41, 82) = JacC( 41, 82)+ 0.2200000000000000D+00*dw(183, 82)
      JacC( 51, 51) = JacC( 51, 51) - dw(183, 51)
      JacC( 51, 82) = JacC( 51, 82) - dw(183, 82)
      JacC( 54, 51) = JacC( 54, 51) + dw(183, 51)
      JacC( 54, 82) = JacC( 54, 82) + dw(183, 82)
      JacC( 66, 51) = JacC( 66, 51)+ 0.3700000000000000D+00*dw(183, 51)
      JacC( 66, 82) = JacC( 66, 82)+ 0.3700000000000000D+00*dw(183, 82)
      JacC( 72, 51) = JacC( 72, 51)+ 0.6300000000000000D+00*dw(183, 51)
      JacC( 72, 82) = JacC( 72, 82)+ 0.6300000000000000D+00*dw(183, 82)
      JacC( 79, 51) = JacC( 79, 51) + dw(183, 51)
      JacC( 79, 82) = JacC( 79, 82) + dw(183, 82)
      JacC( 82, 51) = JacC( 82, 51) - dw(183, 51)
      JacC( 82, 82) = JacC( 82, 82) - dw(183, 82)
      JacC( 88, 51) = JacC( 88, 51) + dw(183, 51)
      JacC( 88, 82) = JacC( 88, 82) + dw(183, 82)
      JacC( 42, 42) = JacC( 42, 42) - dw(184, 42)
      JacC( 42, 82) = JacC( 42, 82) - dw(184, 82)
      JacC( 66, 42) = JacC( 66, 42) + dw(184, 42)
      JacC( 66, 82) = JacC( 66, 82) + dw(184, 82)
      JacC( 72, 42) = JacC( 72, 42) + dw(184, 42)
      JacC( 72, 82) = JacC( 72, 82) + dw(184, 82)
      JacC( 79, 42) = JacC( 79, 42) + dw(184, 42)
      JacC( 79, 82) = JacC( 79, 82) + dw(184, 82)
      JacC( 82, 42) = JacC( 82, 42) - dw(184, 42)
      JacC( 82, 82) = JacC( 82, 82) - dw(184, 82)
      JacC( 88, 42) = JacC( 88, 42)+ 0.2000000000000000D+01*dw(184, 42)
      JacC( 88, 82) = JacC( 88, 82)+ 0.2000000000000000D+01*dw(184, 82)
      JacC( 79, 89) = JacC( 79, 89) + dw(185, 89)
      JacC( 79, 82) = JacC( 79, 82) + dw(185, 82)
      JacC( 88, 89) = JacC( 88, 89) + dw(185, 89)
      JacC( 88, 82) = JacC( 88, 82) + dw(185, 82)
      JacC( 89, 89) = JacC( 89, 89) - dw(185, 89)
      JacC( 89, 82) = JacC( 89, 82) - dw(185, 82)
      JacC( 71, 89) = JacC( 71, 89) + dw(186, 89)
      JacC( 71, 82) = JacC( 71, 82) + dw(186, 82)
      JacC( 79, 89) = JacC( 79, 89) + dw(186, 89)
      JacC( 79, 82) = JacC( 79, 82) + dw(186, 82)
      JacC( 82, 89) = JacC( 82, 89) - dw(186, 89)
      JacC( 82, 82) = JacC( 82, 82) - dw(186, 82)
      JacC( 89, 89) = JacC( 89, 89) - dw(186, 89)
      JacC( 89, 82) = JacC( 89, 82) - dw(186, 82)
      JacC( 79, 86) = JacC( 79, 86)+ 0.2000000000000000D+01*dw(187, 86)
      JacC( 79, 82) = JacC( 79, 82)+ 0.2000000000000000D+01*dw(187, 82)
      JacC( 82, 86) = JacC( 82, 86) - dw(187, 86)
      JacC( 82, 82) = JacC( 82, 82) - dw(187, 82)
      JacC( 86, 86) = JacC( 86, 86) - dw(187, 86)
      JacC( 86, 82) = JacC( 86, 82) - dw(187, 82)
      JacC( 88, 86) = JacC( 88, 86) + dw(187, 86)
      JacC( 88, 82) = JacC( 88, 82) + dw(187, 82)
      JacC( 89, 86) = JacC( 89, 86) + dw(187, 86)
      JacC( 89, 82) = JacC( 89, 82) + dw(187, 82)
      JacC( 71, 86) = JacC( 71, 86) + dw(188, 86)
      JacC( 71, 82) = JacC( 71, 82) + dw(188, 82)
      JacC( 79, 86) = JacC( 79, 86) + dw(188, 86)
      JacC( 79, 82) = JacC( 79, 82) + dw(188, 82)
      JacC( 82, 86) = JacC( 82, 86) - dw(188, 86)
      JacC( 82, 82) = JacC( 82, 82) - dw(188, 82)
      JacC( 86, 86) = JacC( 86, 86) - dw(188, 86)
      JacC( 86, 82) = JacC( 86, 82) - dw(188, 82)
      JacC( 47, 70) = JacC( 47, 70)+ 0.3000000000000000D+00*dw(189, 70)
      JacC( 47, 82) = JacC( 47, 82)+ 0.3000000000000000D+00*dw(189, 82)
      JacC( 70, 70) = JacC( 70, 70) - dw(189, 70)
      JacC( 70, 82) = JacC( 70, 82) - dw(189, 82)
      JacC( 72, 70) = JacC( 72, 70)+ 0.4000000000000000D+00*dw(189, 70)
      JacC( 72, 82) = JacC( 72, 82)+ 0.4000000000000000D+00*dw(189, 82)
      JacC( 75, 70) = JacC( 75, 70)+ 0.8000000000000000D-01*dw(189, 70)
      JacC( 75, 82) = JacC( 75, 82)+ 0.8000000000000000D-01*dw(189, 82)
      JacC( 79, 70) = JacC( 79, 70)+ 0.7500000000000000D+00*dw(189, 70)
      JacC( 79, 82) = JacC( 79, 82)+ 0.7500000000000000D+00*dw(189, 82)
      JacC( 81, 70) = JacC( 81, 70)+ 0.3000000000000000D+00*dw(189, 70)
      JacC( 81, 82) = JacC( 81, 82)+ 0.3000000000000000D+00*dw(189, 82)
      JacC( 82, 70) = JacC( 82, 70) - dw(189, 70)
      JacC( 82, 82) = JacC( 82, 82) - dw(189, 82)
      JacC( 88, 70) = JacC( 88, 70)+ 0.8800000000000000D+00*dw(189, 70)
      JacC( 88, 82) = JacC( 88, 82)+ 0.8800000000000000D+00*dw(189, 82)
      JacC( 89, 70) = JacC( 89, 70)+ 0.1200000000000000D+00*dw(189, 70)
      JacC( 89, 82) = JacC( 89, 82)+ 0.1200000000000000D+00*dw(189, 82)
      JacC( 64, 64) = JacC( 64, 64) - dw(190, 64)
      JacC( 64, 82) = JacC( 64, 82) - dw(190, 82)
      JacC( 79, 64) = JacC( 79, 64)+ 0.7500000000000000D+00*dw(190, 64)
      JacC( 79, 82) = JacC( 79, 82)+ 0.7500000000000000D+00*dw(190, 82)
      JacC( 82, 64) = JacC( 82, 64) - dw(190, 64)
      JacC( 82, 82) = JacC( 82, 82) - dw(190, 82)
      JacC( 83, 64) = JacC( 83, 64) + dw(190, 64)
      JacC( 83, 82) = JacC( 83, 82) + dw(190, 82)
      JacC( 88, 64) = JacC( 88, 64) + dw(190, 64)
      JacC( 88, 82) = JacC( 88, 82) + dw(190, 82)
      JacC( 63, 63) = JacC( 63, 63) - dw(191, 63)
      JacC( 63, 82) = JacC( 63, 82) - dw(191, 82)
      JacC( 77, 63) = JacC( 77, 63)+ 0.1490000000000000D+00*dw(191, 63)
      JacC( 77, 82) = JacC( 77, 82)+ 0.1490000000000000D+00*dw(191, 82)
      JacC( 79, 63) = JacC( 79, 63)+ 0.9600000000000000D+00*dw(191, 63)
      JacC( 79, 82) = JacC( 79, 82)+ 0.9600000000000000D+00*dw(191, 82)
      JacC( 81, 63) = JacC( 81, 63)+ 0.6400000000000000D+00*dw(191, 63)
      JacC( 81, 82) = JacC( 81, 82)+ 0.6400000000000000D+00*dw(191, 82)
      JacC( 82, 63) = JacC( 82, 63) - dw(191, 63)
      JacC( 82, 82) = JacC( 82, 82) - dw(191, 82)
      JacC( 83, 63) = JacC( 83, 63)+ 0.5000000000000000D+00*dw(191, 63)
      JacC( 83, 82) = JacC( 83, 82)+ 0.5000000000000000D+00*dw(191, 82)
      JacC( 84, 63) = JacC( 84, 63)+ 0.5000000000000000D+00*dw(191, 63)
      JacC( 84, 82) = JacC( 84, 82)+ 0.5000000000000000D+00*dw(191, 82)
      JacC( 88, 63) = JacC( 88, 63)+ 0.5000000000000000D+00*dw(191, 63)
      JacC( 88, 82) = JacC( 88, 82)+ 0.5000000000000000D+00*dw(191, 82)
      JacC( 71, 78) = JacC( 71, 78)+ 0.5000000000000000D+00*dw(192, 78)
      JacC( 71, 89) = JacC( 71, 89)+ 0.5000000000000000D+00*dw(192, 89)
      JacC( 78, 78) = JacC( 78, 78) - dw(192, 78)
      JacC( 78, 89) = JacC( 78, 89) - dw(192, 89)
      JacC( 81, 78) = JacC( 81, 78) + dw(192, 78)
      JacC( 81, 89) = JacC( 81, 89) + dw(192, 89)
      JacC( 82, 78) = JacC( 82, 78)+ 0.5000000000000000D+00*dw(192, 78)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5000000000000000D+00*dw(192, 89)
      JacC( 88, 78) = JacC( 88, 78)+ 0.5000000000000000D+00*dw(192, 78)
      JacC( 88, 89) = JacC( 88, 89)+ 0.5000000000000000D+00*dw(192, 89)
      JacC( 89, 78) = JacC( 89, 78) - dw(192, 78)
      JacC( 89, 89) = JacC( 89, 89) - dw(192, 89)
      JacC( 66, 76) = JacC( 66, 76)+ 0.1000000000000000D+00*dw(193, 76)
      JacC( 66, 89) = JacC( 66, 89)+ 0.1000000000000000D+00*dw(193, 89)
      JacC( 71, 76) = JacC( 71, 76)+ 0.4990000000000000D+00*dw(193, 76)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4990000000000000D+00*dw(193, 89)
      JacC( 72, 76) = JacC( 72, 76)+ 0.4000000000000000D-02*dw(193, 76)
      JacC( 72, 89) = JacC( 72, 89)+ 0.4000000000000000D-02*dw(193, 89)
      JacC( 75, 76) = JacC( 75, 76)+ 0.7099999999999999D-01*dw(193, 76)
      JacC( 75, 89) = JacC( 75, 89)+ 0.7099999999999999D-01*dw(193, 89)
      JacC( 76, 76) = JacC( 76, 76) - dw(193, 76)
      JacC( 76, 89) = JacC( 76, 89) - dw(193, 89)
      JacC( 77, 76) = JacC( 77, 76)+ 0.1270000000000000D+00*dw(193, 76)
      JacC( 77, 89) = JacC( 77, 89)+ 0.1270000000000000D+00*dw(193, 89)
      JacC( 78, 76) = JacC( 78, 76)+ 0.6000000000000000D-02*dw(193, 76)
      JacC( 78, 89) = JacC( 78, 89)+ 0.6000000000000000D-02*dw(193, 89)
      JacC( 79, 76) = JacC( 79, 76)+ 0.9100000000000000D-01*dw(193, 76)
      JacC( 79, 89) = JacC( 79, 89)+ 0.9100000000000000D-01*dw(193, 89)
      JacC( 81, 76) = JacC( 81, 76)+ 0.7240000000000000D+00*dw(193, 76)
      JacC( 81, 89) = JacC( 81, 89)+ 0.7240000000000000D+00*dw(193, 89)
      JacC( 82, 76) = JacC( 82, 76)+ 0.5080000000000000D+00*dw(193, 76)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5080000000000000D+00*dw(193, 89)
      JacC( 88, 76) = JacC( 88, 76)+ 0.4880000000000000D+00*dw(193, 76)
      JacC( 88, 89) = JacC( 88, 89)+ 0.4880000000000000D+00*dw(193, 89)
      JacC( 89, 76) = JacC( 89, 76) - dw(193, 76)
      JacC( 89, 89) = JacC( 89, 89) - dw(193, 89)
      JacC( 53, 53) = JacC( 53, 53) - dw(194, 53)
      JacC( 53, 89) = JacC( 53, 89) - dw(194, 89)
      JacC( 71, 53) = JacC( 71, 53)+ 0.4950000000000000D+00*dw(194, 53)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4950000000000000D+00*dw(194, 89)
      JacC( 75, 53) = JacC( 75, 53)+ 0.2370000000000000D+00*dw(194, 53)
      JacC( 75, 89) = JacC( 75, 89)+ 0.2370000000000000D+00*dw(194, 89)
      JacC( 77, 53) = JacC( 77, 53)+ 0.3300000000000000D+00*dw(194, 53)
      JacC( 77, 89) = JacC( 77, 89)+ 0.3300000000000000D+00*dw(194, 89)
      JacC( 78, 53) = JacC( 78, 53)+ 0.1800000000000000D-01*dw(194, 53)
      JacC( 78, 89) = JacC( 78, 89)+ 0.1800000000000000D-01*dw(194, 89)
      JacC( 79, 53) = JacC( 79, 53)+ 0.7600000000000000D-01*dw(194, 53)
      JacC( 79, 89) = JacC( 79, 89)+ 0.7600000000000000D-01*dw(194, 89)
      JacC( 81, 53) = JacC( 81, 53)+ 0.6770000000000000D+00*dw(194, 53)
      JacC( 81, 89) = JacC( 81, 89)+ 0.6770000000000000D+00*dw(194, 89)
      JacC( 82, 53) = JacC( 82, 53)+ 0.5540000000000000D+00*dw(194, 53)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5540000000000000D+00*dw(194, 89)
      JacC( 88, 53) = JacC( 88, 53)+ 0.4380000000000000D+00*dw(194, 53)
      JacC( 88, 89) = JacC( 88, 89)+ 0.4380000000000000D+00*dw(194, 89)
      JacC( 89, 53) = JacC( 89, 53) - dw(194, 53)
      JacC( 89, 89) = JacC( 89, 89) - dw(194, 89)
      JacC( 57, 57) = JacC( 57, 57) - dw(195, 57)
      JacC( 57, 89) = JacC( 57, 89) - dw(195, 89)
      JacC( 71, 57) = JacC( 71, 57)+ 0.4950000000000000D+00*dw(195, 57)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4950000000000000D+00*dw(195, 89)
      JacC( 75, 57) = JacC( 75, 57)+ 0.3180000000000000D+00*dw(195, 57)
      JacC( 75, 89) = JacC( 75, 89)+ 0.3180000000000000D+00*dw(195, 89)
      JacC( 77, 57) = JacC( 77, 57)+ 0.5810000000000000D+00*dw(195, 57)
      JacC( 77, 89) = JacC( 77, 89)+ 0.5810000000000000D+00*dw(195, 89)
      JacC( 78, 57) = JacC( 78, 57)+ 0.1500000000000000D-01*dw(195, 57)
      JacC( 78, 89) = JacC( 78, 89)+ 0.1500000000000000D-01*dw(195, 89)
      JacC( 81, 57) = JacC( 81, 57)+ 0.4970000000000000D+00*dw(195, 57)
      JacC( 81, 89) = JacC( 81, 89)+ 0.4970000000000000D+00*dw(195, 89)
      JacC( 82, 57) = JacC( 82, 57)+ 0.5070000000000000D+00*dw(195, 57)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5070000000000000D+00*dw(195, 89)
      JacC( 88, 57) = JacC( 88, 57)+ 0.4890000000000000D+00*dw(195, 57)
      JacC( 88, 89) = JacC( 88, 89)+ 0.4890000000000000D+00*dw(195, 89)
      JacC( 89, 57) = JacC( 89, 57) - dw(195, 57)
      JacC( 89, 89) = JacC( 89, 89) - dw(195, 89)
      JacC( 56, 56) = JacC( 56, 56) - dw(196, 56)
      JacC( 56, 89) = JacC( 56, 89) - dw(196, 89)
      JacC( 71, 56) = JacC( 71, 56)+ 0.5000000000000000D+00*dw(196, 56)
      JacC( 71, 89) = JacC( 71, 89)+ 0.5000000000000000D+00*dw(196, 89)
      JacC( 79, 56) = JacC( 79, 56)+ 0.8000000000000000D+00*dw(196, 56)
      JacC( 79, 89) = JacC( 79, 89)+ 0.8000000000000000D+00*dw(196, 89)
      JacC( 81, 56) = JacC( 81, 56)+ 0.6000000000000000D+00*dw(196, 56)
      JacC( 81, 89) = JacC( 81, 89)+ 0.6000000000000000D+00*dw(196, 89)
      JacC( 82, 56) = JacC( 82, 56)+ 0.5000000000000000D+00*dw(196, 56)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5000000000000000D+00*dw(196, 89)
      JacC( 88, 56) = JacC( 88, 56)+ 0.5000000000000000D+00*dw(196, 56)
      JacC( 88, 89) = JacC( 88, 89)+ 0.5000000000000000D+00*dw(196, 89)
      JacC( 89, 56) = JacC( 89, 56) - dw(196, 56)
      JacC( 89, 89) = JacC( 89, 89) - dw(196, 89)
      JacC( 61, 61) = JacC( 61, 61) - dw(197, 61)
      JacC( 61, 89) = JacC( 61, 89) - dw(197, 89)
      JacC( 71, 61) = JacC( 71, 61)+ 0.4990000000000000D+00*dw(197, 61)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4990000000000000D+00*dw(197, 89)
      JacC( 77, 61) = JacC( 77, 61)+ 0.1410000000000000D+00*dw(197, 61)
      JacC( 77, 89) = JacC( 77, 89)+ 0.1410000000000000D+00*dw(197, 89)
      JacC( 79, 61) = JacC( 79, 61)+ 0.5010000000000000D+00*dw(197, 61)
      JacC( 79, 89) = JacC( 79, 89)+ 0.5010000000000000D+00*dw(197, 89)
      JacC( 81, 61) = JacC( 81, 61)+ 0.8590000000000000D+00*dw(197, 61)
      JacC( 81, 89) = JacC( 81, 89)+ 0.8590000000000000D+00*dw(197, 89)
      JacC( 82, 61) = JacC( 82, 61)+ 0.5010000000000000D+00*dw(197, 61)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5010000000000000D+00*dw(197, 89)
      JacC( 88, 61) = JacC( 88, 61)+ 0.5010000000000000D+00*dw(197, 61)
      JacC( 88, 89) = JacC( 88, 89)+ 0.5010000000000000D+00*dw(197, 89)
      JacC( 89, 61) = JacC( 89, 61) - dw(197, 61)
      JacC( 89, 89) = JacC( 89, 89) - dw(197, 89)
      JacC( 68, 68) = JacC( 68, 68) - dw(198, 68)
      JacC( 68, 89) = JacC( 68, 89) - dw(198, 89)
      JacC( 71, 68) = JacC( 71, 68)+ 0.4900000000000000D+00*dw(198, 68)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4900000000000000D+00*dw(198, 89)
      JacC( 77, 68) = JacC( 77, 68)+ 0.5690000000000000D+00*dw(198, 68)
      JacC( 77, 89) = JacC( 77, 89)+ 0.5690000000000000D+00*dw(198, 89)
      JacC( 81, 68) = JacC( 81, 68)+ 0.9409999999999999D+00*dw(198, 68)
      JacC( 81, 89) = JacC( 81, 89)+ 0.9409999999999999D+00*dw(198, 89)
      JacC( 82, 68) = JacC( 82, 68)+ 0.5100000000000000D+00*dw(198, 68)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5100000000000000D+00*dw(198, 89)
      JacC( 88, 68) = JacC( 88, 68)+ 0.5100000000000000D+00*dw(198, 68)
      JacC( 88, 89) = JacC( 88, 89)+ 0.5100000000000000D+00*dw(198, 89)
      JacC( 89, 68) = JacC( 89, 68) - dw(198, 68)
      JacC( 89, 89) = JacC( 89, 89) - dw(198, 89)
      JacC( 58, 58) = JacC( 58, 58) - dw(199, 58)
      JacC( 58, 89) = JacC( 58, 89) - dw(199, 89)
      JacC( 59, 58) = JacC( 59, 58)+ 0.7710000000000000D+00*dw(199, 58)
      JacC( 59, 89) = JacC( 59, 89)+ 0.7710000000000000D+00*dw(199, 89)
      JacC( 60, 58) = JacC( 60, 58)+ 0.2290000000000000D+00*dw(199, 58)
      JacC( 60, 89) = JacC( 60, 89)+ 0.2290000000000000D+00*dw(199, 89)
      JacC( 71, 58) = JacC( 71, 58)+ 0.4940000000000000D+00*dw(199, 58)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4940000000000000D+00*dw(199, 89)
      JacC( 79, 58) = JacC( 79, 58)+ 0.3400000000000000D+00*dw(199, 58)
      JacC( 79, 89) = JacC( 79, 89)+ 0.3400000000000000D+00*dw(199, 89)
      JacC( 82, 58) = JacC( 82, 58)+ 0.5060000000000000D+00*dw(199, 58)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5060000000000000D+00*dw(199, 89)
      JacC( 88, 58) = JacC( 88, 58)+ 0.5060000000000000D+00*dw(199, 58)
      JacC( 88, 89) = JacC( 88, 89)+ 0.5060000000000000D+00*dw(199, 89)
      JacC( 89, 58) = JacC( 89, 58) - dw(199, 58)
      JacC( 89, 89) = JacC( 89, 89) - dw(199, 89)
      JacC( 69, 69) = JacC( 69, 69) - dw(200, 69)
      JacC( 69, 89) = JacC( 69, 89) - dw(200, 89)
      JacC( 77, 69) = JacC( 77, 69) + dw(200, 69)
      JacC( 77, 89) = JacC( 77, 89) + dw(200, 89)
      JacC( 81, 69) = JacC( 81, 69) + dw(200, 69)
      JacC( 81, 89) = JacC( 81, 89) + dw(200, 89)
      JacC( 82, 69) = JacC( 82, 69) + dw(200, 69)
      JacC( 82, 89) = JacC( 82, 89) + dw(200, 89)
      JacC( 88, 69) = JacC( 88, 69) + dw(200, 69)
      JacC( 88, 89) = JacC( 88, 89) + dw(200, 89)
      JacC( 89, 69) = JacC( 89, 69) - dw(200, 69)
      JacC( 89, 89) = JacC( 89, 89) - dw(200, 89)
      JacC( 52, 52) = JacC( 52, 52) - dw(201, 52)
      JacC( 52, 89) = JacC( 52, 89) - dw(201, 89)
      JacC( 59, 52) = JacC( 59, 52)+ 0.6000000000000000D+00*dw(201, 52)
      JacC( 59, 89) = JacC( 59, 89)+ 0.6000000000000000D+00*dw(201, 89)
      JacC( 62, 52) = JacC( 62, 52)+ 0.4000000000000000D+00*dw(201, 52)
      JacC( 62, 89) = JacC( 62, 89)+ 0.4000000000000000D+00*dw(201, 89)
      JacC( 79, 52) = JacC( 79, 52)+ 0.4000000000000000D+00*dw(201, 52)
      JacC( 79, 89) = JacC( 79, 89)+ 0.4000000000000000D+00*dw(201, 89)
      JacC( 82, 52) = JacC( 82, 52) + dw(201, 52)
      JacC( 82, 89) = JacC( 82, 89) + dw(201, 89)
      JacC( 88, 52) = JacC( 88, 52) + dw(201, 52)
      JacC( 88, 89) = JacC( 88, 89) + dw(201, 89)
      JacC( 89, 52) = JacC( 89, 52) - dw(201, 52)
      JacC( 89, 89) = JacC( 89, 89) - dw(201, 89)
      JacC( 40, 40) = JacC( 40, 40) - dw(202, 40)
      JacC( 40, 89) = JacC( 40, 89) - dw(202, 89)
      JacC( 41, 40) = JacC( 41, 40)+ 0.2200000000000000D+00*dw(202, 40)
      JacC( 41, 89) = JacC( 41, 89)+ 0.2200000000000000D+00*dw(202, 89)
      JacC( 54, 40) = JacC( 54, 40) + dw(202, 40)
      JacC( 54, 89) = JacC( 54, 89) + dw(202, 89)
      JacC( 66, 40) = JacC( 66, 40)+ 0.6500000000000000D+00*dw(202, 40)
      JacC( 66, 89) = JacC( 66, 89)+ 0.6500000000000000D+00*dw(202, 89)
      JacC( 72, 40) = JacC( 72, 40)+ 0.3500000000000000D+00*dw(202, 40)
      JacC( 72, 89) = JacC( 72, 89)+ 0.3500000000000000D+00*dw(202, 89)
      JacC( 82, 40) = JacC( 82, 40) + dw(202, 40)
      JacC( 82, 89) = JacC( 82, 89) + dw(202, 89)
      JacC( 88, 40) = JacC( 88, 40) + dw(202, 40)
      JacC( 88, 89) = JacC( 88, 89) + dw(202, 89)
      JacC( 89, 40) = JacC( 89, 40) - dw(202, 40)
      JacC( 89, 89) = JacC( 89, 89) - dw(202, 89)
      JacC( 41, 51) = JacC( 41, 51)+ 0.2200000000000000D+00*dw(203, 51)
      JacC( 41, 89) = JacC( 41, 89)+ 0.2200000000000000D+00*dw(203, 89)
      JacC( 51, 51) = JacC( 51, 51) - dw(203, 51)
      JacC( 51, 89) = JacC( 51, 89) - dw(203, 89)
      JacC( 54, 51) = JacC( 54, 51) + dw(203, 51)
      JacC( 54, 89) = JacC( 54, 89) + dw(203, 89)
      JacC( 66, 51) = JacC( 66, 51)+ 0.3700000000000000D+00*dw(203, 51)
      JacC( 66, 89) = JacC( 66, 89)+ 0.3700000000000000D+00*dw(203, 89)
      JacC( 72, 51) = JacC( 72, 51)+ 0.6300000000000000D+00*dw(203, 51)
      JacC( 72, 89) = JacC( 72, 89)+ 0.6300000000000000D+00*dw(203, 89)
      JacC( 82, 51) = JacC( 82, 51) + dw(203, 51)
      JacC( 82, 89) = JacC( 82, 89) + dw(203, 89)
      JacC( 88, 51) = JacC( 88, 51) + dw(203, 51)
      JacC( 88, 89) = JacC( 88, 89) + dw(203, 89)
      JacC( 89, 51) = JacC( 89, 51) - dw(203, 51)
      JacC( 89, 89) = JacC( 89, 89) - dw(203, 89)
      JacC( 42, 42) = JacC( 42, 42) - dw(204, 42)
      JacC( 42, 89) = JacC( 42, 89) - dw(204, 89)
      JacC( 66, 42) = JacC( 66, 42) + dw(204, 42)
      JacC( 66, 89) = JacC( 66, 89) + dw(204, 89)
      JacC( 72, 42) = JacC( 72, 42) + dw(204, 42)
      JacC( 72, 89) = JacC( 72, 89) + dw(204, 89)
      JacC( 82, 42) = JacC( 82, 42) + dw(204, 42)
      JacC( 82, 89) = JacC( 82, 89) + dw(204, 89)
      JacC( 88, 42) = JacC( 88, 42) + dw(204, 42)
      JacC( 88, 89) = JacC( 88, 89) + dw(204, 89)
      JacC( 89, 42) = JacC( 89, 42) - dw(204, 42)
      JacC( 89, 89) = JacC( 89, 89) - dw(204, 89)
      JacC( 82, 89) = JacC( 82, 89)+ 0.2000000000000000D+01*dw(205, 89)
      JacC( 82, 89) = JacC( 82, 89)+ 0.2000000000000000D+01*dw(205, 89)
      JacC( 89, 89) = JacC( 89, 89)- 0.2000000000000000D+01*dw(205, 89)
      JacC( 89, 89) = JacC( 89, 89)- 0.2000000000000000D+01*dw(205, 89)
      JacC( 79, 86) = JacC( 79, 86) + dw(206, 86)
      JacC( 79, 89) = JacC( 79, 89) + dw(206, 89)
      JacC( 82, 86) = JacC( 82, 86) + dw(206, 86)
      JacC( 82, 89) = JacC( 82, 89) + dw(206, 89)
      JacC( 86, 86) = JacC( 86, 86) - dw(206, 86)
      JacC( 86, 89) = JacC( 86, 89) - dw(206, 89)
      JacC( 70, 70) = JacC( 70, 70) - dw(207, 70)
      JacC( 70, 89) = JacC( 70, 89) - dw(207, 89)
      JacC( 71, 70) = JacC( 71, 70)+ 0.5000000000000000D+00*dw(207, 70)
      JacC( 71, 89) = JacC( 71, 89)+ 0.5000000000000000D+00*dw(207, 89)
      JacC( 72, 70) = JacC( 72, 70)+ 0.5400000000000000D+00*dw(207, 70)
      JacC( 72, 89) = JacC( 72, 89)+ 0.5400000000000000D+00*dw(207, 89)
      JacC( 75, 70) = JacC( 75, 70)+ 0.8000000000000000D-01*dw(207, 70)
      JacC( 75, 89) = JacC( 75, 89)+ 0.8000000000000000D-01*dw(207, 89)
      JacC( 77, 70) = JacC( 77, 70)+ 0.1100000000000000D+00*dw(207, 70)
      JacC( 77, 89) = JacC( 77, 89)+ 0.1100000000000000D+00*dw(207, 89)
      JacC( 81, 70) = JacC( 81, 70)+ 0.3500000000000000D+00*dw(207, 70)
      JacC( 81, 89) = JacC( 81, 89)+ 0.3500000000000000D+00*dw(207, 89)
      JacC( 82, 70) = JacC( 82, 70)+ 0.5000000000000000D+00*dw(207, 70)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5000000000000000D+00*dw(207, 89)
      JacC( 88, 70) = JacC( 88, 70)+ 0.3800000000000000D+00*dw(207, 70)
      JacC( 88, 89) = JacC( 88, 89)+ 0.3800000000000000D+00*dw(207, 89)
      JacC( 89, 70) = JacC( 89, 70)- 0.8800000000000000D+00*dw(207, 70)
      JacC( 89, 89) = JacC( 89, 89)- 0.8800000000000000D+00*dw(207, 89)
      JacC( 64, 64) = JacC( 64, 64) - dw(208, 64)
      JacC( 64, 89) = JacC( 64, 89) - dw(208, 89)
      JacC( 71, 64) = JacC( 71, 64)+ 0.5000000000000000D+00*dw(208, 64)
      JacC( 71, 89) = JacC( 71, 89)+ 0.5000000000000000D+00*dw(208, 89)
      JacC( 82, 64) = JacC( 82, 64)+ 0.5000000000000000D+00*dw(208, 64)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5000000000000000D+00*dw(208, 89)
      JacC( 83, 64) = JacC( 83, 64) + dw(208, 64)
      JacC( 83, 89) = JacC( 83, 89) + dw(208, 89)
      JacC( 88, 64) = JacC( 88, 64)+ 0.5000000000000000D+00*dw(208, 64)
      JacC( 88, 89) = JacC( 88, 89)+ 0.5000000000000000D+00*dw(208, 89)
      JacC( 89, 64) = JacC( 89, 64) - dw(208, 64)
      JacC( 89, 89) = JacC( 89, 89) - dw(208, 89)
      JacC( 63, 63) = JacC( 63, 63) - dw(209, 63)
      JacC( 63, 89) = JacC( 63, 89) - dw(209, 89)
      JacC( 71, 63) = JacC( 71, 63)+ 0.4840000000000000D+00*dw(209, 63)
      JacC( 71, 89) = JacC( 71, 89)+ 0.4840000000000000D+00*dw(209, 89)
      JacC( 77, 63) = JacC( 77, 63)+ 0.1670000000000000D+00*dw(209, 63)
      JacC( 77, 89) = JacC( 77, 89)+ 0.1670000000000000D+00*dw(209, 89)
      JacC( 79, 63) = JacC( 79, 63)+ 0.2070000000000000D+00*dw(209, 63)
      JacC( 79, 89) = JacC( 79, 89)+ 0.2070000000000000D+00*dw(209, 89)
      JacC( 81, 63) = JacC( 81, 63)+ 0.6500000000000000D+00*dw(209, 63)
      JacC( 81, 89) = JacC( 81, 89)+ 0.6500000000000000D+00*dw(209, 89)
      JacC( 82, 63) = JacC( 82, 63)+ 0.5160000000000000D+00*dw(209, 63)
      JacC( 82, 89) = JacC( 82, 89)+ 0.5160000000000000D+00*dw(209, 89)
      JacC( 83, 63) = JacC( 83, 63)+ 0.4840000000000000D+00*dw(209, 63)
      JacC( 83, 89) = JacC( 83, 89)+ 0.4840000000000000D+00*dw(209, 89)
      JacC( 84, 63) = JacC( 84, 63)+ 0.5160000000000000D+00*dw(209, 63)
      JacC( 84, 89) = JacC( 84, 89)+ 0.5160000000000000D+00*dw(209, 89)
      JacC( 89, 63) = JacC( 89, 63) - dw(209, 63)
      JacC( 89, 89) = JacC( 89, 89) - dw(209, 89)
      JacC( 64, 64) = JacC( 64, 64)- 0.2000000000000000D+01*dw(210, 64)
      JacC( 64, 64) = JacC( 64, 64)- 0.2000000000000000D+01*dw(210, 64)
      JacC( 83, 64) = JacC( 83, 64)+ 0.2000000000000000D+01*dw(210, 64)
      JacC( 83, 64) = JacC( 83, 64)+ 0.2000000000000000D+01*dw(210, 64)
      JacC( 88, 64) = JacC( 88, 64) + dw(210, 64)
      JacC( 88, 64) = JacC( 88, 64) + dw(210, 64)
      JacC( 63, 64) = JacC( 63, 64) - dw(211, 64)
      JacC( 63, 63) = JacC( 63, 63) - dw(211, 63)
      JacC( 64, 64) = JacC( 64, 64) - dw(211, 64)
      JacC( 64, 63) = JacC( 64, 63) - dw(211, 63)
      JacC( 77, 64) = JacC( 77, 64)+ 0.1490000000000000D+00*dw(211, 64)
      JacC( 77, 63) = JacC( 77, 63)+ 0.1490000000000000D+00*dw(211, 63)
      JacC( 79, 64) = JacC( 79, 64)+ 0.2020000000000000D+00*dw(211, 64)
      JacC( 79, 63) = JacC( 79, 63)+ 0.2020000000000000D+00*dw(211, 63)
      JacC( 81, 64) = JacC( 81, 64)+ 0.6400000000000000D+00*dw(211, 64)
      JacC( 81, 63) = JacC( 81, 63)+ 0.6400000000000000D+00*dw(211, 63)
      JacC( 83, 64) = JacC( 83, 64)+ 0.1500000000000000D+01*dw(211, 64)
      JacC( 83, 63) = JacC( 83, 63)+ 0.1500000000000000D+01*dw(211, 63)
      JacC( 84, 64) = JacC( 84, 64)+ 0.5000000000000000D+00*dw(211, 64)
      JacC( 84, 63) = JacC( 84, 63)+ 0.5000000000000000D+00*dw(211, 63)
      JacC( 88, 64) = JacC( 88, 64)+ 0.5000000000000000D+00*dw(211, 64)
      JacC( 88, 63) = JacC( 88, 63)+ 0.5000000000000000D+00*dw(211, 63)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw(212, 63)
      JacC( 63, 63) = JacC( 63, 63)- 0.2000000000000000D+01*dw(212, 63)
      JacC( 77, 63) = JacC( 77, 63)+ 0.2850000000000000D+00*dw(212, 63)
      JacC( 77, 63) = JacC( 77, 63)+ 0.2850000000000000D+00*dw(212, 63)
      JacC( 79, 63) = JacC( 79, 63)+ 0.5040000000000000D+00*dw(212, 63)
      JacC( 79, 63) = JacC( 79, 63)+ 0.5040000000000000D+00*dw(212, 63)
      JacC( 81, 63) = JacC( 81, 63)+ 0.1210000000000000D+01*dw(212, 63)
      JacC( 81, 63) = JacC( 81, 63)+ 0.1210000000000000D+01*dw(212, 63)
      JacC( 83, 63) = JacC( 83, 63) + dw(212, 63)
      JacC( 83, 63) = JacC( 83, 63) + dw(212, 63)
      JacC( 84, 63) = JacC( 84, 63) + dw(212, 63)
      JacC( 84, 63) = JacC( 84, 63) + dw(212, 63)
      JacC( 79, 82) = JacC( 79, 82) + dw(213, 82)
      JacC( 79, 87) = JacC( 79, 87) + dw(213, 87)
      JacC( 82, 82) = JacC( 82, 82) - dw(213, 82)
      JacC( 82, 87) = JacC( 82, 87) - dw(213, 87)
      JacC( 84, 82) = JacC( 84, 82) + dw(213, 82)
      JacC( 84, 87) = JacC( 84, 87) + dw(213, 87)
      JacC( 87, 82) = JacC( 87, 82) - dw(213, 82)
      JacC( 87, 87) = JacC( 87, 87) - dw(213, 87)
      JacC( 88, 82) = JacC( 88, 82) + dw(213, 82)
      JacC( 88, 87) = JacC( 88, 87) + dw(213, 87)
      JacC( 78, 78) = JacC( 78, 78) - dw(214, 78)
      JacC( 78, 87) = JacC( 78, 87) - dw(214, 87)
      JacC( 81, 78) = JacC( 81, 78) + dw(214, 78)
      JacC( 81, 87) = JacC( 81, 87) + dw(214, 87)
      JacC( 84, 78) = JacC( 84, 78) + dw(214, 78)
      JacC( 84, 87) = JacC( 84, 87) + dw(214, 87)
      JacC( 87, 78) = JacC( 87, 78) - dw(214, 78)
      JacC( 87, 87) = JacC( 87, 87) - dw(214, 87)
      JacC( 88, 78) = JacC( 88, 78) + dw(214, 78)
      JacC( 88, 87) = JacC( 88, 87) + dw(214, 87)
      JacC( 66, 76) = JacC( 66, 76)+ 0.6300000000000000D-01*dw(215, 76)
      JacC( 66, 87) = JacC( 66, 87)+ 0.6300000000000000D-01*dw(215, 87)
      JacC( 75, 76) = JacC( 75, 76)+ 0.5100000000000000D-01*dw(215, 76)
      JacC( 75, 87) = JacC( 75, 87)+ 0.5100000000000000D-01*dw(215, 87)
      JacC( 76, 76) = JacC( 76, 76) - dw(215, 76)
      JacC( 76, 87) = JacC( 76, 87) - dw(215, 87)
      JacC( 77, 76) = JacC( 77, 76)+ 0.6700000000000000D+00*dw(215, 76)
      JacC( 77, 87) = JacC( 77, 87)+ 0.6700000000000000D+00*dw(215, 87)
      JacC( 78, 76) = JacC( 78, 76)+ 0.5300000000000000D-01*dw(215, 76)
      JacC( 78, 87) = JacC( 78, 87)+ 0.5300000000000000D-01*dw(215, 87)
      JacC( 79, 76) = JacC( 79, 76)+ 0.4800000000000000D-01*dw(215, 76)
      JacC( 79, 87) = JacC( 79, 87)+ 0.4800000000000000D-01*dw(215, 87)
      JacC( 81, 76) = JacC( 81, 76)+ 0.2430000000000000D+00*dw(215, 76)
      JacC( 81, 87) = JacC( 81, 87)+ 0.2430000000000000D+00*dw(215, 87)
      JacC( 82, 76) = JacC( 82, 76)+ 0.1550000000000000D+00*dw(215, 76)
      JacC( 82, 87) = JacC( 82, 87)+ 0.1550000000000000D+00*dw(215, 87)
      JacC( 84, 76) = JacC( 84, 76) + dw(215, 76)
      JacC( 84, 87) = JacC( 84, 87) + dw(215, 87)
      JacC( 87, 76) = JacC( 87, 76) - dw(215, 76)
      JacC( 87, 87) = JacC( 87, 87) - dw(215, 87)
      JacC( 88, 76) = JacC( 88, 76)+ 0.7920000000000000D+00*dw(215, 76)
      JacC( 88, 87) = JacC( 88, 87)+ 0.7920000000000000D+00*dw(215, 87)
      JacC( 53, 53) = JacC( 53, 53) - dw(216, 53)
      JacC( 53, 87) = JacC( 53, 87) - dw(216, 87)
      JacC( 75, 53) = JacC( 75, 53)+ 0.3910000000000000D+00*dw(216, 53)
      JacC( 75, 87) = JacC( 75, 87)+ 0.3910000000000000D+00*dw(216, 87)
      JacC( 77, 53) = JacC( 77, 53)+ 0.8280000000000000D+00*dw(216, 53)
      JacC( 77, 87) = JacC( 77, 87)+ 0.8280000000000000D+00*dw(216, 87)
      JacC( 78, 53) = JacC( 78, 53)+ 0.2620000000000000D+00*dw(216, 53)
      JacC( 78, 87) = JacC( 78, 87)+ 0.2620000000000000D+00*dw(216, 87)
      JacC( 79, 53) = JacC( 79, 53)+ 0.2100000000000000D-01*dw(216, 53)
      JacC( 79, 87) = JacC( 79, 87)+ 0.2100000000000000D-01*dw(216, 87)
      JacC( 81, 53) = JacC( 81, 53)+ 0.2390000000000000D+00*dw(216, 53)
      JacC( 81, 87) = JacC( 81, 87)+ 0.2390000000000000D+00*dw(216, 87)
      JacC( 82, 53) = JacC( 82, 53)+ 0.4000000000000000D-01*dw(216, 53)
      JacC( 82, 87) = JacC( 82, 87)+ 0.4000000000000000D-01*dw(216, 87)
      JacC( 84, 53) = JacC( 84, 53) + dw(216, 53)
      JacC( 84, 87) = JacC( 84, 87) + dw(216, 87)
      JacC( 87, 53) = JacC( 87, 53) - dw(216, 53)
      JacC( 87, 87) = JacC( 87, 87) - dw(216, 87)
      JacC( 88, 53) = JacC( 88, 53)+ 0.6990000000000000D+00*dw(216, 53)
      JacC( 88, 87) = JacC( 88, 87)+ 0.6990000000000000D+00*dw(216, 87)
      JacC( 57, 57) = JacC( 57, 57) - dw(217, 57)
      JacC( 57, 87) = JacC( 57, 87) - dw(217, 87)
      JacC( 75, 57) = JacC( 75, 57)+ 0.5870000000000000D+00*dw(217, 57)
      JacC( 75, 87) = JacC( 75, 87)+ 0.5870000000000000D+00*dw(217, 87)
      JacC( 77, 57) = JacC( 77, 57)+ 0.8800000000000000D+00*dw(217, 57)
      JacC( 77, 87) = JacC( 77, 87)+ 0.8800000000000000D+00*dw(217, 87)
      JacC( 78, 57) = JacC( 78, 57)+ 0.1550000000000000D+00*dw(217, 57)
      JacC( 78, 87) = JacC( 78, 87)+ 0.1550000000000000D+00*dw(217, 87)
      JacC( 81, 57) = JacC( 81, 57)+ 0.1870000000000000D+00*dw(217, 57)
      JacC( 81, 87) = JacC( 81, 87)+ 0.1870000000000000D+00*dw(217, 87)
      JacC( 84, 57) = JacC( 84, 57) + dw(217, 57)
      JacC( 84, 87) = JacC( 84, 87) + dw(217, 87)
      JacC( 87, 57) = JacC( 87, 57) - dw(217, 57)
      JacC( 87, 87) = JacC( 87, 87) - dw(217, 87)
      JacC( 88, 57) = JacC( 88, 57)+ 0.8450000000000000D+00*dw(217, 57)
      JacC( 88, 87) = JacC( 88, 87)+ 0.8450000000000000D+00*dw(217, 87)
      JacC( 56, 56) = JacC( 56, 56) - dw(218, 56)
      JacC( 56, 87) = JacC( 56, 87) - dw(218, 87)
      JacC( 79, 56) = JacC( 79, 56)+ 0.1600000000000000D+01*dw(218, 56)
      JacC( 79, 87) = JacC( 79, 87)+ 0.1600000000000000D+01*dw(218, 87)
      JacC( 81, 56) = JacC( 81, 56)+ 0.2000000000000000D+00*dw(218, 56)
      JacC( 81, 87) = JacC( 81, 87)+ 0.2000000000000000D+00*dw(218, 87)
      JacC( 84, 56) = JacC( 84, 56) + dw(218, 56)
      JacC( 84, 87) = JacC( 84, 87) + dw(218, 87)
      JacC( 87, 56) = JacC( 87, 56) - dw(218, 56)
      JacC( 87, 87) = JacC( 87, 87) - dw(218, 87)
      JacC( 88, 56) = JacC( 88, 56) + dw(218, 56)
      JacC( 88, 87) = JacC( 88, 87) + dw(218, 87)
      JacC( 61, 61) = JacC( 61, 61) - dw(219, 61)
      JacC( 61, 87) = JacC( 61, 87) - dw(219, 87)
      JacC( 77, 61) = JacC( 77, 61)+ 0.6000000000000000D-01*dw(219, 61)
      JacC( 77, 87) = JacC( 77, 87)+ 0.6000000000000000D-01*dw(219, 87)
      JacC( 79, 61) = JacC( 79, 61) + dw(219, 61)
      JacC( 79, 87) = JacC( 79, 87) + dw(219, 87)
      JacC( 81, 61) = JacC( 81, 61)+ 0.9399999999999999D+00*dw(219, 61)
      JacC( 81, 87) = JacC( 81, 87)+ 0.9399999999999999D+00*dw(219, 87)
      JacC( 84, 61) = JacC( 84, 61) + dw(219, 61)
      JacC( 84, 87) = JacC( 84, 87) + dw(219, 87)
      JacC( 87, 61) = JacC( 87, 61) - dw(219, 61)
      JacC( 87, 87) = JacC( 87, 87) - dw(219, 87)
      JacC( 88, 61) = JacC( 88, 61) + dw(219, 61)
      JacC( 88, 87) = JacC( 88, 87) + dw(219, 87)
      JacC( 68, 68) = JacC( 68, 68) - dw(220, 68)
      JacC( 68, 87) = JacC( 68, 87) - dw(220, 87)
      JacC( 77, 68) = JacC( 77, 68)+ 0.2900000000000000D+00*dw(220, 68)
      JacC( 77, 87) = JacC( 77, 87)+ 0.2900000000000000D+00*dw(220, 87)
      JacC( 81, 68) = JacC( 81, 68)+ 0.1710000000000000D+01*dw(220, 68)
      JacC( 81, 87) = JacC( 81, 87)+ 0.1710000000000000D+01*dw(220, 87)
      JacC( 84, 68) = JacC( 84, 68) + dw(220, 68)
      JacC( 84, 87) = JacC( 84, 87) + dw(220, 87)
      JacC( 87, 68) = JacC( 87, 68) - dw(220, 68)
      JacC( 87, 87) = JacC( 87, 87) - dw(220, 87)
      JacC( 88, 68) = JacC( 88, 68) + dw(220, 68)
      JacC( 88, 87) = JacC( 88, 87) + dw(220, 87)
      JacC( 58, 58) = JacC( 58, 58) - dw(221, 58)
      JacC( 58, 87) = JacC( 58, 87) - dw(221, 87)
      JacC( 59, 58) = JacC( 59, 58)+ 0.6000000000000000D+00*dw(221, 58)
      JacC( 59, 87) = JacC( 59, 87)+ 0.6000000000000000D+00*dw(221, 87)
      JacC( 60, 58) = JacC( 60, 58)+ 0.4000000000000000D+00*dw(221, 58)
      JacC( 60, 87) = JacC( 60, 87)+ 0.4000000000000000D+00*dw(221, 87)
      JacC( 79, 58) = JacC( 79, 58)+ 0.6860000000000001D+00*dw(221, 58)
      JacC( 79, 87) = JacC( 79, 87)+ 0.6860000000000001D+00*dw(221, 87)
      JacC( 84, 58) = JacC( 84, 58) + dw(221, 58)
      JacC( 84, 87) = JacC( 84, 87) + dw(221, 87)
      JacC( 87, 58) = JacC( 87, 58) - dw(221, 58)
      JacC( 87, 87) = JacC( 87, 87) - dw(221, 87)
      JacC( 88, 58) = JacC( 88, 58) + dw(221, 58)
      JacC( 88, 87) = JacC( 88, 87) + dw(221, 87)
      JacC( 69, 69) = JacC( 69, 69) - dw(222, 69)
      JacC( 69, 87) = JacC( 69, 87) - dw(222, 87)
      JacC( 77, 69) = JacC( 77, 69) + dw(222, 69)
      JacC( 77, 87) = JacC( 77, 87) + dw(222, 87)
      JacC( 81, 69) = JacC( 81, 69) + dw(222, 69)
      JacC( 81, 87) = JacC( 81, 87) + dw(222, 87)
      JacC( 84, 69) = JacC( 84, 69) + dw(222, 69)
      JacC( 84, 87) = JacC( 84, 87) + dw(222, 87)
      JacC( 87, 69) = JacC( 87, 69) - dw(222, 69)
      JacC( 87, 87) = JacC( 87, 87) - dw(222, 87)
      JacC( 88, 69) = JacC( 88, 69) + dw(222, 69)
      JacC( 88, 87) = JacC( 88, 87) + dw(222, 87)
      JacC( 52, 52) = JacC( 52, 52) - dw(223, 52)
      JacC( 52, 87) = JacC( 52, 87) - dw(223, 87)
      JacC( 59, 52) = JacC( 59, 52)+ 0.6000000000000000D+00*dw(223, 52)
      JacC( 59, 87) = JacC( 59, 87)+ 0.6000000000000000D+00*dw(223, 87)
      JacC( 62, 52) = JacC( 62, 52)+ 0.4000000000000000D+00*dw(223, 52)
      JacC( 62, 87) = JacC( 62, 87)+ 0.4000000000000000D+00*dw(223, 87)
      JacC( 79, 52) = JacC( 79, 52)+ 0.4000000000000000D+00*dw(223, 52)
      JacC( 79, 87) = JacC( 79, 87)+ 0.4000000000000000D+00*dw(223, 87)
      JacC( 84, 52) = JacC( 84, 52) + dw(223, 52)
      JacC( 84, 87) = JacC( 84, 87) + dw(223, 87)
      JacC( 87, 52) = JacC( 87, 52) - dw(223, 52)
      JacC( 87, 87) = JacC( 87, 87) - dw(223, 87)
      JacC( 88, 52) = JacC( 88, 52) + dw(223, 52)
      JacC( 88, 87) = JacC( 88, 87) + dw(223, 87)
      JacC( 40, 40) = JacC( 40, 40) - dw(224, 40)
      JacC( 40, 87) = JacC( 40, 87) - dw(224, 87)
      JacC( 46, 40) = JacC( 46, 40)+ 0.9500000000000000D-01*dw(224, 40)
      JacC( 46, 87) = JacC( 46, 87)+ 0.9500000000000000D-01*dw(224, 87)
      JacC( 54, 40) = JacC( 54, 40)+ 0.5000000000000000D+00*dw(224, 40)
      JacC( 54, 87) = JacC( 54, 87)+ 0.5000000000000000D+00*dw(224, 87)
      JacC( 55, 40) = JacC( 55, 40)+ 0.1500000000000000D-01*dw(224, 40)
      JacC( 55, 87) = JacC( 55, 87)+ 0.1500000000000000D-01*dw(224, 87)
      JacC( 66, 40) = JacC( 66, 40)+ 0.1300000000000000D+01*dw(224, 40)
      JacC( 66, 87) = JacC( 66, 87)+ 0.1300000000000000D+01*dw(224, 87)
      JacC( 72, 40) = JacC( 72, 40)+ 0.7000000000000000D+00*dw(224, 40)
      JacC( 72, 87) = JacC( 72, 87)+ 0.7000000000000000D+00*dw(224, 87)
      JacC( 84, 40) = JacC( 84, 40) + dw(224, 40)
      JacC( 84, 87) = JacC( 84, 87) + dw(224, 87)
      JacC( 87, 40) = JacC( 87, 40) - dw(224, 40)
      JacC( 87, 87) = JacC( 87, 87) - dw(224, 87)
      JacC( 88, 40) = JacC( 88, 40) + dw(224, 40)
      JacC( 88, 87) = JacC( 88, 87) + dw(224, 87)
      JacC( 46, 51) = JacC( 46, 51)+ 0.1000000000000000D+00*dw(225, 51)
      JacC( 46, 87) = JacC( 46, 87)+ 0.1000000000000000D+00*dw(225, 87)
      JacC( 51, 51) = JacC( 51, 51) - dw(225, 51)
      JacC( 51, 87) = JacC( 51, 87) - dw(225, 87)
      JacC( 54, 51) = JacC( 54, 51) + dw(225, 51)
      JacC( 54, 87) = JacC( 54, 87) + dw(225, 87)
      JacC( 55, 51) = JacC( 55, 51)+ 0.7000000000000000D-02*dw(225, 51)
      JacC( 55, 87) = JacC( 55, 87)+ 0.7000000000000000D-02*dw(225, 87)
      JacC( 66, 51) = JacC( 66, 51)+ 0.7400000000000000D+00*dw(225, 51)
      JacC( 66, 87) = JacC( 66, 87)+ 0.7400000000000000D+00*dw(225, 87)
      JacC( 72, 51) = JacC( 72, 51)+ 0.1260000000000000D+01*dw(225, 51)
      JacC( 72, 87) = JacC( 72, 87)+ 0.1260000000000000D+01*dw(225, 87)
      JacC( 84, 51) = JacC( 84, 51) + dw(225, 51)
      JacC( 84, 87) = JacC( 84, 87) + dw(225, 87)
      JacC( 87, 51) = JacC( 87, 51) - dw(225, 51)
      JacC( 87, 87) = JacC( 87, 87) - dw(225, 87)
      JacC( 88, 51) = JacC( 88, 51) + dw(225, 51)
      JacC( 88, 87) = JacC( 88, 87) + dw(225, 87)
      JacC( 42, 42) = JacC( 42, 42) - dw(226, 42)
      JacC( 42, 87) = JacC( 42, 87) - dw(226, 87)
      JacC( 66, 42) = JacC( 66, 42) + dw(226, 42)
      JacC( 66, 87) = JacC( 66, 87) + dw(226, 87)
      JacC( 72, 42) = JacC( 72, 42) + dw(226, 42)
      JacC( 72, 87) = JacC( 72, 87) + dw(226, 87)
      JacC( 84, 42) = JacC( 84, 42) + dw(226, 42)
      JacC( 84, 87) = JacC( 84, 87) + dw(226, 87)
      JacC( 87, 42) = JacC( 87, 42) - dw(226, 42)
      JacC( 87, 87) = JacC( 87, 87) - dw(226, 87)
      JacC( 88, 42) = JacC( 88, 42) + dw(226, 42)
      JacC( 88, 87) = JacC( 88, 87) + dw(226, 87)
      JacC( 82, 89) = JacC( 82, 89) + dw(227, 89)
      JacC( 82, 87) = JacC( 82, 87) + dw(227, 87)
      JacC( 84, 89) = JacC( 84, 89) + dw(227, 89)
      JacC( 84, 87) = JacC( 84, 87) + dw(227, 87)
      JacC( 87, 89) = JacC( 87, 89) - dw(227, 89)
      JacC( 87, 87) = JacC( 87, 87) - dw(227, 87)
      JacC( 89, 89) = JacC( 89, 89) - dw(227, 89)
      JacC( 89, 87) = JacC( 89, 87) - dw(227, 87)
      JacC( 79, 86) = JacC( 79, 86) + dw(228, 86)
      JacC( 79, 87) = JacC( 79, 87) + dw(228, 87)
      JacC( 84, 86) = JacC( 84, 86) + dw(228, 86)
      JacC( 84, 87) = JacC( 84, 87) + dw(228, 87)
      JacC( 86, 86) = JacC( 86, 86) - dw(228, 86)
      JacC( 86, 87) = JacC( 86, 87) - dw(228, 87)
      JacC( 87, 86) = JacC( 87, 86) - dw(228, 86)
      JacC( 87, 87) = JacC( 87, 87) - dw(228, 87)
      JacC( 89, 86) = JacC( 89, 86) + dw(228, 86)
      JacC( 89, 87) = JacC( 89, 87) + dw(228, 87)
      JacC( 70, 70) = JacC( 70, 70) - dw(229, 70)
      JacC( 70, 87) = JacC( 70, 87) - dw(229, 87)
      JacC( 72, 70) = JacC( 72, 70)+ 0.5400000000000000D+00*dw(229, 70)
      JacC( 72, 87) = JacC( 72, 87)+ 0.5400000000000000D+00*dw(229, 87)
      JacC( 75, 70) = JacC( 75, 70)+ 0.1600000000000000D+00*dw(229, 70)
      JacC( 75, 87) = JacC( 75, 87)+ 0.1600000000000000D+00*dw(229, 87)
      JacC( 81, 70) = JacC( 81, 70)+ 0.4600000000000000D+00*dw(229, 70)
      JacC( 81, 87) = JacC( 81, 87)+ 0.4600000000000000D+00*dw(229, 87)
      JacC( 84, 70) = JacC( 84, 70) + dw(229, 70)
      JacC( 84, 87) = JacC( 84, 87) + dw(229, 87)
      JacC( 87, 70) = JacC( 87, 70) - dw(229, 70)
      JacC( 87, 87) = JacC( 87, 87) - dw(229, 87)
      JacC( 88, 70) = JacC( 88, 70)+ 0.7700000000000000D+00*dw(229, 70)
      JacC( 88, 87) = JacC( 88, 87)+ 0.7700000000000000D+00*dw(229, 87)
      JacC( 89, 70) = JacC( 89, 70)+ 0.2300000000000000D+00*dw(229, 70)
      JacC( 89, 87) = JacC( 89, 87)+ 0.2300000000000000D+00*dw(229, 87)
      JacC( 64, 64) = JacC( 64, 64) - dw(230, 64)
      JacC( 64, 87) = JacC( 64, 87) - dw(230, 87)
      JacC( 83, 64) = JacC( 83, 64) + dw(230, 64)
      JacC( 83, 87) = JacC( 83, 87) + dw(230, 87)
      JacC( 84, 64) = JacC( 84, 64) + dw(230, 64)
      JacC( 84, 87) = JacC( 84, 87) + dw(230, 87)
      JacC( 87, 64) = JacC( 87, 64) - dw(230, 64)
      JacC( 87, 87) = JacC( 87, 87) - dw(230, 87)
      JacC( 88, 64) = JacC( 88, 64) + dw(230, 64)
      JacC( 88, 87) = JacC( 88, 87) + dw(230, 87)
      JacC( 63, 63) = JacC( 63, 63) - dw(231, 63)
      JacC( 63, 87) = JacC( 63, 87) - dw(231, 87)
      JacC( 77, 63) = JacC( 77, 63)+ 0.4690000000000000D+00*dw(231, 63)
      JacC( 77, 87) = JacC( 77, 87)+ 0.4690000000000000D+00*dw(231, 87)
      JacC( 79, 63) = JacC( 79, 63)+ 0.2800000000000000D+00*dw(231, 63)
      JacC( 79, 87) = JacC( 79, 87)+ 0.2800000000000000D+00*dw(231, 87)
      JacC( 81, 63) = JacC( 81, 63)+ 0.1240000000000000D+01*dw(231, 63)
      JacC( 81, 87) = JacC( 81, 87)+ 0.1240000000000000D+01*dw(231, 87)
      JacC( 84, 63) = JacC( 84, 63)+ 0.2000000000000000D+01*dw(231, 63)
      JacC( 84, 87) = JacC( 84, 87)+ 0.2000000000000000D+01*dw(231, 87)
      JacC( 87, 63) = JacC( 87, 63) - dw(231, 63)
      JacC( 87, 87) = JacC( 87, 87) - dw(231, 87)
      JacC( 73, 75) = JacC( 73, 75) + dw(232, 75)
      JacC( 73, 88) = JacC( 73, 88) + dw(232, 88)
      JacC( 75, 75) = JacC( 75, 75) - dw(232, 75)
      JacC( 75, 88) = JacC( 75, 88) - dw(232, 88)
      JacC( 88, 75) = JacC( 88, 75) - dw(232, 75)
      JacC( 88, 88) = JacC( 88, 88) - dw(232, 88)
      JacC( 75, 75) = JacC( 75, 75) - dw(233, 75)
      JacC( 75, 82) = JacC( 75, 82) - dw(233, 82)
      JacC( 79, 75) = JacC( 79, 75) + dw(233, 75)
      JacC( 79, 82) = JacC( 79, 82) + dw(233, 82)
      JacC( 82, 75) = JacC( 82, 75) - dw(233, 75)
      JacC( 82, 82) = JacC( 82, 82) - dw(233, 82)
      JacC( 88, 75) = JacC( 88, 75) + dw(233, 75)
      JacC( 88, 82) = JacC( 88, 82) + dw(233, 82)
      JacC( 75, 75) = JacC( 75, 75) - dw(234, 75)
      JacC( 75, 89) = JacC( 75, 89) - dw(234, 89)
      JacC( 82, 75) = JacC( 82, 75) + dw(234, 75)
      JacC( 82, 89) = JacC( 82, 89) + dw(234, 89)
      JacC( 89, 75) = JacC( 89, 75) - dw(234, 75)
      JacC( 89, 89) = JacC( 89, 89) - dw(234, 89)
      JacC( 75, 75) = JacC( 75, 75)- 0.2000000000000000D+01*dw(235, 75)
      JacC( 75, 75) = JacC( 75, 75)- 0.2000000000000000D+01*dw(235, 75)
      JacC( 75, 75) = JacC( 75, 75) - dw(236, 75)
      JacC( 75, 85) = JacC( 75, 85) - dw(236, 85)
      JacC( 84, 75) = JacC( 84, 75) + dw(236, 75)
      JacC( 84, 85) = JacC( 84, 85) + dw(236, 85)
      JacC( 85, 75) = JacC( 85, 75) - dw(236, 75)
      JacC( 85, 85) = JacC( 85, 85) - dw(236, 85)
      JacC( 75, 75) = JacC( 75, 75) - dw(237, 75)
      JacC( 75, 87) = JacC( 75, 87) - dw(237, 87)
      JacC( 84, 75) = JacC( 84, 75) + dw(237, 75)
      JacC( 84, 87) = JacC( 84, 87) + dw(237, 87)
      JacC( 87, 75) = JacC( 87, 75) - dw(237, 75)
      JacC( 87, 87) = JacC( 87, 87) - dw(237, 87)
      JacC( 44, 88) = JacC( 44, 88)+ 0.5000000000000000D+00*dw(238, 88)
      JacC( 88, 88) = JacC( 88, 88) - dw(238, 88)
      JacC( 33, 84) = JacC( 33, 84)+ 0.5000000000000000D+00*dw(239, 84)
      JacC( 74, 84) = JacC( 74, 84)+ 0.5000000000000000D+00*dw(239, 84)
      JacC( 84, 84) = JacC( 84, 84) - dw(239, 84)
      JacC( 74, 87) = JacC( 74, 87) + dw(240, 87)
      JacC( 87, 87) = JacC( 87, 87) - dw(240, 87)
      JacC( 17, 17) = JacC( 17, 17) - dw(241, 17)
      JacC( 74, 17) = JacC( 74, 17)+ 0.2000000000000000D+01*dw(241, 17)
      JacC( 11, 11) = JacC( 11, 11) - dw(242, 11)
      JacC( 11, 80) = JacC( 11, 80) - dw(242, 80)
      JacC( 12, 11) = JacC( 12, 11)+ 0.2600000000000000D+00*dw(242, 11)
      JacC( 12, 80) = JacC( 12, 80)+ 0.2600000000000000D+00*dw(242, 80)
      JacC( 29, 11) = JacC( 29, 11)+ 0.7400000000000000D+00*dw(242, 11)
      JacC( 29, 80) = JacC( 29, 80)+ 0.7400000000000000D+00*dw(242, 80)
      JacC( 80, 11) = JacC( 80, 11) - dw(242, 11)
      JacC( 80, 80) = JacC( 80, 80) - dw(242, 80)
      JacC( 13, 13) = JacC( 13, 13) - dw(243, 13)
      JacC( 13, 80) = JacC( 13, 80) - dw(243, 80)
      JacC( 16, 13) = JacC( 16, 13) + dw(243, 13)
      JacC( 16, 80) = JacC( 16, 80) + dw(243, 80)
      JacC( 80, 13) = JacC( 80, 13) - dw(243, 13)
      JacC( 80, 80) = JacC( 80, 80) - dw(243, 80)
      JacC( 14, 14) = JacC( 14, 14) - dw(244, 14)
      JacC( 14, 80) = JacC( 14, 80) - dw(244, 80)
      JacC( 16, 14) = JacC( 16, 14) + dw(244, 14)
      JacC( 16, 80) = JacC( 16, 80) + dw(244, 80)
      JacC( 80, 14) = JacC( 80, 14) - dw(244, 14)
      JacC( 80, 80) = JacC( 80, 80) - dw(244, 80)
      JacC( 15, 15) = JacC( 15, 15) - dw(245, 15)
      JacC( 15, 80) = JacC( 15, 80) - dw(245, 80)
      JacC( 16, 15) = JacC( 16, 15) + dw(245, 15)
      JacC( 16, 80) = JacC( 16, 80) + dw(245, 80)
      JacC( 80, 15) = JacC( 80, 15) - dw(245, 15)
      JacC( 80, 80) = JacC( 80, 80) - dw(245, 80)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo

 
      RETURN
      END
 
