C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C	  This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C	  nesp: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp




C     Upper part.
      M(3, 91) = M(3, 91) / M(3, 3)

C     Upper part.
      M(4, 118) = M(4, 118) / M(4, 4)

C     Upper part.
      temp = M(5, 4) * M(4, 118)
      M(5, 118) = ( M(5, 118) - temp ) / M(5, 5)

C     Upper part.
      M(6, 118) = M(6, 118) / M(6, 6)

C     Upper part.
      M(7, 118) = M(7, 118) / M(7, 7)

C     Upper part.
      M(8, 118) = M(8, 118) / M(8, 8)

C     Upper part.
      M(9, 118) = M(9, 118) / M(9, 9)

C     Upper part.
      M(10, 118) = M(10, 118) / M(10, 10)

C     Upper part.
      M(11, 118) = M(11, 118) / M(11, 11)

C     Upper part.
      temp = M(12, 11) * M(11, 118)
      M(12, 118) = ( M(12, 118) - temp ) / M(12, 12)

C     Upper part.
      M(13, 118) = M(13, 118) / M(13, 13)

C     Upper part.
      temp = M(14, 13) * M(13, 118)
      M(14, 118) = ( M(14, 118) - temp ) / M(14, 14)

C     Upper part.
      M(15, 118) = M(15, 118) / M(15, 15)

C     Upper part.
      temp = M(16, 15) * M(15, 118)
      M(16, 118) = ( M(16, 118) - temp ) / M(16, 16)

C     Upper part.
      temp = M(17, 10) * M(10, 118)
      M(17, 118) = ( M(17, 118) - temp ) / M(17, 17)

C     Upper part.
      M(18, 117) = M(18, 117) / M(18, 18)
C     Upper part.
      M(18, 121) = M(18, 121) / M(18, 18)

C     Upper part.
      M(19, 45) = M(19, 45) / M(19, 19)
C     Upper part.
      M(19, 118) = M(19, 118) / M(19, 19)

C     Upper part.
      M(20, 117) = M(20, 117) / M(20, 20)
C     Upper part.
      temp = M(20, 7) * M(7, 118)
      M(20, 118) = ( M(20, 118) - temp ) / M(20, 20)

C     Upper part.
      M(21, 91) = M(21, 91) / M(21, 21)
C     Upper part.
      M(21, 117) = M(21, 117) / M(21, 21)
C     Upper part.
      M(21, 118) = M(21, 118) / M(21, 21)

C     Upper part.
      temp = M(22, 21) * M(21, 91)
      M(22, 91) = ( M(22, 91) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 21) * M(21, 117)
      M(22, 117) = ( M(22, 117) - temp ) / M(22, 22)
C     Upper part.
      temp = M(22, 21) * M(21, 118)
      M(22, 118) = ( M(22, 118) - temp ) / M(22, 22)

C     Upper part.
      temp = M(23, 21) * M(21, 91)
      M(23, 91) = ( M(23, 91) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 21) * M(21, 117)
      M(23, 117) = ( M(23, 117) - temp ) / M(23, 23)
C     Upper part.
      temp = M(23, 21) * M(21, 118)
      M(23, 118) = ( M(23, 118) - temp ) / M(23, 23)

C     Upper part.
      M(24, 118) = M(24, 118) / M(24, 24)
C     Upper part.
      M(24, 121) = M(24, 121) / M(24, 24)
C     Upper part.
      M(24, 123) = M(24, 123) / M(24, 24)

C     Upper part.
      M(25, 91) = M(25, 91) / M(25, 25)
C     Upper part.
      M(25, 117) = M(25, 117) / M(25, 25)
C     Upper part.
      M(25, 118) = M(25, 118) / M(25, 25)

C     Upper part.
      M(26, 113) = M(26, 113) / M(26, 26)
C     Upper part.
      M(26, 114) = M(26, 114) / M(26, 26)
C     Upper part.
      M(26, 118) = M(26, 118) / M(26, 26)

C     Upper part.
      M(27, 91) = M(27, 91) / M(27, 27)
C     Upper part.
      M(27, 117) = M(27, 117) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 118)
      temp = temp + M(27, 14) * M(14, 118)
      temp = temp + M(27, 16) * M(16, 118)
      M(27, 118) = ( M(27, 118) - temp ) / M(27, 27)

C     Upper part.
      M(28, 91) = M(28, 91) / M(28, 28)
C     Upper part.
      M(28, 117) = M(28, 117) / M(28, 28)
C     Upper part.
      M(28, 118) = M(28, 118) / M(28, 28)

C     Upper part.
      M(29, 98) = M(29, 98) / M(29, 29)
C     Upper part.
      M(29, 113) = M(29, 113) / M(29, 29)
C     Upper part.
      M(29, 118) = M(29, 118) / M(29, 29)

C     Upper part.
      M(30, 80) = M(30, 80) / M(30, 30)
C     Upper part.
      M(30, 118) = M(30, 118) / M(30, 30)
C     Upper part.
      M(30, 119) = M(30, 119) / M(30, 30)

C     Upper part.
      M(31, 91) = M(31, 91) / M(31, 31)
C     Upper part.
      M(31, 117) = M(31, 117) / M(31, 31)
C     Upper part.
      M(31, 118) = M(31, 118) / M(31, 31)

C     Upper part.
      M(32, 91) = M(32, 91) / M(32, 32)
C     Upper part.
      M(32, 117) = M(32, 117) / M(32, 32)
C     Upper part.
      M(32, 118) = M(32, 118) / M(32, 32)

C     Upper part.
      temp = M(33, 32) * M(32, 91)
      M(33, 91) = ( M(33, 91) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 32) * M(32, 117)
      M(33, 117) = ( M(33, 117) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 32) * M(32, 118)
      M(33, 118) = ( M(33, 118) - temp ) / M(33, 33)

C     Upper part.
      temp = M(34, 32) * M(32, 91)
      M(34, 91) = ( M(34, 91) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 32) * M(32, 117)
      M(34, 117) = ( M(34, 117) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 32) * M(32, 118)
      M(34, 118) = ( M(34, 118) - temp ) / M(34, 34)

C     Upper part.
      M(35, 104) = M(35, 104) / M(35, 35)
C     Upper part.
      M(35, 118) = M(35, 118) / M(35, 35)
C     Upper part.
      M(35, 119) = M(35, 119) / M(35, 35)

C     Upper part.
      M(36, 61) = M(36, 61) / M(36, 36)
C     Upper part.
      temp = M(36, 20) * M(20, 117)
      M(36, 117) = ( M(36, 117) - temp ) / M(36, 36)
C     Upper part.
      temp = M(36, 20) * M(20, 118)
      M(36, 118) = ( M(36, 118) - temp ) / M(36, 36)

C     Upper part.
      M(37, 76) = M(37, 76) / M(37, 37)
C     Upper part.
      M(37, 118) = M(37, 118) / M(37, 37)
C     Upper part.
      M(37, 123) = M(37, 123) / M(37, 37)

C     Upper part.
      temp = M(38, 25) * M(25, 91)
      temp = temp + M(38, 32) * M(32, 91)
      M(38, 91) = ( M(38, 91) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 25) * M(25, 117)
      temp = temp + M(38, 32) * M(32, 117)
      M(38, 117) = ( M(38, 117) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 25) * M(25, 118)
      temp = temp + M(38, 32) * M(32, 118)
      M(38, 118) = ( M(38, 118) - temp ) / M(38, 38)

C     Upper part.
      M(39, 86) = M(39, 86) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 91)
      M(39, 91) = ( M(39, 91) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 117)
      M(39, 117) = ( M(39, 117) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 38) * M(38, 118)
      M(39, 118) = ( M(39, 118) - temp ) / M(39, 39)

C     Upper part.
      M(40, 113) = M(40, 113) / M(40, 40)
C     Upper part.
      M(40, 118) = M(40, 118) / M(40, 40)
C     Upper part.
      M(40, 119) = M(40, 119) / M(40, 40)

C     Upper part.
      M(41, 118) = M(41, 118) / M(41, 41)
C     Upper part.
      M(41, 121) = M(41, 121) / M(41, 41)
C     Upper part.
      M(41, 122) = M(41, 122) / M(41, 41)

C     Upper part.
      M(42, 118) = M(42, 118) / M(42, 42)
C     Upper part.
      M(42, 120) = M(42, 120) / M(42, 42)
C     Upper part.
      M(42, 121) = M(42, 121) / M(42, 42)

C     Upper part.
      M(43, 118) = M(43, 118) / M(43, 43)
C     Upper part.
      M(43, 119) = M(43, 119) / M(43, 43)
C     Upper part.
      M(43, 121) = M(43, 121) / M(43, 43)

C     Upper part.
      M(44, 86) = M(44, 86) / M(44, 44)
C     Upper part.
      temp = M(44, 38) * M(38, 91)
      M(44, 91) = ( M(44, 91) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 38) * M(38, 117)
      M(44, 117) = ( M(44, 117) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 38) * M(38, 118)
      M(44, 118) = ( M(44, 118) - temp ) / M(44, 44)

C     Lower part.
      temp = M(107, 19) * M(19, 45)
      M(107, 45) = M(107, 45) - temp
C     Lower part.
      temp = M(116, 19) * M(19, 45)
      M(116, 45) = M(116, 45) - temp
C     Lower part.
      temp = M(118, 19) * M(19, 45)
      M(118, 45) = M(118, 45) - temp
C     Lower part.
      temp = M(121, 19) * M(19, 45)
      M(121, 45) = M(121, 45) - temp
C     Upper part.
      M(45, 80) = M(45, 80) / M(45, 45)
C     Upper part.
      temp = M(45, 31) * M(31, 91)
      M(45, 91) = ( M(45, 91) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 31) * M(31, 117)
      M(45, 117) = ( M(45, 117) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 31) * M(31, 118)
      M(45, 118) = ( M(45, 118) - temp ) / M(45, 45)
C     Upper part.
      M(45, 123) = M(45, 123) / M(45, 45)

C     Upper part.
      M(46, 104) = M(46, 104) / M(46, 46)
C     Upper part.
      M(46, 117) = M(46, 117) / M(46, 46)
C     Upper part.
      M(46, 118) = M(46, 118) / M(46, 46)
C     Upper part.
      M(46, 121) = M(46, 121) / M(46, 46)

C     Upper part.
      temp = M(47, 3) * M(3, 91)
      temp = temp + M(47, 25) * M(25, 91)
      M(47, 91) = ( M(47, 91) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 25) * M(25, 117)
      M(47, 117) = ( M(47, 117) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 25) * M(25, 118)
      M(47, 118) = ( M(47, 118) - temp ) / M(47, 47)
C     Upper part.
      M(47, 121) = M(47, 121) / M(47, 47)
C     Upper part.
      M(47, 123) = M(47, 123) / M(47, 47)

C     Upper part.
      M(48, 56) = M(48, 56) / M(48, 48)
C     Upper part.
      M(48, 61) = M(48, 61) / M(48, 48)
C     Upper part.
      temp = M(48, 20) * M(20, 117)
      M(48, 117) = ( M(48, 117) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 7) * M(7, 118)
      temp = temp + M(48, 11) * M(11, 118)
      temp = temp + M(48, 13) * M(13, 118)
      temp = temp + M(48, 15) * M(15, 118)
      temp = temp + M(48, 20) * M(20, 118)
      M(48, 118) = ( M(48, 118) - temp ) / M(48, 48)

C     Upper part.
      M(49, 56) = M(49, 56) / M(49, 49)
C     Upper part.
      M(49, 61) = M(49, 61) / M(49, 49)
C     Upper part.
      temp = M(49, 20) * M(20, 117)
      M(49, 117) = ( M(49, 117) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 7) * M(7, 118)
      temp = temp + M(49, 11) * M(11, 118)
      temp = temp + M(49, 13) * M(13, 118)
      temp = temp + M(49, 15) * M(15, 118)
      temp = temp + M(49, 20) * M(20, 118)
      M(49, 118) = ( M(49, 118) - temp ) / M(49, 49)

C     Upper part.
      M(50, 86) = M(50, 86) / M(50, 50)
C     Upper part.
      temp = M(50, 38) * M(38, 91)
      M(50, 91) = ( M(50, 91) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 38) * M(38, 117)
      M(50, 117) = ( M(50, 117) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 38) * M(38, 118)
      M(50, 118) = ( M(50, 118) - temp ) / M(50, 50)

C     Upper part.
      M(51, 86) = M(51, 86) / M(51, 51)
C     Upper part.
      temp = M(51, 21) * M(21, 91)
      temp = temp + M(51, 25) * M(25, 91)
      temp = temp + M(51, 31) * M(31, 91)
      temp = temp + M(51, 32) * M(32, 91)
      temp = temp + M(51, 38) * M(38, 91)
      M(51, 91) = ( M(51, 91) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 21) * M(21, 117)
      temp = temp + M(51, 25) * M(25, 117)
      temp = temp + M(51, 31) * M(31, 117)
      temp = temp + M(51, 32) * M(32, 117)
      temp = temp + M(51, 38) * M(38, 117)
      M(51, 117) = ( M(51, 117) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 21) * M(21, 118)
      temp = temp + M(51, 25) * M(25, 118)
      temp = temp + M(51, 31) * M(31, 118)
      temp = temp + M(51, 32) * M(32, 118)
      temp = temp + M(51, 38) * M(38, 118)
      M(51, 118) = ( M(51, 118) - temp ) / M(51, 51)
C     Upper part.
      M(51, 119) = M(51, 119) / M(51, 51)

C     Upper part.
      M(52, 54) = M(52, 54) / M(52, 52)
C     Upper part.
      M(52, 113) = M(52, 113) / M(52, 52)
C     Upper part.
      M(52, 117) = M(52, 117) / M(52, 52)
C     Upper part.
      temp = M(52, 12) * M(12, 118)
      M(52, 118) = ( M(52, 118) - temp ) / M(52, 52)
C     Upper part.
      M(52, 122) = M(52, 122) / M(52, 52)
C     Upper part.
      M(52, 123) = M(52, 123) / M(52, 52)

C     Upper part.
      M(53, 113) = M(53, 113) / M(53, 53)
C     Upper part.
      M(53, 117) = M(53, 117) / M(53, 53)
C     Upper part.
      temp = M(53, 11) * M(11, 118)
      M(53, 118) = ( M(53, 118) - temp ) / M(53, 53)
C     Upper part.
      M(53, 122) = M(53, 122) / M(53, 53)
C     Upper part.
      M(53, 123) = M(53, 123) / M(53, 53)

C     Lower part.
      temp = M(68, 52) * M(52, 54)
      M(68, 54) = M(68, 54) - temp
C     Lower part.
      temp = M(100, 52) * M(52, 54)
      M(100, 54) = M(100, 54) - temp
C     Lower part.
      temp = M(108, 52) * M(52, 54)
      M(108, 54) = M(108, 54) - temp
C     Lower part.
      temp = M(113, 52) * M(52, 54)
      M(113, 54) = M(113, 54) - temp
C     Lower part.
      temp = M(116, 52) * M(52, 54)
      M(116, 54) = M(116, 54) - temp
C     Lower part.
      temp = M(117, 52) * M(52, 54)
      M(117, 54) = M(117, 54) - temp
C     Lower part.
      temp = M(119, 52) * M(52, 54)
      M(119, 54) = M(119, 54) - temp
C     Lower part.
      temp = M(121, 52) * M(52, 54)
      M(121, 54) = M(121, 54) - temp
C     Lower part.
      temp = M(122, 52) * M(52, 54)
      M(122, 54) = M(122, 54) - temp
C     Lower part.
      temp = M(123, 52) * M(52, 54)
      M(123, 54) = M(123, 54) - temp
C     Upper part.
      M(54, 113) = M(54, 113) / M(54, 54)
C     Upper part.
      M(54, 117) = M(54, 117) / M(54, 54)
C     Upper part.
      temp = M(54, 12) * M(12, 118)
      M(54, 118) = ( M(54, 118) - temp ) / M(54, 54)
C     Upper part.
      M(54, 119) = M(54, 119) / M(54, 54)
C     Upper part.
      M(54, 122) = M(54, 122) / M(54, 54)
C     Upper part.
      M(54, 123) = M(54, 123) / M(54, 54)

C     Upper part.
      M(55, 113) = M(55, 113) / M(55, 55)
C     Upper part.
      M(55, 117) = M(55, 117) / M(55, 55)
C     Upper part.
      temp = M(55, 13) * M(13, 118)
      temp = temp + M(55, 15) * M(15, 118)
      M(55, 118) = ( M(55, 118) - temp ) / M(55, 55)
C     Upper part.
      M(55, 122) = M(55, 122) / M(55, 55)
C     Upper part.
      M(55, 123) = M(55, 123) / M(55, 55)

C     Upper part.
      temp = M(56, 53) * M(53, 113)
      temp = temp + M(56, 55) * M(55, 113)
      M(56, 113) = ( M(56, 113) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 53) * M(53, 117)
      temp = temp + M(56, 55) * M(55, 117)
      M(56, 117) = ( M(56, 117) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 53) * M(53, 118)
      temp = temp + M(56, 55) * M(55, 118)
      M(56, 118) = ( M(56, 118) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 53) * M(53, 122)
      temp = temp + M(56, 55) * M(55, 122)
      M(56, 122) = ( M(56, 122) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 53) * M(53, 123)
      temp = temp + M(56, 55) * M(55, 123)
      M(56, 123) = ( M(56, 123) - temp ) / M(56, 56)

C     Upper part.
      temp = M(57, 56) * M(56, 113)
      M(57, 113) = ( M(57, 113) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 117)
      M(57, 117) = ( M(57, 117) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 118)
      M(57, 118) = ( M(57, 118) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 122)
      M(57, 122) = ( M(57, 122) - temp ) / M(57, 57)
C     Upper part.
      temp = M(57, 56) * M(56, 123)
      M(57, 123) = ( M(57, 123) - temp ) / M(57, 57)

C     Upper part.
      temp = M(58, 57) * M(57, 113)
      M(58, 113) = ( M(58, 113) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 117)
      M(58, 117) = ( M(58, 117) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 118)
      M(58, 118) = ( M(58, 118) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 122)
      M(58, 122) = ( M(58, 122) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 123)
      M(58, 123) = ( M(58, 123) - temp ) / M(58, 58)

C     Upper part.
      temp = M(59, 58) * M(58, 113)
      M(59, 113) = ( M(59, 113) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 58) * M(58, 117)
      M(59, 117) = ( M(59, 117) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 58) * M(58, 118)
      M(59, 118) = ( M(59, 118) - temp ) / M(59, 59)
C     Upper part.
      M(59, 121) = M(59, 121) / M(59, 59)
C     Upper part.
      temp = M(59, 58) * M(58, 122)
      M(59, 122) = ( M(59, 122) - temp ) / M(59, 59)
C     Upper part.
      temp = M(59, 58) * M(58, 123)
      M(59, 123) = ( M(59, 123) - temp ) / M(59, 59)

C     Upper part.
      M(60, 113) = M(60, 113) / M(60, 60)
C     Upper part.
      M(60, 117) = M(60, 117) / M(60, 60)
C     Upper part.
      temp = M(60, 14) * M(14, 118)
      M(60, 118) = ( M(60, 118) - temp ) / M(60, 60)
C     Upper part.
      M(60, 119) = M(60, 119) / M(60, 60)
C     Upper part.
      M(60, 122) = M(60, 122) / M(60, 60)
C     Upper part.
      M(60, 123) = M(60, 123) / M(60, 60)

C     Lower part.
      temp = M(96, 36) * M(36, 61)
      M(96, 61) = M(96, 61) - temp
C     Lower part.
      temp = M(101, 36) * M(36, 61)
      M(101, 61) = M(101, 61) - temp
C     Lower part.
      temp = M(117, 36) * M(36, 61)
      M(117, 61) = M(117, 61) - temp
C     Lower part.
      temp = M(118, 36) * M(36, 61)
      M(118, 61) = M(118, 61) - temp
C     Upper part.
      M(61, 62) = M(61, 62) / M(61, 61)
C     Upper part.
      M(61, 64) = M(61, 64) / M(61, 61)
C     Upper part.
      temp = M(61, 54) * M(54, 113)
      temp = temp + M(61, 60) * M(60, 113)
      M(61, 113) = ( M(61, 113) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 54) * M(54, 117)
      temp = temp + M(61, 60) * M(60, 117)
      M(61, 117) = ( M(61, 117) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 11) * M(11, 118)
      temp = temp + M(61, 12) * M(12, 118)
      temp = temp + M(61, 13) * M(13, 118)
      temp = temp + M(61, 14) * M(14, 118)
      temp = temp + M(61, 15) * M(15, 118)
      temp = temp + M(61, 16) * M(16, 118)
      temp = temp + M(61, 54) * M(54, 118)
      temp = temp + M(61, 60) * M(60, 118)
      M(61, 118) = ( M(61, 118) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 54) * M(54, 119)
      temp = temp + M(61, 60) * M(60, 119)
      M(61, 119) = ( M(61, 119) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 54) * M(54, 122)
      temp = temp + M(61, 60) * M(60, 122)
      M(61, 122) = ( M(61, 122) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 54) * M(54, 123)
      temp = temp + M(61, 60) * M(60, 123)
      M(61, 123) = ( M(61, 123) - temp ) / M(61, 61)

C     Lower part.
      temp = M(62, 61) * M(61, 62)
      M(62, 62) = M(62, 62) - temp
C     Lower part.
      temp = M(66, 61) * M(61, 62)
      M(66, 62) = M(66, 62) - temp
C     Lower part.
      temp = M(96, 61) * M(61, 62)
      M(96, 62) = M(96, 62) - temp
C     Lower part.
      temp = M(97, 61) * M(61, 62)
      M(97, 62) = M(97, 62) - temp
C     Lower part.
      temp = M(101, 61) * M(61, 62)
      M(101, 62) = M(101, 62) - temp
C     Lower part.
      temp = M(117, 61) * M(61, 62)
      M(117, 62) = M(117, 62) - temp
C     Lower part.
      temp = M(118, 61) * M(61, 62)
      M(118, 62) = M(118, 62) - temp
C     Lower part.
      temp = M(119, 61) * M(61, 62)
      M(119, 62) = M(119, 62) - temp
C     Upper part.
      temp = M(62, 61) * M(61, 64)
      M(62, 64) = ( M(62, 64) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 113)
      temp = temp + M(62, 61) * M(61, 113)
      M(62, 113) = ( M(62, 113) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 20) * M(20, 117)
      temp = temp + M(62, 56) * M(56, 117)
      temp = temp + M(62, 61) * M(61, 117)
      M(62, 117) = ( M(62, 117) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 20) * M(20, 118)
      temp = temp + M(62, 56) * M(56, 118)
      temp = temp + M(62, 61) * M(61, 118)
      M(62, 118) = ( M(62, 118) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 61) * M(61, 119)
      M(62, 119) = ( M(62, 119) - temp ) / M(62, 62)
C     Upper part.
      M(62, 121) = M(62, 121) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 122)
      temp = temp + M(62, 61) * M(61, 122)
      M(62, 122) = ( M(62, 122) - temp ) / M(62, 62)
C     Upper part.
      temp = M(62, 56) * M(56, 123)
      temp = temp + M(62, 61) * M(61, 123)
      M(62, 123) = ( M(62, 123) - temp ) / M(62, 62)

C     Upper part.
      M(63, 64) = M(63, 64) / M(63, 63)
C     Upper part.
      temp = M(63, 60) * M(60, 113)
      M(63, 113) = ( M(63, 113) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 60) * M(60, 117)
      M(63, 117) = ( M(63, 117) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 14) * M(14, 118)
      temp = temp + M(63, 16) * M(16, 118)
      temp = temp + M(63, 60) * M(60, 118)
      M(63, 118) = ( M(63, 118) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 60) * M(60, 119)
      M(63, 119) = ( M(63, 119) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 60) * M(60, 122)
      M(63, 122) = ( M(63, 122) - temp ) / M(63, 63)
C     Upper part.
      temp = M(63, 60) * M(60, 123)
      M(63, 123) = ( M(63, 123) - temp ) / M(63, 63)

C     Lower part.
      temp = M(66, 61) * M(61, 64)
      temp = temp + M(66, 62) * M(62, 64)
      M(66, 64) = M(66, 64) - temp
C     Lower part.
      temp = M(68, 63) * M(63, 64)
      M(68, 64) = M(68, 64) - temp
C     Lower part.
      temp = M(69, 63) * M(63, 64)
      M(69, 64) = M(69, 64) - temp
C     Lower part.
      temp = M(96, 61) * M(61, 64)
      temp = temp + M(96, 62) * M(62, 64)
      M(96, 64) = M(96, 64) - temp
C     Lower part.
      temp = M(97, 61) * M(61, 64)
      temp = temp + M(97, 62) * M(62, 64)
      M(97, 64) = M(97, 64) - temp
C     Lower part.
      temp = M(100, 63) * M(63, 64)
      M(100, 64) = M(100, 64) - temp
C     Lower part.
      temp = M(101, 61) * M(61, 64)
      temp = temp + M(101, 62) * M(62, 64)
      M(101, 64) = M(101, 64) - temp
C     Lower part.
      temp = M(108, 62) * M(62, 64)
      temp = temp + M(108, 63) * M(63, 64)
      M(108, 64) = M(108, 64) - temp
C     Lower part.
      temp = M(113, 63) * M(63, 64)
      M(113, 64) = M(113, 64) - temp
C     Lower part.
      temp = M(116, 63) * M(63, 64)
      M(116, 64) = M(116, 64) - temp
C     Lower part.
      temp = M(117, 61) * M(61, 64)
      temp = temp + M(117, 62) * M(62, 64)
      temp = temp + M(117, 63) * M(63, 64)
      M(117, 64) = M(117, 64) - temp
C     Lower part.
      temp = M(118, 61) * M(61, 64)
      temp = temp + M(118, 62) * M(62, 64)
      M(118, 64) = M(118, 64) - temp
C     Lower part.
      temp = M(119, 61) * M(61, 64)
      temp = temp + M(119, 62) * M(62, 64)
      temp = temp + M(119, 63) * M(63, 64)
      M(119, 64) = M(119, 64) - temp
C     Lower part.
      temp = M(121, 62) * M(62, 64)
      temp = temp + M(121, 63) * M(63, 64)
      M(121, 64) = M(121, 64) - temp
C     Lower part.
      temp = M(122, 63) * M(63, 64)
      M(122, 64) = M(122, 64) - temp
C     Lower part.
      temp = M(123, 63) * M(63, 64)
      M(123, 64) = M(123, 64) - temp
C     Upper part.
      M(64, 113) = M(64, 113) / M(64, 64)
C     Upper part.
      M(64, 117) = M(64, 117) / M(64, 64)
C     Upper part.
      temp = M(64, 16) * M(16, 118)
      M(64, 118) = ( M(64, 118) - temp ) / M(64, 64)
C     Upper part.
      M(64, 119) = M(64, 119) / M(64, 64)
C     Upper part.
      M(64, 122) = M(64, 122) / M(64, 64)
C     Upper part.
      M(64, 123) = M(64, 123) / M(64, 64)

C     Upper part.
      temp = M(65, 54) * M(54, 113)
      temp = temp + M(65, 60) * M(60, 113)
      temp = temp + M(65, 64) * M(64, 113)
      M(65, 113) = ( M(65, 113) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 54) * M(54, 117)
      temp = temp + M(65, 60) * M(60, 117)
      temp = temp + M(65, 64) * M(64, 117)
      M(65, 117) = ( M(65, 117) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 12) * M(12, 118)
      temp = temp + M(65, 14) * M(14, 118)
      temp = temp + M(65, 16) * M(16, 118)
      temp = temp + M(65, 54) * M(54, 118)
      temp = temp + M(65, 60) * M(60, 118)
      temp = temp + M(65, 64) * M(64, 118)
      M(65, 118) = ( M(65, 118) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 54) * M(54, 119)
      temp = temp + M(65, 60) * M(60, 119)
      temp = temp + M(65, 64) * M(64, 119)
      M(65, 119) = ( M(65, 119) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 54) * M(54, 122)
      temp = temp + M(65, 60) * M(60, 122)
      temp = temp + M(65, 64) * M(64, 122)
      M(65, 122) = ( M(65, 122) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 54) * M(54, 123)
      temp = temp + M(65, 60) * M(60, 123)
      temp = temp + M(65, 64) * M(64, 123)
      M(65, 123) = ( M(65, 123) - temp ) / M(65, 65)

C     Upper part.
      temp = M(66, 61) * M(61, 113)
      temp = temp + M(66, 62) * M(62, 113)
      temp = temp + M(66, 64) * M(64, 113)
      M(66, 113) = ( M(66, 113) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 20) * M(20, 117)
      temp = temp + M(66, 61) * M(61, 117)
      temp = temp + M(66, 62) * M(62, 117)
      temp = temp + M(66, 64) * M(64, 117)
      M(66, 117) = ( M(66, 117) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 20) * M(20, 118)
      temp = temp + M(66, 61) * M(61, 118)
      temp = temp + M(66, 62) * M(62, 118)
      temp = temp + M(66, 64) * M(64, 118)
      M(66, 118) = ( M(66, 118) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 119)
      temp = temp + M(66, 62) * M(62, 119)
      temp = temp + M(66, 64) * M(64, 119)
      M(66, 119) = ( M(66, 119) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 62) * M(62, 121)
      M(66, 121) = ( M(66, 121) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 122)
      temp = temp + M(66, 62) * M(62, 122)
      temp = temp + M(66, 64) * M(64, 122)
      M(66, 122) = ( M(66, 122) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 61) * M(61, 123)
      temp = temp + M(66, 62) * M(62, 123)
      temp = temp + M(66, 64) * M(64, 123)
      M(66, 123) = ( M(66, 123) - temp ) / M(66, 66)

C     Upper part.
      temp = M(67, 37) * M(37, 76)
      M(67, 76) = ( M(67, 76) - temp ) / M(67, 67)
C     Upper part.
      M(67, 113) = M(67, 113) / M(67, 67)
C     Upper part.
      M(67, 117) = M(67, 117) / M(67, 67)
C     Upper part.
      temp = M(67, 37) * M(37, 118)
      M(67, 118) = ( M(67, 118) - temp ) / M(67, 67)
C     Upper part.
      M(67, 119) = M(67, 119) / M(67, 67)
C     Upper part.
      M(67, 122) = M(67, 122) / M(67, 67)
C     Upper part.
      temp = M(67, 37) * M(37, 123)
      M(67, 123) = ( M(67, 123) - temp ) / M(67, 67)

C     Upper part.
      temp = M(68, 67) * M(67, 76)
      M(68, 76) = ( M(68, 76) - temp ) / M(68, 68)
C     Upper part.
      M(68, 105) = M(68, 105) / M(68, 68)
C     Upper part.
      temp = M(68, 52) * M(52, 113)
      temp = temp + M(68, 54) * M(54, 113)
      temp = temp + M(68, 63) * M(63, 113)
      temp = temp + M(68, 64) * M(64, 113)
      temp = temp + M(68, 67) * M(67, 113)
      M(68, 113) = ( M(68, 113) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 52) * M(52, 117)
      temp = temp + M(68, 54) * M(54, 117)
      temp = temp + M(68, 63) * M(63, 117)
      temp = temp + M(68, 64) * M(64, 117)
      temp = temp + M(68, 67) * M(67, 117)
      M(68, 117) = ( M(68, 117) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 52) * M(52, 118)
      temp = temp + M(68, 54) * M(54, 118)
      temp = temp + M(68, 63) * M(63, 118)
      temp = temp + M(68, 64) * M(64, 118)
      temp = temp + M(68, 67) * M(67, 118)
      M(68, 118) = ( M(68, 118) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 54) * M(54, 119)
      temp = temp + M(68, 63) * M(63, 119)
      temp = temp + M(68, 64) * M(64, 119)
      temp = temp + M(68, 67) * M(67, 119)
      M(68, 119) = ( M(68, 119) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 52) * M(52, 122)
      temp = temp + M(68, 54) * M(54, 122)
      temp = temp + M(68, 63) * M(63, 122)
      temp = temp + M(68, 64) * M(64, 122)
      temp = temp + M(68, 67) * M(67, 122)
      M(68, 122) = ( M(68, 122) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 52) * M(52, 123)
      temp = temp + M(68, 54) * M(54, 123)
      temp = temp + M(68, 63) * M(63, 123)
      temp = temp + M(68, 64) * M(64, 123)
      temp = temp + M(68, 67) * M(67, 123)
      M(68, 123) = ( M(68, 123) - temp ) / M(68, 68)

C     Upper part.
      M(69, 91) = M(69, 91) / M(69, 69)
C     Upper part.
      temp = M(69, 63) * M(63, 113)
      temp = temp + M(69, 64) * M(64, 113)
      M(69, 113) = ( M(69, 113) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 63) * M(63, 117)
      temp = temp + M(69, 64) * M(64, 117)
      M(69, 117) = ( M(69, 117) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 63) * M(63, 118)
      temp = temp + M(69, 64) * M(64, 118)
      M(69, 118) = ( M(69, 118) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 63) * M(63, 119)
      temp = temp + M(69, 64) * M(64, 119)
      M(69, 119) = ( M(69, 119) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 63) * M(63, 122)
      temp = temp + M(69, 64) * M(64, 122)
      M(69, 122) = ( M(69, 122) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 63) * M(63, 123)
      temp = temp + M(69, 64) * M(64, 123)
      M(69, 123) = ( M(69, 123) - temp ) / M(69, 69)

C     Upper part.
      temp = M(70, 69) * M(69, 91)
      M(70, 91) = ( M(70, 91) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 113)
      M(70, 113) = ( M(70, 113) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 117)
      M(70, 117) = ( M(70, 117) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 118)
      M(70, 118) = ( M(70, 118) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 119)
      M(70, 119) = ( M(70, 119) - temp ) / M(70, 70)
C     Upper part.
      M(70, 120) = M(70, 120) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 122)
      M(70, 122) = ( M(70, 122) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 123)
      M(70, 123) = ( M(70, 123) - temp ) / M(70, 70)

C     Upper part.
      temp = M(71, 38) * M(38, 91)
      M(71, 91) = ( M(71, 91) - temp ) / M(71, 71)
C     Upper part.
      M(71, 113) = M(71, 113) / M(71, 71)
C     Upper part.
      temp = M(71, 38) * M(38, 117)
      M(71, 117) = ( M(71, 117) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 38) * M(38, 118)
      M(71, 118) = ( M(71, 118) - temp ) / M(71, 71)
C     Upper part.
      M(71, 119) = M(71, 119) / M(71, 71)
C     Upper part.
      M(71, 122) = M(71, 122) / M(71, 71)
C     Upper part.
      M(71, 123) = M(71, 123) / M(71, 71)

C     Upper part.
      temp = M(72, 21) * M(21, 91)
      M(72, 91) = ( M(72, 91) - temp ) / M(72, 72)
C     Upper part.
      M(72, 113) = M(72, 113) / M(72, 72)
C     Upper part.
      temp = M(72, 21) * M(21, 117)
      M(72, 117) = ( M(72, 117) - temp ) / M(72, 72)
C     Upper part.
      temp = M(72, 21) * M(21, 118)
      M(72, 118) = ( M(72, 118) - temp ) / M(72, 72)
C     Upper part.
      M(72, 119) = M(72, 119) / M(72, 72)
C     Upper part.
      M(72, 122) = M(72, 122) / M(72, 72)
C     Upper part.
      M(72, 123) = M(72, 123) / M(72, 72)

C     Upper part.
      M(73, 76) = M(73, 76) / M(73, 73)
C     Upper part.
      M(73, 85) = M(73, 85) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 91)
      M(73, 91) = ( M(73, 91) - temp ) / M(73, 73)
C     Upper part.
      M(73, 110) = M(73, 110) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 113)
      M(73, 113) = ( M(73, 113) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 117)
      M(73, 117) = ( M(73, 117) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 118)
      M(73, 118) = ( M(73, 118) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 119)
      M(73, 119) = ( M(73, 119) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 122)
      M(73, 122) = ( M(73, 122) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 72) * M(72, 123)
      M(73, 123) = ( M(73, 123) - temp ) / M(73, 73)

C     Upper part.
      M(74, 81) = M(74, 81) / M(74, 74)
C     Upper part.
      M(74, 83) = M(74, 83) / M(74, 74)
C     Upper part.
      temp = M(74, 25) * M(25, 91)
      temp = temp + M(74, 28) * M(28, 91)
      temp = temp + M(74, 31) * M(31, 91)
      temp = temp + M(74, 32) * M(32, 91)
      temp = temp + M(74, 38) * M(38, 91)
      temp = temp + M(74, 69) * M(69, 91)
      temp = temp + M(74, 72) * M(72, 91)
      M(74, 91) = ( M(74, 91) - temp ) / M(74, 74)
C     Upper part.
      M(74, 92) = M(74, 92) / M(74, 74)
C     Upper part.
      temp = M(74, 69) * M(69, 113)
      temp = temp + M(74, 72) * M(72, 113)
      M(74, 113) = ( M(74, 113) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 25) * M(25, 117)
      temp = temp + M(74, 28) * M(28, 117)
      temp = temp + M(74, 31) * M(31, 117)
      temp = temp + M(74, 32) * M(32, 117)
      temp = temp + M(74, 38) * M(38, 117)
      temp = temp + M(74, 69) * M(69, 117)
      temp = temp + M(74, 72) * M(72, 117)
      M(74, 117) = ( M(74, 117) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 6) * M(6, 118)
      temp = temp + M(74, 25) * M(25, 118)
      temp = temp + M(74, 28) * M(28, 118)
      temp = temp + M(74, 31) * M(31, 118)
      temp = temp + M(74, 32) * M(32, 118)
      temp = temp + M(74, 38) * M(38, 118)
      temp = temp + M(74, 69) * M(69, 118)
      temp = temp + M(74, 72) * M(72, 118)
      M(74, 118) = ( M(74, 118) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 69) * M(69, 119)
      temp = temp + M(74, 72) * M(72, 119)
      M(74, 119) = ( M(74, 119) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 69) * M(69, 122)
      temp = temp + M(74, 72) * M(72, 122)
      M(74, 122) = ( M(74, 122) - temp ) / M(74, 74)
C     Upper part.
      temp = M(74, 69) * M(69, 123)
      temp = temp + M(74, 72) * M(72, 123)
      M(74, 123) = ( M(74, 123) - temp ) / M(74, 74)

C     Upper part.
      M(75, 97) = M(75, 97) / M(75, 75)
C     Upper part.
      M(75, 113) = M(75, 113) / M(75, 75)
C     Upper part.
      M(75, 117) = M(75, 117) / M(75, 75)
C     Upper part.
      temp = M(75, 10) * M(10, 118)
      M(75, 118) = ( M(75, 118) - temp ) / M(75, 75)
C     Upper part.
      M(75, 122) = M(75, 122) / M(75, 75)
C     Upper part.
      M(75, 123) = M(75, 123) / M(75, 75)

C     Lower part.
      temp = M(78, 73) * M(73, 76)
      M(78, 76) = M(78, 76) - temp
C     Lower part.
      temp = M(89, 67) * M(67, 76)
      M(89, 76) = M(89, 76) - temp
C     Lower part.
      temp = M(99, 67) * M(67, 76)
      M(99, 76) = M(99, 76) - temp
C     Lower part.
      temp = M(100, 68) * M(68, 76)
      M(100, 76) = M(100, 76) - temp
C     Lower part.
      temp = M(102, 68) * M(68, 76)
      M(102, 76) = M(102, 76) - temp
C     Lower part.
      temp = M(106, 67) * M(67, 76)
      M(106, 76) = M(106, 76) - temp
C     Lower part.
      temp = M(107, 68) * M(68, 76)
      M(107, 76) = M(107, 76) - temp
C     Lower part.
      temp = M(109, 68) * M(68, 76)
      M(109, 76) = M(109, 76) - temp
C     Lower part.
      temp = M(112, 68) * M(68, 76)
      M(112, 76) = M(112, 76) - temp
C     Lower part.
      temp = M(113, 37) * M(37, 76)
      temp = temp + M(113, 67) * M(67, 76)
      temp = temp + M(113, 73) * M(73, 76)
      M(113, 76) = M(113, 76) - temp
C     Lower part.
      temp = M(114, 37) * M(37, 76)
      M(114, 76) = M(114, 76) - temp
C     Lower part.
      temp = M(115, 67) * M(67, 76)
      M(115, 76) = M(115, 76) - temp
C     Lower part.
      temp = M(116, 67) * M(67, 76)
      M(116, 76) = M(116, 76) - temp
C     Lower part.
      temp = M(117, 67) * M(67, 76)
      M(117, 76) = M(117, 76) - temp
C     Lower part.
      temp = M(118, 37) * M(37, 76)
      temp = temp + M(118, 68) * M(68, 76)
      temp = temp + M(118, 73) * M(73, 76)
      M(118, 76) = M(118, 76) - temp
C     Lower part.
      temp = M(119, 67) * M(67, 76)
      temp = temp + M(119, 68) * M(68, 76)
      M(119, 76) = M(119, 76) - temp
C     Lower part.
      temp = M(121, 67) * M(67, 76)
      M(121, 76) = M(121, 76) - temp
C     Lower part.
      temp = M(122, 37) * M(37, 76)
      temp = temp + M(122, 67) * M(67, 76)
      temp = temp + M(122, 68) * M(68, 76)
      temp = temp + M(122, 73) * M(73, 76)
      M(122, 76) = M(122, 76) - temp
C     Lower part.
      temp = M(123, 67) * M(67, 76)
      M(123, 76) = M(123, 76) - temp
C     Upper part.
      M(76, 113) = M(76, 113) / M(76, 76)
C     Upper part.
      M(76, 117) = M(76, 117) / M(76, 76)
C     Upper part.
      temp = M(76, 9) * M(9, 118)
      M(76, 118) = ( M(76, 118) - temp ) / M(76, 76)
C     Upper part.
      M(76, 119) = M(76, 119) / M(76, 76)
C     Upper part.
      M(76, 122) = M(76, 122) / M(76, 76)
C     Upper part.
      M(76, 123) = M(76, 123) / M(76, 76)

C     Upper part.
      M(77, 113) = M(77, 113) / M(77, 77)
C     Upper part.
      M(77, 117) = M(77, 117) / M(77, 77)
C     Upper part.
      temp = M(77, 7) * M(7, 118)
      M(77, 118) = ( M(77, 118) - temp ) / M(77, 77)
C     Upper part.
      M(77, 119) = M(77, 119) / M(77, 77)
C     Upper part.
      M(77, 122) = M(77, 122) / M(77, 77)
C     Upper part.
      M(77, 123) = M(77, 123) / M(77, 77)

C     Upper part.
      temp = M(78, 73) * M(73, 85)
      M(78, 85) = ( M(78, 85) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 91)
      M(78, 91) = ( M(78, 91) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 110)
      M(78, 110) = ( M(78, 110) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 113)
      temp = temp + M(78, 76) * M(76, 113)
      M(78, 113) = ( M(78, 113) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 117)
      temp = temp + M(78, 76) * M(76, 117)
      M(78, 117) = ( M(78, 117) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 118)
      temp = temp + M(78, 76) * M(76, 118)
      M(78, 118) = ( M(78, 118) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 119)
      temp = temp + M(78, 76) * M(76, 119)
      M(78, 119) = ( M(78, 119) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 122)
      temp = temp + M(78, 76) * M(76, 122)
      M(78, 122) = ( M(78, 122) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 73) * M(73, 123)
      temp = temp + M(78, 76) * M(76, 123)
      M(78, 123) = ( M(78, 123) - temp ) / M(78, 78)

C     Upper part.
      M(79, 113) = M(79, 113) / M(79, 79)
C     Upper part.
      M(79, 117) = M(79, 117) / M(79, 79)
C     Upper part.
      temp = M(79, 10) * M(10, 118)
      M(79, 118) = ( M(79, 118) - temp ) / M(79, 79)
C     Upper part.
      M(79, 119) = M(79, 119) / M(79, 79)
C     Upper part.
      M(79, 122) = M(79, 122) / M(79, 79)
C     Upper part.
      M(79, 123) = M(79, 123) / M(79, 79)

C     Lower part.
      temp = M(92, 30) * M(30, 80)
      M(92, 80) = M(92, 80) - temp
C     Lower part.
      temp = M(93, 45) * M(45, 80)
      M(93, 80) = M(93, 80) - temp
C     Lower part.
      temp = M(107, 45) * M(45, 80)
      M(107, 80) = M(107, 80) - temp
C     Lower part.
      temp = M(116, 45) * M(45, 80)
      M(116, 80) = M(116, 80) - temp
C     Lower part.
      temp = M(118, 45) * M(45, 80)
      M(118, 80) = M(118, 80) - temp
C     Lower part.
      temp = M(121, 45) * M(45, 80)
      M(121, 80) = M(121, 80) - temp
C     Upper part.
      temp = M(80, 31) * M(31, 91)
      M(80, 91) = ( M(80, 91) - temp ) / M(80, 80)
C     Upper part.
      M(80, 113) = M(80, 113) / M(80, 80)
C     Upper part.
      temp = M(80, 31) * M(31, 117)
      M(80, 117) = ( M(80, 117) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 31) * M(31, 118)
      M(80, 118) = ( M(80, 118) - temp ) / M(80, 80)
C     Upper part.
      M(80, 119) = M(80, 119) / M(80, 80)
C     Upper part.
      M(80, 122) = M(80, 122) / M(80, 80)
C     Upper part.
      M(80, 123) = M(80, 123) / M(80, 80)

C     Lower part.
      temp = M(118, 74) * M(74, 81)
      M(118, 81) = M(118, 81) - temp
C     Lower part.
      temp = M(119, 74) * M(74, 81)
      M(119, 81) = M(119, 81) - temp
C     Upper part.
      temp = M(81, 31) * M(31, 91)
      temp = temp + M(81, 80) * M(80, 91)
      M(81, 91) = ( M(81, 91) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 113)
      M(81, 113) = ( M(81, 113) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 31) * M(31, 117)
      temp = temp + M(81, 80) * M(80, 117)
      M(81, 117) = ( M(81, 117) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 31) * M(31, 118)
      temp = temp + M(81, 80) * M(80, 118)
      M(81, 118) = ( M(81, 118) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 119)
      M(81, 119) = ( M(81, 119) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 122)
      M(81, 122) = ( M(81, 122) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 80) * M(80, 123)
      M(81, 123) = ( M(81, 123) - temp ) / M(81, 81)

C     Upper part.
      temp = M(82, 81) * M(81, 91)
      M(82, 91) = ( M(82, 91) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 113)
      M(82, 113) = ( M(82, 113) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 117)
      M(82, 117) = ( M(82, 117) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 118)
      M(82, 118) = ( M(82, 118) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 119)
      M(82, 119) = ( M(82, 119) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 122)
      M(82, 122) = ( M(82, 122) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 123)
      M(82, 123) = ( M(82, 123) - temp ) / M(82, 82)

C     Lower part.
      temp = M(118, 74) * M(74, 83)
      M(118, 83) = M(118, 83) - temp
C     Lower part.
      temp = M(119, 74) * M(74, 83)
      M(119, 83) = M(119, 83) - temp
C     Upper part.
      temp = M(83, 81) * M(81, 91)
      M(83, 91) = ( M(83, 91) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 77) * M(77, 113)
      temp = temp + M(83, 81) * M(81, 113)
      M(83, 113) = ( M(83, 113) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 77) * M(77, 117)
      temp = temp + M(83, 81) * M(81, 117)
      M(83, 117) = ( M(83, 117) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 7) * M(7, 118)
      temp = temp + M(83, 77) * M(77, 118)
      temp = temp + M(83, 81) * M(81, 118)
      M(83, 118) = ( M(83, 118) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 77) * M(77, 119)
      temp = temp + M(83, 81) * M(81, 119)
      M(83, 119) = ( M(83, 119) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 77) * M(77, 122)
      temp = temp + M(83, 81) * M(81, 122)
      M(83, 122) = ( M(83, 122) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 77) * M(77, 123)
      temp = temp + M(83, 81) * M(81, 123)
      M(83, 123) = ( M(83, 123) - temp ) / M(83, 83)

C     Upper part.
      temp = M(84, 83) * M(83, 91)
      M(84, 91) = ( M(84, 91) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 83) * M(83, 113)
      M(84, 113) = ( M(84, 113) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 83) * M(83, 117)
      M(84, 117) = ( M(84, 117) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 83) * M(83, 118)
      M(84, 118) = ( M(84, 118) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 83) * M(83, 119)
      M(84, 119) = ( M(84, 119) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 83) * M(83, 122)
      M(84, 122) = ( M(84, 122) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 83) * M(83, 123)
      M(84, 123) = ( M(84, 123) - temp ) / M(84, 84)

C     Lower part.
      temp = M(89, 78) * M(78, 85)
      M(89, 85) = M(89, 85) - temp
C     Lower part.
      temp = M(99, 78) * M(78, 85)
      M(99, 85) = M(99, 85) - temp
C     Lower part.
      temp = M(106, 78) * M(78, 85)
      M(106, 85) = M(106, 85) - temp
C     Lower part.
      temp = M(113, 73) * M(73, 85)
      temp = temp + M(113, 78) * M(78, 85)
      M(113, 85) = M(113, 85) - temp
C     Lower part.
      temp = M(115, 78) * M(78, 85)
      M(115, 85) = M(115, 85) - temp
C     Lower part.
      temp = M(116, 78) * M(78, 85)
      M(116, 85) = M(116, 85) - temp
C     Lower part.
      temp = M(117, 78) * M(78, 85)
      M(117, 85) = M(117, 85) - temp
C     Lower part.
      temp = M(118, 73) * M(73, 85)
      temp = temp + M(118, 78) * M(78, 85)
      M(118, 85) = M(118, 85) - temp
C     Lower part.
      temp = M(119, 78) * M(78, 85)
      M(119, 85) = M(119, 85) - temp
C     Lower part.
      temp = M(121, 78) * M(78, 85)
      M(121, 85) = M(121, 85) - temp
C     Lower part.
      temp = M(122, 73) * M(73, 85)
      temp = temp + M(122, 78) * M(78, 85)
      M(122, 85) = M(122, 85) - temp
C     Lower part.
      temp = M(123, 78) * M(78, 85)
      M(123, 85) = M(123, 85) - temp
C     Upper part.
      temp = M(85, 32) * M(32, 91)
      M(85, 91) = ( M(85, 91) - temp ) / M(85, 85)
C     Upper part.
      M(85, 113) = M(85, 113) / M(85, 85)
C     Upper part.
      temp = M(85, 32) * M(32, 117)
      M(85, 117) = ( M(85, 117) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 32) * M(32, 118)
      M(85, 118) = ( M(85, 118) - temp ) / M(85, 85)
C     Upper part.
      M(85, 119) = M(85, 119) / M(85, 85)
C     Upper part.
      M(85, 122) = M(85, 122) / M(85, 85)
C     Upper part.
      M(85, 123) = M(85, 123) / M(85, 85)

C     Lower part.
      temp = M(113, 44) * M(44, 86)
      M(113, 86) = M(113, 86) - temp
C     Lower part.
      temp = M(114, 39) * M(39, 86)
      M(114, 86) = M(114, 86) - temp
C     Lower part.
      temp = M(118, 39) * M(39, 86)
      temp = temp + M(118, 44) * M(44, 86)
      temp = temp + M(118, 51) * M(51, 86)
      M(118, 86) = M(118, 86) - temp
C     Lower part.
      temp = M(119, 51) * M(51, 86)
      M(119, 86) = M(119, 86) - temp
C     Upper part.
      temp = M(86, 85) * M(85, 91)
      M(86, 91) = ( M(86, 91) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 113)
      temp = temp + M(86, 85) * M(85, 113)
      M(86, 113) = ( M(86, 113) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 117)
      temp = temp + M(86, 85) * M(85, 117)
      M(86, 117) = ( M(86, 117) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 118)
      temp = temp + M(86, 85) * M(85, 118)
      M(86, 118) = ( M(86, 118) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 119)
      temp = temp + M(86, 85) * M(85, 119)
      M(86, 119) = ( M(86, 119) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 122)
      temp = temp + M(86, 85) * M(85, 122)
      M(86, 122) = ( M(86, 122) - temp ) / M(86, 86)
C     Upper part.
      temp = M(86, 77) * M(77, 123)
      temp = temp + M(86, 85) * M(85, 123)
      M(86, 123) = ( M(86, 123) - temp ) / M(86, 86)

C     Upper part.
      temp = M(87, 25) * M(25, 91)
      temp = temp + M(87, 69) * M(69, 91)
      temp = temp + M(87, 86) * M(86, 91)
      M(87, 91) = ( M(87, 91) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 69) * M(69, 113)
      temp = temp + M(87, 86) * M(86, 113)
      M(87, 113) = ( M(87, 113) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 25) * M(25, 117)
      temp = temp + M(87, 69) * M(69, 117)
      temp = temp + M(87, 86) * M(86, 117)
      M(87, 117) = ( M(87, 117) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 25) * M(25, 118)
      temp = temp + M(87, 69) * M(69, 118)
      temp = temp + M(87, 86) * M(86, 118)
      M(87, 118) = ( M(87, 118) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 69) * M(69, 119)
      temp = temp + M(87, 86) * M(86, 119)
      M(87, 119) = ( M(87, 119) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 69) * M(69, 122)
      temp = temp + M(87, 86) * M(86, 122)
      M(87, 122) = ( M(87, 122) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 69) * M(69, 123)
      temp = temp + M(87, 86) * M(86, 123)
      M(87, 123) = ( M(87, 123) - temp ) / M(87, 87)

C     Upper part.
      M(88, 90) = M(88, 90) / M(88, 88)
C     Upper part.
      temp = M(88, 21) * M(21, 91)
      temp = temp + M(88, 25) * M(25, 91)
      temp = temp + M(88, 28) * M(28, 91)
      temp = temp + M(88, 32) * M(32, 91)
      temp = temp + M(88, 38) * M(38, 91)
      temp = temp + M(88, 86) * M(86, 91)
      M(88, 91) = ( M(88, 91) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 86) * M(86, 113)
      M(88, 113) = ( M(88, 113) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 21) * M(21, 117)
      temp = temp + M(88, 25) * M(25, 117)
      temp = temp + M(88, 28) * M(28, 117)
      temp = temp + M(88, 32) * M(32, 117)
      temp = temp + M(88, 38) * M(38, 117)
      temp = temp + M(88, 86) * M(86, 117)
      M(88, 117) = ( M(88, 117) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 21) * M(21, 118)
      temp = temp + M(88, 25) * M(25, 118)
      temp = temp + M(88, 28) * M(28, 118)
      temp = temp + M(88, 32) * M(32, 118)
      temp = temp + M(88, 38) * M(38, 118)
      temp = temp + M(88, 86) * M(86, 118)
      M(88, 118) = ( M(88, 118) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 86) * M(86, 119)
      M(88, 119) = ( M(88, 119) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 86) * M(86, 122)
      M(88, 122) = ( M(88, 122) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 86) * M(86, 123)
      M(88, 123) = ( M(88, 123) - temp ) / M(88, 88)

C     Upper part.
      temp = M(89, 88) * M(88, 90)
      M(89, 90) = ( M(89, 90) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 71) * M(71, 91)
      temp = temp + M(89, 72) * M(72, 91)
      temp = temp + M(89, 78) * M(78, 91)
      temp = temp + M(89, 80) * M(80, 91)
      temp = temp + M(89, 82) * M(82, 91)
      temp = temp + M(89, 84) * M(84, 91)
      temp = temp + M(89, 85) * M(85, 91)
      temp = temp + M(89, 87) * M(87, 91)
      temp = temp + M(89, 88) * M(88, 91)
      M(89, 91) = ( M(89, 91) - temp ) / M(89, 89)
C     Upper part.
      M(89, 104) = M(89, 104) / M(89, 89)
C     Upper part.
      M(89, 105) = M(89, 105) / M(89, 89)
C     Upper part.
      temp = M(89, 78) * M(78, 110)
      M(89, 110) = ( M(89, 110) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 67) * M(67, 113)
      temp = temp + M(89, 71) * M(71, 113)
      temp = temp + M(89, 72) * M(72, 113)
      temp = temp + M(89, 76) * M(76, 113)
      temp = temp + M(89, 78) * M(78, 113)
      temp = temp + M(89, 79) * M(79, 113)
      temp = temp + M(89, 80) * M(80, 113)
      temp = temp + M(89, 82) * M(82, 113)
      temp = temp + M(89, 84) * M(84, 113)
      temp = temp + M(89, 85) * M(85, 113)
      temp = temp + M(89, 87) * M(87, 113)
      temp = temp + M(89, 88) * M(88, 113)
      M(89, 113) = ( M(89, 113) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 67) * M(67, 117)
      temp = temp + M(89, 71) * M(71, 117)
      temp = temp + M(89, 72) * M(72, 117)
      temp = temp + M(89, 76) * M(76, 117)
      temp = temp + M(89, 78) * M(78, 117)
      temp = temp + M(89, 79) * M(79, 117)
      temp = temp + M(89, 80) * M(80, 117)
      temp = temp + M(89, 82) * M(82, 117)
      temp = temp + M(89, 84) * M(84, 117)
      temp = temp + M(89, 85) * M(85, 117)
      temp = temp + M(89, 87) * M(87, 117)
      temp = temp + M(89, 88) * M(88, 117)
      M(89, 117) = ( M(89, 117) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 67) * M(67, 118)
      temp = temp + M(89, 71) * M(71, 118)
      temp = temp + M(89, 72) * M(72, 118)
      temp = temp + M(89, 76) * M(76, 118)
      temp = temp + M(89, 78) * M(78, 118)
      temp = temp + M(89, 79) * M(79, 118)
      temp = temp + M(89, 80) * M(80, 118)
      temp = temp + M(89, 82) * M(82, 118)
      temp = temp + M(89, 84) * M(84, 118)
      temp = temp + M(89, 85) * M(85, 118)
      temp = temp + M(89, 87) * M(87, 118)
      temp = temp + M(89, 88) * M(88, 118)
      M(89, 118) = ( M(89, 118) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 67) * M(67, 119)
      temp = temp + M(89, 71) * M(71, 119)
      temp = temp + M(89, 72) * M(72, 119)
      temp = temp + M(89, 76) * M(76, 119)
      temp = temp + M(89, 78) * M(78, 119)
      temp = temp + M(89, 79) * M(79, 119)
      temp = temp + M(89, 80) * M(80, 119)
      temp = temp + M(89, 82) * M(82, 119)
      temp = temp + M(89, 84) * M(84, 119)
      temp = temp + M(89, 85) * M(85, 119)
      temp = temp + M(89, 87) * M(87, 119)
      temp = temp + M(89, 88) * M(88, 119)
      M(89, 119) = ( M(89, 119) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 67) * M(67, 122)
      temp = temp + M(89, 71) * M(71, 122)
      temp = temp + M(89, 72) * M(72, 122)
      temp = temp + M(89, 76) * M(76, 122)
      temp = temp + M(89, 78) * M(78, 122)
      temp = temp + M(89, 79) * M(79, 122)
      temp = temp + M(89, 80) * M(80, 122)
      temp = temp + M(89, 82) * M(82, 122)
      temp = temp + M(89, 84) * M(84, 122)
      temp = temp + M(89, 85) * M(85, 122)
      temp = temp + M(89, 87) * M(87, 122)
      temp = temp + M(89, 88) * M(88, 122)
      M(89, 122) = ( M(89, 122) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 67) * M(67, 123)
      temp = temp + M(89, 71) * M(71, 123)
      temp = temp + M(89, 72) * M(72, 123)
      temp = temp + M(89, 76) * M(76, 123)
      temp = temp + M(89, 78) * M(78, 123)
      temp = temp + M(89, 79) * M(79, 123)
      temp = temp + M(89, 80) * M(80, 123)
      temp = temp + M(89, 82) * M(82, 123)
      temp = temp + M(89, 84) * M(84, 123)
      temp = temp + M(89, 85) * M(85, 123)
      temp = temp + M(89, 87) * M(87, 123)
      temp = temp + M(89, 88) * M(88, 123)
      M(89, 123) = ( M(89, 123) - temp ) / M(89, 89)

C     Lower part.
      temp = M(90, 88) * M(88, 90)
      M(90, 90) = M(90, 90) - temp
C     Lower part.
      temp = M(94, 89) * M(89, 90)
      M(94, 90) = M(94, 90) - temp
C     Lower part.
      temp = M(99, 88) * M(88, 90)
      M(99, 90) = M(99, 90) - temp
C     Lower part.
      temp = M(106, 88) * M(88, 90)
      M(106, 90) = M(106, 90) - temp
C     Lower part.
      temp = M(108, 88) * M(88, 90)
      M(108, 90) = M(108, 90) - temp
C     Lower part.
      temp = M(109, 88) * M(88, 90)
      temp = temp + M(109, 89) * M(89, 90)
      M(109, 90) = M(109, 90) - temp
C     Lower part.
      temp = M(111, 88) * M(88, 90)
      M(111, 90) = M(111, 90) - temp
C     Lower part.
      temp = M(113, 88) * M(88, 90)
      M(113, 90) = M(113, 90) - temp
C     Lower part.
      temp = M(116, 88) * M(88, 90)
      M(116, 90) = M(116, 90) - temp
C     Lower part.
      temp = M(117, 88) * M(88, 90)
      M(117, 90) = M(117, 90) - temp
C     Lower part.
      temp = M(118, 89) * M(89, 90)
      M(118, 90) = M(118, 90) - temp
C     Lower part.
      temp = M(119, 88) * M(88, 90)
      temp = temp + M(119, 89) * M(89, 90)
      M(119, 90) = M(119, 90) - temp
C     Lower part.
      temp = M(121, 88) * M(88, 90)
      M(121, 90) = M(121, 90) - temp
C     Lower part.
      temp = M(122, 88) * M(88, 90)
      M(122, 90) = M(122, 90) - temp
C     Lower part.
      temp = M(123, 88) * M(88, 90)
      M(123, 90) = M(123, 90) - temp
C     Upper part.
      temp = M(90, 21) * M(21, 91)
      temp = temp + M(90, 25) * M(25, 91)
      temp = temp + M(90, 28) * M(28, 91)
      temp = temp + M(90, 32) * M(32, 91)
      temp = temp + M(90, 38) * M(38, 91)
      temp = temp + M(90, 86) * M(86, 91)
      temp = temp + M(90, 88) * M(88, 91)
      M(90, 91) = ( M(90, 91) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 86) * M(86, 113)
      temp = temp + M(90, 88) * M(88, 113)
      M(90, 113) = ( M(90, 113) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 21) * M(21, 117)
      temp = temp + M(90, 25) * M(25, 117)
      temp = temp + M(90, 28) * M(28, 117)
      temp = temp + M(90, 32) * M(32, 117)
      temp = temp + M(90, 38) * M(38, 117)
      temp = temp + M(90, 86) * M(86, 117)
      temp = temp + M(90, 88) * M(88, 117)
      M(90, 117) = ( M(90, 117) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 21) * M(21, 118)
      temp = temp + M(90, 25) * M(25, 118)
      temp = temp + M(90, 28) * M(28, 118)
      temp = temp + M(90, 32) * M(32, 118)
      temp = temp + M(90, 38) * M(38, 118)
      temp = temp + M(90, 86) * M(86, 118)
      temp = temp + M(90, 88) * M(88, 118)
      M(90, 118) = ( M(90, 118) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 86) * M(86, 119)
      temp = temp + M(90, 88) * M(88, 119)
      M(90, 119) = ( M(90, 119) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 86) * M(86, 122)
      temp = temp + M(90, 88) * M(88, 122)
      M(90, 122) = ( M(90, 122) - temp ) / M(90, 90)
C     Upper part.
      temp = M(90, 86) * M(86, 123)
      temp = temp + M(90, 88) * M(88, 123)
      M(90, 123) = ( M(90, 123) - temp ) / M(90, 90)

C     Lower part.
      temp = M(91, 21) * M(21, 91)
      temp = temp + M(91, 25) * M(25, 91)
      temp = temp + M(91, 27) * M(27, 91)
      temp = temp + M(91, 28) * M(28, 91)
      temp = temp + M(91, 31) * M(31, 91)
      temp = temp + M(91, 32) * M(32, 91)
      temp = temp + M(91, 38) * M(38, 91)
      temp = temp + M(91, 47) * M(47, 91)
      temp = temp + M(91, 69) * M(69, 91)
      temp = temp + M(91, 81) * M(81, 91)
      temp = temp + M(91, 83) * M(83, 91)
      temp = temp + M(91, 86) * M(86, 91)
      M(91, 91) = M(91, 91) - temp
C     Lower part.
      temp = M(92, 25) * M(25, 91)
      temp = temp + M(92, 31) * M(31, 91)
      temp = temp + M(92, 32) * M(32, 91)
      temp = temp + M(92, 80) * M(80, 91)
      temp = temp + M(92, 85) * M(85, 91)
      M(92, 91) = M(92, 91) - temp
C     Lower part.
      temp = M(93, 45) * M(45, 91)
      temp = temp + M(93, 80) * M(80, 91)
      M(93, 91) = M(93, 91) - temp
C     Lower part.
      temp = M(94, 89) * M(89, 91)
      temp = temp + M(94, 90) * M(90, 91)
      M(94, 91) = M(94, 91) - temp
C     Lower part.
      temp = M(98, 28) * M(28, 91)
      M(98, 91) = M(98, 91) - temp
C     Lower part.
      temp = M(99, 71) * M(71, 91)
      temp = temp + M(99, 72) * M(72, 91)
      temp = temp + M(99, 78) * M(78, 91)
      temp = temp + M(99, 80) * M(80, 91)
      temp = temp + M(99, 82) * M(82, 91)
      temp = temp + M(99, 84) * M(84, 91)
      temp = temp + M(99, 85) * M(85, 91)
      temp = temp + M(99, 87) * M(87, 91)
      temp = temp + M(99, 88) * M(88, 91)
      temp = temp + M(99, 90) * M(90, 91)
      M(99, 91) = M(99, 91) - temp
C     Lower part.
      temp = M(100, 69) * M(69, 91)
      temp = temp + M(100, 81) * M(81, 91)
      temp = temp + M(100, 82) * M(82, 91)
      temp = temp + M(100, 83) * M(83, 91)
      temp = temp + M(100, 84) * M(84, 91)
      M(100, 91) = M(100, 91) - temp
C     Lower part.
      temp = M(101, 27) * M(27, 91)
      M(101, 91) = M(101, 91) - temp
C     Lower part.
      temp = M(102, 27) * M(27, 91)
      temp = temp + M(102, 83) * M(83, 91)
      temp = temp + M(102, 84) * M(84, 91)
      M(102, 91) = M(102, 91) - temp
C     Lower part.
      temp = M(104, 31) * M(31, 91)
      temp = temp + M(104, 81) * M(81, 91)
      M(104, 91) = M(104, 91) - temp
C     Lower part.
      temp = M(105, 21) * M(21, 91)
      temp = temp + M(105, 25) * M(25, 91)
      temp = temp + M(105, 32) * M(32, 91)
      temp = temp + M(105, 38) * M(38, 91)
      temp = temp + M(105, 86) * M(86, 91)
      M(105, 91) = M(105, 91) - temp
C     Lower part.
      temp = M(106, 32) * M(32, 91)
      temp = temp + M(106, 38) * M(38, 91)
      temp = temp + M(106, 69) * M(69, 91)
      temp = temp + M(106, 71) * M(71, 91)
      temp = temp + M(106, 72) * M(72, 91)
      temp = temp + M(106, 78) * M(78, 91)
      temp = temp + M(106, 80) * M(80, 91)
      temp = temp + M(106, 82) * M(82, 91)
      temp = temp + M(106, 84) * M(84, 91)
      temp = temp + M(106, 85) * M(85, 91)
      temp = temp + M(106, 86) * M(86, 91)
      temp = temp + M(106, 87) * M(87, 91)
      temp = temp + M(106, 88) * M(88, 91)
      temp = temp + M(106, 90) * M(90, 91)
      M(106, 91) = M(106, 91) - temp
C     Lower part.
      temp = M(107, 21) * M(21, 91)
      temp = temp + M(107, 25) * M(25, 91)
      temp = temp + M(107, 27) * M(27, 91)
      temp = temp + M(107, 28) * M(28, 91)
      temp = temp + M(107, 31) * M(31, 91)
      temp = temp + M(107, 32) * M(32, 91)
      temp = temp + M(107, 38) * M(38, 91)
      temp = temp + M(107, 45) * M(45, 91)
      temp = temp + M(107, 69) * M(69, 91)
      temp = temp + M(107, 80) * M(80, 91)
      temp = temp + M(107, 81) * M(81, 91)
      temp = temp + M(107, 83) * M(83, 91)
      temp = temp + M(107, 84) * M(84, 91)
      temp = temp + M(107, 86) * M(86, 91)
      M(107, 91) = M(107, 91) - temp
C     Lower part.
      temp = M(108, 72) * M(72, 91)
      temp = temp + M(108, 83) * M(83, 91)
      temp = temp + M(108, 85) * M(85, 91)
      temp = temp + M(108, 88) * M(88, 91)
      temp = temp + M(108, 90) * M(90, 91)
      M(108, 91) = M(108, 91) - temp
C     Lower part.
      temp = M(109, 21) * M(21, 91)
      temp = temp + M(109, 27) * M(27, 91)
      temp = temp + M(109, 38) * M(38, 91)
      temp = temp + M(109, 71) * M(71, 91)
      temp = temp + M(109, 72) * M(72, 91)
      temp = temp + M(109, 82) * M(82, 91)
      temp = temp + M(109, 83) * M(83, 91)
      temp = temp + M(109, 84) * M(84, 91)
      temp = temp + M(109, 86) * M(86, 91)
      temp = temp + M(109, 87) * M(87, 91)
      temp = temp + M(109, 88) * M(88, 91)
      temp = temp + M(109, 89) * M(89, 91)
      temp = temp + M(109, 90) * M(90, 91)
      M(109, 91) = M(109, 91) - temp
C     Lower part.
      temp = M(111, 21) * M(21, 91)
      temp = temp + M(111, 38) * M(38, 91)
      temp = temp + M(111, 71) * M(71, 91)
      temp = temp + M(111, 72) * M(72, 91)
      temp = temp + M(111, 83) * M(83, 91)
      temp = temp + M(111, 84) * M(84, 91)
      temp = temp + M(111, 85) * M(85, 91)
      temp = temp + M(111, 86) * M(86, 91)
      temp = temp + M(111, 87) * M(87, 91)
      temp = temp + M(111, 88) * M(88, 91)
      temp = temp + M(111, 90) * M(90, 91)
      M(111, 91) = M(111, 91) - temp
C     Lower part.
      temp = M(112, 25) * M(25, 91)
      temp = temp + M(112, 27) * M(27, 91)
      temp = temp + M(112, 70) * M(70, 91)
      temp = temp + M(112, 81) * M(81, 91)
      temp = temp + M(112, 82) * M(82, 91)
      temp = temp + M(112, 83) * M(83, 91)
      M(112, 91) = M(112, 91) - temp
C     Lower part.
      temp = M(113, 25) * M(25, 91)
      temp = temp + M(113, 31) * M(31, 91)
      temp = temp + M(113, 38) * M(38, 91)
      temp = temp + M(113, 44) * M(44, 91)
      temp = temp + M(113, 70) * M(70, 91)
      temp = temp + M(113, 71) * M(71, 91)
      temp = temp + M(113, 72) * M(72, 91)
      temp = temp + M(113, 73) * M(73, 91)
      temp = temp + M(113, 78) * M(78, 91)
      temp = temp + M(113, 80) * M(80, 91)
      temp = temp + M(113, 81) * M(81, 91)
      temp = temp + M(113, 82) * M(82, 91)
      temp = temp + M(113, 83) * M(83, 91)
      temp = temp + M(113, 84) * M(84, 91)
      temp = temp + M(113, 85) * M(85, 91)
      temp = temp + M(113, 86) * M(86, 91)
      temp = temp + M(113, 87) * M(87, 91)
      temp = temp + M(113, 88) * M(88, 91)
      temp = temp + M(113, 90) * M(90, 91)
      M(113, 91) = M(113, 91) - temp
C     Lower part.
      temp = M(114, 21) * M(21, 91)
      temp = temp + M(114, 32) * M(32, 91)
      temp = temp + M(114, 38) * M(38, 91)
      temp = temp + M(114, 39) * M(39, 91)
      temp = temp + M(114, 86) * M(86, 91)
      M(114, 91) = M(114, 91) - temp
C     Lower part.
      temp = M(115, 71) * M(71, 91)
      temp = temp + M(115, 72) * M(72, 91)
      temp = temp + M(115, 78) * M(78, 91)
      temp = temp + M(115, 82) * M(82, 91)
      temp = temp + M(115, 84) * M(84, 91)
      temp = temp + M(115, 85) * M(85, 91)
      temp = temp + M(115, 87) * M(87, 91)
      M(115, 91) = M(115, 91) - temp
C     Lower part.
      temp = M(116, 25) * M(25, 91)
      temp = temp + M(116, 28) * M(28, 91)
      temp = temp + M(116, 31) * M(31, 91)
      temp = temp + M(116, 32) * M(32, 91)
      temp = temp + M(116, 38) * M(38, 91)
      temp = temp + M(116, 45) * M(45, 91)
      temp = temp + M(116, 70) * M(70, 91)
      temp = temp + M(116, 71) * M(71, 91)
      temp = temp + M(116, 72) * M(72, 91)
      temp = temp + M(116, 78) * M(78, 91)
      temp = temp + M(116, 80) * M(80, 91)
      temp = temp + M(116, 81) * M(81, 91)
      temp = temp + M(116, 82) * M(82, 91)
      temp = temp + M(116, 83) * M(83, 91)
      temp = temp + M(116, 84) * M(84, 91)
      temp = temp + M(116, 85) * M(85, 91)
      temp = temp + M(116, 86) * M(86, 91)
      temp = temp + M(116, 87) * M(87, 91)
      temp = temp + M(116, 88) * M(88, 91)
      temp = temp + M(116, 90) * M(90, 91)
      M(116, 91) = M(116, 91) - temp
C     Lower part.
      temp = M(117, 21) * M(21, 91)
      temp = temp + M(117, 25) * M(25, 91)
      temp = temp + M(117, 27) * M(27, 91)
      temp = temp + M(117, 28) * M(28, 91)
      temp = temp + M(117, 31) * M(31, 91)
      temp = temp + M(117, 32) * M(32, 91)
      temp = temp + M(117, 38) * M(38, 91)
      temp = temp + M(117, 47) * M(47, 91)
      temp = temp + M(117, 71) * M(71, 91)
      temp = temp + M(117, 72) * M(72, 91)
      temp = temp + M(117, 78) * M(78, 91)
      temp = temp + M(117, 80) * M(80, 91)
      temp = temp + M(117, 82) * M(82, 91)
      temp = temp + M(117, 83) * M(83, 91)
      temp = temp + M(117, 84) * M(84, 91)
      temp = temp + M(117, 85) * M(85, 91)
      temp = temp + M(117, 86) * M(86, 91)
      temp = temp + M(117, 87) * M(87, 91)
      temp = temp + M(117, 88) * M(88, 91)
      temp = temp + M(117, 90) * M(90, 91)
      M(117, 91) = M(117, 91) - temp
C     Lower part.
      temp = M(118, 3) * M(3, 91)
      temp = temp + M(118, 21) * M(21, 91)
      temp = temp + M(118, 25) * M(25, 91)
      temp = temp + M(118, 27) * M(27, 91)
      temp = temp + M(118, 28) * M(28, 91)
      temp = temp + M(118, 31) * M(31, 91)
      temp = temp + M(118, 32) * M(32, 91)
      temp = temp + M(118, 38) * M(38, 91)
      temp = temp + M(118, 39) * M(39, 91)
      temp = temp + M(118, 44) * M(44, 91)
      temp = temp + M(118, 45) * M(45, 91)
      temp = temp + M(118, 51) * M(51, 91)
      temp = temp + M(118, 69) * M(69, 91)
      temp = temp + M(118, 70) * M(70, 91)
      temp = temp + M(118, 73) * M(73, 91)
      temp = temp + M(118, 74) * M(74, 91)
      temp = temp + M(118, 78) * M(78, 91)
      temp = temp + M(118, 80) * M(80, 91)
      temp = temp + M(118, 81) * M(81, 91)
      temp = temp + M(118, 83) * M(83, 91)
      temp = temp + M(118, 85) * M(85, 91)
      temp = temp + M(118, 86) * M(86, 91)
      temp = temp + M(118, 89) * M(89, 91)
      temp = temp + M(118, 90) * M(90, 91)
      M(118, 91) = M(118, 91) - temp
C     Lower part.
      temp = M(119, 21) * M(21, 91)
      temp = temp + M(119, 25) * M(25, 91)
      temp = temp + M(119, 27) * M(27, 91)
      temp = temp + M(119, 28) * M(28, 91)
      temp = temp + M(119, 31) * M(31, 91)
      temp = temp + M(119, 32) * M(32, 91)
      temp = temp + M(119, 38) * M(38, 91)
      temp = temp + M(119, 51) * M(51, 91)
      temp = temp + M(119, 69) * M(69, 91)
      temp = temp + M(119, 71) * M(71, 91)
      temp = temp + M(119, 72) * M(72, 91)
      temp = temp + M(119, 74) * M(74, 91)
      temp = temp + M(119, 78) * M(78, 91)
      temp = temp + M(119, 80) * M(80, 91)
      temp = temp + M(119, 81) * M(81, 91)
      temp = temp + M(119, 82) * M(82, 91)
      temp = temp + M(119, 83) * M(83, 91)
      temp = temp + M(119, 84) * M(84, 91)
      temp = temp + M(119, 85) * M(85, 91)
      temp = temp + M(119, 86) * M(86, 91)
      temp = temp + M(119, 87) * M(87, 91)
      temp = temp + M(119, 88) * M(88, 91)
      temp = temp + M(119, 89) * M(89, 91)
      temp = temp + M(119, 90) * M(90, 91)
      M(119, 91) = M(119, 91) - temp
C     Lower part.
      temp = M(121, 27) * M(27, 91)
      temp = temp + M(121, 45) * M(45, 91)
      temp = temp + M(121, 47) * M(47, 91)
      temp = temp + M(121, 71) * M(71, 91)
      temp = temp + M(121, 72) * M(72, 91)
      temp = temp + M(121, 78) * M(78, 91)
      temp = temp + M(121, 80) * M(80, 91)
      temp = temp + M(121, 82) * M(82, 91)
      temp = temp + M(121, 84) * M(84, 91)
      temp = temp + M(121, 85) * M(85, 91)
      temp = temp + M(121, 87) * M(87, 91)
      temp = temp + M(121, 88) * M(88, 91)
      temp = temp + M(121, 90) * M(90, 91)
      M(121, 91) = M(121, 91) - temp
C     Lower part.
      temp = M(122, 25) * M(25, 91)
      temp = temp + M(122, 31) * M(31, 91)
      temp = temp + M(122, 69) * M(69, 91)
      temp = temp + M(122, 70) * M(70, 91)
      temp = temp + M(122, 71) * M(71, 91)
      temp = temp + M(122, 72) * M(72, 91)
      temp = temp + M(122, 73) * M(73, 91)
      temp = temp + M(122, 78) * M(78, 91)
      temp = temp + M(122, 80) * M(80, 91)
      temp = temp + M(122, 81) * M(81, 91)
      temp = temp + M(122, 82) * M(82, 91)
      temp = temp + M(122, 83) * M(83, 91)
      temp = temp + M(122, 84) * M(84, 91)
      temp = temp + M(122, 85) * M(85, 91)
      temp = temp + M(122, 87) * M(87, 91)
      temp = temp + M(122, 88) * M(88, 91)
      temp = temp + M(122, 90) * M(90, 91)
      M(122, 91) = M(122, 91) - temp
C     Lower part.
      temp = M(123, 47) * M(47, 91)
      temp = temp + M(123, 71) * M(71, 91)
      temp = temp + M(123, 72) * M(72, 91)
      temp = temp + M(123, 78) * M(78, 91)
      temp = temp + M(123, 80) * M(80, 91)
      temp = temp + M(123, 82) * M(82, 91)
      temp = temp + M(123, 84) * M(84, 91)
      temp = temp + M(123, 85) * M(85, 91)
      temp = temp + M(123, 87) * M(87, 91)
      temp = temp + M(123, 88) * M(88, 91)
      temp = temp + M(123, 90) * M(90, 91)
      M(123, 91) = M(123, 91) - temp
C     Upper part.
      M(91, 92) = M(91, 92) / M(91, 91)
C     Upper part.
      M(91, 96) = M(91, 96) / M(91, 91)
C     Upper part.
      temp = M(91, 69) * M(69, 113)
      temp = temp + M(91, 81) * M(81, 113)
      temp = temp + M(91, 83) * M(83, 113)
      temp = temp + M(91, 86) * M(86, 113)
      M(91, 113) = ( M(91, 113) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 21) * M(21, 117)
      temp = temp + M(91, 25) * M(25, 117)
      temp = temp + M(91, 27) * M(27, 117)
      temp = temp + M(91, 28) * M(28, 117)
      temp = temp + M(91, 31) * M(31, 117)
      temp = temp + M(91, 32) * M(32, 117)
      temp = temp + M(91, 38) * M(38, 117)
      temp = temp + M(91, 47) * M(47, 117)
      temp = temp + M(91, 69) * M(69, 117)
      temp = temp + M(91, 81) * M(81, 117)
      temp = temp + M(91, 83) * M(83, 117)
      temp = temp + M(91, 86) * M(86, 117)
      M(91, 117) = ( M(91, 117) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 21) * M(21, 118)
      temp = temp + M(91, 25) * M(25, 118)
      temp = temp + M(91, 27) * M(27, 118)
      temp = temp + M(91, 28) * M(28, 118)
      temp = temp + M(91, 31) * M(31, 118)
      temp = temp + M(91, 32) * M(32, 118)
      temp = temp + M(91, 38) * M(38, 118)
      temp = temp + M(91, 47) * M(47, 118)
      temp = temp + M(91, 69) * M(69, 118)
      temp = temp + M(91, 81) * M(81, 118)
      temp = temp + M(91, 83) * M(83, 118)
      temp = temp + M(91, 86) * M(86, 118)
      M(91, 118) = ( M(91, 118) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 69) * M(69, 119)
      temp = temp + M(91, 81) * M(81, 119)
      temp = temp + M(91, 83) * M(83, 119)
      temp = temp + M(91, 86) * M(86, 119)
      M(91, 119) = ( M(91, 119) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 47) * M(47, 121)
      M(91, 121) = ( M(91, 121) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 69) * M(69, 122)
      temp = temp + M(91, 81) * M(81, 122)
      temp = temp + M(91, 83) * M(83, 122)
      temp = temp + M(91, 86) * M(86, 122)
      M(91, 122) = ( M(91, 122) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 47) * M(47, 123)
      temp = temp + M(91, 69) * M(69, 123)
      temp = temp + M(91, 81) * M(81, 123)
      temp = temp + M(91, 83) * M(83, 123)
      temp = temp + M(91, 86) * M(86, 123)
      M(91, 123) = ( M(91, 123) - temp ) / M(91, 91)

C     Lower part.
      temp = M(92, 91) * M(91, 92)
      M(92, 92) = M(92, 92) - temp
C     Lower part.
      temp = M(93, 91) * M(91, 92)
      M(93, 92) = M(93, 92) - temp
C     Lower part.
      temp = M(94, 91) * M(91, 92)
      M(94, 92) = M(94, 92) - temp
C     Lower part.
      temp = M(95, 91) * M(91, 92)
      M(95, 92) = M(95, 92) - temp
C     Lower part.
      temp = M(96, 91) * M(91, 92)
      M(96, 92) = M(96, 92) - temp
C     Lower part.
      temp = M(98, 91) * M(91, 92)
      M(98, 92) = M(98, 92) - temp
C     Lower part.
      temp = M(99, 91) * M(91, 92)
      M(99, 92) = M(99, 92) - temp
C     Lower part.
      temp = M(100, 91) * M(91, 92)
      M(100, 92) = M(100, 92) - temp
C     Lower part.
      temp = M(101, 91) * M(91, 92)
      M(101, 92) = M(101, 92) - temp
C     Lower part.
      temp = M(102, 91) * M(91, 92)
      M(102, 92) = M(102, 92) - temp
C     Lower part.
      temp = M(104, 91) * M(91, 92)
      M(104, 92) = M(104, 92) - temp
C     Lower part.
      temp = M(105, 91) * M(91, 92)
      M(105, 92) = M(105, 92) - temp
C     Lower part.
      temp = M(106, 91) * M(91, 92)
      M(106, 92) = M(106, 92) - temp
C     Lower part.
      temp = M(107, 91) * M(91, 92)
      M(107, 92) = M(107, 92) - temp
C     Lower part.
      temp = M(108, 91) * M(91, 92)
      M(108, 92) = M(108, 92) - temp
C     Lower part.
      temp = M(109, 91) * M(91, 92)
      M(109, 92) = M(109, 92) - temp
C     Lower part.
      temp = M(111, 91) * M(91, 92)
      M(111, 92) = M(111, 92) - temp
C     Lower part.
      temp = M(112, 91) * M(91, 92)
      M(112, 92) = M(112, 92) - temp
C     Lower part.
      temp = M(113, 91) * M(91, 92)
      M(113, 92) = M(113, 92) - temp
C     Lower part.
      temp = M(114, 91) * M(91, 92)
      M(114, 92) = M(114, 92) - temp
C     Lower part.
      temp = M(115, 91) * M(91, 92)
      M(115, 92) = M(115, 92) - temp
C     Lower part.
      temp = M(116, 91) * M(91, 92)
      M(116, 92) = M(116, 92) - temp
C     Lower part.
      temp = M(117, 91) * M(91, 92)
      M(117, 92) = M(117, 92) - temp
C     Lower part.
      temp = M(118, 74) * M(74, 92)
      temp = temp + M(118, 91) * M(91, 92)
      M(118, 92) = M(118, 92) - temp
C     Lower part.
      temp = M(119, 74) * M(74, 92)
      temp = temp + M(119, 91) * M(91, 92)
      M(119, 92) = M(119, 92) - temp
C     Lower part.
      temp = M(121, 91) * M(91, 92)
      M(121, 92) = M(121, 92) - temp
C     Lower part.
      temp = M(122, 91) * M(91, 92)
      M(122, 92) = M(122, 92) - temp
C     Lower part.
      temp = M(123, 91) * M(91, 92)
      M(123, 92) = M(123, 92) - temp
C     Upper part.
      temp = M(92, 91) * M(91, 96)
      M(92, 96) = ( M(92, 96) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 80) * M(80, 113)
      temp = temp + M(92, 85) * M(85, 113)
      temp = temp + M(92, 91) * M(91, 113)
      M(92, 113) = ( M(92, 113) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 25) * M(25, 117)
      temp = temp + M(92, 31) * M(31, 117)
      temp = temp + M(92, 32) * M(32, 117)
      temp = temp + M(92, 80) * M(80, 117)
      temp = temp + M(92, 85) * M(85, 117)
      temp = temp + M(92, 91) * M(91, 117)
      M(92, 117) = ( M(92, 117) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 25) * M(25, 118)
      temp = temp + M(92, 30) * M(30, 118)
      temp = temp + M(92, 31) * M(31, 118)
      temp = temp + M(92, 32) * M(32, 118)
      temp = temp + M(92, 80) * M(80, 118)
      temp = temp + M(92, 85) * M(85, 118)
      temp = temp + M(92, 91) * M(91, 118)
      M(92, 118) = ( M(92, 118) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 30) * M(30, 119)
      temp = temp + M(92, 80) * M(80, 119)
      temp = temp + M(92, 85) * M(85, 119)
      temp = temp + M(92, 91) * M(91, 119)
      M(92, 119) = ( M(92, 119) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 91) * M(91, 121)
      M(92, 121) = ( M(92, 121) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 80) * M(80, 122)
      temp = temp + M(92, 85) * M(85, 122)
      temp = temp + M(92, 91) * M(91, 122)
      M(92, 122) = ( M(92, 122) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 80) * M(80, 123)
      temp = temp + M(92, 85) * M(85, 123)
      temp = temp + M(92, 91) * M(91, 123)
      M(92, 123) = ( M(92, 123) - temp ) / M(92, 92)

C     Upper part.
      temp = M(93, 91) * M(91, 96)
      temp = temp + M(93, 92) * M(92, 96)
      M(93, 96) = ( M(93, 96) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 46) * M(46, 104)
      M(93, 104) = ( M(93, 104) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 80) * M(80, 113)
      temp = temp + M(93, 91) * M(91, 113)
      temp = temp + M(93, 92) * M(92, 113)
      M(93, 113) = ( M(93, 113) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 45) * M(45, 117)
      temp = temp + M(93, 46) * M(46, 117)
      temp = temp + M(93, 80) * M(80, 117)
      temp = temp + M(93, 91) * M(91, 117)
      temp = temp + M(93, 92) * M(92, 117)
      M(93, 117) = ( M(93, 117) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 45) * M(45, 118)
      temp = temp + M(93, 46) * M(46, 118)
      temp = temp + M(93, 80) * M(80, 118)
      temp = temp + M(93, 91) * M(91, 118)
      temp = temp + M(93, 92) * M(92, 118)
      M(93, 118) = ( M(93, 118) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 80) * M(80, 119)
      temp = temp + M(93, 91) * M(91, 119)
      temp = temp + M(93, 92) * M(92, 119)
      M(93, 119) = ( M(93, 119) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 46) * M(46, 121)
      temp = temp + M(93, 91) * M(91, 121)
      temp = temp + M(93, 92) * M(92, 121)
      M(93, 121) = ( M(93, 121) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 80) * M(80, 122)
      temp = temp + M(93, 91) * M(91, 122)
      temp = temp + M(93, 92) * M(92, 122)
      M(93, 122) = ( M(93, 122) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 45) * M(45, 123)
      temp = temp + M(93, 80) * M(80, 123)
      temp = temp + M(93, 91) * M(91, 123)
      temp = temp + M(93, 92) * M(92, 123)
      M(93, 123) = ( M(93, 123) - temp ) / M(93, 93)

C     Upper part.
      temp = M(94, 91) * M(91, 96)
      temp = temp + M(94, 92) * M(92, 96)
      M(94, 96) = ( M(94, 96) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 104)
      M(94, 104) = ( M(94, 104) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 105)
      M(94, 105) = ( M(94, 105) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 110)
      M(94, 110) = ( M(94, 110) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 26) * M(26, 113)
      temp = temp + M(94, 89) * M(89, 113)
      temp = temp + M(94, 90) * M(90, 113)
      temp = temp + M(94, 91) * M(91, 113)
      temp = temp + M(94, 92) * M(92, 113)
      M(94, 113) = ( M(94, 113) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 26) * M(26, 114)
      M(94, 114) = ( M(94, 114) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 117)
      temp = temp + M(94, 90) * M(90, 117)
      temp = temp + M(94, 91) * M(91, 117)
      temp = temp + M(94, 92) * M(92, 117)
      M(94, 117) = ( M(94, 117) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 26) * M(26, 118)
      temp = temp + M(94, 89) * M(89, 118)
      temp = temp + M(94, 90) * M(90, 118)
      temp = temp + M(94, 91) * M(91, 118)
      temp = temp + M(94, 92) * M(92, 118)
      M(94, 118) = ( M(94, 118) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 119)
      temp = temp + M(94, 90) * M(90, 119)
      temp = temp + M(94, 91) * M(91, 119)
      temp = temp + M(94, 92) * M(92, 119)
      M(94, 119) = ( M(94, 119) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 91) * M(91, 121)
      temp = temp + M(94, 92) * M(92, 121)
      M(94, 121) = ( M(94, 121) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 122)
      temp = temp + M(94, 90) * M(90, 122)
      temp = temp + M(94, 91) * M(91, 122)
      temp = temp + M(94, 92) * M(92, 122)
      M(94, 122) = ( M(94, 122) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 89) * M(89, 123)
      temp = temp + M(94, 90) * M(90, 123)
      temp = temp + M(94, 91) * M(91, 123)
      temp = temp + M(94, 92) * M(92, 123)
      M(94, 123) = ( M(94, 123) - temp ) / M(94, 94)

C     Upper part.
      temp = M(95, 91) * M(91, 96)
      temp = temp + M(95, 92) * M(92, 96)
      M(95, 96) = ( M(95, 96) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 113)
      temp = temp + M(95, 92) * M(92, 113)
      M(95, 113) = ( M(95, 113) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 117)
      temp = temp + M(95, 92) * M(92, 117)
      M(95, 117) = ( M(95, 117) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 118)
      temp = temp + M(95, 92) * M(92, 118)
      M(95, 118) = ( M(95, 118) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 119)
      temp = temp + M(95, 92) * M(92, 119)
      M(95, 119) = ( M(95, 119) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 121)
      temp = temp + M(95, 92) * M(92, 121)
      M(95, 121) = ( M(95, 121) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 122)
      temp = temp + M(95, 92) * M(92, 122)
      M(95, 122) = ( M(95, 122) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 91) * M(91, 123)
      temp = temp + M(95, 92) * M(92, 123)
      M(95, 123) = ( M(95, 123) - temp ) / M(95, 95)

C     Lower part.
      temp = M(96, 91) * M(91, 96)
      temp = temp + M(96, 92) * M(92, 96)
      temp = temp + M(96, 95) * M(95, 96)
      M(96, 96) = M(96, 96) - temp
C     Lower part.
      temp = M(98, 91) * M(91, 96)
      temp = temp + M(98, 92) * M(92, 96)
      M(98, 96) = M(98, 96) - temp
C     Lower part.
      temp = M(99, 91) * M(91, 96)
      temp = temp + M(99, 92) * M(92, 96)
      M(99, 96) = M(99, 96) - temp
C     Lower part.
      temp = M(100, 91) * M(91, 96)
      temp = temp + M(100, 92) * M(92, 96)
      temp = temp + M(100, 93) * M(93, 96)
      M(100, 96) = M(100, 96) - temp
C     Lower part.
      temp = M(101, 91) * M(91, 96)
      temp = temp + M(101, 92) * M(92, 96)
      temp = temp + M(101, 94) * M(94, 96)
      M(101, 96) = M(101, 96) - temp
C     Lower part.
      temp = M(102, 91) * M(91, 96)
      temp = temp + M(102, 92) * M(92, 96)
      M(102, 96) = M(102, 96) - temp
C     Lower part.
      temp = M(104, 91) * M(91, 96)
      temp = temp + M(104, 92) * M(92, 96)
      M(104, 96) = M(104, 96) - temp
C     Lower part.
      temp = M(105, 91) * M(91, 96)
      temp = temp + M(105, 92) * M(92, 96)
      M(105, 96) = M(105, 96) - temp
C     Lower part.
      temp = M(106, 91) * M(91, 96)
      temp = temp + M(106, 92) * M(92, 96)
      M(106, 96) = M(106, 96) - temp
C     Lower part.
      temp = M(107, 91) * M(91, 96)
      temp = temp + M(107, 92) * M(92, 96)
      temp = temp + M(107, 94) * M(94, 96)
      M(107, 96) = M(107, 96) - temp
C     Lower part.
      temp = M(108, 91) * M(91, 96)
      temp = temp + M(108, 92) * M(92, 96)
      M(108, 96) = M(108, 96) - temp
C     Lower part.
      temp = M(109, 91) * M(91, 96)
      temp = temp + M(109, 92) * M(92, 96)
      M(109, 96) = M(109, 96) - temp
C     Lower part.
      temp = M(111, 91) * M(91, 96)
      temp = temp + M(111, 92) * M(92, 96)
      M(111, 96) = M(111, 96) - temp
C     Lower part.
      temp = M(112, 91) * M(91, 96)
      temp = temp + M(112, 92) * M(92, 96)
      M(112, 96) = M(112, 96) - temp
C     Lower part.
      temp = M(113, 91) * M(91, 96)
      temp = temp + M(113, 92) * M(92, 96)
      temp = temp + M(113, 94) * M(94, 96)
      temp = temp + M(113, 95) * M(95, 96)
      M(113, 96) = M(113, 96) - temp
C     Lower part.
      temp = M(114, 91) * M(91, 96)
      temp = temp + M(114, 92) * M(92, 96)
      M(114, 96) = M(114, 96) - temp
C     Lower part.
      temp = M(115, 91) * M(91, 96)
      temp = temp + M(115, 92) * M(92, 96)
      temp = temp + M(115, 95) * M(95, 96)
      M(115, 96) = M(115, 96) - temp
C     Lower part.
      temp = M(116, 91) * M(91, 96)
      temp = temp + M(116, 92) * M(92, 96)
      temp = temp + M(116, 95) * M(95, 96)
      M(116, 96) = M(116, 96) - temp
C     Lower part.
      temp = M(117, 91) * M(91, 96)
      temp = temp + M(117, 92) * M(92, 96)
      temp = temp + M(117, 94) * M(94, 96)
      temp = temp + M(117, 95) * M(95, 96)
      M(117, 96) = M(117, 96) - temp
C     Lower part.
      temp = M(118, 91) * M(91, 96)
      temp = temp + M(118, 92) * M(92, 96)
      temp = temp + M(118, 93) * M(93, 96)
      temp = temp + M(118, 94) * M(94, 96)
      M(118, 96) = M(118, 96) - temp
C     Lower part.
      temp = M(119, 91) * M(91, 96)
      temp = temp + M(119, 92) * M(92, 96)
      temp = temp + M(119, 93) * M(93, 96)
      temp = temp + M(119, 94) * M(94, 96)
      temp = temp + M(119, 95) * M(95, 96)
      M(119, 96) = M(119, 96) - temp
C     Lower part.
      temp = M(121, 91) * M(91, 96)
      temp = temp + M(121, 92) * M(92, 96)
      temp = temp + M(121, 95) * M(95, 96)
      M(121, 96) = M(121, 96) - temp
C     Lower part.
      temp = M(122, 91) * M(91, 96)
      temp = temp + M(122, 92) * M(92, 96)
      temp = temp + M(122, 94) * M(94, 96)
      temp = temp + M(122, 95) * M(95, 96)
      M(122, 96) = M(122, 96) - temp
C     Lower part.
      temp = M(123, 91) * M(91, 96)
      temp = temp + M(123, 92) * M(92, 96)
      temp = temp + M(123, 95) * M(95, 96)
      M(123, 96) = M(123, 96) - temp
C     Upper part.
      temp = M(96, 61) * M(61, 113)
      temp = temp + M(96, 62) * M(62, 113)
      temp = temp + M(96, 64) * M(64, 113)
      temp = temp + M(96, 91) * M(91, 113)
      temp = temp + M(96, 92) * M(92, 113)
      temp = temp + M(96, 95) * M(95, 113)
      M(96, 113) = ( M(96, 113) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 36) * M(36, 117)
      temp = temp + M(96, 61) * M(61, 117)
      temp = temp + M(96, 62) * M(62, 117)
      temp = temp + M(96, 64) * M(64, 117)
      temp = temp + M(96, 91) * M(91, 117)
      temp = temp + M(96, 92) * M(92, 117)
      temp = temp + M(96, 95) * M(95, 117)
      M(96, 117) = ( M(96, 117) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 36) * M(36, 118)
      temp = temp + M(96, 61) * M(61, 118)
      temp = temp + M(96, 62) * M(62, 118)
      temp = temp + M(96, 64) * M(64, 118)
      temp = temp + M(96, 91) * M(91, 118)
      temp = temp + M(96, 92) * M(92, 118)
      temp = temp + M(96, 95) * M(95, 118)
      M(96, 118) = ( M(96, 118) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 61) * M(61, 119)
      temp = temp + M(96, 62) * M(62, 119)
      temp = temp + M(96, 64) * M(64, 119)
      temp = temp + M(96, 91) * M(91, 119)
      temp = temp + M(96, 92) * M(92, 119)
      temp = temp + M(96, 95) * M(95, 119)
      M(96, 119) = ( M(96, 119) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 62) * M(62, 121)
      temp = temp + M(96, 91) * M(91, 121)
      temp = temp + M(96, 92) * M(92, 121)
      temp = temp + M(96, 95) * M(95, 121)
      M(96, 121) = ( M(96, 121) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 61) * M(61, 122)
      temp = temp + M(96, 62) * M(62, 122)
      temp = temp + M(96, 64) * M(64, 122)
      temp = temp + M(96, 91) * M(91, 122)
      temp = temp + M(96, 92) * M(92, 122)
      temp = temp + M(96, 95) * M(95, 122)
      M(96, 122) = ( M(96, 122) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 61) * M(61, 123)
      temp = temp + M(96, 62) * M(62, 123)
      temp = temp + M(96, 64) * M(64, 123)
      temp = temp + M(96, 91) * M(91, 123)
      temp = temp + M(96, 92) * M(92, 123)
      temp = temp + M(96, 95) * M(95, 123)
      M(96, 123) = ( M(96, 123) - temp ) / M(96, 96)

C     Lower part.
      temp = M(100, 75) * M(75, 97)
      M(100, 97) = M(100, 97) - temp
C     Lower part.
      temp = M(116, 75) * M(75, 97)
      M(116, 97) = M(116, 97) - temp
C     Lower part.
      temp = M(118, 75) * M(75, 97)
      M(118, 97) = M(118, 97) - temp
C     Lower part.
      temp = M(119, 75) * M(75, 97)
      M(119, 97) = M(119, 97) - temp
C     Lower part.
      temp = M(122, 75) * M(75, 97)
      M(122, 97) = M(122, 97) - temp
C     Upper part.
      temp = M(97, 61) * M(61, 113)
      temp = temp + M(97, 62) * M(62, 113)
      temp = temp + M(97, 64) * M(64, 113)
      M(97, 113) = ( M(97, 113) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 20) * M(20, 117)
      temp = temp + M(97, 61) * M(61, 117)
      temp = temp + M(97, 62) * M(62, 117)
      temp = temp + M(97, 64) * M(64, 117)
      M(97, 117) = ( M(97, 117) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 20) * M(20, 118)
      temp = temp + M(97, 61) * M(61, 118)
      temp = temp + M(97, 62) * M(62, 118)
      temp = temp + M(97, 64) * M(64, 118)
      M(97, 118) = ( M(97, 118) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 61) * M(61, 119)
      temp = temp + M(97, 62) * M(62, 119)
      temp = temp + M(97, 64) * M(64, 119)
      M(97, 119) = ( M(97, 119) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 62) * M(62, 121)
      M(97, 121) = ( M(97, 121) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 61) * M(61, 122)
      temp = temp + M(97, 62) * M(62, 122)
      temp = temp + M(97, 64) * M(64, 122)
      M(97, 122) = ( M(97, 122) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 61) * M(61, 123)
      temp = temp + M(97, 62) * M(62, 123)
      temp = temp + M(97, 64) * M(64, 123)
      M(97, 123) = ( M(97, 123) - temp ) / M(97, 97)

C     Lower part.
      temp = M(109, 29) * M(29, 98)
      M(109, 98) = M(109, 98) - temp
C     Lower part.
      temp = M(118, 29) * M(29, 98)
      M(118, 98) = M(118, 98) - temp
C     Lower part.
      temp = M(119, 29) * M(29, 98)
      M(119, 98) = M(119, 98) - temp
C     Upper part.
      temp = M(98, 91) * M(91, 113)
      temp = temp + M(98, 92) * M(92, 113)
      temp = temp + M(98, 96) * M(96, 113)
      M(98, 113) = ( M(98, 113) - temp ) / M(98, 98)
C     Upper part.
      temp = M(98, 28) * M(28, 117)
      temp = temp + M(98, 91) * M(91, 117)
      temp = temp + M(98, 92) * M(92, 117)
      temp = temp + M(98, 96) * M(96, 117)
      M(98, 117) = ( M(98, 117) - temp ) / M(98, 98)
C     Upper part.
      temp = M(98, 28) * M(28, 118)
      temp = temp + M(98, 91) * M(91, 118)
      temp = temp + M(98, 92) * M(92, 118)
      temp = temp + M(98, 96) * M(96, 118)
      M(98, 118) = ( M(98, 118) - temp ) / M(98, 98)
C     Upper part.
      temp = M(98, 91) * M(91, 119)
      temp = temp + M(98, 92) * M(92, 119)
      temp = temp + M(98, 96) * M(96, 119)
      M(98, 119) = ( M(98, 119) - temp ) / M(98, 98)
C     Upper part.
      temp = M(98, 91) * M(91, 121)
      temp = temp + M(98, 92) * M(92, 121)
      temp = temp + M(98, 96) * M(96, 121)
      M(98, 121) = ( M(98, 121) - temp ) / M(98, 98)
C     Upper part.
      temp = M(98, 91) * M(91, 122)
      temp = temp + M(98, 92) * M(92, 122)
      temp = temp + M(98, 96) * M(96, 122)
      M(98, 122) = ( M(98, 122) - temp ) / M(98, 98)
C     Upper part.
      temp = M(98, 91) * M(91, 123)
      temp = temp + M(98, 92) * M(92, 123)
      temp = temp + M(98, 96) * M(96, 123)
      M(98, 123) = ( M(98, 123) - temp ) / M(98, 98)

C     Upper part.
      M(99, 104) = M(99, 104) / M(99, 99)
C     Upper part.
      M(99, 105) = M(99, 105) / M(99, 99)
C     Upper part.
      temp = M(99, 78) * M(78, 110)
      M(99, 110) = ( M(99, 110) - temp ) / M(99, 99)
C     Upper part.
      temp = M(99, 67) * M(67, 113)
      temp = temp + M(99, 71) * M(71, 113)
      temp = temp + M(99, 72) * M(72, 113)
      temp = temp + M(99, 76) * M(76, 113)
      temp = temp + M(99, 78) * M(78, 113)
      temp = temp + M(99, 79) * M(79, 113)
      temp = temp + M(99, 80) * M(80, 113)
      temp = temp + M(99, 82) * M(82, 113)
      temp = temp + M(99, 84) * M(84, 113)
      temp = temp + M(99, 85) * M(85, 113)
      temp = temp + M(99, 87) * M(87, 113)
      temp = temp + M(99, 88) * M(88, 113)
      temp = temp + M(99, 90) * M(90, 113)
      temp = temp + M(99, 91) * M(91, 113)
      temp = temp + M(99, 92) * M(92, 113)
      temp = temp + M(99, 96) * M(96, 113)
      temp = temp + M(99, 98) * M(98, 113)
      M(99, 113) = ( M(99, 113) - temp ) / M(99, 99)
C     Upper part.
      M(99, 114) = M(99, 114) / M(99, 99)
C     Upper part.
      temp = M(99, 67) * M(67, 117)
      temp = temp + M(99, 71) * M(71, 117)
      temp = temp + M(99, 72) * M(72, 117)
      temp = temp + M(99, 76) * M(76, 117)
      temp = temp + M(99, 78) * M(78, 117)
      temp = temp + M(99, 79) * M(79, 117)
      temp = temp + M(99, 80) * M(80, 117)
      temp = temp + M(99, 82) * M(82, 117)
      temp = temp + M(99, 84) * M(84, 117)
      temp = temp + M(99, 85) * M(85, 117)
      temp = temp + M(99, 87) * M(87, 117)
      temp = temp + M(99, 88) * M(88, 117)
      temp = temp + M(99, 90) * M(90, 117)
      temp = temp + M(99, 91) * M(91, 117)
      temp = temp + M(99, 92) * M(92, 117)
      temp = temp + M(99, 96) * M(96, 117)
      temp = temp + M(99, 98) * M(98, 117)
      M(99, 117) = ( M(99, 117) - temp ) / M(99, 99)
C     Upper part.
      temp = M(99, 67) * M(67, 118)
      temp = temp + M(99, 71) * M(71, 118)
      temp = temp + M(99, 72) * M(72, 118)
      temp = temp + M(99, 76) * M(76, 118)
      temp = temp + M(99, 78) * M(78, 118)
      temp = temp + M(99, 79) * M(79, 118)
      temp = temp + M(99, 80) * M(80, 118)
      temp = temp + M(99, 82) * M(82, 118)
      temp = temp + M(99, 84) * M(84, 118)
      temp = temp + M(99, 85) * M(85, 118)
      temp = temp + M(99, 87) * M(87, 118)
      temp = temp + M(99, 88) * M(88, 118)
      temp = temp + M(99, 90) * M(90, 118)
      temp = temp + M(99, 91) * M(91, 118)
      temp = temp + M(99, 92) * M(92, 118)
      temp = temp + M(99, 96) * M(96, 118)
      temp = temp + M(99, 98) * M(98, 118)
      M(99, 118) = ( M(99, 118) - temp ) / M(99, 99)
C     Upper part.
      temp = M(99, 67) * M(67, 119)
      temp = temp + M(99, 71) * M(71, 119)
      temp = temp + M(99, 72) * M(72, 119)
      temp = temp + M(99, 76) * M(76, 119)
      temp = temp + M(99, 78) * M(78, 119)
      temp = temp + M(99, 79) * M(79, 119)
      temp = temp + M(99, 80) * M(80, 119)
      temp = temp + M(99, 82) * M(82, 119)
      temp = temp + M(99, 84) * M(84, 119)
      temp = temp + M(99, 85) * M(85, 119)
      temp = temp + M(99, 87) * M(87, 119)
      temp = temp + M(99, 88) * M(88, 119)
      temp = temp + M(99, 90) * M(90, 119)
      temp = temp + M(99, 91) * M(91, 119)
      temp = temp + M(99, 92) * M(92, 119)
      temp = temp + M(99, 96) * M(96, 119)
      temp = temp + M(99, 98) * M(98, 119)
      M(99, 119) = ( M(99, 119) - temp ) / M(99, 99)
C     Upper part.
      temp = M(99, 91) * M(91, 121)
      temp = temp + M(99, 92) * M(92, 121)
      temp = temp + M(99, 96) * M(96, 121)
      temp = temp + M(99, 98) * M(98, 121)
      M(99, 121) = ( M(99, 121) - temp ) / M(99, 99)
C     Upper part.
      temp = M(99, 67) * M(67, 122)
      temp = temp + M(99, 71) * M(71, 122)
      temp = temp + M(99, 72) * M(72, 122)
      temp = temp + M(99, 76) * M(76, 122)
      temp = temp + M(99, 78) * M(78, 122)
      temp = temp + M(99, 79) * M(79, 122)
      temp = temp + M(99, 80) * M(80, 122)
      temp = temp + M(99, 82) * M(82, 122)
      temp = temp + M(99, 84) * M(84, 122)
      temp = temp + M(99, 85) * M(85, 122)
      temp = temp + M(99, 87) * M(87, 122)
      temp = temp + M(99, 88) * M(88, 122)
      temp = temp + M(99, 90) * M(90, 122)
      temp = temp + M(99, 91) * M(91, 122)
      temp = temp + M(99, 92) * M(92, 122)
      temp = temp + M(99, 96) * M(96, 122)
      temp = temp + M(99, 98) * M(98, 122)
      M(99, 122) = ( M(99, 122) - temp ) / M(99, 99)
C     Upper part.
      temp = M(99, 67) * M(67, 123)
      temp = temp + M(99, 71) * M(71, 123)
      temp = temp + M(99, 72) * M(72, 123)
      temp = temp + M(99, 76) * M(76, 123)
      temp = temp + M(99, 78) * M(78, 123)
      temp = temp + M(99, 79) * M(79, 123)
      temp = temp + M(99, 80) * M(80, 123)
      temp = temp + M(99, 82) * M(82, 123)
      temp = temp + M(99, 84) * M(84, 123)
      temp = temp + M(99, 85) * M(85, 123)
      temp = temp + M(99, 87) * M(87, 123)
      temp = temp + M(99, 88) * M(88, 123)
      temp = temp + M(99, 90) * M(90, 123)
      temp = temp + M(99, 91) * M(91, 123)
      temp = temp + M(99, 92) * M(92, 123)
      temp = temp + M(99, 96) * M(96, 123)
      temp = temp + M(99, 98) * M(98, 123)
      M(99, 123) = ( M(99, 123) - temp ) / M(99, 99)

C     Upper part.
      temp = M(100, 93) * M(93, 104)
      M(100, 104) = ( M(100, 104) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 68) * M(68, 105)
      M(100, 105) = ( M(100, 105) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 52) * M(52, 113)
      temp = temp + M(100, 54) * M(54, 113)
      temp = temp + M(100, 63) * M(63, 113)
      temp = temp + M(100, 64) * M(64, 113)
      temp = temp + M(100, 65) * M(65, 113)
      temp = temp + M(100, 68) * M(68, 113)
      temp = temp + M(100, 69) * M(69, 113)
      temp = temp + M(100, 75) * M(75, 113)
      temp = temp + M(100, 76) * M(76, 113)
      temp = temp + M(100, 81) * M(81, 113)
      temp = temp + M(100, 82) * M(82, 113)
      temp = temp + M(100, 83) * M(83, 113)
      temp = temp + M(100, 84) * M(84, 113)
      temp = temp + M(100, 91) * M(91, 113)
      temp = temp + M(100, 92) * M(92, 113)
      temp = temp + M(100, 93) * M(93, 113)
      temp = temp + M(100, 96) * M(96, 113)
      temp = temp + M(100, 97) * M(97, 113)
      M(100, 113) = ( M(100, 113) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 52) * M(52, 117)
      temp = temp + M(100, 54) * M(54, 117)
      temp = temp + M(100, 63) * M(63, 117)
      temp = temp + M(100, 64) * M(64, 117)
      temp = temp + M(100, 65) * M(65, 117)
      temp = temp + M(100, 68) * M(68, 117)
      temp = temp + M(100, 69) * M(69, 117)
      temp = temp + M(100, 75) * M(75, 117)
      temp = temp + M(100, 76) * M(76, 117)
      temp = temp + M(100, 81) * M(81, 117)
      temp = temp + M(100, 82) * M(82, 117)
      temp = temp + M(100, 83) * M(83, 117)
      temp = temp + M(100, 84) * M(84, 117)
      temp = temp + M(100, 91) * M(91, 117)
      temp = temp + M(100, 92) * M(92, 117)
      temp = temp + M(100, 93) * M(93, 117)
      temp = temp + M(100, 96) * M(96, 117)
      temp = temp + M(100, 97) * M(97, 117)
      M(100, 117) = ( M(100, 117) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 52) * M(52, 118)
      temp = temp + M(100, 54) * M(54, 118)
      temp = temp + M(100, 63) * M(63, 118)
      temp = temp + M(100, 64) * M(64, 118)
      temp = temp + M(100, 65) * M(65, 118)
      temp = temp + M(100, 68) * M(68, 118)
      temp = temp + M(100, 69) * M(69, 118)
      temp = temp + M(100, 75) * M(75, 118)
      temp = temp + M(100, 76) * M(76, 118)
      temp = temp + M(100, 81) * M(81, 118)
      temp = temp + M(100, 82) * M(82, 118)
      temp = temp + M(100, 83) * M(83, 118)
      temp = temp + M(100, 84) * M(84, 118)
      temp = temp + M(100, 91) * M(91, 118)
      temp = temp + M(100, 92) * M(92, 118)
      temp = temp + M(100, 93) * M(93, 118)
      temp = temp + M(100, 96) * M(96, 118)
      temp = temp + M(100, 97) * M(97, 118)
      M(100, 118) = ( M(100, 118) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 54) * M(54, 119)
      temp = temp + M(100, 63) * M(63, 119)
      temp = temp + M(100, 64) * M(64, 119)
      temp = temp + M(100, 65) * M(65, 119)
      temp = temp + M(100, 68) * M(68, 119)
      temp = temp + M(100, 69) * M(69, 119)
      temp = temp + M(100, 76) * M(76, 119)
      temp = temp + M(100, 81) * M(81, 119)
      temp = temp + M(100, 82) * M(82, 119)
      temp = temp + M(100, 83) * M(83, 119)
      temp = temp + M(100, 84) * M(84, 119)
      temp = temp + M(100, 91) * M(91, 119)
      temp = temp + M(100, 92) * M(92, 119)
      temp = temp + M(100, 93) * M(93, 119)
      temp = temp + M(100, 96) * M(96, 119)
      temp = temp + M(100, 97) * M(97, 119)
      M(100, 119) = ( M(100, 119) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 91) * M(91, 121)
      temp = temp + M(100, 92) * M(92, 121)
      temp = temp + M(100, 93) * M(93, 121)
      temp = temp + M(100, 96) * M(96, 121)
      temp = temp + M(100, 97) * M(97, 121)
      M(100, 121) = ( M(100, 121) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 52) * M(52, 122)
      temp = temp + M(100, 54) * M(54, 122)
      temp = temp + M(100, 63) * M(63, 122)
      temp = temp + M(100, 64) * M(64, 122)
      temp = temp + M(100, 65) * M(65, 122)
      temp = temp + M(100, 68) * M(68, 122)
      temp = temp + M(100, 69) * M(69, 122)
      temp = temp + M(100, 75) * M(75, 122)
      temp = temp + M(100, 76) * M(76, 122)
      temp = temp + M(100, 81) * M(81, 122)
      temp = temp + M(100, 82) * M(82, 122)
      temp = temp + M(100, 83) * M(83, 122)
      temp = temp + M(100, 84) * M(84, 122)
      temp = temp + M(100, 91) * M(91, 122)
      temp = temp + M(100, 92) * M(92, 122)
      temp = temp + M(100, 93) * M(93, 122)
      temp = temp + M(100, 96) * M(96, 122)
      temp = temp + M(100, 97) * M(97, 122)
      M(100, 122) = ( M(100, 122) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 52) * M(52, 123)
      temp = temp + M(100, 54) * M(54, 123)
      temp = temp + M(100, 63) * M(63, 123)
      temp = temp + M(100, 64) * M(64, 123)
      temp = temp + M(100, 65) * M(65, 123)
      temp = temp + M(100, 68) * M(68, 123)
      temp = temp + M(100, 69) * M(69, 123)
      temp = temp + M(100, 75) * M(75, 123)
      temp = temp + M(100, 76) * M(76, 123)
      temp = temp + M(100, 81) * M(81, 123)
      temp = temp + M(100, 82) * M(82, 123)
      temp = temp + M(100, 83) * M(83, 123)
      temp = temp + M(100, 84) * M(84, 123)
      temp = temp + M(100, 91) * M(91, 123)
      temp = temp + M(100, 92) * M(92, 123)
      temp = temp + M(100, 93) * M(93, 123)
      temp = temp + M(100, 96) * M(96, 123)
      temp = temp + M(100, 97) * M(97, 123)
      M(100, 123) = ( M(100, 123) - temp ) / M(100, 100)

C     Upper part.
      M(101, 102) = M(101, 102) / M(101, 101)
C     Upper part.
      temp = M(101, 94) * M(94, 104)
      temp = temp + M(101, 100) * M(100, 104)
      M(101, 104) = ( M(101, 104) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 94) * M(94, 105)
      temp = temp + M(101, 100) * M(100, 105)
      M(101, 105) = ( M(101, 105) - temp ) / M(101, 101)
C     Upper part.
      M(101, 109) = M(101, 109) / M(101, 101)
C     Upper part.
      temp = M(101, 94) * M(94, 110)
      M(101, 110) = ( M(101, 110) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 61) * M(61, 113)
      temp = temp + M(101, 62) * M(62, 113)
      temp = temp + M(101, 64) * M(64, 113)
      temp = temp + M(101, 91) * M(91, 113)
      temp = temp + M(101, 92) * M(92, 113)
      temp = temp + M(101, 94) * M(94, 113)
      temp = temp + M(101, 96) * M(96, 113)
      temp = temp + M(101, 100) * M(100, 113)
      M(101, 113) = ( M(101, 113) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 94) * M(94, 114)
      M(101, 114) = ( M(101, 114) - temp ) / M(101, 101)
C     Upper part.
      M(101, 116) = M(101, 116) / M(101, 101)
C     Upper part.
      temp = M(101, 18) * M(18, 117)
      temp = temp + M(101, 20) * M(20, 117)
      temp = temp + M(101, 27) * M(27, 117)
      temp = temp + M(101, 36) * M(36, 117)
      temp = temp + M(101, 61) * M(61, 117)
      temp = temp + M(101, 62) * M(62, 117)
      temp = temp + M(101, 64) * M(64, 117)
      temp = temp + M(101, 91) * M(91, 117)
      temp = temp + M(101, 92) * M(92, 117)
      temp = temp + M(101, 94) * M(94, 117)
      temp = temp + M(101, 96) * M(96, 117)
      temp = temp + M(101, 100) * M(100, 117)
      M(101, 117) = ( M(101, 117) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 20) * M(20, 118)
      temp = temp + M(101, 27) * M(27, 118)
      temp = temp + M(101, 36) * M(36, 118)
      temp = temp + M(101, 61) * M(61, 118)
      temp = temp + M(101, 62) * M(62, 118)
      temp = temp + M(101, 64) * M(64, 118)
      temp = temp + M(101, 91) * M(91, 118)
      temp = temp + M(101, 92) * M(92, 118)
      temp = temp + M(101, 94) * M(94, 118)
      temp = temp + M(101, 96) * M(96, 118)
      temp = temp + M(101, 100) * M(100, 118)
      M(101, 118) = ( M(101, 118) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 61) * M(61, 119)
      temp = temp + M(101, 62) * M(62, 119)
      temp = temp + M(101, 64) * M(64, 119)
      temp = temp + M(101, 91) * M(91, 119)
      temp = temp + M(101, 92) * M(92, 119)
      temp = temp + M(101, 94) * M(94, 119)
      temp = temp + M(101, 96) * M(96, 119)
      temp = temp + M(101, 100) * M(100, 119)
      M(101, 119) = ( M(101, 119) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 18) * M(18, 121)
      temp = temp + M(101, 62) * M(62, 121)
      temp = temp + M(101, 91) * M(91, 121)
      temp = temp + M(101, 92) * M(92, 121)
      temp = temp + M(101, 94) * M(94, 121)
      temp = temp + M(101, 96) * M(96, 121)
      temp = temp + M(101, 100) * M(100, 121)
      M(101, 121) = ( M(101, 121) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 61) * M(61, 122)
      temp = temp + M(101, 62) * M(62, 122)
      temp = temp + M(101, 64) * M(64, 122)
      temp = temp + M(101, 91) * M(91, 122)
      temp = temp + M(101, 92) * M(92, 122)
      temp = temp + M(101, 94) * M(94, 122)
      temp = temp + M(101, 96) * M(96, 122)
      temp = temp + M(101, 100) * M(100, 122)
      M(101, 122) = ( M(101, 122) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 61) * M(61, 123)
      temp = temp + M(101, 62) * M(62, 123)
      temp = temp + M(101, 64) * M(64, 123)
      temp = temp + M(101, 91) * M(91, 123)
      temp = temp + M(101, 92) * M(92, 123)
      temp = temp + M(101, 94) * M(94, 123)
      temp = temp + M(101, 96) * M(96, 123)
      temp = temp + M(101, 100) * M(100, 123)
      M(101, 123) = ( M(101, 123) - temp ) / M(101, 101)

C     Lower part.
      temp = M(117, 101) * M(101, 102)
      M(117, 102) = M(117, 102) - temp
C     Lower part.
      temp = M(118, 101) * M(101, 102)
      M(118, 102) = M(118, 102) - temp
C     Lower part.
      temp = M(121, 101) * M(101, 102)
      M(121, 102) = M(121, 102) - temp
C     Upper part.
      M(102, 103) = M(102, 103) / M(102, 102)
C     Upper part.
      temp = M(102, 68) * M(68, 105)
      M(102, 105) = ( M(102, 105) - temp ) / M(102, 102)
C     Upper part.
      M(102, 110) = M(102, 110) / M(102, 102)
C     Upper part.
      temp = M(102, 54) * M(54, 113)
      temp = temp + M(102, 64) * M(64, 113)
      temp = temp + M(102, 65) * M(65, 113)
      temp = temp + M(102, 66) * M(66, 113)
      temp = temp + M(102, 68) * M(68, 113)
      temp = temp + M(102, 76) * M(76, 113)
      temp = temp + M(102, 77) * M(77, 113)
      temp = temp + M(102, 83) * M(83, 113)
      temp = temp + M(102, 84) * M(84, 113)
      temp = temp + M(102, 91) * M(91, 113)
      temp = temp + M(102, 92) * M(92, 113)
      temp = temp + M(102, 96) * M(96, 113)
      temp = temp + M(102, 97) * M(97, 113)
      M(102, 113) = ( M(102, 113) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 27) * M(27, 117)
      temp = temp + M(102, 54) * M(54, 117)
      temp = temp + M(102, 64) * M(64, 117)
      temp = temp + M(102, 65) * M(65, 117)
      temp = temp + M(102, 66) * M(66, 117)
      temp = temp + M(102, 68) * M(68, 117)
      temp = temp + M(102, 76) * M(76, 117)
      temp = temp + M(102, 77) * M(77, 117)
      temp = temp + M(102, 83) * M(83, 117)
      temp = temp + M(102, 84) * M(84, 117)
      temp = temp + M(102, 91) * M(91, 117)
      temp = temp + M(102, 92) * M(92, 117)
      temp = temp + M(102, 96) * M(96, 117)
      temp = temp + M(102, 97) * M(97, 117)
      M(102, 117) = ( M(102, 117) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 6) * M(6, 118)
      temp = temp + M(102, 27) * M(27, 118)
      temp = temp + M(102, 54) * M(54, 118)
      temp = temp + M(102, 64) * M(64, 118)
      temp = temp + M(102, 65) * M(65, 118)
      temp = temp + M(102, 66) * M(66, 118)
      temp = temp + M(102, 68) * M(68, 118)
      temp = temp + M(102, 76) * M(76, 118)
      temp = temp + M(102, 77) * M(77, 118)
      temp = temp + M(102, 83) * M(83, 118)
      temp = temp + M(102, 84) * M(84, 118)
      temp = temp + M(102, 91) * M(91, 118)
      temp = temp + M(102, 92) * M(92, 118)
      temp = temp + M(102, 96) * M(96, 118)
      temp = temp + M(102, 97) * M(97, 118)
      M(102, 118) = ( M(102, 118) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 54) * M(54, 119)
      temp = temp + M(102, 64) * M(64, 119)
      temp = temp + M(102, 65) * M(65, 119)
      temp = temp + M(102, 66) * M(66, 119)
      temp = temp + M(102, 68) * M(68, 119)
      temp = temp + M(102, 76) * M(76, 119)
      temp = temp + M(102, 77) * M(77, 119)
      temp = temp + M(102, 83) * M(83, 119)
      temp = temp + M(102, 84) * M(84, 119)
      temp = temp + M(102, 91) * M(91, 119)
      temp = temp + M(102, 92) * M(92, 119)
      temp = temp + M(102, 96) * M(96, 119)
      temp = temp + M(102, 97) * M(97, 119)
      M(102, 119) = ( M(102, 119) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 66) * M(66, 121)
      temp = temp + M(102, 91) * M(91, 121)
      temp = temp + M(102, 92) * M(92, 121)
      temp = temp + M(102, 96) * M(96, 121)
      temp = temp + M(102, 97) * M(97, 121)
      M(102, 121) = ( M(102, 121) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 54) * M(54, 122)
      temp = temp + M(102, 64) * M(64, 122)
      temp = temp + M(102, 65) * M(65, 122)
      temp = temp + M(102, 66) * M(66, 122)
      temp = temp + M(102, 68) * M(68, 122)
      temp = temp + M(102, 76) * M(76, 122)
      temp = temp + M(102, 77) * M(77, 122)
      temp = temp + M(102, 83) * M(83, 122)
      temp = temp + M(102, 84) * M(84, 122)
      temp = temp + M(102, 91) * M(91, 122)
      temp = temp + M(102, 92) * M(92, 122)
      temp = temp + M(102, 96) * M(96, 122)
      temp = temp + M(102, 97) * M(97, 122)
      M(102, 122) = ( M(102, 122) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 54) * M(54, 123)
      temp = temp + M(102, 64) * M(64, 123)
      temp = temp + M(102, 65) * M(65, 123)
      temp = temp + M(102, 66) * M(66, 123)
      temp = temp + M(102, 68) * M(68, 123)
      temp = temp + M(102, 76) * M(76, 123)
      temp = temp + M(102, 77) * M(77, 123)
      temp = temp + M(102, 83) * M(83, 123)
      temp = temp + M(102, 84) * M(84, 123)
      temp = temp + M(102, 91) * M(91, 123)
      temp = temp + M(102, 92) * M(92, 123)
      temp = temp + M(102, 96) * M(96, 123)
      temp = temp + M(102, 97) * M(97, 123)
      M(102, 123) = ( M(102, 123) - temp ) / M(102, 102)

C     Lower part.
      temp = M(107, 102) * M(102, 103)
      M(107, 103) = M(107, 103) - temp
C     Lower part.
      temp = M(116, 102) * M(102, 103)
      M(116, 103) = M(116, 103) - temp
C     Lower part.
      temp = M(117, 102) * M(102, 103)
      M(117, 103) = M(117, 103) - temp
C     Lower part.
      temp = M(118, 102) * M(102, 103)
      M(118, 103) = M(118, 103) - temp
C     Lower part.
      temp = M(119, 102) * M(102, 103)
      M(119, 103) = M(119, 103) - temp
C     Lower part.
      temp = M(121, 102) * M(102, 103)
      M(121, 103) = M(121, 103) - temp
C     Upper part.
      M(103, 106) = M(103, 106) / M(103, 103)
C     Upper part.
      M(103, 113) = M(103, 113) / M(103, 103)
C     Upper part.
      M(103, 117) = M(103, 117) / M(103, 103)
C     Upper part.
      M(103, 118) = M(103, 118) / M(103, 103)
C     Upper part.
      M(103, 119) = M(103, 119) / M(103, 103)
C     Upper part.
      M(103, 122) = M(103, 122) / M(103, 103)
C     Upper part.
      M(103, 123) = M(103, 123) / M(103, 103)

C     Lower part.
      temp = M(104, 35) * M(35, 104)
      temp = temp + M(104, 46) * M(46, 104)
      M(104, 104) = M(104, 104) - temp
C     Lower part.
      temp = M(107, 94) * M(94, 104)
      temp = temp + M(107, 100) * M(100, 104)
      M(107, 104) = M(107, 104) - temp
C     Lower part.
      temp = M(109, 89) * M(89, 104)
      M(109, 104) = M(109, 104) - temp
C     Lower part.
      temp = M(113, 94) * M(94, 104)
      M(113, 104) = M(113, 104) - temp
C     Lower part.
      temp = M(116, 99) * M(99, 104)
      M(116, 104) = M(116, 104) - temp
C     Lower part.
      temp = M(117, 46) * M(46, 104)
      temp = temp + M(117, 94) * M(94, 104)
      temp = temp + M(117, 100) * M(100, 104)
      temp = temp + M(117, 101) * M(101, 104)
      M(117, 104) = M(117, 104) - temp
C     Lower part.
      temp = M(118, 35) * M(35, 104)
      temp = temp + M(118, 46) * M(46, 104)
      temp = temp + M(118, 89) * M(89, 104)
      temp = temp + M(118, 93) * M(93, 104)
      temp = temp + M(118, 94) * M(94, 104)
      temp = temp + M(118, 99) * M(99, 104)
      temp = temp + M(118, 100) * M(100, 104)
      temp = temp + M(118, 101) * M(101, 104)
      M(118, 104) = M(118, 104) - temp
C     Lower part.
      temp = M(119, 89) * M(89, 104)
      temp = temp + M(119, 93) * M(93, 104)
      temp = temp + M(119, 94) * M(94, 104)
      temp = temp + M(119, 99) * M(99, 104)
      temp = temp + M(119, 100) * M(100, 104)
      M(119, 104) = M(119, 104) - temp
C     Lower part.
      temp = M(121, 46) * M(46, 104)
      temp = temp + M(121, 101) * M(101, 104)
      M(121, 104) = M(121, 104) - temp
C     Lower part.
      temp = M(122, 94) * M(94, 104)
      temp = temp + M(122, 100) * M(100, 104)
      M(122, 104) = M(122, 104) - temp
C     Upper part.
      temp = M(104, 81) * M(81, 113)
      temp = temp + M(104, 91) * M(91, 113)
      temp = temp + M(104, 92) * M(92, 113)
      temp = temp + M(104, 96) * M(96, 113)
      M(104, 113) = ( M(104, 113) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 31) * M(31, 117)
      temp = temp + M(104, 46) * M(46, 117)
      temp = temp + M(104, 81) * M(81, 117)
      temp = temp + M(104, 91) * M(91, 117)
      temp = temp + M(104, 92) * M(92, 117)
      temp = temp + M(104, 96) * M(96, 117)
      M(104, 117) = ( M(104, 117) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 31) * M(31, 118)
      temp = temp + M(104, 35) * M(35, 118)
      temp = temp + M(104, 46) * M(46, 118)
      temp = temp + M(104, 81) * M(81, 118)
      temp = temp + M(104, 91) * M(91, 118)
      temp = temp + M(104, 92) * M(92, 118)
      temp = temp + M(104, 96) * M(96, 118)
      M(104, 118) = ( M(104, 118) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 35) * M(35, 119)
      temp = temp + M(104, 81) * M(81, 119)
      temp = temp + M(104, 91) * M(91, 119)
      temp = temp + M(104, 92) * M(92, 119)
      temp = temp + M(104, 96) * M(96, 119)
      M(104, 119) = ( M(104, 119) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 46) * M(46, 121)
      temp = temp + M(104, 91) * M(91, 121)
      temp = temp + M(104, 92) * M(92, 121)
      temp = temp + M(104, 96) * M(96, 121)
      M(104, 121) = ( M(104, 121) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 81) * M(81, 122)
      temp = temp + M(104, 91) * M(91, 122)
      temp = temp + M(104, 92) * M(92, 122)
      temp = temp + M(104, 96) * M(96, 122)
      M(104, 122) = ( M(104, 122) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 81) * M(81, 123)
      temp = temp + M(104, 91) * M(91, 123)
      temp = temp + M(104, 92) * M(92, 123)
      temp = temp + M(104, 96) * M(96, 123)
      M(104, 123) = ( M(104, 123) - temp ) / M(104, 104)

C     Lower part.
      temp = M(107, 68) * M(68, 105)
      temp = temp + M(107, 94) * M(94, 105)
      temp = temp + M(107, 100) * M(100, 105)
      temp = temp + M(107, 102) * M(102, 105)
      M(107, 105) = M(107, 105) - temp
C     Lower part.
      temp = M(109, 68) * M(68, 105)
      temp = temp + M(109, 89) * M(89, 105)
      M(109, 105) = M(109, 105) - temp
C     Lower part.
      temp = M(112, 68) * M(68, 105)
      M(112, 105) = M(112, 105) - temp
C     Lower part.
      temp = M(113, 94) * M(94, 105)
      M(113, 105) = M(113, 105) - temp
C     Lower part.
      temp = M(116, 99) * M(99, 105)
      temp = temp + M(116, 102) * M(102, 105)
      M(116, 105) = M(116, 105) - temp
C     Lower part.
      temp = M(117, 94) * M(94, 105)
      temp = temp + M(117, 100) * M(100, 105)
      temp = temp + M(117, 101) * M(101, 105)
      temp = temp + M(117, 102) * M(102, 105)
      M(117, 105) = M(117, 105) - temp
C     Lower part.
      temp = M(118, 68) * M(68, 105)
      temp = temp + M(118, 89) * M(89, 105)
      temp = temp + M(118, 94) * M(94, 105)
      temp = temp + M(118, 99) * M(99, 105)
      temp = temp + M(118, 100) * M(100, 105)
      temp = temp + M(118, 101) * M(101, 105)
      temp = temp + M(118, 102) * M(102, 105)
      M(118, 105) = M(118, 105) - temp
C     Lower part.
      temp = M(119, 68) * M(68, 105)
      temp = temp + M(119, 89) * M(89, 105)
      temp = temp + M(119, 94) * M(94, 105)
      temp = temp + M(119, 99) * M(99, 105)
      temp = temp + M(119, 100) * M(100, 105)
      temp = temp + M(119, 102) * M(102, 105)
      M(119, 105) = M(119, 105) - temp
C     Lower part.
      temp = M(121, 101) * M(101, 105)
      temp = temp + M(121, 102) * M(102, 105)
      M(121, 105) = M(121, 105) - temp
C     Lower part.
      temp = M(122, 68) * M(68, 105)
      temp = temp + M(122, 94) * M(94, 105)
      temp = temp + M(122, 100) * M(100, 105)
      M(122, 105) = M(122, 105) - temp
C     Upper part.
      M(105, 111) = M(105, 111) / M(105, 105)
C     Upper part.
      temp = M(105, 86) * M(86, 113)
      temp = temp + M(105, 91) * M(91, 113)
      temp = temp + M(105, 92) * M(92, 113)
      temp = temp + M(105, 96) * M(96, 113)
      M(105, 113) = ( M(105, 113) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 21) * M(21, 117)
      temp = temp + M(105, 25) * M(25, 117)
      temp = temp + M(105, 32) * M(32, 117)
      temp = temp + M(105, 38) * M(38, 117)
      temp = temp + M(105, 86) * M(86, 117)
      temp = temp + M(105, 91) * M(91, 117)
      temp = temp + M(105, 92) * M(92, 117)
      temp = temp + M(105, 96) * M(96, 117)
      M(105, 117) = ( M(105, 117) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 21) * M(21, 118)
      temp = temp + M(105, 25) * M(25, 118)
      temp = temp + M(105, 32) * M(32, 118)
      temp = temp + M(105, 38) * M(38, 118)
      temp = temp + M(105, 86) * M(86, 118)
      temp = temp + M(105, 91) * M(91, 118)
      temp = temp + M(105, 92) * M(92, 118)
      temp = temp + M(105, 96) * M(96, 118)
      M(105, 118) = ( M(105, 118) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 86) * M(86, 119)
      temp = temp + M(105, 91) * M(91, 119)
      temp = temp + M(105, 92) * M(92, 119)
      temp = temp + M(105, 96) * M(96, 119)
      M(105, 119) = ( M(105, 119) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 91) * M(91, 121)
      temp = temp + M(105, 92) * M(92, 121)
      temp = temp + M(105, 96) * M(96, 121)
      M(105, 121) = ( M(105, 121) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 86) * M(86, 122)
      temp = temp + M(105, 91) * M(91, 122)
      temp = temp + M(105, 92) * M(92, 122)
      temp = temp + M(105, 96) * M(96, 122)
      M(105, 122) = ( M(105, 122) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 86) * M(86, 123)
      temp = temp + M(105, 91) * M(91, 123)
      temp = temp + M(105, 92) * M(92, 123)
      temp = temp + M(105, 96) * M(96, 123)
      M(105, 123) = ( M(105, 123) - temp ) / M(105, 105)

C     Lower part.
      temp = M(107, 103) * M(103, 106)
      M(107, 106) = M(107, 106) - temp
C     Lower part.
      temp = M(113, 103) * M(103, 106)
      M(113, 106) = M(113, 106) - temp
C     Lower part.
      temp = M(115, 103) * M(103, 106)
      M(115, 106) = M(115, 106) - temp
C     Lower part.
      temp = M(116, 103) * M(103, 106)
      M(116, 106) = M(116, 106) - temp
C     Lower part.
      temp = M(117, 103) * M(103, 106)
      M(117, 106) = M(117, 106) - temp
C     Lower part.
      temp = M(118, 103) * M(103, 106)
      M(118, 106) = M(118, 106) - temp
C     Lower part.
      temp = M(119, 103) * M(103, 106)
      M(119, 106) = M(119, 106) - temp
C     Lower part.
      temp = M(121, 103) * M(103, 106)
      M(121, 106) = M(121, 106) - temp
C     Lower part.
      temp = M(122, 103) * M(103, 106)
      M(122, 106) = M(122, 106) - temp
C     Lower part.
      temp = M(123, 103) * M(103, 106)
      M(123, 106) = M(123, 106) - temp
C     Upper part.
      temp = M(106, 78) * M(78, 110)
      M(106, 110) = ( M(106, 110) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 105) * M(105, 111)
      M(106, 111) = ( M(106, 111) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 67) * M(67, 113)
      temp = temp + M(106, 69) * M(69, 113)
      temp = temp + M(106, 71) * M(71, 113)
      temp = temp + M(106, 72) * M(72, 113)
      temp = temp + M(106, 76) * M(76, 113)
      temp = temp + M(106, 78) * M(78, 113)
      temp = temp + M(106, 79) * M(79, 113)
      temp = temp + M(106, 80) * M(80, 113)
      temp = temp + M(106, 82) * M(82, 113)
      temp = temp + M(106, 84) * M(84, 113)
      temp = temp + M(106, 85) * M(85, 113)
      temp = temp + M(106, 86) * M(86, 113)
      temp = temp + M(106, 87) * M(87, 113)
      temp = temp + M(106, 88) * M(88, 113)
      temp = temp + M(106, 90) * M(90, 113)
      temp = temp + M(106, 91) * M(91, 113)
      temp = temp + M(106, 92) * M(92, 113)
      temp = temp + M(106, 96) * M(96, 113)
      temp = temp + M(106, 98) * M(98, 113)
      temp = temp + M(106, 104) * M(104, 113)
      temp = temp + M(106, 105) * M(105, 113)
      M(106, 113) = ( M(106, 113) - temp ) / M(106, 106)
C     Upper part.
      M(106, 114) = M(106, 114) / M(106, 106)
C     Upper part.
      temp = M(106, 32) * M(32, 117)
      temp = temp + M(106, 38) * M(38, 117)
      temp = temp + M(106, 67) * M(67, 117)
      temp = temp + M(106, 69) * M(69, 117)
      temp = temp + M(106, 71) * M(71, 117)
      temp = temp + M(106, 72) * M(72, 117)
      temp = temp + M(106, 76) * M(76, 117)
      temp = temp + M(106, 78) * M(78, 117)
      temp = temp + M(106, 79) * M(79, 117)
      temp = temp + M(106, 80) * M(80, 117)
      temp = temp + M(106, 82) * M(82, 117)
      temp = temp + M(106, 84) * M(84, 117)
      temp = temp + M(106, 85) * M(85, 117)
      temp = temp + M(106, 86) * M(86, 117)
      temp = temp + M(106, 87) * M(87, 117)
      temp = temp + M(106, 88) * M(88, 117)
      temp = temp + M(106, 90) * M(90, 117)
      temp = temp + M(106, 91) * M(91, 117)
      temp = temp + M(106, 92) * M(92, 117)
      temp = temp + M(106, 96) * M(96, 117)
      temp = temp + M(106, 98) * M(98, 117)
      temp = temp + M(106, 104) * M(104, 117)
      temp = temp + M(106, 105) * M(105, 117)
      M(106, 117) = ( M(106, 117) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 32) * M(32, 118)
      temp = temp + M(106, 38) * M(38, 118)
      temp = temp + M(106, 67) * M(67, 118)
      temp = temp + M(106, 69) * M(69, 118)
      temp = temp + M(106, 71) * M(71, 118)
      temp = temp + M(106, 72) * M(72, 118)
      temp = temp + M(106, 76) * M(76, 118)
      temp = temp + M(106, 78) * M(78, 118)
      temp = temp + M(106, 79) * M(79, 118)
      temp = temp + M(106, 80) * M(80, 118)
      temp = temp + M(106, 82) * M(82, 118)
      temp = temp + M(106, 84) * M(84, 118)
      temp = temp + M(106, 85) * M(85, 118)
      temp = temp + M(106, 86) * M(86, 118)
      temp = temp + M(106, 87) * M(87, 118)
      temp = temp + M(106, 88) * M(88, 118)
      temp = temp + M(106, 90) * M(90, 118)
      temp = temp + M(106, 91) * M(91, 118)
      temp = temp + M(106, 92) * M(92, 118)
      temp = temp + M(106, 96) * M(96, 118)
      temp = temp + M(106, 98) * M(98, 118)
      temp = temp + M(106, 104) * M(104, 118)
      temp = temp + M(106, 105) * M(105, 118)
      M(106, 118) = ( M(106, 118) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 67) * M(67, 119)
      temp = temp + M(106, 69) * M(69, 119)
      temp = temp + M(106, 71) * M(71, 119)
      temp = temp + M(106, 72) * M(72, 119)
      temp = temp + M(106, 76) * M(76, 119)
      temp = temp + M(106, 78) * M(78, 119)
      temp = temp + M(106, 79) * M(79, 119)
      temp = temp + M(106, 80) * M(80, 119)
      temp = temp + M(106, 82) * M(82, 119)
      temp = temp + M(106, 84) * M(84, 119)
      temp = temp + M(106, 85) * M(85, 119)
      temp = temp + M(106, 86) * M(86, 119)
      temp = temp + M(106, 87) * M(87, 119)
      temp = temp + M(106, 88) * M(88, 119)
      temp = temp + M(106, 90) * M(90, 119)
      temp = temp + M(106, 91) * M(91, 119)
      temp = temp + M(106, 92) * M(92, 119)
      temp = temp + M(106, 96) * M(96, 119)
      temp = temp + M(106, 98) * M(98, 119)
      temp = temp + M(106, 104) * M(104, 119)
      temp = temp + M(106, 105) * M(105, 119)
      M(106, 119) = ( M(106, 119) - temp ) / M(106, 106)
C     Upper part.
      M(106, 120) = M(106, 120) / M(106, 106)
C     Upper part.
      temp = M(106, 91) * M(91, 121)
      temp = temp + M(106, 92) * M(92, 121)
      temp = temp + M(106, 96) * M(96, 121)
      temp = temp + M(106, 98) * M(98, 121)
      temp = temp + M(106, 104) * M(104, 121)
      temp = temp + M(106, 105) * M(105, 121)
      M(106, 121) = ( M(106, 121) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 67) * M(67, 122)
      temp = temp + M(106, 69) * M(69, 122)
      temp = temp + M(106, 71) * M(71, 122)
      temp = temp + M(106, 72) * M(72, 122)
      temp = temp + M(106, 76) * M(76, 122)
      temp = temp + M(106, 78) * M(78, 122)
      temp = temp + M(106, 79) * M(79, 122)
      temp = temp + M(106, 80) * M(80, 122)
      temp = temp + M(106, 82) * M(82, 122)
      temp = temp + M(106, 84) * M(84, 122)
      temp = temp + M(106, 85) * M(85, 122)
      temp = temp + M(106, 86) * M(86, 122)
      temp = temp + M(106, 87) * M(87, 122)
      temp = temp + M(106, 88) * M(88, 122)
      temp = temp + M(106, 90) * M(90, 122)
      temp = temp + M(106, 91) * M(91, 122)
      temp = temp + M(106, 92) * M(92, 122)
      temp = temp + M(106, 96) * M(96, 122)
      temp = temp + M(106, 98) * M(98, 122)
      temp = temp + M(106, 104) * M(104, 122)
      temp = temp + M(106, 105) * M(105, 122)
      M(106, 122) = ( M(106, 122) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 67) * M(67, 123)
      temp = temp + M(106, 69) * M(69, 123)
      temp = temp + M(106, 71) * M(71, 123)
      temp = temp + M(106, 72) * M(72, 123)
      temp = temp + M(106, 76) * M(76, 123)
      temp = temp + M(106, 78) * M(78, 123)
      temp = temp + M(106, 79) * M(79, 123)
      temp = temp + M(106, 80) * M(80, 123)
      temp = temp + M(106, 82) * M(82, 123)
      temp = temp + M(106, 84) * M(84, 123)
      temp = temp + M(106, 85) * M(85, 123)
      temp = temp + M(106, 86) * M(86, 123)
      temp = temp + M(106, 87) * M(87, 123)
      temp = temp + M(106, 88) * M(88, 123)
      temp = temp + M(106, 90) * M(90, 123)
      temp = temp + M(106, 91) * M(91, 123)
      temp = temp + M(106, 92) * M(92, 123)
      temp = temp + M(106, 96) * M(96, 123)
      temp = temp + M(106, 98) * M(98, 123)
      temp = temp + M(106, 104) * M(104, 123)
      temp = temp + M(106, 105) * M(105, 123)
      M(106, 123) = ( M(106, 123) - temp ) / M(106, 106)

C     Upper part.
      M(107, 109) = M(107, 109) / M(107, 107)
C     Upper part.
      temp = M(107, 94) * M(94, 110)
      temp = temp + M(107, 102) * M(102, 110)
      temp = temp + M(107, 106) * M(106, 110)
      M(107, 110) = ( M(107, 110) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 105) * M(105, 111)
      temp = temp + M(107, 106) * M(106, 111)
      M(107, 111) = ( M(107, 111) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 56) * M(56, 113)
      temp = temp + M(107, 65) * M(65, 113)
      temp = temp + M(107, 68) * M(68, 113)
      temp = temp + M(107, 69) * M(69, 113)
      temp = temp + M(107, 76) * M(76, 113)
      temp = temp + M(107, 80) * M(80, 113)
      temp = temp + M(107, 81) * M(81, 113)
      temp = temp + M(107, 83) * M(83, 113)
      temp = temp + M(107, 84) * M(84, 113)
      temp = temp + M(107, 86) * M(86, 113)
      temp = temp + M(107, 91) * M(91, 113)
      temp = temp + M(107, 92) * M(92, 113)
      temp = temp + M(107, 94) * M(94, 113)
      temp = temp + M(107, 96) * M(96, 113)
      temp = temp + M(107, 100) * M(100, 113)
      temp = temp + M(107, 102) * M(102, 113)
      temp = temp + M(107, 103) * M(103, 113)
      temp = temp + M(107, 104) * M(104, 113)
      temp = temp + M(107, 105) * M(105, 113)
      temp = temp + M(107, 106) * M(106, 113)
      M(107, 113) = ( M(107, 113) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 94) * M(94, 114)
      temp = temp + M(107, 106) * M(106, 114)
      M(107, 114) = ( M(107, 114) - temp ) / M(107, 107)
C     Upper part.
      M(107, 116) = M(107, 116) / M(107, 107)
C     Upper part.
      temp = M(107, 21) * M(21, 117)
      temp = temp + M(107, 25) * M(25, 117)
      temp = temp + M(107, 27) * M(27, 117)
      temp = temp + M(107, 28) * M(28, 117)
      temp = temp + M(107, 31) * M(31, 117)
      temp = temp + M(107, 32) * M(32, 117)
      temp = temp + M(107, 38) * M(38, 117)
      temp = temp + M(107, 45) * M(45, 117)
      temp = temp + M(107, 56) * M(56, 117)
      temp = temp + M(107, 65) * M(65, 117)
      temp = temp + M(107, 68) * M(68, 117)
      temp = temp + M(107, 69) * M(69, 117)
      temp = temp + M(107, 76) * M(76, 117)
      temp = temp + M(107, 80) * M(80, 117)
      temp = temp + M(107, 81) * M(81, 117)
      temp = temp + M(107, 83) * M(83, 117)
      temp = temp + M(107, 84) * M(84, 117)
      temp = temp + M(107, 86) * M(86, 117)
      temp = temp + M(107, 91) * M(91, 117)
      temp = temp + M(107, 92) * M(92, 117)
      temp = temp + M(107, 94) * M(94, 117)
      temp = temp + M(107, 96) * M(96, 117)
      temp = temp + M(107, 100) * M(100, 117)
      temp = temp + M(107, 102) * M(102, 117)
      temp = temp + M(107, 103) * M(103, 117)
      temp = temp + M(107, 104) * M(104, 117)
      temp = temp + M(107, 105) * M(105, 117)
      temp = temp + M(107, 106) * M(106, 117)
      M(107, 117) = ( M(107, 117) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 6) * M(6, 118)
      temp = temp + M(107, 19) * M(19, 118)
      temp = temp + M(107, 21) * M(21, 118)
      temp = temp + M(107, 25) * M(25, 118)
      temp = temp + M(107, 27) * M(27, 118)
      temp = temp + M(107, 28) * M(28, 118)
      temp = temp + M(107, 31) * M(31, 118)
      temp = temp + M(107, 32) * M(32, 118)
      temp = temp + M(107, 38) * M(38, 118)
      temp = temp + M(107, 45) * M(45, 118)
      temp = temp + M(107, 56) * M(56, 118)
      temp = temp + M(107, 65) * M(65, 118)
      temp = temp + M(107, 68) * M(68, 118)
      temp = temp + M(107, 69) * M(69, 118)
      temp = temp + M(107, 76) * M(76, 118)
      temp = temp + M(107, 80) * M(80, 118)
      temp = temp + M(107, 81) * M(81, 118)
      temp = temp + M(107, 83) * M(83, 118)
      temp = temp + M(107, 84) * M(84, 118)
      temp = temp + M(107, 86) * M(86, 118)
      temp = temp + M(107, 91) * M(91, 118)
      temp = temp + M(107, 92) * M(92, 118)
      temp = temp + M(107, 94) * M(94, 118)
      temp = temp + M(107, 96) * M(96, 118)
      temp = temp + M(107, 100) * M(100, 118)
      temp = temp + M(107, 102) * M(102, 118)
      temp = temp + M(107, 103) * M(103, 118)
      temp = temp + M(107, 104) * M(104, 118)
      temp = temp + M(107, 105) * M(105, 118)
      temp = temp + M(107, 106) * M(106, 118)
      M(107, 118) = ( M(107, 118) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 65) * M(65, 119)
      temp = temp + M(107, 68) * M(68, 119)
      temp = temp + M(107, 69) * M(69, 119)
      temp = temp + M(107, 76) * M(76, 119)
      temp = temp + M(107, 80) * M(80, 119)
      temp = temp + M(107, 81) * M(81, 119)
      temp = temp + M(107, 83) * M(83, 119)
      temp = temp + M(107, 84) * M(84, 119)
      temp = temp + M(107, 86) * M(86, 119)
      temp = temp + M(107, 91) * M(91, 119)
      temp = temp + M(107, 92) * M(92, 119)
      temp = temp + M(107, 94) * M(94, 119)
      temp = temp + M(107, 96) * M(96, 119)
      temp = temp + M(107, 100) * M(100, 119)
      temp = temp + M(107, 102) * M(102, 119)
      temp = temp + M(107, 103) * M(103, 119)
      temp = temp + M(107, 104) * M(104, 119)
      temp = temp + M(107, 105) * M(105, 119)
      temp = temp + M(107, 106) * M(106, 119)
      M(107, 119) = ( M(107, 119) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 106) * M(106, 120)
      M(107, 120) = ( M(107, 120) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 91) * M(91, 121)
      temp = temp + M(107, 92) * M(92, 121)
      temp = temp + M(107, 94) * M(94, 121)
      temp = temp + M(107, 96) * M(96, 121)
      temp = temp + M(107, 100) * M(100, 121)
      temp = temp + M(107, 102) * M(102, 121)
      temp = temp + M(107, 104) * M(104, 121)
      temp = temp + M(107, 105) * M(105, 121)
      temp = temp + M(107, 106) * M(106, 121)
      M(107, 121) = ( M(107, 121) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 56) * M(56, 122)
      temp = temp + M(107, 65) * M(65, 122)
      temp = temp + M(107, 68) * M(68, 122)
      temp = temp + M(107, 69) * M(69, 122)
      temp = temp + M(107, 76) * M(76, 122)
      temp = temp + M(107, 80) * M(80, 122)
      temp = temp + M(107, 81) * M(81, 122)
      temp = temp + M(107, 83) * M(83, 122)
      temp = temp + M(107, 84) * M(84, 122)
      temp = temp + M(107, 86) * M(86, 122)
      temp = temp + M(107, 91) * M(91, 122)
      temp = temp + M(107, 92) * M(92, 122)
      temp = temp + M(107, 94) * M(94, 122)
      temp = temp + M(107, 96) * M(96, 122)
      temp = temp + M(107, 100) * M(100, 122)
      temp = temp + M(107, 102) * M(102, 122)
      temp = temp + M(107, 103) * M(103, 122)
      temp = temp + M(107, 104) * M(104, 122)
      temp = temp + M(107, 105) * M(105, 122)
      temp = temp + M(107, 106) * M(106, 122)
      M(107, 122) = ( M(107, 122) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 45) * M(45, 123)
      temp = temp + M(107, 56) * M(56, 123)
      temp = temp + M(107, 65) * M(65, 123)
      temp = temp + M(107, 68) * M(68, 123)
      temp = temp + M(107, 69) * M(69, 123)
      temp = temp + M(107, 76) * M(76, 123)
      temp = temp + M(107, 80) * M(80, 123)
      temp = temp + M(107, 81) * M(81, 123)
      temp = temp + M(107, 83) * M(83, 123)
      temp = temp + M(107, 84) * M(84, 123)
      temp = temp + M(107, 86) * M(86, 123)
      temp = temp + M(107, 91) * M(91, 123)
      temp = temp + M(107, 92) * M(92, 123)
      temp = temp + M(107, 94) * M(94, 123)
      temp = temp + M(107, 96) * M(96, 123)
      temp = temp + M(107, 100) * M(100, 123)
      temp = temp + M(107, 102) * M(102, 123)
      temp = temp + M(107, 103) * M(103, 123)
      temp = temp + M(107, 104) * M(104, 123)
      temp = temp + M(107, 105) * M(105, 123)
      temp = temp + M(107, 106) * M(106, 123)
      M(107, 123) = ( M(107, 123) - temp ) / M(107, 107)

C     Upper part.
      M(108, 110) = M(108, 110) / M(108, 108)
C     Upper part.
      temp = M(108, 52) * M(52, 113)
      temp = temp + M(108, 54) * M(54, 113)
      temp = temp + M(108, 59) * M(59, 113)
      temp = temp + M(108, 60) * M(60, 113)
      temp = temp + M(108, 62) * M(62, 113)
      temp = temp + M(108, 63) * M(63, 113)
      temp = temp + M(108, 64) * M(64, 113)
      temp = temp + M(108, 66) * M(66, 113)
      temp = temp + M(108, 72) * M(72, 113)
      temp = temp + M(108, 76) * M(76, 113)
      temp = temp + M(108, 77) * M(77, 113)
      temp = temp + M(108, 79) * M(79, 113)
      temp = temp + M(108, 83) * M(83, 113)
      temp = temp + M(108, 85) * M(85, 113)
      temp = temp + M(108, 88) * M(88, 113)
      temp = temp + M(108, 90) * M(90, 113)
      temp = temp + M(108, 91) * M(91, 113)
      temp = temp + M(108, 92) * M(92, 113)
      temp = temp + M(108, 96) * M(96, 113)
      M(108, 113) = ( M(108, 113) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 52) * M(52, 117)
      temp = temp + M(108, 54) * M(54, 117)
      temp = temp + M(108, 59) * M(59, 117)
      temp = temp + M(108, 60) * M(60, 117)
      temp = temp + M(108, 62) * M(62, 117)
      temp = temp + M(108, 63) * M(63, 117)
      temp = temp + M(108, 64) * M(64, 117)
      temp = temp + M(108, 66) * M(66, 117)
      temp = temp + M(108, 72) * M(72, 117)
      temp = temp + M(108, 76) * M(76, 117)
      temp = temp + M(108, 77) * M(77, 117)
      temp = temp + M(108, 79) * M(79, 117)
      temp = temp + M(108, 83) * M(83, 117)
      temp = temp + M(108, 85) * M(85, 117)
      temp = temp + M(108, 88) * M(88, 117)
      temp = temp + M(108, 90) * M(90, 117)
      temp = temp + M(108, 91) * M(91, 117)
      temp = temp + M(108, 92) * M(92, 117)
      temp = temp + M(108, 96) * M(96, 117)
      M(108, 117) = ( M(108, 117) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 52) * M(52, 118)
      temp = temp + M(108, 54) * M(54, 118)
      temp = temp + M(108, 59) * M(59, 118)
      temp = temp + M(108, 60) * M(60, 118)
      temp = temp + M(108, 62) * M(62, 118)
      temp = temp + M(108, 63) * M(63, 118)
      temp = temp + M(108, 64) * M(64, 118)
      temp = temp + M(108, 66) * M(66, 118)
      temp = temp + M(108, 72) * M(72, 118)
      temp = temp + M(108, 76) * M(76, 118)
      temp = temp + M(108, 77) * M(77, 118)
      temp = temp + M(108, 79) * M(79, 118)
      temp = temp + M(108, 83) * M(83, 118)
      temp = temp + M(108, 85) * M(85, 118)
      temp = temp + M(108, 88) * M(88, 118)
      temp = temp + M(108, 90) * M(90, 118)
      temp = temp + M(108, 91) * M(91, 118)
      temp = temp + M(108, 92) * M(92, 118)
      temp = temp + M(108, 96) * M(96, 118)
      M(108, 118) = ( M(108, 118) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 54) * M(54, 119)
      temp = temp + M(108, 60) * M(60, 119)
      temp = temp + M(108, 62) * M(62, 119)
      temp = temp + M(108, 63) * M(63, 119)
      temp = temp + M(108, 64) * M(64, 119)
      temp = temp + M(108, 66) * M(66, 119)
      temp = temp + M(108, 72) * M(72, 119)
      temp = temp + M(108, 76) * M(76, 119)
      temp = temp + M(108, 77) * M(77, 119)
      temp = temp + M(108, 79) * M(79, 119)
      temp = temp + M(108, 83) * M(83, 119)
      temp = temp + M(108, 85) * M(85, 119)
      temp = temp + M(108, 88) * M(88, 119)
      temp = temp + M(108, 90) * M(90, 119)
      temp = temp + M(108, 91) * M(91, 119)
      temp = temp + M(108, 92) * M(92, 119)
      temp = temp + M(108, 96) * M(96, 119)
      M(108, 119) = ( M(108, 119) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 59) * M(59, 121)
      temp = temp + M(108, 62) * M(62, 121)
      temp = temp + M(108, 66) * M(66, 121)
      temp = temp + M(108, 91) * M(91, 121)
      temp = temp + M(108, 92) * M(92, 121)
      temp = temp + M(108, 96) * M(96, 121)
      M(108, 121) = ( M(108, 121) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 52) * M(52, 122)
      temp = temp + M(108, 54) * M(54, 122)
      temp = temp + M(108, 59) * M(59, 122)
      temp = temp + M(108, 60) * M(60, 122)
      temp = temp + M(108, 62) * M(62, 122)
      temp = temp + M(108, 63) * M(63, 122)
      temp = temp + M(108, 64) * M(64, 122)
      temp = temp + M(108, 66) * M(66, 122)
      temp = temp + M(108, 72) * M(72, 122)
      temp = temp + M(108, 76) * M(76, 122)
      temp = temp + M(108, 77) * M(77, 122)
      temp = temp + M(108, 79) * M(79, 122)
      temp = temp + M(108, 83) * M(83, 122)
      temp = temp + M(108, 85) * M(85, 122)
      temp = temp + M(108, 88) * M(88, 122)
      temp = temp + M(108, 90) * M(90, 122)
      temp = temp + M(108, 91) * M(91, 122)
      temp = temp + M(108, 92) * M(92, 122)
      temp = temp + M(108, 96) * M(96, 122)
      M(108, 122) = ( M(108, 122) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 52) * M(52, 123)
      temp = temp + M(108, 54) * M(54, 123)
      temp = temp + M(108, 59) * M(59, 123)
      temp = temp + M(108, 60) * M(60, 123)
      temp = temp + M(108, 62) * M(62, 123)
      temp = temp + M(108, 63) * M(63, 123)
      temp = temp + M(108, 64) * M(64, 123)
      temp = temp + M(108, 66) * M(66, 123)
      temp = temp + M(108, 72) * M(72, 123)
      temp = temp + M(108, 76) * M(76, 123)
      temp = temp + M(108, 77) * M(77, 123)
      temp = temp + M(108, 79) * M(79, 123)
      temp = temp + M(108, 83) * M(83, 123)
      temp = temp + M(108, 85) * M(85, 123)
      temp = temp + M(108, 88) * M(88, 123)
      temp = temp + M(108, 90) * M(90, 123)
      temp = temp + M(108, 91) * M(91, 123)
      temp = temp + M(108, 92) * M(92, 123)
      temp = temp + M(108, 96) * M(96, 123)
      M(108, 123) = ( M(108, 123) - temp ) / M(108, 108)

C     Lower part.
      temp = M(117, 101) * M(101, 109)
      M(117, 109) = M(117, 109) - temp
C     Lower part.
      temp = M(118, 101) * M(101, 109)
      temp = temp + M(118, 107) * M(107, 109)
      M(118, 109) = M(118, 109) - temp
C     Lower part.
      temp = M(119, 107) * M(107, 109)
      M(119, 109) = M(119, 109) - temp
C     Lower part.
      temp = M(121, 101) * M(101, 109)
      M(121, 109) = M(121, 109) - temp
C     Upper part.
      temp = M(109, 89) * M(89, 110)
      temp = temp + M(109, 108) * M(108, 110)
      M(109, 110) = ( M(109, 110) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 105) * M(105, 111)
      M(109, 111) = ( M(109, 111) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 29) * M(29, 113)
      temp = temp + M(109, 65) * M(65, 113)
      temp = temp + M(109, 68) * M(68, 113)
      temp = temp + M(109, 71) * M(71, 113)
      temp = temp + M(109, 72) * M(72, 113)
      temp = temp + M(109, 76) * M(76, 113)
      temp = temp + M(109, 79) * M(79, 113)
      temp = temp + M(109, 82) * M(82, 113)
      temp = temp + M(109, 83) * M(83, 113)
      temp = temp + M(109, 84) * M(84, 113)
      temp = temp + M(109, 86) * M(86, 113)
      temp = temp + M(109, 87) * M(87, 113)
      temp = temp + M(109, 88) * M(88, 113)
      temp = temp + M(109, 89) * M(89, 113)
      temp = temp + M(109, 90) * M(90, 113)
      temp = temp + M(109, 91) * M(91, 113)
      temp = temp + M(109, 92) * M(92, 113)
      temp = temp + M(109, 96) * M(96, 113)
      temp = temp + M(109, 98) * M(98, 113)
      temp = temp + M(109, 104) * M(104, 113)
      temp = temp + M(109, 105) * M(105, 113)
      temp = temp + M(109, 108) * M(108, 113)
      M(109, 113) = ( M(109, 113) - temp ) / M(109, 109)
C     Upper part.
      M(109, 115) = M(109, 115) / M(109, 109)
C     Upper part.
      temp = M(109, 21) * M(21, 117)
      temp = temp + M(109, 27) * M(27, 117)
      temp = temp + M(109, 38) * M(38, 117)
      temp = temp + M(109, 65) * M(65, 117)
      temp = temp + M(109, 68) * M(68, 117)
      temp = temp + M(109, 71) * M(71, 117)
      temp = temp + M(109, 72) * M(72, 117)
      temp = temp + M(109, 76) * M(76, 117)
      temp = temp + M(109, 79) * M(79, 117)
      temp = temp + M(109, 82) * M(82, 117)
      temp = temp + M(109, 83) * M(83, 117)
      temp = temp + M(109, 84) * M(84, 117)
      temp = temp + M(109, 86) * M(86, 117)
      temp = temp + M(109, 87) * M(87, 117)
      temp = temp + M(109, 88) * M(88, 117)
      temp = temp + M(109, 89) * M(89, 117)
      temp = temp + M(109, 90) * M(90, 117)
      temp = temp + M(109, 91) * M(91, 117)
      temp = temp + M(109, 92) * M(92, 117)
      temp = temp + M(109, 96) * M(96, 117)
      temp = temp + M(109, 98) * M(98, 117)
      temp = temp + M(109, 104) * M(104, 117)
      temp = temp + M(109, 105) * M(105, 117)
      temp = temp + M(109, 108) * M(108, 117)
      M(109, 117) = ( M(109, 117) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 10) * M(10, 118)
      temp = temp + M(109, 21) * M(21, 118)
      temp = temp + M(109, 27) * M(27, 118)
      temp = temp + M(109, 29) * M(29, 118)
      temp = temp + M(109, 38) * M(38, 118)
      temp = temp + M(109, 65) * M(65, 118)
      temp = temp + M(109, 68) * M(68, 118)
      temp = temp + M(109, 71) * M(71, 118)
      temp = temp + M(109, 72) * M(72, 118)
      temp = temp + M(109, 76) * M(76, 118)
      temp = temp + M(109, 79) * M(79, 118)
      temp = temp + M(109, 82) * M(82, 118)
      temp = temp + M(109, 83) * M(83, 118)
      temp = temp + M(109, 84) * M(84, 118)
      temp = temp + M(109, 86) * M(86, 118)
      temp = temp + M(109, 87) * M(87, 118)
      temp = temp + M(109, 88) * M(88, 118)
      temp = temp + M(109, 89) * M(89, 118)
      temp = temp + M(109, 90) * M(90, 118)
      temp = temp + M(109, 91) * M(91, 118)
      temp = temp + M(109, 92) * M(92, 118)
      temp = temp + M(109, 96) * M(96, 118)
      temp = temp + M(109, 98) * M(98, 118)
      temp = temp + M(109, 104) * M(104, 118)
      temp = temp + M(109, 105) * M(105, 118)
      temp = temp + M(109, 108) * M(108, 118)
      M(109, 118) = ( M(109, 118) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 65) * M(65, 119)
      temp = temp + M(109, 68) * M(68, 119)
      temp = temp + M(109, 71) * M(71, 119)
      temp = temp + M(109, 72) * M(72, 119)
      temp = temp + M(109, 76) * M(76, 119)
      temp = temp + M(109, 79) * M(79, 119)
      temp = temp + M(109, 82) * M(82, 119)
      temp = temp + M(109, 83) * M(83, 119)
      temp = temp + M(109, 84) * M(84, 119)
      temp = temp + M(109, 86) * M(86, 119)
      temp = temp + M(109, 87) * M(87, 119)
      temp = temp + M(109, 88) * M(88, 119)
      temp = temp + M(109, 89) * M(89, 119)
      temp = temp + M(109, 90) * M(90, 119)
      temp = temp + M(109, 91) * M(91, 119)
      temp = temp + M(109, 92) * M(92, 119)
      temp = temp + M(109, 96) * M(96, 119)
      temp = temp + M(109, 98) * M(98, 119)
      temp = temp + M(109, 104) * M(104, 119)
      temp = temp + M(109, 105) * M(105, 119)
      temp = temp + M(109, 108) * M(108, 119)
      M(109, 119) = ( M(109, 119) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 91) * M(91, 121)
      temp = temp + M(109, 92) * M(92, 121)
      temp = temp + M(109, 96) * M(96, 121)
      temp = temp + M(109, 98) * M(98, 121)
      temp = temp + M(109, 104) * M(104, 121)
      temp = temp + M(109, 105) * M(105, 121)
      temp = temp + M(109, 108) * M(108, 121)
      M(109, 121) = ( M(109, 121) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 65) * M(65, 122)
      temp = temp + M(109, 68) * M(68, 122)
      temp = temp + M(109, 71) * M(71, 122)
      temp = temp + M(109, 72) * M(72, 122)
      temp = temp + M(109, 76) * M(76, 122)
      temp = temp + M(109, 79) * M(79, 122)
      temp = temp + M(109, 82) * M(82, 122)
      temp = temp + M(109, 83) * M(83, 122)
      temp = temp + M(109, 84) * M(84, 122)
      temp = temp + M(109, 86) * M(86, 122)
      temp = temp + M(109, 87) * M(87, 122)
      temp = temp + M(109, 88) * M(88, 122)
      temp = temp + M(109, 89) * M(89, 122)
      temp = temp + M(109, 90) * M(90, 122)
      temp = temp + M(109, 91) * M(91, 122)
      temp = temp + M(109, 92) * M(92, 122)
      temp = temp + M(109, 96) * M(96, 122)
      temp = temp + M(109, 98) * M(98, 122)
      temp = temp + M(109, 104) * M(104, 122)
      temp = temp + M(109, 105) * M(105, 122)
      temp = temp + M(109, 108) * M(108, 122)
      M(109, 122) = ( M(109, 122) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 65) * M(65, 123)
      temp = temp + M(109, 68) * M(68, 123)
      temp = temp + M(109, 71) * M(71, 123)
      temp = temp + M(109, 72) * M(72, 123)
      temp = temp + M(109, 76) * M(76, 123)
      temp = temp + M(109, 79) * M(79, 123)
      temp = temp + M(109, 82) * M(82, 123)
      temp = temp + M(109, 83) * M(83, 123)
      temp = temp + M(109, 84) * M(84, 123)
      temp = temp + M(109, 86) * M(86, 123)
      temp = temp + M(109, 87) * M(87, 123)
      temp = temp + M(109, 88) * M(88, 123)
      temp = temp + M(109, 89) * M(89, 123)
      temp = temp + M(109, 90) * M(90, 123)
      temp = temp + M(109, 91) * M(91, 123)
      temp = temp + M(109, 92) * M(92, 123)
      temp = temp + M(109, 96) * M(96, 123)
      temp = temp + M(109, 98) * M(98, 123)
      temp = temp + M(109, 104) * M(104, 123)
      temp = temp + M(109, 105) * M(105, 123)
      temp = temp + M(109, 108) * M(108, 123)
      M(109, 123) = ( M(109, 123) - temp ) / M(109, 109)

C     Lower part.
      temp = M(110, 108) * M(108, 110)
      M(110, 110) = M(110, 110) - temp
C     Lower part.
      temp = M(111, 108) * M(108, 110)
      M(111, 110) = M(111, 110) - temp
C     Lower part.
      temp = M(113, 73) * M(73, 110)
      temp = temp + M(113, 78) * M(78, 110)
      temp = temp + M(113, 94) * M(94, 110)
      temp = temp + M(113, 106) * M(106, 110)
      M(113, 110) = M(113, 110) - temp
C     Lower part.
      temp = M(114, 109) * M(109, 110)
      M(114, 110) = M(114, 110) - temp
C     Lower part.
      temp = M(115, 78) * M(78, 110)
      temp = temp + M(115, 106) * M(106, 110)
      M(115, 110) = M(115, 110) - temp
C     Lower part.
      temp = M(116, 78) * M(78, 110)
      temp = temp + M(116, 99) * M(99, 110)
      temp = temp + M(116, 102) * M(102, 110)
      temp = temp + M(116, 106) * M(106, 110)
      M(116, 110) = M(116, 110) - temp
C     Lower part.
      temp = M(117, 78) * M(78, 110)
      temp = temp + M(117, 94) * M(94, 110)
      temp = temp + M(117, 101) * M(101, 110)
      temp = temp + M(117, 102) * M(102, 110)
      temp = temp + M(117, 106) * M(106, 110)
      temp = temp + M(117, 109) * M(109, 110)
      M(117, 110) = M(117, 110) - temp
C     Lower part.
      temp = M(118, 73) * M(73, 110)
      temp = temp + M(118, 78) * M(78, 110)
      temp = temp + M(118, 89) * M(89, 110)
      temp = temp + M(118, 94) * M(94, 110)
      temp = temp + M(118, 99) * M(99, 110)
      temp = temp + M(118, 101) * M(101, 110)
      temp = temp + M(118, 102) * M(102, 110)
      temp = temp + M(118, 106) * M(106, 110)
      temp = temp + M(118, 107) * M(107, 110)
      temp = temp + M(118, 108) * M(108, 110)
      temp = temp + M(118, 109) * M(109, 110)
      M(118, 110) = M(118, 110) - temp
C     Lower part.
      temp = M(119, 78) * M(78, 110)
      temp = temp + M(119, 89) * M(89, 110)
      temp = temp + M(119, 94) * M(94, 110)
      temp = temp + M(119, 99) * M(99, 110)
      temp = temp + M(119, 102) * M(102, 110)
      temp = temp + M(119, 106) * M(106, 110)
      temp = temp + M(119, 107) * M(107, 110)
      temp = temp + M(119, 108) * M(108, 110)
      temp = temp + M(119, 109) * M(109, 110)
      M(119, 110) = M(119, 110) - temp
C     Lower part.
      temp = M(120, 109) * M(109, 110)
      M(120, 110) = M(120, 110) - temp
C     Lower part.
      temp = M(121, 78) * M(78, 110)
      temp = temp + M(121, 101) * M(101, 110)
      temp = temp + M(121, 102) * M(102, 110)
      temp = temp + M(121, 106) * M(106, 110)
      temp = temp + M(121, 108) * M(108, 110)
      temp = temp + M(121, 109) * M(109, 110)
      M(121, 110) = M(121, 110) - temp
C     Lower part.
      temp = M(122, 73) * M(73, 110)
      temp = temp + M(122, 78) * M(78, 110)
      temp = temp + M(122, 94) * M(94, 110)
      temp = temp + M(122, 106) * M(106, 110)
      M(122, 110) = M(122, 110) - temp
C     Lower part.
      temp = M(123, 78) * M(78, 110)
      temp = temp + M(123, 106) * M(106, 110)
      M(123, 110) = M(123, 110) - temp
C     Upper part.
      temp = M(110, 108) * M(108, 113)
      M(110, 113) = ( M(110, 113) - temp ) / M(110, 110)
C     Upper part.
      M(110, 115) = M(110, 115) / M(110, 110)
C     Upper part.
      temp = M(110, 108) * M(108, 117)
      M(110, 117) = ( M(110, 117) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 8) * M(8, 118)
      temp = temp + M(110, 108) * M(108, 118)
      M(110, 118) = ( M(110, 118) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 108) * M(108, 119)
      M(110, 119) = ( M(110, 119) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 108) * M(108, 121)
      M(110, 121) = ( M(110, 121) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 108) * M(108, 122)
      M(110, 122) = ( M(110, 122) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 108) * M(108, 123)
      M(110, 123) = ( M(110, 123) - temp ) / M(110, 110)

C     Lower part.
      temp = M(112, 105) * M(105, 111)
      M(112, 111) = M(112, 111) - temp
C     Lower part.
      temp = M(113, 105) * M(105, 111)
      temp = temp + M(113, 106) * M(106, 111)
      M(113, 111) = M(113, 111) - temp
C     Lower part.
      temp = M(114, 109) * M(109, 111)
      M(114, 111) = M(114, 111) - temp
C     Lower part.
      temp = M(115, 105) * M(105, 111)
      temp = temp + M(115, 106) * M(106, 111)
      M(115, 111) = M(115, 111) - temp
C     Lower part.
      temp = M(116, 105) * M(105, 111)
      temp = temp + M(116, 106) * M(106, 111)
      M(116, 111) = M(116, 111) - temp
C     Lower part.
      temp = M(117, 105) * M(105, 111)
      temp = temp + M(117, 106) * M(106, 111)
      temp = temp + M(117, 109) * M(109, 111)
      M(117, 111) = M(117, 111) - temp
C     Lower part.
      temp = M(118, 105) * M(105, 111)
      temp = temp + M(118, 106) * M(106, 111)
      temp = temp + M(118, 107) * M(107, 111)
      temp = temp + M(118, 109) * M(109, 111)
      M(118, 111) = M(118, 111) - temp
C     Lower part.
      temp = M(119, 105) * M(105, 111)
      temp = temp + M(119, 106) * M(106, 111)
      temp = temp + M(119, 107) * M(107, 111)
      temp = temp + M(119, 109) * M(109, 111)
      M(119, 111) = M(119, 111) - temp
C     Lower part.
      temp = M(120, 109) * M(109, 111)
      M(120, 111) = M(120, 111) - temp
C     Lower part.
      temp = M(121, 105) * M(105, 111)
      temp = temp + M(121, 106) * M(106, 111)
      temp = temp + M(121, 109) * M(109, 111)
      M(121, 111) = M(121, 111) - temp
C     Lower part.
      temp = M(122, 105) * M(105, 111)
      temp = temp + M(122, 106) * M(106, 111)
      M(122, 111) = M(122, 111) - temp
C     Lower part.
      temp = M(123, 105) * M(105, 111)
      temp = temp + M(123, 106) * M(106, 111)
      M(123, 111) = M(123, 111) - temp
C     Upper part.
      temp = M(111, 71) * M(71, 113)
      temp = temp + M(111, 72) * M(72, 113)
      temp = temp + M(111, 76) * M(76, 113)
      temp = temp + M(111, 79) * M(79, 113)
      temp = temp + M(111, 83) * M(83, 113)
      temp = temp + M(111, 84) * M(84, 113)
      temp = temp + M(111, 85) * M(85, 113)
      temp = temp + M(111, 86) * M(86, 113)
      temp = temp + M(111, 87) * M(87, 113)
      temp = temp + M(111, 88) * M(88, 113)
      temp = temp + M(111, 90) * M(90, 113)
      temp = temp + M(111, 91) * M(91, 113)
      temp = temp + M(111, 92) * M(92, 113)
      temp = temp + M(111, 96) * M(96, 113)
      temp = temp + M(111, 108) * M(108, 113)
      temp = temp + M(111, 110) * M(110, 113)
      M(111, 113) = ( M(111, 113) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 110) * M(110, 115)
      M(111, 115) = ( M(111, 115) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 21) * M(21, 117)
      temp = temp + M(111, 38) * M(38, 117)
      temp = temp + M(111, 71) * M(71, 117)
      temp = temp + M(111, 72) * M(72, 117)
      temp = temp + M(111, 76) * M(76, 117)
      temp = temp + M(111, 79) * M(79, 117)
      temp = temp + M(111, 83) * M(83, 117)
      temp = temp + M(111, 84) * M(84, 117)
      temp = temp + M(111, 85) * M(85, 117)
      temp = temp + M(111, 86) * M(86, 117)
      temp = temp + M(111, 87) * M(87, 117)
      temp = temp + M(111, 88) * M(88, 117)
      temp = temp + M(111, 90) * M(90, 117)
      temp = temp + M(111, 91) * M(91, 117)
      temp = temp + M(111, 92) * M(92, 117)
      temp = temp + M(111, 96) * M(96, 117)
      temp = temp + M(111, 108) * M(108, 117)
      temp = temp + M(111, 110) * M(110, 117)
      M(111, 117) = ( M(111, 117) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 21) * M(21, 118)
      temp = temp + M(111, 38) * M(38, 118)
      temp = temp + M(111, 71) * M(71, 118)
      temp = temp + M(111, 72) * M(72, 118)
      temp = temp + M(111, 76) * M(76, 118)
      temp = temp + M(111, 79) * M(79, 118)
      temp = temp + M(111, 83) * M(83, 118)
      temp = temp + M(111, 84) * M(84, 118)
      temp = temp + M(111, 85) * M(85, 118)
      temp = temp + M(111, 86) * M(86, 118)
      temp = temp + M(111, 87) * M(87, 118)
      temp = temp + M(111, 88) * M(88, 118)
      temp = temp + M(111, 90) * M(90, 118)
      temp = temp + M(111, 91) * M(91, 118)
      temp = temp + M(111, 92) * M(92, 118)
      temp = temp + M(111, 96) * M(96, 118)
      temp = temp + M(111, 108) * M(108, 118)
      temp = temp + M(111, 110) * M(110, 118)
      M(111, 118) = ( M(111, 118) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 71) * M(71, 119)
      temp = temp + M(111, 72) * M(72, 119)
      temp = temp + M(111, 76) * M(76, 119)
      temp = temp + M(111, 79) * M(79, 119)
      temp = temp + M(111, 83) * M(83, 119)
      temp = temp + M(111, 84) * M(84, 119)
      temp = temp + M(111, 85) * M(85, 119)
      temp = temp + M(111, 86) * M(86, 119)
      temp = temp + M(111, 87) * M(87, 119)
      temp = temp + M(111, 88) * M(88, 119)
      temp = temp + M(111, 90) * M(90, 119)
      temp = temp + M(111, 91) * M(91, 119)
      temp = temp + M(111, 92) * M(92, 119)
      temp = temp + M(111, 96) * M(96, 119)
      temp = temp + M(111, 108) * M(108, 119)
      temp = temp + M(111, 110) * M(110, 119)
      M(111, 119) = ( M(111, 119) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 91) * M(91, 121)
      temp = temp + M(111, 92) * M(92, 121)
      temp = temp + M(111, 96) * M(96, 121)
      temp = temp + M(111, 108) * M(108, 121)
      temp = temp + M(111, 110) * M(110, 121)
      M(111, 121) = ( M(111, 121) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 71) * M(71, 122)
      temp = temp + M(111, 72) * M(72, 122)
      temp = temp + M(111, 76) * M(76, 122)
      temp = temp + M(111, 79) * M(79, 122)
      temp = temp + M(111, 83) * M(83, 122)
      temp = temp + M(111, 84) * M(84, 122)
      temp = temp + M(111, 85) * M(85, 122)
      temp = temp + M(111, 86) * M(86, 122)
      temp = temp + M(111, 87) * M(87, 122)
      temp = temp + M(111, 88) * M(88, 122)
      temp = temp + M(111, 90) * M(90, 122)
      temp = temp + M(111, 91) * M(91, 122)
      temp = temp + M(111, 92) * M(92, 122)
      temp = temp + M(111, 96) * M(96, 122)
      temp = temp + M(111, 108) * M(108, 122)
      temp = temp + M(111, 110) * M(110, 122)
      M(111, 122) = ( M(111, 122) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 71) * M(71, 123)
      temp = temp + M(111, 72) * M(72, 123)
      temp = temp + M(111, 76) * M(76, 123)
      temp = temp + M(111, 79) * M(79, 123)
      temp = temp + M(111, 83) * M(83, 123)
      temp = temp + M(111, 84) * M(84, 123)
      temp = temp + M(111, 85) * M(85, 123)
      temp = temp + M(111, 86) * M(86, 123)
      temp = temp + M(111, 87) * M(87, 123)
      temp = temp + M(111, 88) * M(88, 123)
      temp = temp + M(111, 90) * M(90, 123)
      temp = temp + M(111, 91) * M(91, 123)
      temp = temp + M(111, 92) * M(92, 123)
      temp = temp + M(111, 96) * M(96, 123)
      temp = temp + M(111, 108) * M(108, 123)
      temp = temp + M(111, 110) * M(110, 123)
      M(111, 123) = ( M(111, 123) - temp ) / M(111, 111)

C     Upper part.
      temp = M(112, 65) * M(65, 113)
      temp = temp + M(112, 68) * M(68, 113)
      temp = temp + M(112, 70) * M(70, 113)
      temp = temp + M(112, 76) * M(76, 113)
      temp = temp + M(112, 79) * M(79, 113)
      temp = temp + M(112, 81) * M(81, 113)
      temp = temp + M(112, 82) * M(82, 113)
      temp = temp + M(112, 83) * M(83, 113)
      temp = temp + M(112, 91) * M(91, 113)
      temp = temp + M(112, 92) * M(92, 113)
      temp = temp + M(112, 96) * M(96, 113)
      temp = temp + M(112, 105) * M(105, 113)
      temp = temp + M(112, 110) * M(110, 113)
      temp = temp + M(112, 111) * M(111, 113)
      M(112, 113) = ( M(112, 113) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 110) * M(110, 115)
      temp = temp + M(112, 111) * M(111, 115)
      M(112, 115) = ( M(112, 115) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 25) * M(25, 117)
      temp = temp + M(112, 27) * M(27, 117)
      temp = temp + M(112, 65) * M(65, 117)
      temp = temp + M(112, 68) * M(68, 117)
      temp = temp + M(112, 70) * M(70, 117)
      temp = temp + M(112, 76) * M(76, 117)
      temp = temp + M(112, 79) * M(79, 117)
      temp = temp + M(112, 81) * M(81, 117)
      temp = temp + M(112, 82) * M(82, 117)
      temp = temp + M(112, 83) * M(83, 117)
      temp = temp + M(112, 91) * M(91, 117)
      temp = temp + M(112, 92) * M(92, 117)
      temp = temp + M(112, 96) * M(96, 117)
      temp = temp + M(112, 105) * M(105, 117)
      temp = temp + M(112, 110) * M(110, 117)
      temp = temp + M(112, 111) * M(111, 117)
      M(112, 117) = ( M(112, 117) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 25) * M(25, 118)
      temp = temp + M(112, 27) * M(27, 118)
      temp = temp + M(112, 41) * M(41, 118)
      temp = temp + M(112, 42) * M(42, 118)
      temp = temp + M(112, 65) * M(65, 118)
      temp = temp + M(112, 68) * M(68, 118)
      temp = temp + M(112, 70) * M(70, 118)
      temp = temp + M(112, 76) * M(76, 118)
      temp = temp + M(112, 79) * M(79, 118)
      temp = temp + M(112, 81) * M(81, 118)
      temp = temp + M(112, 82) * M(82, 118)
      temp = temp + M(112, 83) * M(83, 118)
      temp = temp + M(112, 91) * M(91, 118)
      temp = temp + M(112, 92) * M(92, 118)
      temp = temp + M(112, 96) * M(96, 118)
      temp = temp + M(112, 105) * M(105, 118)
      temp = temp + M(112, 110) * M(110, 118)
      temp = temp + M(112, 111) * M(111, 118)
      M(112, 118) = ( M(112, 118) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 65) * M(65, 119)
      temp = temp + M(112, 68) * M(68, 119)
      temp = temp + M(112, 70) * M(70, 119)
      temp = temp + M(112, 76) * M(76, 119)
      temp = temp + M(112, 79) * M(79, 119)
      temp = temp + M(112, 81) * M(81, 119)
      temp = temp + M(112, 82) * M(82, 119)
      temp = temp + M(112, 83) * M(83, 119)
      temp = temp + M(112, 91) * M(91, 119)
      temp = temp + M(112, 92) * M(92, 119)
      temp = temp + M(112, 96) * M(96, 119)
      temp = temp + M(112, 105) * M(105, 119)
      temp = temp + M(112, 110) * M(110, 119)
      temp = temp + M(112, 111) * M(111, 119)
      M(112, 119) = ( M(112, 119) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 42) * M(42, 120)
      temp = temp + M(112, 70) * M(70, 120)
      M(112, 120) = ( M(112, 120) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 41) * M(41, 121)
      temp = temp + M(112, 42) * M(42, 121)
      temp = temp + M(112, 91) * M(91, 121)
      temp = temp + M(112, 92) * M(92, 121)
      temp = temp + M(112, 96) * M(96, 121)
      temp = temp + M(112, 105) * M(105, 121)
      temp = temp + M(112, 110) * M(110, 121)
      temp = temp + M(112, 111) * M(111, 121)
      M(112, 121) = ( M(112, 121) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 41) * M(41, 122)
      temp = temp + M(112, 65) * M(65, 122)
      temp = temp + M(112, 68) * M(68, 122)
      temp = temp + M(112, 70) * M(70, 122)
      temp = temp + M(112, 76) * M(76, 122)
      temp = temp + M(112, 79) * M(79, 122)
      temp = temp + M(112, 81) * M(81, 122)
      temp = temp + M(112, 82) * M(82, 122)
      temp = temp + M(112, 83) * M(83, 122)
      temp = temp + M(112, 91) * M(91, 122)
      temp = temp + M(112, 92) * M(92, 122)
      temp = temp + M(112, 96) * M(96, 122)
      temp = temp + M(112, 105) * M(105, 122)
      temp = temp + M(112, 110) * M(110, 122)
      temp = temp + M(112, 111) * M(111, 122)
      M(112, 122) = ( M(112, 122) - temp ) / M(112, 112)
C     Upper part.
      temp = M(112, 65) * M(65, 123)
      temp = temp + M(112, 68) * M(68, 123)
      temp = temp + M(112, 70) * M(70, 123)
      temp = temp + M(112, 76) * M(76, 123)
      temp = temp + M(112, 79) * M(79, 123)
      temp = temp + M(112, 81) * M(81, 123)
      temp = temp + M(112, 82) * M(82, 123)
      temp = temp + M(112, 83) * M(83, 123)
      temp = temp + M(112, 91) * M(91, 123)
      temp = temp + M(112, 92) * M(92, 123)
      temp = temp + M(112, 96) * M(96, 123)
      temp = temp + M(112, 105) * M(105, 123)
      temp = temp + M(112, 110) * M(110, 123)
      temp = temp + M(112, 111) * M(111, 123)
      M(112, 123) = ( M(112, 123) - temp ) / M(112, 112)

C     Lower part.
      temp = M(113, 40) * M(40, 113)
      temp = temp + M(113, 52) * M(52, 113)
      temp = temp + M(113, 53) * M(53, 113)
      temp = temp + M(113, 54) * M(54, 113)
      temp = temp + M(113, 55) * M(55, 113)
      temp = temp + M(113, 57) * M(57, 113)
      temp = temp + M(113, 58) * M(58, 113)
      temp = temp + M(113, 60) * M(60, 113)
      temp = temp + M(113, 63) * M(63, 113)
      temp = temp + M(113, 64) * M(64, 113)
      temp = temp + M(113, 66) * M(66, 113)
      temp = temp + M(113, 67) * M(67, 113)
      temp = temp + M(113, 70) * M(70, 113)
      temp = temp + M(113, 71) * M(71, 113)
      temp = temp + M(113, 72) * M(72, 113)
      temp = temp + M(113, 73) * M(73, 113)
      temp = temp + M(113, 76) * M(76, 113)
      temp = temp + M(113, 77) * M(77, 113)
      temp = temp + M(113, 78) * M(78, 113)
      temp = temp + M(113, 79) * M(79, 113)
      temp = temp + M(113, 80) * M(80, 113)
      temp = temp + M(113, 81) * M(81, 113)
      temp = temp + M(113, 82) * M(82, 113)
      temp = temp + M(113, 83) * M(83, 113)
      temp = temp + M(113, 84) * M(84, 113)
      temp = temp + M(113, 85) * M(85, 113)
      temp = temp + M(113, 86) * M(86, 113)
      temp = temp + M(113, 87) * M(87, 113)
      temp = temp + M(113, 88) * M(88, 113)
      temp = temp + M(113, 90) * M(90, 113)
      temp = temp + M(113, 91) * M(91, 113)
      temp = temp + M(113, 92) * M(92, 113)
      temp = temp + M(113, 94) * M(94, 113)
      temp = temp + M(113, 95) * M(95, 113)
      temp = temp + M(113, 96) * M(96, 113)
      temp = temp + M(113, 97) * M(97, 113)
      temp = temp + M(113, 98) * M(98, 113)
      temp = temp + M(113, 103) * M(103, 113)
      temp = temp + M(113, 104) * M(104, 113)
      temp = temp + M(113, 105) * M(105, 113)
      temp = temp + M(113, 106) * M(106, 113)
      temp = temp + M(113, 110) * M(110, 113)
      temp = temp + M(113, 111) * M(111, 113)
      temp = temp + M(113, 112) * M(112, 113)
      M(113, 113) = M(113, 113) - temp
C     Lower part.
      temp = M(114, 76) * M(76, 113)
      temp = temp + M(114, 79) * M(79, 113)
      temp = temp + M(114, 86) * M(86, 113)
      temp = temp + M(114, 91) * M(91, 113)
      temp = temp + M(114, 92) * M(92, 113)
      temp = temp + M(114, 96) * M(96, 113)
      temp = temp + M(114, 109) * M(109, 113)
      temp = temp + M(114, 110) * M(110, 113)
      temp = temp + M(114, 111) * M(111, 113)
      M(114, 113) = M(114, 113) - temp
C     Lower part.
      temp = M(115, 54) * M(54, 113)
      temp = temp + M(115, 60) * M(60, 113)
      temp = temp + M(115, 64) * M(64, 113)
      temp = temp + M(115, 66) * M(66, 113)
      temp = temp + M(115, 67) * M(67, 113)
      temp = temp + M(115, 71) * M(71, 113)
      temp = temp + M(115, 72) * M(72, 113)
      temp = temp + M(115, 76) * M(76, 113)
      temp = temp + M(115, 77) * M(77, 113)
      temp = temp + M(115, 78) * M(78, 113)
      temp = temp + M(115, 79) * M(79, 113)
      temp = temp + M(115, 82) * M(82, 113)
      temp = temp + M(115, 84) * M(84, 113)
      temp = temp + M(115, 85) * M(85, 113)
      temp = temp + M(115, 87) * M(87, 113)
      temp = temp + M(115, 91) * M(91, 113)
      temp = temp + M(115, 92) * M(92, 113)
      temp = temp + M(115, 95) * M(95, 113)
      temp = temp + M(115, 96) * M(96, 113)
      temp = temp + M(115, 97) * M(97, 113)
      temp = temp + M(115, 98) * M(98, 113)
      temp = temp + M(115, 103) * M(103, 113)
      temp = temp + M(115, 105) * M(105, 113)
      temp = temp + M(115, 106) * M(106, 113)
      temp = temp + M(115, 110) * M(110, 113)
      temp = temp + M(115, 111) * M(111, 113)
      temp = temp + M(115, 112) * M(112, 113)
      M(115, 113) = M(115, 113) - temp
C     Lower part.
      temp = M(116, 40) * M(40, 113)
      temp = temp + M(116, 52) * M(52, 113)
      temp = temp + M(116, 53) * M(53, 113)
      temp = temp + M(116, 54) * M(54, 113)
      temp = temp + M(116, 55) * M(55, 113)
      temp = temp + M(116, 57) * M(57, 113)
      temp = temp + M(116, 58) * M(58, 113)
      temp = temp + M(116, 60) * M(60, 113)
      temp = temp + M(116, 63) * M(63, 113)
      temp = temp + M(116, 64) * M(64, 113)
      temp = temp + M(116, 66) * M(66, 113)
      temp = temp + M(116, 67) * M(67, 113)
      temp = temp + M(116, 70) * M(70, 113)
      temp = temp + M(116, 71) * M(71, 113)
      temp = temp + M(116, 72) * M(72, 113)
      temp = temp + M(116, 75) * M(75, 113)
      temp = temp + M(116, 76) * M(76, 113)
      temp = temp + M(116, 77) * M(77, 113)
      temp = temp + M(116, 78) * M(78, 113)
      temp = temp + M(116, 79) * M(79, 113)
      temp = temp + M(116, 80) * M(80, 113)
      temp = temp + M(116, 81) * M(81, 113)
      temp = temp + M(116, 82) * M(82, 113)
      temp = temp + M(116, 83) * M(83, 113)
      temp = temp + M(116, 84) * M(84, 113)
      temp = temp + M(116, 85) * M(85, 113)
      temp = temp + M(116, 86) * M(86, 113)
      temp = temp + M(116, 87) * M(87, 113)
      temp = temp + M(116, 88) * M(88, 113)
      temp = temp + M(116, 90) * M(90, 113)
      temp = temp + M(116, 91) * M(91, 113)
      temp = temp + M(116, 92) * M(92, 113)
      temp = temp + M(116, 95) * M(95, 113)
      temp = temp + M(116, 96) * M(96, 113)
      temp = temp + M(116, 97) * M(97, 113)
      temp = temp + M(116, 98) * M(98, 113)
      temp = temp + M(116, 99) * M(99, 113)
      temp = temp + M(116, 102) * M(102, 113)
      temp = temp + M(116, 103) * M(103, 113)
      temp = temp + M(116, 104) * M(104, 113)
      temp = temp + M(116, 105) * M(105, 113)
      temp = temp + M(116, 106) * M(106, 113)
      temp = temp + M(116, 110) * M(110, 113)
      temp = temp + M(116, 111) * M(111, 113)
      temp = temp + M(116, 112) * M(112, 113)
      M(116, 113) = M(116, 113) - temp
C     Lower part.
      temp = M(117, 52) * M(52, 113)
      temp = temp + M(117, 53) * M(53, 113)
      temp = temp + M(117, 54) * M(54, 113)
      temp = temp + M(117, 55) * M(55, 113)
      temp = temp + M(117, 57) * M(57, 113)
      temp = temp + M(117, 58) * M(58, 113)
      temp = temp + M(117, 60) * M(60, 113)
      temp = temp + M(117, 61) * M(61, 113)
      temp = temp + M(117, 62) * M(62, 113)
      temp = temp + M(117, 63) * M(63, 113)
      temp = temp + M(117, 64) * M(64, 113)
      temp = temp + M(117, 66) * M(66, 113)
      temp = temp + M(117, 67) * M(67, 113)
      temp = temp + M(117, 71) * M(71, 113)
      temp = temp + M(117, 72) * M(72, 113)
      temp = temp + M(117, 76) * M(76, 113)
      temp = temp + M(117, 77) * M(77, 113)
      temp = temp + M(117, 78) * M(78, 113)
      temp = temp + M(117, 79) * M(79, 113)
      temp = temp + M(117, 80) * M(80, 113)
      temp = temp + M(117, 82) * M(82, 113)
      temp = temp + M(117, 83) * M(83, 113)
      temp = temp + M(117, 84) * M(84, 113)
      temp = temp + M(117, 85) * M(85, 113)
      temp = temp + M(117, 86) * M(86, 113)
      temp = temp + M(117, 87) * M(87, 113)
      temp = temp + M(117, 88) * M(88, 113)
      temp = temp + M(117, 90) * M(90, 113)
      temp = temp + M(117, 91) * M(91, 113)
      temp = temp + M(117, 92) * M(92, 113)
      temp = temp + M(117, 94) * M(94, 113)
      temp = temp + M(117, 95) * M(95, 113)
      temp = temp + M(117, 96) * M(96, 113)
      temp = temp + M(117, 97) * M(97, 113)
      temp = temp + M(117, 98) * M(98, 113)
      temp = temp + M(117, 100) * M(100, 113)
      temp = temp + M(117, 101) * M(101, 113)
      temp = temp + M(117, 102) * M(102, 113)
      temp = temp + M(117, 103) * M(103, 113)
      temp = temp + M(117, 104) * M(104, 113)
      temp = temp + M(117, 105) * M(105, 113)
      temp = temp + M(117, 106) * M(106, 113)
      temp = temp + M(117, 109) * M(109, 113)
      temp = temp + M(117, 110) * M(110, 113)
      temp = temp + M(117, 111) * M(111, 113)
      temp = temp + M(117, 112) * M(112, 113)
      M(117, 113) = M(117, 113) - temp
C     Lower part.
      temp = M(118, 26) * M(26, 113)
      temp = temp + M(118, 29) * M(29, 113)
      temp = temp + M(118, 40) * M(40, 113)
      temp = temp + M(118, 54) * M(54, 113)
      temp = temp + M(118, 56) * M(56, 113)
      temp = temp + M(118, 60) * M(60, 113)
      temp = temp + M(118, 61) * M(61, 113)
      temp = temp + M(118, 62) * M(62, 113)
      temp = temp + M(118, 64) * M(64, 113)
      temp = temp + M(118, 65) * M(65, 113)
      temp = temp + M(118, 68) * M(68, 113)
      temp = temp + M(118, 69) * M(69, 113)
      temp = temp + M(118, 70) * M(70, 113)
      temp = temp + M(118, 73) * M(73, 113)
      temp = temp + M(118, 74) * M(74, 113)
      temp = temp + M(118, 75) * M(75, 113)
      temp = temp + M(118, 76) * M(76, 113)
      temp = temp + M(118, 78) * M(78, 113)
      temp = temp + M(118, 80) * M(80, 113)
      temp = temp + M(118, 81) * M(81, 113)
      temp = temp + M(118, 83) * M(83, 113)
      temp = temp + M(118, 85) * M(85, 113)
      temp = temp + M(118, 86) * M(86, 113)
      temp = temp + M(118, 89) * M(89, 113)
      temp = temp + M(118, 90) * M(90, 113)
      temp = temp + M(118, 91) * M(91, 113)
      temp = temp + M(118, 92) * M(92, 113)
      temp = temp + M(118, 93) * M(93, 113)
      temp = temp + M(118, 94) * M(94, 113)
      temp = temp + M(118, 96) * M(96, 113)
      temp = temp + M(118, 97) * M(97, 113)
      temp = temp + M(118, 98) * M(98, 113)
      temp = temp + M(118, 99) * M(99, 113)
      temp = temp + M(118, 100) * M(100, 113)
      temp = temp + M(118, 101) * M(101, 113)
      temp = temp + M(118, 102) * M(102, 113)
      temp = temp + M(118, 103) * M(103, 113)
      temp = temp + M(118, 104) * M(104, 113)
      temp = temp + M(118, 105) * M(105, 113)
      temp = temp + M(118, 106) * M(106, 113)
      temp = temp + M(118, 107) * M(107, 113)
      temp = temp + M(118, 108) * M(108, 113)
      temp = temp + M(118, 109) * M(109, 113)
      temp = temp + M(118, 110) * M(110, 113)
      temp = temp + M(118, 111) * M(111, 113)
      M(118, 113) = M(118, 113) - temp
C     Lower part.
      temp = M(119, 26) * M(26, 113)
      temp = temp + M(119, 29) * M(29, 113)
      temp = temp + M(119, 40) * M(40, 113)
      temp = temp + M(119, 52) * M(52, 113)
      temp = temp + M(119, 53) * M(53, 113)
      temp = temp + M(119, 54) * M(54, 113)
      temp = temp + M(119, 55) * M(55, 113)
      temp = temp + M(119, 56) * M(56, 113)
      temp = temp + M(119, 57) * M(57, 113)
      temp = temp + M(119, 58) * M(58, 113)
      temp = temp + M(119, 60) * M(60, 113)
      temp = temp + M(119, 61) * M(61, 113)
      temp = temp + M(119, 62) * M(62, 113)
      temp = temp + M(119, 63) * M(63, 113)
      temp = temp + M(119, 64) * M(64, 113)
      temp = temp + M(119, 65) * M(65, 113)
      temp = temp + M(119, 66) * M(66, 113)
      temp = temp + M(119, 67) * M(67, 113)
      temp = temp + M(119, 68) * M(68, 113)
      temp = temp + M(119, 69) * M(69, 113)
      temp = temp + M(119, 71) * M(71, 113)
      temp = temp + M(119, 72) * M(72, 113)
      temp = temp + M(119, 74) * M(74, 113)
      temp = temp + M(119, 75) * M(75, 113)
      temp = temp + M(119, 76) * M(76, 113)
      temp = temp + M(119, 77) * M(77, 113)
      temp = temp + M(119, 78) * M(78, 113)
      temp = temp + M(119, 79) * M(79, 113)
      temp = temp + M(119, 80) * M(80, 113)
      temp = temp + M(119, 81) * M(81, 113)
      temp = temp + M(119, 82) * M(82, 113)
      temp = temp + M(119, 83) * M(83, 113)
      temp = temp + M(119, 84) * M(84, 113)
      temp = temp + M(119, 85) * M(85, 113)
      temp = temp + M(119, 86) * M(86, 113)
      temp = temp + M(119, 87) * M(87, 113)
      temp = temp + M(119, 88) * M(88, 113)
      temp = temp + M(119, 89) * M(89, 113)
      temp = temp + M(119, 90) * M(90, 113)
      temp = temp + M(119, 91) * M(91, 113)
      temp = temp + M(119, 92) * M(92, 113)
      temp = temp + M(119, 93) * M(93, 113)
      temp = temp + M(119, 94) * M(94, 113)
      temp = temp + M(119, 95) * M(95, 113)
      temp = temp + M(119, 96) * M(96, 113)
      temp = temp + M(119, 97) * M(97, 113)
      temp = temp + M(119, 98) * M(98, 113)
      temp = temp + M(119, 99) * M(99, 113)
      temp = temp + M(119, 100) * M(100, 113)
      temp = temp + M(119, 102) * M(102, 113)
      temp = temp + M(119, 103) * M(103, 113)
      temp = temp + M(119, 104) * M(104, 113)
      temp = temp + M(119, 105) * M(105, 113)
      temp = temp + M(119, 106) * M(106, 113)
      temp = temp + M(119, 107) * M(107, 113)
      temp = temp + M(119, 108) * M(108, 113)
      temp = temp + M(119, 109) * M(109, 113)
      temp = temp + M(119, 110) * M(110, 113)
      temp = temp + M(119, 111) * M(111, 113)
      temp = temp + M(119, 112) * M(112, 113)
      M(119, 113) = M(119, 113) - temp
C     Lower part.
      temp = M(120, 109) * M(109, 113)
      temp = temp + M(120, 110) * M(110, 113)
      temp = temp + M(120, 111) * M(111, 113)
      M(120, 113) = M(120, 113) - temp
C     Lower part.
      temp = M(121, 52) * M(52, 113)
      temp = temp + M(121, 53) * M(53, 113)
      temp = temp + M(121, 54) * M(54, 113)
      temp = temp + M(121, 55) * M(55, 113)
      temp = temp + M(121, 57) * M(57, 113)
      temp = temp + M(121, 58) * M(58, 113)
      temp = temp + M(121, 59) * M(59, 113)
      temp = temp + M(121, 60) * M(60, 113)
      temp = temp + M(121, 62) * M(62, 113)
      temp = temp + M(121, 63) * M(63, 113)
      temp = temp + M(121, 64) * M(64, 113)
      temp = temp + M(121, 66) * M(66, 113)
      temp = temp + M(121, 67) * M(67, 113)
      temp = temp + M(121, 71) * M(71, 113)
      temp = temp + M(121, 72) * M(72, 113)
      temp = temp + M(121, 76) * M(76, 113)
      temp = temp + M(121, 77) * M(77, 113)
      temp = temp + M(121, 78) * M(78, 113)
      temp = temp + M(121, 79) * M(79, 113)
      temp = temp + M(121, 80) * M(80, 113)
      temp = temp + M(121, 82) * M(82, 113)
      temp = temp + M(121, 84) * M(84, 113)
      temp = temp + M(121, 85) * M(85, 113)
      temp = temp + M(121, 87) * M(87, 113)
      temp = temp + M(121, 88) * M(88, 113)
      temp = temp + M(121, 90) * M(90, 113)
      temp = temp + M(121, 91) * M(91, 113)
      temp = temp + M(121, 92) * M(92, 113)
      temp = temp + M(121, 95) * M(95, 113)
      temp = temp + M(121, 96) * M(96, 113)
      temp = temp + M(121, 97) * M(97, 113)
      temp = temp + M(121, 98) * M(98, 113)
      temp = temp + M(121, 101) * M(101, 113)
      temp = temp + M(121, 102) * M(102, 113)
      temp = temp + M(121, 103) * M(103, 113)
      temp = temp + M(121, 104) * M(104, 113)
      temp = temp + M(121, 105) * M(105, 113)
      temp = temp + M(121, 106) * M(106, 113)
      temp = temp + M(121, 108) * M(108, 113)
      temp = temp + M(121, 109) * M(109, 113)
      temp = temp + M(121, 110) * M(110, 113)
      temp = temp + M(121, 111) * M(111, 113)
      temp = temp + M(121, 112) * M(112, 113)
      M(121, 113) = M(121, 113) - temp
C     Lower part.
      temp = M(122, 52) * M(52, 113)
      temp = temp + M(122, 53) * M(53, 113)
      temp = temp + M(122, 54) * M(54, 113)
      temp = temp + M(122, 55) * M(55, 113)
      temp = temp + M(122, 57) * M(57, 113)
      temp = temp + M(122, 58) * M(58, 113)
      temp = temp + M(122, 60) * M(60, 113)
      temp = temp + M(122, 63) * M(63, 113)
      temp = temp + M(122, 64) * M(64, 113)
      temp = temp + M(122, 65) * M(65, 113)
      temp = temp + M(122, 66) * M(66, 113)
      temp = temp + M(122, 67) * M(67, 113)
      temp = temp + M(122, 68) * M(68, 113)
      temp = temp + M(122, 69) * M(69, 113)
      temp = temp + M(122, 70) * M(70, 113)
      temp = temp + M(122, 71) * M(71, 113)
      temp = temp + M(122, 72) * M(72, 113)
      temp = temp + M(122, 73) * M(73, 113)
      temp = temp + M(122, 75) * M(75, 113)
      temp = temp + M(122, 76) * M(76, 113)
      temp = temp + M(122, 77) * M(77, 113)
      temp = temp + M(122, 78) * M(78, 113)
      temp = temp + M(122, 79) * M(79, 113)
      temp = temp + M(122, 80) * M(80, 113)
      temp = temp + M(122, 81) * M(81, 113)
      temp = temp + M(122, 82) * M(82, 113)
      temp = temp + M(122, 83) * M(83, 113)
      temp = temp + M(122, 84) * M(84, 113)
      temp = temp + M(122, 85) * M(85, 113)
      temp = temp + M(122, 87) * M(87, 113)
      temp = temp + M(122, 88) * M(88, 113)
      temp = temp + M(122, 90) * M(90, 113)
      temp = temp + M(122, 91) * M(91, 113)
      temp = temp + M(122, 92) * M(92, 113)
      temp = temp + M(122, 94) * M(94, 113)
      temp = temp + M(122, 95) * M(95, 113)
      temp = temp + M(122, 96) * M(96, 113)
      temp = temp + M(122, 97) * M(97, 113)
      temp = temp + M(122, 98) * M(98, 113)
      temp = temp + M(122, 100) * M(100, 113)
      temp = temp + M(122, 103) * M(103, 113)
      temp = temp + M(122, 104) * M(104, 113)
      temp = temp + M(122, 105) * M(105, 113)
      temp = temp + M(122, 106) * M(106, 113)
      temp = temp + M(122, 110) * M(110, 113)
      temp = temp + M(122, 111) * M(111, 113)
      temp = temp + M(122, 112) * M(112, 113)
      M(122, 113) = M(122, 113) - temp
C     Lower part.
      temp = M(123, 52) * M(52, 113)
      temp = temp + M(123, 53) * M(53, 113)
      temp = temp + M(123, 54) * M(54, 113)
      temp = temp + M(123, 55) * M(55, 113)
      temp = temp + M(123, 57) * M(57, 113)
      temp = temp + M(123, 58) * M(58, 113)
      temp = temp + M(123, 60) * M(60, 113)
      temp = temp + M(123, 63) * M(63, 113)
      temp = temp + M(123, 64) * M(64, 113)
      temp = temp + M(123, 66) * M(66, 113)
      temp = temp + M(123, 67) * M(67, 113)
      temp = temp + M(123, 71) * M(71, 113)
      temp = temp + M(123, 72) * M(72, 113)
      temp = temp + M(123, 76) * M(76, 113)
      temp = temp + M(123, 77) * M(77, 113)
      temp = temp + M(123, 78) * M(78, 113)
      temp = temp + M(123, 79) * M(79, 113)
      temp = temp + M(123, 80) * M(80, 113)
      temp = temp + M(123, 82) * M(82, 113)
      temp = temp + M(123, 84) * M(84, 113)
      temp = temp + M(123, 85) * M(85, 113)
      temp = temp + M(123, 87) * M(87, 113)
      temp = temp + M(123, 88) * M(88, 113)
      temp = temp + M(123, 90) * M(90, 113)
      temp = temp + M(123, 91) * M(91, 113)
      temp = temp + M(123, 92) * M(92, 113)
      temp = temp + M(123, 95) * M(95, 113)
      temp = temp + M(123, 96) * M(96, 113)
      temp = temp + M(123, 97) * M(97, 113)
      temp = temp + M(123, 98) * M(98, 113)
      temp = temp + M(123, 103) * M(103, 113)
      temp = temp + M(123, 104) * M(104, 113)
      temp = temp + M(123, 105) * M(105, 113)
      temp = temp + M(123, 106) * M(106, 113)
      temp = temp + M(123, 110) * M(110, 113)
      temp = temp + M(123, 111) * M(111, 113)
      temp = temp + M(123, 112) * M(112, 113)
      M(123, 113) = M(123, 113) - temp
C     Upper part.
      temp = M(113, 94) * M(94, 114)
      temp = temp + M(113, 106) * M(106, 114)
      M(113, 114) = ( M(113, 114) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 110) * M(110, 115)
      temp = temp + M(113, 111) * M(111, 115)
      temp = temp + M(113, 112) * M(112, 115)
      M(113, 115) = ( M(113, 115) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 25) * M(25, 117)
      temp = temp + M(113, 31) * M(31, 117)
      temp = temp + M(113, 38) * M(38, 117)
      temp = temp + M(113, 44) * M(44, 117)
      temp = temp + M(113, 52) * M(52, 117)
      temp = temp + M(113, 53) * M(53, 117)
      temp = temp + M(113, 54) * M(54, 117)
      temp = temp + M(113, 55) * M(55, 117)
      temp = temp + M(113, 57) * M(57, 117)
      temp = temp + M(113, 58) * M(58, 117)
      temp = temp + M(113, 60) * M(60, 117)
      temp = temp + M(113, 63) * M(63, 117)
      temp = temp + M(113, 64) * M(64, 117)
      temp = temp + M(113, 66) * M(66, 117)
      temp = temp + M(113, 67) * M(67, 117)
      temp = temp + M(113, 70) * M(70, 117)
      temp = temp + M(113, 71) * M(71, 117)
      temp = temp + M(113, 72) * M(72, 117)
      temp = temp + M(113, 73) * M(73, 117)
      temp = temp + M(113, 76) * M(76, 117)
      temp = temp + M(113, 77) * M(77, 117)
      temp = temp + M(113, 78) * M(78, 117)
      temp = temp + M(113, 79) * M(79, 117)
      temp = temp + M(113, 80) * M(80, 117)
      temp = temp + M(113, 81) * M(81, 117)
      temp = temp + M(113, 82) * M(82, 117)
      temp = temp + M(113, 83) * M(83, 117)
      temp = temp + M(113, 84) * M(84, 117)
      temp = temp + M(113, 85) * M(85, 117)
      temp = temp + M(113, 86) * M(86, 117)
      temp = temp + M(113, 87) * M(87, 117)
      temp = temp + M(113, 88) * M(88, 117)
      temp = temp + M(113, 90) * M(90, 117)
      temp = temp + M(113, 91) * M(91, 117)
      temp = temp + M(113, 92) * M(92, 117)
      temp = temp + M(113, 94) * M(94, 117)
      temp = temp + M(113, 95) * M(95, 117)
      temp = temp + M(113, 96) * M(96, 117)
      temp = temp + M(113, 97) * M(97, 117)
      temp = temp + M(113, 98) * M(98, 117)
      temp = temp + M(113, 103) * M(103, 117)
      temp = temp + M(113, 104) * M(104, 117)
      temp = temp + M(113, 105) * M(105, 117)
      temp = temp + M(113, 106) * M(106, 117)
      temp = temp + M(113, 110) * M(110, 117)
      temp = temp + M(113, 111) * M(111, 117)
      temp = temp + M(113, 112) * M(112, 117)
      M(113, 117) = ( M(113, 117) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 25) * M(25, 118)
      temp = temp + M(113, 31) * M(31, 118)
      temp = temp + M(113, 37) * M(37, 118)
      temp = temp + M(113, 38) * M(38, 118)
      temp = temp + M(113, 40) * M(40, 118)
      temp = temp + M(113, 41) * M(41, 118)
      temp = temp + M(113, 44) * M(44, 118)
      temp = temp + M(113, 52) * M(52, 118)
      temp = temp + M(113, 53) * M(53, 118)
      temp = temp + M(113, 54) * M(54, 118)
      temp = temp + M(113, 55) * M(55, 118)
      temp = temp + M(113, 57) * M(57, 118)
      temp = temp + M(113, 58) * M(58, 118)
      temp = temp + M(113, 60) * M(60, 118)
      temp = temp + M(113, 63) * M(63, 118)
      temp = temp + M(113, 64) * M(64, 118)
      temp = temp + M(113, 66) * M(66, 118)
      temp = temp + M(113, 67) * M(67, 118)
      temp = temp + M(113, 70) * M(70, 118)
      temp = temp + M(113, 71) * M(71, 118)
      temp = temp + M(113, 72) * M(72, 118)
      temp = temp + M(113, 73) * M(73, 118)
      temp = temp + M(113, 76) * M(76, 118)
      temp = temp + M(113, 77) * M(77, 118)
      temp = temp + M(113, 78) * M(78, 118)
      temp = temp + M(113, 79) * M(79, 118)
      temp = temp + M(113, 80) * M(80, 118)
      temp = temp + M(113, 81) * M(81, 118)
      temp = temp + M(113, 82) * M(82, 118)
      temp = temp + M(113, 83) * M(83, 118)
      temp = temp + M(113, 84) * M(84, 118)
      temp = temp + M(113, 85) * M(85, 118)
      temp = temp + M(113, 86) * M(86, 118)
      temp = temp + M(113, 87) * M(87, 118)
      temp = temp + M(113, 88) * M(88, 118)
      temp = temp + M(113, 90) * M(90, 118)
      temp = temp + M(113, 91) * M(91, 118)
      temp = temp + M(113, 92) * M(92, 118)
      temp = temp + M(113, 94) * M(94, 118)
      temp = temp + M(113, 95) * M(95, 118)
      temp = temp + M(113, 96) * M(96, 118)
      temp = temp + M(113, 97) * M(97, 118)
      temp = temp + M(113, 98) * M(98, 118)
      temp = temp + M(113, 103) * M(103, 118)
      temp = temp + M(113, 104) * M(104, 118)
      temp = temp + M(113, 105) * M(105, 118)
      temp = temp + M(113, 106) * M(106, 118)
      temp = temp + M(113, 110) * M(110, 118)
      temp = temp + M(113, 111) * M(111, 118)
      temp = temp + M(113, 112) * M(112, 118)
      M(113, 118) = ( M(113, 118) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 40) * M(40, 119)
      temp = temp + M(113, 54) * M(54, 119)
      temp = temp + M(113, 60) * M(60, 119)
      temp = temp + M(113, 63) * M(63, 119)
      temp = temp + M(113, 64) * M(64, 119)
      temp = temp + M(113, 66) * M(66, 119)
      temp = temp + M(113, 67) * M(67, 119)
      temp = temp + M(113, 70) * M(70, 119)
      temp = temp + M(113, 71) * M(71, 119)
      temp = temp + M(113, 72) * M(72, 119)
      temp = temp + M(113, 73) * M(73, 119)
      temp = temp + M(113, 76) * M(76, 119)
      temp = temp + M(113, 77) * M(77, 119)
      temp = temp + M(113, 78) * M(78, 119)
      temp = temp + M(113, 79) * M(79, 119)
      temp = temp + M(113, 80) * M(80, 119)
      temp = temp + M(113, 81) * M(81, 119)
      temp = temp + M(113, 82) * M(82, 119)
      temp = temp + M(113, 83) * M(83, 119)
      temp = temp + M(113, 84) * M(84, 119)
      temp = temp + M(113, 85) * M(85, 119)
      temp = temp + M(113, 86) * M(86, 119)
      temp = temp + M(113, 87) * M(87, 119)
      temp = temp + M(113, 88) * M(88, 119)
      temp = temp + M(113, 90) * M(90, 119)
      temp = temp + M(113, 91) * M(91, 119)
      temp = temp + M(113, 92) * M(92, 119)
      temp = temp + M(113, 94) * M(94, 119)
      temp = temp + M(113, 95) * M(95, 119)
      temp = temp + M(113, 96) * M(96, 119)
      temp = temp + M(113, 97) * M(97, 119)
      temp = temp + M(113, 98) * M(98, 119)
      temp = temp + M(113, 103) * M(103, 119)
      temp = temp + M(113, 104) * M(104, 119)
      temp = temp + M(113, 105) * M(105, 119)
      temp = temp + M(113, 106) * M(106, 119)
      temp = temp + M(113, 110) * M(110, 119)
      temp = temp + M(113, 111) * M(111, 119)
      temp = temp + M(113, 112) * M(112, 119)
      M(113, 119) = ( M(113, 119) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 70) * M(70, 120)
      temp = temp + M(113, 106) * M(106, 120)
      temp = temp + M(113, 112) * M(112, 120)
      M(113, 120) = ( M(113, 120) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 41) * M(41, 121)
      temp = temp + M(113, 66) * M(66, 121)
      temp = temp + M(113, 91) * M(91, 121)
      temp = temp + M(113, 92) * M(92, 121)
      temp = temp + M(113, 94) * M(94, 121)
      temp = temp + M(113, 95) * M(95, 121)
      temp = temp + M(113, 96) * M(96, 121)
      temp = temp + M(113, 97) * M(97, 121)
      temp = temp + M(113, 98) * M(98, 121)
      temp = temp + M(113, 104) * M(104, 121)
      temp = temp + M(113, 105) * M(105, 121)
      temp = temp + M(113, 106) * M(106, 121)
      temp = temp + M(113, 110) * M(110, 121)
      temp = temp + M(113, 111) * M(111, 121)
      temp = temp + M(113, 112) * M(112, 121)
      M(113, 121) = ( M(113, 121) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 41) * M(41, 122)
      temp = temp + M(113, 52) * M(52, 122)
      temp = temp + M(113, 53) * M(53, 122)
      temp = temp + M(113, 54) * M(54, 122)
      temp = temp + M(113, 55) * M(55, 122)
      temp = temp + M(113, 57) * M(57, 122)
      temp = temp + M(113, 58) * M(58, 122)
      temp = temp + M(113, 60) * M(60, 122)
      temp = temp + M(113, 63) * M(63, 122)
      temp = temp + M(113, 64) * M(64, 122)
      temp = temp + M(113, 66) * M(66, 122)
      temp = temp + M(113, 67) * M(67, 122)
      temp = temp + M(113, 70) * M(70, 122)
      temp = temp + M(113, 71) * M(71, 122)
      temp = temp + M(113, 72) * M(72, 122)
      temp = temp + M(113, 73) * M(73, 122)
      temp = temp + M(113, 76) * M(76, 122)
      temp = temp + M(113, 77) * M(77, 122)
      temp = temp + M(113, 78) * M(78, 122)
      temp = temp + M(113, 79) * M(79, 122)
      temp = temp + M(113, 80) * M(80, 122)
      temp = temp + M(113, 81) * M(81, 122)
      temp = temp + M(113, 82) * M(82, 122)
      temp = temp + M(113, 83) * M(83, 122)
      temp = temp + M(113, 84) * M(84, 122)
      temp = temp + M(113, 85) * M(85, 122)
      temp = temp + M(113, 86) * M(86, 122)
      temp = temp + M(113, 87) * M(87, 122)
      temp = temp + M(113, 88) * M(88, 122)
      temp = temp + M(113, 90) * M(90, 122)
      temp = temp + M(113, 91) * M(91, 122)
      temp = temp + M(113, 92) * M(92, 122)
      temp = temp + M(113, 94) * M(94, 122)
      temp = temp + M(113, 95) * M(95, 122)
      temp = temp + M(113, 96) * M(96, 122)
      temp = temp + M(113, 97) * M(97, 122)
      temp = temp + M(113, 98) * M(98, 122)
      temp = temp + M(113, 103) * M(103, 122)
      temp = temp + M(113, 104) * M(104, 122)
      temp = temp + M(113, 105) * M(105, 122)
      temp = temp + M(113, 106) * M(106, 122)
      temp = temp + M(113, 110) * M(110, 122)
      temp = temp + M(113, 111) * M(111, 122)
      temp = temp + M(113, 112) * M(112, 122)
      M(113, 122) = ( M(113, 122) - temp ) / M(113, 113)
C     Upper part.
      temp = M(113, 37) * M(37, 123)
      temp = temp + M(113, 52) * M(52, 123)
      temp = temp + M(113, 53) * M(53, 123)
      temp = temp + M(113, 54) * M(54, 123)
      temp = temp + M(113, 55) * M(55, 123)
      temp = temp + M(113, 57) * M(57, 123)
      temp = temp + M(113, 58) * M(58, 123)
      temp = temp + M(113, 60) * M(60, 123)
      temp = temp + M(113, 63) * M(63, 123)
      temp = temp + M(113, 64) * M(64, 123)
      temp = temp + M(113, 66) * M(66, 123)
      temp = temp + M(113, 67) * M(67, 123)
      temp = temp + M(113, 70) * M(70, 123)
      temp = temp + M(113, 71) * M(71, 123)
      temp = temp + M(113, 72) * M(72, 123)
      temp = temp + M(113, 73) * M(73, 123)
      temp = temp + M(113, 76) * M(76, 123)
      temp = temp + M(113, 77) * M(77, 123)
      temp = temp + M(113, 78) * M(78, 123)
      temp = temp + M(113, 79) * M(79, 123)
      temp = temp + M(113, 80) * M(80, 123)
      temp = temp + M(113, 81) * M(81, 123)
      temp = temp + M(113, 82) * M(82, 123)
      temp = temp + M(113, 83) * M(83, 123)
      temp = temp + M(113, 84) * M(84, 123)
      temp = temp + M(113, 85) * M(85, 123)
      temp = temp + M(113, 86) * M(86, 123)
      temp = temp + M(113, 87) * M(87, 123)
      temp = temp + M(113, 88) * M(88, 123)
      temp = temp + M(113, 90) * M(90, 123)
      temp = temp + M(113, 91) * M(91, 123)
      temp = temp + M(113, 92) * M(92, 123)
      temp = temp + M(113, 94) * M(94, 123)
      temp = temp + M(113, 95) * M(95, 123)
      temp = temp + M(113, 96) * M(96, 123)
      temp = temp + M(113, 97) * M(97, 123)
      temp = temp + M(113, 98) * M(98, 123)
      temp = temp + M(113, 103) * M(103, 123)
      temp = temp + M(113, 104) * M(104, 123)
      temp = temp + M(113, 105) * M(105, 123)
      temp = temp + M(113, 106) * M(106, 123)
      temp = temp + M(113, 110) * M(110, 123)
      temp = temp + M(113, 111) * M(111, 123)
      temp = temp + M(113, 112) * M(112, 123)
      M(113, 123) = ( M(113, 123) - temp ) / M(113, 113)

C     Lower part.
      temp = M(114, 113) * M(113, 114)
      M(114, 114) = M(114, 114) - temp
C     Lower part.
      temp = M(115, 106) * M(106, 114)
      temp = temp + M(115, 113) * M(113, 114)
      M(115, 114) = M(115, 114) - temp
C     Lower part.
      temp = M(116, 99) * M(99, 114)
      temp = temp + M(116, 106) * M(106, 114)
      temp = temp + M(116, 113) * M(113, 114)
      M(116, 114) = M(116, 114) - temp
C     Lower part.
      temp = M(117, 94) * M(94, 114)
      temp = temp + M(117, 101) * M(101, 114)
      temp = temp + M(117, 106) * M(106, 114)
      temp = temp + M(117, 113) * M(113, 114)
      M(117, 114) = M(117, 114) - temp
C     Lower part.
      temp = M(118, 26) * M(26, 114)
      temp = temp + M(118, 94) * M(94, 114)
      temp = temp + M(118, 99) * M(99, 114)
      temp = temp + M(118, 101) * M(101, 114)
      temp = temp + M(118, 106) * M(106, 114)
      temp = temp + M(118, 107) * M(107, 114)
      temp = temp + M(118, 113) * M(113, 114)
      M(118, 114) = M(118, 114) - temp
C     Lower part.
      temp = M(119, 26) * M(26, 114)
      temp = temp + M(119, 94) * M(94, 114)
      temp = temp + M(119, 99) * M(99, 114)
      temp = temp + M(119, 106) * M(106, 114)
      temp = temp + M(119, 107) * M(107, 114)
      temp = temp + M(119, 113) * M(113, 114)
      M(119, 114) = M(119, 114) - temp
C     Lower part.
      temp = M(120, 113) * M(113, 114)
      M(120, 114) = M(120, 114) - temp
C     Lower part.
      temp = M(121, 101) * M(101, 114)
      temp = temp + M(121, 106) * M(106, 114)
      temp = temp + M(121, 113) * M(113, 114)
      M(121, 114) = M(121, 114) - temp
C     Lower part.
      temp = M(122, 94) * M(94, 114)
      temp = temp + M(122, 106) * M(106, 114)
      temp = temp + M(122, 113) * M(113, 114)
      M(122, 114) = M(122, 114) - temp
C     Lower part.
      temp = M(123, 106) * M(106, 114)
      temp = temp + M(123, 113) * M(113, 114)
      M(123, 114) = M(123, 114) - temp
C     Upper part.
      temp = M(114, 109) * M(109, 115)
      temp = temp + M(114, 110) * M(110, 115)
      temp = temp + M(114, 111) * M(111, 115)
      temp = temp + M(114, 113) * M(113, 115)
      M(114, 115) = ( M(114, 115) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 21) * M(21, 117)
      temp = temp + M(114, 32) * M(32, 117)
      temp = temp + M(114, 38) * M(38, 117)
      temp = temp + M(114, 39) * M(39, 117)
      temp = temp + M(114, 76) * M(76, 117)
      temp = temp + M(114, 79) * M(79, 117)
      temp = temp + M(114, 86) * M(86, 117)
      temp = temp + M(114, 91) * M(91, 117)
      temp = temp + M(114, 92) * M(92, 117)
      temp = temp + M(114, 96) * M(96, 117)
      temp = temp + M(114, 109) * M(109, 117)
      temp = temp + M(114, 110) * M(110, 117)
      temp = temp + M(114, 111) * M(111, 117)
      temp = temp + M(114, 113) * M(113, 117)
      M(114, 117) = ( M(114, 117) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 21) * M(21, 118)
      temp = temp + M(114, 32) * M(32, 118)
      temp = temp + M(114, 37) * M(37, 118)
      temp = temp + M(114, 38) * M(38, 118)
      temp = temp + M(114, 39) * M(39, 118)
      temp = temp + M(114, 76) * M(76, 118)
      temp = temp + M(114, 79) * M(79, 118)
      temp = temp + M(114, 86) * M(86, 118)
      temp = temp + M(114, 91) * M(91, 118)
      temp = temp + M(114, 92) * M(92, 118)
      temp = temp + M(114, 96) * M(96, 118)
      temp = temp + M(114, 109) * M(109, 118)
      temp = temp + M(114, 110) * M(110, 118)
      temp = temp + M(114, 111) * M(111, 118)
      temp = temp + M(114, 113) * M(113, 118)
      M(114, 118) = ( M(114, 118) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 76) * M(76, 119)
      temp = temp + M(114, 79) * M(79, 119)
      temp = temp + M(114, 86) * M(86, 119)
      temp = temp + M(114, 91) * M(91, 119)
      temp = temp + M(114, 92) * M(92, 119)
      temp = temp + M(114, 96) * M(96, 119)
      temp = temp + M(114, 109) * M(109, 119)
      temp = temp + M(114, 110) * M(110, 119)
      temp = temp + M(114, 111) * M(111, 119)
      temp = temp + M(114, 113) * M(113, 119)
      M(114, 119) = ( M(114, 119) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 113) * M(113, 120)
      M(114, 120) = ( M(114, 120) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 91) * M(91, 121)
      temp = temp + M(114, 92) * M(92, 121)
      temp = temp + M(114, 96) * M(96, 121)
      temp = temp + M(114, 109) * M(109, 121)
      temp = temp + M(114, 110) * M(110, 121)
      temp = temp + M(114, 111) * M(111, 121)
      temp = temp + M(114, 113) * M(113, 121)
      M(114, 121) = ( M(114, 121) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 76) * M(76, 122)
      temp = temp + M(114, 79) * M(79, 122)
      temp = temp + M(114, 86) * M(86, 122)
      temp = temp + M(114, 91) * M(91, 122)
      temp = temp + M(114, 92) * M(92, 122)
      temp = temp + M(114, 96) * M(96, 122)
      temp = temp + M(114, 109) * M(109, 122)
      temp = temp + M(114, 110) * M(110, 122)
      temp = temp + M(114, 111) * M(111, 122)
      temp = temp + M(114, 113) * M(113, 122)
      M(114, 122) = ( M(114, 122) - temp ) / M(114, 114)
C     Upper part.
      temp = M(114, 37) * M(37, 123)
      temp = temp + M(114, 76) * M(76, 123)
      temp = temp + M(114, 79) * M(79, 123)
      temp = temp + M(114, 86) * M(86, 123)
      temp = temp + M(114, 91) * M(91, 123)
      temp = temp + M(114, 92) * M(92, 123)
      temp = temp + M(114, 96) * M(96, 123)
      temp = temp + M(114, 109) * M(109, 123)
      temp = temp + M(114, 110) * M(110, 123)
      temp = temp + M(114, 111) * M(111, 123)
      temp = temp + M(114, 113) * M(113, 123)
      M(114, 123) = ( M(114, 123) - temp ) / M(114, 114)

C     Lower part.
      temp = M(115, 110) * M(110, 115)
      temp = temp + M(115, 111) * M(111, 115)
      temp = temp + M(115, 112) * M(112, 115)
      temp = temp + M(115, 113) * M(113, 115)
      temp = temp + M(115, 114) * M(114, 115)
      M(115, 115) = M(115, 115) - temp
C     Lower part.
      temp = M(116, 110) * M(110, 115)
      temp = temp + M(116, 111) * M(111, 115)
      temp = temp + M(116, 112) * M(112, 115)
      temp = temp + M(116, 113) * M(113, 115)
      temp = temp + M(116, 114) * M(114, 115)
      M(116, 115) = M(116, 115) - temp
C     Lower part.
      temp = M(117, 109) * M(109, 115)
      temp = temp + M(117, 110) * M(110, 115)
      temp = temp + M(117, 111) * M(111, 115)
      temp = temp + M(117, 112) * M(112, 115)
      temp = temp + M(117, 113) * M(113, 115)
      temp = temp + M(117, 114) * M(114, 115)
      M(117, 115) = M(117, 115) - temp
C     Lower part.
      temp = M(118, 109) * M(109, 115)
      temp = temp + M(118, 110) * M(110, 115)
      temp = temp + M(118, 111) * M(111, 115)
      temp = temp + M(118, 113) * M(113, 115)
      temp = temp + M(118, 114) * M(114, 115)
      M(118, 115) = M(118, 115) - temp
C     Lower part.
      temp = M(119, 109) * M(109, 115)
      temp = temp + M(119, 110) * M(110, 115)
      temp = temp + M(119, 111) * M(111, 115)
      temp = temp + M(119, 112) * M(112, 115)
      temp = temp + M(119, 113) * M(113, 115)
      temp = temp + M(119, 114) * M(114, 115)
      M(119, 115) = M(119, 115) - temp
C     Lower part.
      temp = M(120, 109) * M(109, 115)
      temp = temp + M(120, 110) * M(110, 115)
      temp = temp + M(120, 111) * M(111, 115)
      temp = temp + M(120, 113) * M(113, 115)
      temp = temp + M(120, 114) * M(114, 115)
      M(120, 115) = M(120, 115) - temp
C     Lower part.
      temp = M(121, 109) * M(109, 115)
      temp = temp + M(121, 110) * M(110, 115)
      temp = temp + M(121, 111) * M(111, 115)
      temp = temp + M(121, 112) * M(112, 115)
      temp = temp + M(121, 113) * M(113, 115)
      temp = temp + M(121, 114) * M(114, 115)
      M(121, 115) = M(121, 115) - temp
C     Lower part.
      temp = M(122, 110) * M(110, 115)
      temp = temp + M(122, 111) * M(111, 115)
      temp = temp + M(122, 112) * M(112, 115)
      temp = temp + M(122, 113) * M(113, 115)
      temp = temp + M(122, 114) * M(114, 115)
      M(122, 115) = M(122, 115) - temp
C     Lower part.
      temp = M(123, 110) * M(110, 115)
      temp = temp + M(123, 111) * M(111, 115)
      temp = temp + M(123, 112) * M(112, 115)
      temp = temp + M(123, 113) * M(113, 115)
      temp = temp + M(123, 114) * M(114, 115)
      M(123, 115) = M(123, 115) - temp
C     Upper part.
      temp = M(115, 54) * M(54, 117)
      temp = temp + M(115, 60) * M(60, 117)
      temp = temp + M(115, 64) * M(64, 117)
      temp = temp + M(115, 66) * M(66, 117)
      temp = temp + M(115, 67) * M(67, 117)
      temp = temp + M(115, 71) * M(71, 117)
      temp = temp + M(115, 72) * M(72, 117)
      temp = temp + M(115, 76) * M(76, 117)
      temp = temp + M(115, 77) * M(77, 117)
      temp = temp + M(115, 78) * M(78, 117)
      temp = temp + M(115, 79) * M(79, 117)
      temp = temp + M(115, 82) * M(82, 117)
      temp = temp + M(115, 84) * M(84, 117)
      temp = temp + M(115, 85) * M(85, 117)
      temp = temp + M(115, 87) * M(87, 117)
      temp = temp + M(115, 91) * M(91, 117)
      temp = temp + M(115, 92) * M(92, 117)
      temp = temp + M(115, 95) * M(95, 117)
      temp = temp + M(115, 96) * M(96, 117)
      temp = temp + M(115, 97) * M(97, 117)
      temp = temp + M(115, 98) * M(98, 117)
      temp = temp + M(115, 103) * M(103, 117)
      temp = temp + M(115, 105) * M(105, 117)
      temp = temp + M(115, 106) * M(106, 117)
      temp = temp + M(115, 110) * M(110, 117)
      temp = temp + M(115, 111) * M(111, 117)
      temp = temp + M(115, 112) * M(112, 117)
      temp = temp + M(115, 113) * M(113, 117)
      temp = temp + M(115, 114) * M(114, 117)
      M(115, 117) = ( M(115, 117) - temp ) / M(115, 115)
C     Upper part.
      temp = M(115, 54) * M(54, 118)
      temp = temp + M(115, 60) * M(60, 118)
      temp = temp + M(115, 64) * M(64, 118)
      temp = temp + M(115, 66) * M(66, 118)
      temp = temp + M(115, 67) * M(67, 118)
      temp = temp + M(115, 71) * M(71, 118)
      temp = temp + M(115, 72) * M(72, 118)
      temp = temp + M(115, 76) * M(76, 118)
      temp = temp + M(115, 77) * M(77, 118)
      temp = temp + M(115, 78) * M(78, 118)
      temp = temp + M(115, 79) * M(79, 118)
      temp = temp + M(115, 82) * M(82, 118)
      temp = temp + M(115, 84) * M(84, 118)
      temp = temp + M(115, 85) * M(85, 118)
      temp = temp + M(115, 87) * M(87, 118)
      temp = temp + M(115, 91) * M(91, 118)
      temp = temp + M(115, 92) * M(92, 118)
      temp = temp + M(115, 95) * M(95, 118)
      temp = temp + M(115, 96) * M(96, 118)
      temp = temp + M(115, 97) * M(97, 118)
      temp = temp + M(115, 98) * M(98, 118)
      temp = temp + M(115, 103) * M(103, 118)
      temp = temp + M(115, 105) * M(105, 118)
      temp = temp + M(115, 106) * M(106, 118)
      temp = temp + M(115, 110) * M(110, 118)
      temp = temp + M(115, 111) * M(111, 118)
      temp = temp + M(115, 112) * M(112, 118)
      temp = temp + M(115, 113) * M(113, 118)
      temp = temp + M(115, 114) * M(114, 118)
      M(115, 118) = ( M(115, 118) - temp ) / M(115, 115)
C     Upper part.
      temp = M(115, 54) * M(54, 119)
      temp = temp + M(115, 60) * M(60, 119)
      temp = temp + M(115, 64) * M(64, 119)
      temp = temp + M(115, 66) * M(66, 119)
      temp = temp + M(115, 67) * M(67, 119)
      temp = temp + M(115, 71) * M(71, 119)
      temp = temp + M(115, 72) * M(72, 119)
      temp = temp + M(115, 76) * M(76, 119)
      temp = temp + M(115, 77) * M(77, 119)
      temp = temp + M(115, 78) * M(78, 119)
      temp = temp + M(115, 79) * M(79, 119)
      temp = temp + M(115, 82) * M(82, 119)
      temp = temp + M(115, 84) * M(84, 119)
      temp = temp + M(115, 85) * M(85, 119)
      temp = temp + M(115, 87) * M(87, 119)
      temp = temp + M(115, 91) * M(91, 119)
      temp = temp + M(115, 92) * M(92, 119)
      temp = temp + M(115, 95) * M(95, 119)
      temp = temp + M(115, 96) * M(96, 119)
      temp = temp + M(115, 97) * M(97, 119)
      temp = temp + M(115, 98) * M(98, 119)
      temp = temp + M(115, 103) * M(103, 119)
      temp = temp + M(115, 105) * M(105, 119)
      temp = temp + M(115, 106) * M(106, 119)
      temp = temp + M(115, 110) * M(110, 119)
      temp = temp + M(115, 111) * M(111, 119)
      temp = temp + M(115, 112) * M(112, 119)
      temp = temp + M(115, 113) * M(113, 119)
      temp = temp + M(115, 114) * M(114, 119)
      M(115, 119) = ( M(115, 119) - temp ) / M(115, 115)
C     Upper part.
      temp = M(115, 106) * M(106, 120)
      temp = temp + M(115, 112) * M(112, 120)
      temp = temp + M(115, 113) * M(113, 120)
      temp = temp + M(115, 114) * M(114, 120)
      M(115, 120) = ( M(115, 120) - temp ) / M(115, 115)
C     Upper part.
      temp = M(115, 66) * M(66, 121)
      temp = temp + M(115, 91) * M(91, 121)
      temp = temp + M(115, 92) * M(92, 121)
      temp = temp + M(115, 95) * M(95, 121)
      temp = temp + M(115, 96) * M(96, 121)
      temp = temp + M(115, 97) * M(97, 121)
      temp = temp + M(115, 98) * M(98, 121)
      temp = temp + M(115, 105) * M(105, 121)
      temp = temp + M(115, 106) * M(106, 121)
      temp = temp + M(115, 110) * M(110, 121)
      temp = temp + M(115, 111) * M(111, 121)
      temp = temp + M(115, 112) * M(112, 121)
      temp = temp + M(115, 113) * M(113, 121)
      temp = temp + M(115, 114) * M(114, 121)
      M(115, 121) = ( M(115, 121) - temp ) / M(115, 115)
C     Upper part.
      temp = M(115, 54) * M(54, 122)
      temp = temp + M(115, 60) * M(60, 122)
      temp = temp + M(115, 64) * M(64, 122)
      temp = temp + M(115, 66) * M(66, 122)
      temp = temp + M(115, 67) * M(67, 122)
      temp = temp + M(115, 71) * M(71, 122)
      temp = temp + M(115, 72) * M(72, 122)
      temp = temp + M(115, 76) * M(76, 122)
      temp = temp + M(115, 77) * M(77, 122)
      temp = temp + M(115, 78) * M(78, 122)
      temp = temp + M(115, 79) * M(79, 122)
      temp = temp + M(115, 82) * M(82, 122)
      temp = temp + M(115, 84) * M(84, 122)
      temp = temp + M(115, 85) * M(85, 122)
      temp = temp + M(115, 87) * M(87, 122)
      temp = temp + M(115, 91) * M(91, 122)
      temp = temp + M(115, 92) * M(92, 122)
      temp = temp + M(115, 95) * M(95, 122)
      temp = temp + M(115, 96) * M(96, 122)
      temp = temp + M(115, 97) * M(97, 122)
      temp = temp + M(115, 98) * M(98, 122)
      temp = temp + M(115, 103) * M(103, 122)
      temp = temp + M(115, 105) * M(105, 122)
      temp = temp + M(115, 106) * M(106, 122)
      temp = temp + M(115, 110) * M(110, 122)
      temp = temp + M(115, 111) * M(111, 122)
      temp = temp + M(115, 112) * M(112, 122)
      temp = temp + M(115, 113) * M(113, 122)
      temp = temp + M(115, 114) * M(114, 122)
      M(115, 122) = ( M(115, 122) - temp ) / M(115, 115)
C     Upper part.
      temp = M(115, 54) * M(54, 123)
      temp = temp + M(115, 60) * M(60, 123)
      temp = temp + M(115, 64) * M(64, 123)
      temp = temp + M(115, 66) * M(66, 123)
      temp = temp + M(115, 67) * M(67, 123)
      temp = temp + M(115, 71) * M(71, 123)
      temp = temp + M(115, 72) * M(72, 123)
      temp = temp + M(115, 76) * M(76, 123)
      temp = temp + M(115, 77) * M(77, 123)
      temp = temp + M(115, 78) * M(78, 123)
      temp = temp + M(115, 79) * M(79, 123)
      temp = temp + M(115, 82) * M(82, 123)
      temp = temp + M(115, 84) * M(84, 123)
      temp = temp + M(115, 85) * M(85, 123)
      temp = temp + M(115, 87) * M(87, 123)
      temp = temp + M(115, 91) * M(91, 123)
      temp = temp + M(115, 92) * M(92, 123)
      temp = temp + M(115, 95) * M(95, 123)
      temp = temp + M(115, 96) * M(96, 123)
      temp = temp + M(115, 97) * M(97, 123)
      temp = temp + M(115, 98) * M(98, 123)
      temp = temp + M(115, 103) * M(103, 123)
      temp = temp + M(115, 105) * M(105, 123)
      temp = temp + M(115, 106) * M(106, 123)
      temp = temp + M(115, 110) * M(110, 123)
      temp = temp + M(115, 111) * M(111, 123)
      temp = temp + M(115, 112) * M(112, 123)
      temp = temp + M(115, 113) * M(113, 123)
      temp = temp + M(115, 114) * M(114, 123)
      M(115, 123) = ( M(115, 123) - temp ) / M(115, 115)

C     Lower part.
      temp = M(117, 101) * M(101, 116)
      M(117, 116) = M(117, 116) - temp
C     Lower part.
      temp = M(118, 101) * M(101, 116)
      temp = temp + M(118, 107) * M(107, 116)
      M(118, 116) = M(118, 116) - temp
C     Lower part.
      temp = M(119, 107) * M(107, 116)
      M(119, 116) = M(119, 116) - temp
C     Lower part.
      temp = M(121, 101) * M(101, 116)
      M(121, 116) = M(121, 116) - temp
C     Upper part.
      temp = M(116, 25) * M(25, 117)
      temp = temp + M(116, 28) * M(28, 117)
      temp = temp + M(116, 31) * M(31, 117)
      temp = temp + M(116, 32) * M(32, 117)
      temp = temp + M(116, 38) * M(38, 117)
      temp = temp + M(116, 45) * M(45, 117)
      temp = temp + M(116, 52) * M(52, 117)
      temp = temp + M(116, 53) * M(53, 117)
      temp = temp + M(116, 54) * M(54, 117)
      temp = temp + M(116, 55) * M(55, 117)
      temp = temp + M(116, 57) * M(57, 117)
      temp = temp + M(116, 58) * M(58, 117)
      temp = temp + M(116, 60) * M(60, 117)
      temp = temp + M(116, 63) * M(63, 117)
      temp = temp + M(116, 64) * M(64, 117)
      temp = temp + M(116, 66) * M(66, 117)
      temp = temp + M(116, 67) * M(67, 117)
      temp = temp + M(116, 70) * M(70, 117)
      temp = temp + M(116, 71) * M(71, 117)
      temp = temp + M(116, 72) * M(72, 117)
      temp = temp + M(116, 75) * M(75, 117)
      temp = temp + M(116, 76) * M(76, 117)
      temp = temp + M(116, 77) * M(77, 117)
      temp = temp + M(116, 78) * M(78, 117)
      temp = temp + M(116, 79) * M(79, 117)
      temp = temp + M(116, 80) * M(80, 117)
      temp = temp + M(116, 81) * M(81, 117)
      temp = temp + M(116, 82) * M(82, 117)
      temp = temp + M(116, 83) * M(83, 117)
      temp = temp + M(116, 84) * M(84, 117)
      temp = temp + M(116, 85) * M(85, 117)
      temp = temp + M(116, 86) * M(86, 117)
      temp = temp + M(116, 87) * M(87, 117)
      temp = temp + M(116, 88) * M(88, 117)
      temp = temp + M(116, 90) * M(90, 117)
      temp = temp + M(116, 91) * M(91, 117)
      temp = temp + M(116, 92) * M(92, 117)
      temp = temp + M(116, 95) * M(95, 117)
      temp = temp + M(116, 96) * M(96, 117)
      temp = temp + M(116, 97) * M(97, 117)
      temp = temp + M(116, 98) * M(98, 117)
      temp = temp + M(116, 99) * M(99, 117)
      temp = temp + M(116, 102) * M(102, 117)
      temp = temp + M(116, 103) * M(103, 117)
      temp = temp + M(116, 104) * M(104, 117)
      temp = temp + M(116, 105) * M(105, 117)
      temp = temp + M(116, 106) * M(106, 117)
      temp = temp + M(116, 110) * M(110, 117)
      temp = temp + M(116, 111) * M(111, 117)
      temp = temp + M(116, 112) * M(112, 117)
      temp = temp + M(116, 113) * M(113, 117)
      temp = temp + M(116, 114) * M(114, 117)
      temp = temp + M(116, 115) * M(115, 117)
      M(116, 117) = ( M(116, 117) - temp ) / M(116, 116)
C     Upper part.
      temp = M(116, 19) * M(19, 118)
      temp = temp + M(116, 25) * M(25, 118)
      temp = temp + M(116, 28) * M(28, 118)
      temp = temp + M(116, 31) * M(31, 118)
      temp = temp + M(116, 32) * M(32, 118)
      temp = temp + M(116, 38) * M(38, 118)
      temp = temp + M(116, 40) * M(40, 118)
      temp = temp + M(116, 41) * M(41, 118)
      temp = temp + M(116, 42) * M(42, 118)
      temp = temp + M(116, 45) * M(45, 118)
      temp = temp + M(116, 52) * M(52, 118)
      temp = temp + M(116, 53) * M(53, 118)
      temp = temp + M(116, 54) * M(54, 118)
      temp = temp + M(116, 55) * M(55, 118)
      temp = temp + M(116, 57) * M(57, 118)
      temp = temp + M(116, 58) * M(58, 118)
      temp = temp + M(116, 60) * M(60, 118)
      temp = temp + M(116, 63) * M(63, 118)
      temp = temp + M(116, 64) * M(64, 118)
      temp = temp + M(116, 66) * M(66, 118)
      temp = temp + M(116, 67) * M(67, 118)
      temp = temp + M(116, 70) * M(70, 118)
      temp = temp + M(116, 71) * M(71, 118)
      temp = temp + M(116, 72) * M(72, 118)
      temp = temp + M(116, 75) * M(75, 118)
      temp = temp + M(116, 76) * M(76, 118)
      temp = temp + M(116, 77) * M(77, 118)
      temp = temp + M(116, 78) * M(78, 118)
      temp = temp + M(116, 79) * M(79, 118)
      temp = temp + M(116, 80) * M(80, 118)
      temp = temp + M(116, 81) * M(81, 118)
      temp = temp + M(116, 82) * M(82, 118)
      temp = temp + M(116, 83) * M(83, 118)
      temp = temp + M(116, 84) * M(84, 118)
      temp = temp + M(116, 85) * M(85, 118)
      temp = temp + M(116, 86) * M(86, 118)
      temp = temp + M(116, 87) * M(87, 118)
      temp = temp + M(116, 88) * M(88, 118)
      temp = temp + M(116, 90) * M(90, 118)
      temp = temp + M(116, 91) * M(91, 118)
      temp = temp + M(116, 92) * M(92, 118)
      temp = temp + M(116, 95) * M(95, 118)
      temp = temp + M(116, 96) * M(96, 118)
      temp = temp + M(116, 97) * M(97, 118)
      temp = temp + M(116, 98) * M(98, 118)
      temp = temp + M(116, 99) * M(99, 118)
      temp = temp + M(116, 102) * M(102, 118)
      temp = temp + M(116, 103) * M(103, 118)
      temp = temp + M(116, 104) * M(104, 118)
      temp = temp + M(116, 105) * M(105, 118)
      temp = temp + M(116, 106) * M(106, 118)
      temp = temp + M(116, 110) * M(110, 118)
      temp = temp + M(116, 111) * M(111, 118)
      temp = temp + M(116, 112) * M(112, 118)
      temp = temp + M(116, 113) * M(113, 118)
      temp = temp + M(116, 114) * M(114, 118)
      temp = temp + M(116, 115) * M(115, 118)
      M(116, 118) = ( M(116, 118) - temp ) / M(116, 116)
C     Upper part.
      temp = M(116, 40) * M(40, 119)
      temp = temp + M(116, 54) * M(54, 119)
      temp = temp + M(116, 60) * M(60, 119)
      temp = temp + M(116, 63) * M(63, 119)
      temp = temp + M(116, 64) * M(64, 119)
      temp = temp + M(116, 66) * M(66, 119)
      temp = temp + M(116, 67) * M(67, 119)
      temp = temp + M(116, 70) * M(70, 119)
      temp = temp + M(116, 71) * M(71, 119)
      temp = temp + M(116, 72) * M(72, 119)
      temp = temp + M(116, 76) * M(76, 119)
      temp = temp + M(116, 77) * M(77, 119)
      temp = temp + M(116, 78) * M(78, 119)
      temp = temp + M(116, 79) * M(79, 119)
      temp = temp + M(116, 80) * M(80, 119)
      temp = temp + M(116, 81) * M(81, 119)
      temp = temp + M(116, 82) * M(82, 119)
      temp = temp + M(116, 83) * M(83, 119)
      temp = temp + M(116, 84) * M(84, 119)
      temp = temp + M(116, 85) * M(85, 119)
      temp = temp + M(116, 86) * M(86, 119)
      temp = temp + M(116, 87) * M(87, 119)
      temp = temp + M(116, 88) * M(88, 119)
      temp = temp + M(116, 90) * M(90, 119)
      temp = temp + M(116, 91) * M(91, 119)
      temp = temp + M(116, 92) * M(92, 119)
      temp = temp + M(116, 95) * M(95, 119)
      temp = temp + M(116, 96) * M(96, 119)
      temp = temp + M(116, 97) * M(97, 119)
      temp = temp + M(116, 98) * M(98, 119)
      temp = temp + M(116, 99) * M(99, 119)
      temp = temp + M(116, 102) * M(102, 119)
      temp = temp + M(116, 103) * M(103, 119)
      temp = temp + M(116, 104) * M(104, 119)
      temp = temp + M(116, 105) * M(105, 119)
      temp = temp + M(116, 106) * M(106, 119)
      temp = temp + M(116, 110) * M(110, 119)
      temp = temp + M(116, 111) * M(111, 119)
      temp = temp + M(116, 112) * M(112, 119)
      temp = temp + M(116, 113) * M(113, 119)
      temp = temp + M(116, 114) * M(114, 119)
      temp = temp + M(116, 115) * M(115, 119)
      M(116, 119) = ( M(116, 119) - temp ) / M(116, 116)
C     Upper part.
      temp = M(116, 42) * M(42, 120)
      temp = temp + M(116, 70) * M(70, 120)
      temp = temp + M(116, 106) * M(106, 120)
      temp = temp + M(116, 112) * M(112, 120)
      temp = temp + M(116, 113) * M(113, 120)
      temp = temp + M(116, 114) * M(114, 120)
      temp = temp + M(116, 115) * M(115, 120)
      M(116, 120) = ( M(116, 120) - temp ) / M(116, 116)
C     Upper part.
      temp = M(116, 41) * M(41, 121)
      temp = temp + M(116, 42) * M(42, 121)
      temp = temp + M(116, 66) * M(66, 121)
      temp = temp + M(116, 91) * M(91, 121)
      temp = temp + M(116, 92) * M(92, 121)
      temp = temp + M(116, 95) * M(95, 121)
      temp = temp + M(116, 96) * M(96, 121)
      temp = temp + M(116, 97) * M(97, 121)
      temp = temp + M(116, 98) * M(98, 121)
      temp = temp + M(116, 99) * M(99, 121)
      temp = temp + M(116, 102) * M(102, 121)
      temp = temp + M(116, 104) * M(104, 121)
      temp = temp + M(116, 105) * M(105, 121)
      temp = temp + M(116, 106) * M(106, 121)
      temp = temp + M(116, 110) * M(110, 121)
      temp = temp + M(116, 111) * M(111, 121)
      temp = temp + M(116, 112) * M(112, 121)
      temp = temp + M(116, 113) * M(113, 121)
      temp = temp + M(116, 114) * M(114, 121)
      temp = temp + M(116, 115) * M(115, 121)
      M(116, 121) = ( M(116, 121) - temp ) / M(116, 116)
C     Upper part.
      temp = M(116, 41) * M(41, 122)
      temp = temp + M(116, 52) * M(52, 122)
      temp = temp + M(116, 53) * M(53, 122)
      temp = temp + M(116, 54) * M(54, 122)
      temp = temp + M(116, 55) * M(55, 122)
      temp = temp + M(116, 57) * M(57, 122)
      temp = temp + M(116, 58) * M(58, 122)
      temp = temp + M(116, 60) * M(60, 122)
      temp = temp + M(116, 63) * M(63, 122)
      temp = temp + M(116, 64) * M(64, 122)
      temp = temp + M(116, 66) * M(66, 122)
      temp = temp + M(116, 67) * M(67, 122)
      temp = temp + M(116, 70) * M(70, 122)
      temp = temp + M(116, 71) * M(71, 122)
      temp = temp + M(116, 72) * M(72, 122)
      temp = temp + M(116, 75) * M(75, 122)
      temp = temp + M(116, 76) * M(76, 122)
      temp = temp + M(116, 77) * M(77, 122)
      temp = temp + M(116, 78) * M(78, 122)
      temp = temp + M(116, 79) * M(79, 122)
      temp = temp + M(116, 80) * M(80, 122)
      temp = temp + M(116, 81) * M(81, 122)
      temp = temp + M(116, 82) * M(82, 122)
      temp = temp + M(116, 83) * M(83, 122)
      temp = temp + M(116, 84) * M(84, 122)
      temp = temp + M(116, 85) * M(85, 122)
      temp = temp + M(116, 86) * M(86, 122)
      temp = temp + M(116, 87) * M(87, 122)
      temp = temp + M(116, 88) * M(88, 122)
      temp = temp + M(116, 90) * M(90, 122)
      temp = temp + M(116, 91) * M(91, 122)
      temp = temp + M(116, 92) * M(92, 122)
      temp = temp + M(116, 95) * M(95, 122)
      temp = temp + M(116, 96) * M(96, 122)
      temp = temp + M(116, 97) * M(97, 122)
      temp = temp + M(116, 98) * M(98, 122)
      temp = temp + M(116, 99) * M(99, 122)
      temp = temp + M(116, 102) * M(102, 122)
      temp = temp + M(116, 103) * M(103, 122)
      temp = temp + M(116, 104) * M(104, 122)
      temp = temp + M(116, 105) * M(105, 122)
      temp = temp + M(116, 106) * M(106, 122)
      temp = temp + M(116, 110) * M(110, 122)
      temp = temp + M(116, 111) * M(111, 122)
      temp = temp + M(116, 112) * M(112, 122)
      temp = temp + M(116, 113) * M(113, 122)
      temp = temp + M(116, 114) * M(114, 122)
      temp = temp + M(116, 115) * M(115, 122)
      M(116, 122) = ( M(116, 122) - temp ) / M(116, 116)
C     Upper part.
      temp = M(116, 45) * M(45, 123)
      temp = temp + M(116, 52) * M(52, 123)
      temp = temp + M(116, 53) * M(53, 123)
      temp = temp + M(116, 54) * M(54, 123)
      temp = temp + M(116, 55) * M(55, 123)
      temp = temp + M(116, 57) * M(57, 123)
      temp = temp + M(116, 58) * M(58, 123)
      temp = temp + M(116, 60) * M(60, 123)
      temp = temp + M(116, 63) * M(63, 123)
      temp = temp + M(116, 64) * M(64, 123)
      temp = temp + M(116, 66) * M(66, 123)
      temp = temp + M(116, 67) * M(67, 123)
      temp = temp + M(116, 70) * M(70, 123)
      temp = temp + M(116, 71) * M(71, 123)
      temp = temp + M(116, 72) * M(72, 123)
      temp = temp + M(116, 75) * M(75, 123)
      temp = temp + M(116, 76) * M(76, 123)
      temp = temp + M(116, 77) * M(77, 123)
      temp = temp + M(116, 78) * M(78, 123)
      temp = temp + M(116, 79) * M(79, 123)
      temp = temp + M(116, 80) * M(80, 123)
      temp = temp + M(116, 81) * M(81, 123)
      temp = temp + M(116, 82) * M(82, 123)
      temp = temp + M(116, 83) * M(83, 123)
      temp = temp + M(116, 84) * M(84, 123)
      temp = temp + M(116, 85) * M(85, 123)
      temp = temp + M(116, 86) * M(86, 123)
      temp = temp + M(116, 87) * M(87, 123)
      temp = temp + M(116, 88) * M(88, 123)
      temp = temp + M(116, 90) * M(90, 123)
      temp = temp + M(116, 91) * M(91, 123)
      temp = temp + M(116, 92) * M(92, 123)
      temp = temp + M(116, 95) * M(95, 123)
      temp = temp + M(116, 96) * M(96, 123)
      temp = temp + M(116, 97) * M(97, 123)
      temp = temp + M(116, 98) * M(98, 123)
      temp = temp + M(116, 99) * M(99, 123)
      temp = temp + M(116, 102) * M(102, 123)
      temp = temp + M(116, 103) * M(103, 123)
      temp = temp + M(116, 104) * M(104, 123)
      temp = temp + M(116, 105) * M(105, 123)
      temp = temp + M(116, 106) * M(106, 123)
      temp = temp + M(116, 110) * M(110, 123)
      temp = temp + M(116, 111) * M(111, 123)
      temp = temp + M(116, 112) * M(112, 123)
      temp = temp + M(116, 113) * M(113, 123)
      temp = temp + M(116, 114) * M(114, 123)
      temp = temp + M(116, 115) * M(115, 123)
      M(116, 123) = ( M(116, 123) - temp ) / M(116, 116)

C     Lower part.
      temp = M(117, 18) * M(18, 117)
      temp = temp + M(117, 20) * M(20, 117)
      temp = temp + M(117, 21) * M(21, 117)
      temp = temp + M(117, 25) * M(25, 117)
      temp = temp + M(117, 27) * M(27, 117)
      temp = temp + M(117, 28) * M(28, 117)
      temp = temp + M(117, 31) * M(31, 117)
      temp = temp + M(117, 32) * M(32, 117)
      temp = temp + M(117, 36) * M(36, 117)
      temp = temp + M(117, 38) * M(38, 117)
      temp = temp + M(117, 46) * M(46, 117)
      temp = temp + M(117, 47) * M(47, 117)
      temp = temp + M(117, 52) * M(52, 117)
      temp = temp + M(117, 53) * M(53, 117)
      temp = temp + M(117, 54) * M(54, 117)
      temp = temp + M(117, 55) * M(55, 117)
      temp = temp + M(117, 57) * M(57, 117)
      temp = temp + M(117, 58) * M(58, 117)
      temp = temp + M(117, 60) * M(60, 117)
      temp = temp + M(117, 61) * M(61, 117)
      temp = temp + M(117, 62) * M(62, 117)
      temp = temp + M(117, 63) * M(63, 117)
      temp = temp + M(117, 64) * M(64, 117)
      temp = temp + M(117, 66) * M(66, 117)
      temp = temp + M(117, 67) * M(67, 117)
      temp = temp + M(117, 71) * M(71, 117)
      temp = temp + M(117, 72) * M(72, 117)
      temp = temp + M(117, 76) * M(76, 117)
      temp = temp + M(117, 77) * M(77, 117)
      temp = temp + M(117, 78) * M(78, 117)
      temp = temp + M(117, 79) * M(79, 117)
      temp = temp + M(117, 80) * M(80, 117)
      temp = temp + M(117, 82) * M(82, 117)
      temp = temp + M(117, 83) * M(83, 117)
      temp = temp + M(117, 84) * M(84, 117)
      temp = temp + M(117, 85) * M(85, 117)
      temp = temp + M(117, 86) * M(86, 117)
      temp = temp + M(117, 87) * M(87, 117)
      temp = temp + M(117, 88) * M(88, 117)
      temp = temp + M(117, 90) * M(90, 117)
      temp = temp + M(117, 91) * M(91, 117)
      temp = temp + M(117, 92) * M(92, 117)
      temp = temp + M(117, 94) * M(94, 117)
      temp = temp + M(117, 95) * M(95, 117)
      temp = temp + M(117, 96) * M(96, 117)
      temp = temp + M(117, 97) * M(97, 117)
      temp = temp + M(117, 98) * M(98, 117)
      temp = temp + M(117, 100) * M(100, 117)
      temp = temp + M(117, 101) * M(101, 117)
      temp = temp + M(117, 102) * M(102, 117)
      temp = temp + M(117, 103) * M(103, 117)
      temp = temp + M(117, 104) * M(104, 117)
      temp = temp + M(117, 105) * M(105, 117)
      temp = temp + M(117, 106) * M(106, 117)
      temp = temp + M(117, 109) * M(109, 117)
      temp = temp + M(117, 110) * M(110, 117)
      temp = temp + M(117, 111) * M(111, 117)
      temp = temp + M(117, 112) * M(112, 117)
      temp = temp + M(117, 113) * M(113, 117)
      temp = temp + M(117, 114) * M(114, 117)
      temp = temp + M(117, 115) * M(115, 117)
      temp = temp + M(117, 116) * M(116, 117)
      M(117, 117) = M(117, 117) - temp
C     Lower part.
      temp = M(118, 20) * M(20, 117)
      temp = temp + M(118, 21) * M(21, 117)
      temp = temp + M(118, 25) * M(25, 117)
      temp = temp + M(118, 27) * M(27, 117)
      temp = temp + M(118, 28) * M(28, 117)
      temp = temp + M(118, 31) * M(31, 117)
      temp = temp + M(118, 32) * M(32, 117)
      temp = temp + M(118, 36) * M(36, 117)
      temp = temp + M(118, 38) * M(38, 117)
      temp = temp + M(118, 39) * M(39, 117)
      temp = temp + M(118, 44) * M(44, 117)
      temp = temp + M(118, 45) * M(45, 117)
      temp = temp + M(118, 46) * M(46, 117)
      temp = temp + M(118, 51) * M(51, 117)
      temp = temp + M(118, 54) * M(54, 117)
      temp = temp + M(118, 56) * M(56, 117)
      temp = temp + M(118, 60) * M(60, 117)
      temp = temp + M(118, 61) * M(61, 117)
      temp = temp + M(118, 62) * M(62, 117)
      temp = temp + M(118, 64) * M(64, 117)
      temp = temp + M(118, 65) * M(65, 117)
      temp = temp + M(118, 68) * M(68, 117)
      temp = temp + M(118, 69) * M(69, 117)
      temp = temp + M(118, 70) * M(70, 117)
      temp = temp + M(118, 73) * M(73, 117)
      temp = temp + M(118, 74) * M(74, 117)
      temp = temp + M(118, 75) * M(75, 117)
      temp = temp + M(118, 76) * M(76, 117)
      temp = temp + M(118, 78) * M(78, 117)
      temp = temp + M(118, 80) * M(80, 117)
      temp = temp + M(118, 81) * M(81, 117)
      temp = temp + M(118, 83) * M(83, 117)
      temp = temp + M(118, 85) * M(85, 117)
      temp = temp + M(118, 86) * M(86, 117)
      temp = temp + M(118, 89) * M(89, 117)
      temp = temp + M(118, 90) * M(90, 117)
      temp = temp + M(118, 91) * M(91, 117)
      temp = temp + M(118, 92) * M(92, 117)
      temp = temp + M(118, 93) * M(93, 117)
      temp = temp + M(118, 94) * M(94, 117)
      temp = temp + M(118, 96) * M(96, 117)
      temp = temp + M(118, 97) * M(97, 117)
      temp = temp + M(118, 98) * M(98, 117)
      temp = temp + M(118, 99) * M(99, 117)
      temp = temp + M(118, 100) * M(100, 117)
      temp = temp + M(118, 101) * M(101, 117)
      temp = temp + M(118, 102) * M(102, 117)
      temp = temp + M(118, 103) * M(103, 117)
      temp = temp + M(118, 104) * M(104, 117)
      temp = temp + M(118, 105) * M(105, 117)
      temp = temp + M(118, 106) * M(106, 117)
      temp = temp + M(118, 107) * M(107, 117)
      temp = temp + M(118, 108) * M(108, 117)
      temp = temp + M(118, 109) * M(109, 117)
      temp = temp + M(118, 110) * M(110, 117)
      temp = temp + M(118, 111) * M(111, 117)
      temp = temp + M(118, 113) * M(113, 117)
      temp = temp + M(118, 114) * M(114, 117)
      temp = temp + M(118, 115) * M(115, 117)
      temp = temp + M(118, 116) * M(116, 117)
      M(118, 117) = M(118, 117) - temp
C     Lower part.
      temp = M(119, 20) * M(20, 117)
      temp = temp + M(119, 21) * M(21, 117)
      temp = temp + M(119, 25) * M(25, 117)
      temp = temp + M(119, 27) * M(27, 117)
      temp = temp + M(119, 28) * M(28, 117)
      temp = temp + M(119, 31) * M(31, 117)
      temp = temp + M(119, 32) * M(32, 117)
      temp = temp + M(119, 38) * M(38, 117)
      temp = temp + M(119, 51) * M(51, 117)
      temp = temp + M(119, 52) * M(52, 117)
      temp = temp + M(119, 53) * M(53, 117)
      temp = temp + M(119, 54) * M(54, 117)
      temp = temp + M(119, 55) * M(55, 117)
      temp = temp + M(119, 56) * M(56, 117)
      temp = temp + M(119, 57) * M(57, 117)
      temp = temp + M(119, 58) * M(58, 117)
      temp = temp + M(119, 60) * M(60, 117)
      temp = temp + M(119, 61) * M(61, 117)
      temp = temp + M(119, 62) * M(62, 117)
      temp = temp + M(119, 63) * M(63, 117)
      temp = temp + M(119, 64) * M(64, 117)
      temp = temp + M(119, 65) * M(65, 117)
      temp = temp + M(119, 66) * M(66, 117)
      temp = temp + M(119, 67) * M(67, 117)
      temp = temp + M(119, 68) * M(68, 117)
      temp = temp + M(119, 69) * M(69, 117)
      temp = temp + M(119, 71) * M(71, 117)
      temp = temp + M(119, 72) * M(72, 117)
      temp = temp + M(119, 74) * M(74, 117)
      temp = temp + M(119, 75) * M(75, 117)
      temp = temp + M(119, 76) * M(76, 117)
      temp = temp + M(119, 77) * M(77, 117)
      temp = temp + M(119, 78) * M(78, 117)
      temp = temp + M(119, 79) * M(79, 117)
      temp = temp + M(119, 80) * M(80, 117)
      temp = temp + M(119, 81) * M(81, 117)
      temp = temp + M(119, 82) * M(82, 117)
      temp = temp + M(119, 83) * M(83, 117)
      temp = temp + M(119, 84) * M(84, 117)
      temp = temp + M(119, 85) * M(85, 117)
      temp = temp + M(119, 86) * M(86, 117)
      temp = temp + M(119, 87) * M(87, 117)
      temp = temp + M(119, 88) * M(88, 117)
      temp = temp + M(119, 89) * M(89, 117)
      temp = temp + M(119, 90) * M(90, 117)
      temp = temp + M(119, 91) * M(91, 117)
      temp = temp + M(119, 92) * M(92, 117)
      temp = temp + M(119, 93) * M(93, 117)
      temp = temp + M(119, 94) * M(94, 117)
      temp = temp + M(119, 95) * M(95, 117)
      temp = temp + M(119, 96) * M(96, 117)
      temp = temp + M(119, 97) * M(97, 117)
      temp = temp + M(119, 98) * M(98, 117)
      temp = temp + M(119, 99) * M(99, 117)
      temp = temp + M(119, 100) * M(100, 117)
      temp = temp + M(119, 102) * M(102, 117)
      temp = temp + M(119, 103) * M(103, 117)
      temp = temp + M(119, 104) * M(104, 117)
      temp = temp + M(119, 105) * M(105, 117)
      temp = temp + M(119, 106) * M(106, 117)
      temp = temp + M(119, 107) * M(107, 117)
      temp = temp + M(119, 108) * M(108, 117)
      temp = temp + M(119, 109) * M(109, 117)
      temp = temp + M(119, 110) * M(110, 117)
      temp = temp + M(119, 111) * M(111, 117)
      temp = temp + M(119, 112) * M(112, 117)
      temp = temp + M(119, 113) * M(113, 117)
      temp = temp + M(119, 114) * M(114, 117)
      temp = temp + M(119, 115) * M(115, 117)
      temp = temp + M(119, 116) * M(116, 117)
      M(119, 117) = M(119, 117) - temp
C     Lower part.
      temp = M(120, 109) * M(109, 117)
      temp = temp + M(120, 110) * M(110, 117)
      temp = temp + M(120, 111) * M(111, 117)
      temp = temp + M(120, 113) * M(113, 117)
      temp = temp + M(120, 114) * M(114, 117)
      temp = temp + M(120, 115) * M(115, 117)
      M(120, 117) = M(120, 117) - temp
C     Lower part.
      temp = M(121, 18) * M(18, 117)
      temp = temp + M(121, 27) * M(27, 117)
      temp = temp + M(121, 45) * M(45, 117)
      temp = temp + M(121, 46) * M(46, 117)
      temp = temp + M(121, 47) * M(47, 117)
      temp = temp + M(121, 52) * M(52, 117)
      temp = temp + M(121, 53) * M(53, 117)
      temp = temp + M(121, 54) * M(54, 117)
      temp = temp + M(121, 55) * M(55, 117)
      temp = temp + M(121, 57) * M(57, 117)
      temp = temp + M(121, 58) * M(58, 117)
      temp = temp + M(121, 59) * M(59, 117)
      temp = temp + M(121, 60) * M(60, 117)
      temp = temp + M(121, 62) * M(62, 117)
      temp = temp + M(121, 63) * M(63, 117)
      temp = temp + M(121, 64) * M(64, 117)
      temp = temp + M(121, 66) * M(66, 117)
      temp = temp + M(121, 67) * M(67, 117)
      temp = temp + M(121, 71) * M(71, 117)
      temp = temp + M(121, 72) * M(72, 117)
      temp = temp + M(121, 76) * M(76, 117)
      temp = temp + M(121, 77) * M(77, 117)
      temp = temp + M(121, 78) * M(78, 117)
      temp = temp + M(121, 79) * M(79, 117)
      temp = temp + M(121, 80) * M(80, 117)
      temp = temp + M(121, 82) * M(82, 117)
      temp = temp + M(121, 84) * M(84, 117)
      temp = temp + M(121, 85) * M(85, 117)
      temp = temp + M(121, 87) * M(87, 117)
      temp = temp + M(121, 88) * M(88, 117)
      temp = temp + M(121, 90) * M(90, 117)
      temp = temp + M(121, 91) * M(91, 117)
      temp = temp + M(121, 92) * M(92, 117)
      temp = temp + M(121, 95) * M(95, 117)
      temp = temp + M(121, 96) * M(96, 117)
      temp = temp + M(121, 97) * M(97, 117)
      temp = temp + M(121, 98) * M(98, 117)
      temp = temp + M(121, 101) * M(101, 117)
      temp = temp + M(121, 102) * M(102, 117)
      temp = temp + M(121, 103) * M(103, 117)
      temp = temp + M(121, 104) * M(104, 117)
      temp = temp + M(121, 105) * M(105, 117)
      temp = temp + M(121, 106) * M(106, 117)
      temp = temp + M(121, 108) * M(108, 117)
      temp = temp + M(121, 109) * M(109, 117)
      temp = temp + M(121, 110) * M(110, 117)
      temp = temp + M(121, 111) * M(111, 117)
      temp = temp + M(121, 112) * M(112, 117)
      temp = temp + M(121, 113) * M(113, 117)
      temp = temp + M(121, 114) * M(114, 117)
      temp = temp + M(121, 115) * M(115, 117)
      temp = temp + M(121, 116) * M(116, 117)
      M(121, 117) = M(121, 117) - temp
C     Lower part.
      temp = M(122, 25) * M(25, 117)
      temp = temp + M(122, 31) * M(31, 117)
      temp = temp + M(122, 52) * M(52, 117)
      temp = temp + M(122, 53) * M(53, 117)
      temp = temp + M(122, 54) * M(54, 117)
      temp = temp + M(122, 55) * M(55, 117)
      temp = temp + M(122, 57) * M(57, 117)
      temp = temp + M(122, 58) * M(58, 117)
      temp = temp + M(122, 60) * M(60, 117)
      temp = temp + M(122, 63) * M(63, 117)
      temp = temp + M(122, 64) * M(64, 117)
      temp = temp + M(122, 65) * M(65, 117)
      temp = temp + M(122, 66) * M(66, 117)
      temp = temp + M(122, 67) * M(67, 117)
      temp = temp + M(122, 68) * M(68, 117)
      temp = temp + M(122, 69) * M(69, 117)
      temp = temp + M(122, 70) * M(70, 117)
      temp = temp + M(122, 71) * M(71, 117)
      temp = temp + M(122, 72) * M(72, 117)
      temp = temp + M(122, 73) * M(73, 117)
      temp = temp + M(122, 75) * M(75, 117)
      temp = temp + M(122, 76) * M(76, 117)
      temp = temp + M(122, 77) * M(77, 117)
      temp = temp + M(122, 78) * M(78, 117)
      temp = temp + M(122, 79) * M(79, 117)
      temp = temp + M(122, 80) * M(80, 117)
      temp = temp + M(122, 81) * M(81, 117)
      temp = temp + M(122, 82) * M(82, 117)
      temp = temp + M(122, 83) * M(83, 117)
      temp = temp + M(122, 84) * M(84, 117)
      temp = temp + M(122, 85) * M(85, 117)
      temp = temp + M(122, 87) * M(87, 117)
      temp = temp + M(122, 88) * M(88, 117)
      temp = temp + M(122, 90) * M(90, 117)
      temp = temp + M(122, 91) * M(91, 117)
      temp = temp + M(122, 92) * M(92, 117)
      temp = temp + M(122, 94) * M(94, 117)
      temp = temp + M(122, 95) * M(95, 117)
      temp = temp + M(122, 96) * M(96, 117)
      temp = temp + M(122, 97) * M(97, 117)
      temp = temp + M(122, 98) * M(98, 117)
      temp = temp + M(122, 100) * M(100, 117)
      temp = temp + M(122, 103) * M(103, 117)
      temp = temp + M(122, 104) * M(104, 117)
      temp = temp + M(122, 105) * M(105, 117)
      temp = temp + M(122, 106) * M(106, 117)
      temp = temp + M(122, 110) * M(110, 117)
      temp = temp + M(122, 111) * M(111, 117)
      temp = temp + M(122, 112) * M(112, 117)
      temp = temp + M(122, 113) * M(113, 117)
      temp = temp + M(122, 114) * M(114, 117)
      temp = temp + M(122, 115) * M(115, 117)
      M(122, 117) = M(122, 117) - temp
C     Lower part.
      temp = M(123, 47) * M(47, 117)
      temp = temp + M(123, 52) * M(52, 117)
      temp = temp + M(123, 53) * M(53, 117)
      temp = temp + M(123, 54) * M(54, 117)
      temp = temp + M(123, 55) * M(55, 117)
      temp = temp + M(123, 57) * M(57, 117)
      temp = temp + M(123, 58) * M(58, 117)
      temp = temp + M(123, 60) * M(60, 117)
      temp = temp + M(123, 63) * M(63, 117)
      temp = temp + M(123, 64) * M(64, 117)
      temp = temp + M(123, 66) * M(66, 117)
      temp = temp + M(123, 67) * M(67, 117)
      temp = temp + M(123, 71) * M(71, 117)
      temp = temp + M(123, 72) * M(72, 117)
      temp = temp + M(123, 76) * M(76, 117)
      temp = temp + M(123, 77) * M(77, 117)
      temp = temp + M(123, 78) * M(78, 117)
      temp = temp + M(123, 79) * M(79, 117)
      temp = temp + M(123, 80) * M(80, 117)
      temp = temp + M(123, 82) * M(82, 117)
      temp = temp + M(123, 84) * M(84, 117)
      temp = temp + M(123, 85) * M(85, 117)
      temp = temp + M(123, 87) * M(87, 117)
      temp = temp + M(123, 88) * M(88, 117)
      temp = temp + M(123, 90) * M(90, 117)
      temp = temp + M(123, 91) * M(91, 117)
      temp = temp + M(123, 92) * M(92, 117)
      temp = temp + M(123, 95) * M(95, 117)
      temp = temp + M(123, 96) * M(96, 117)
      temp = temp + M(123, 97) * M(97, 117)
      temp = temp + M(123, 98) * M(98, 117)
      temp = temp + M(123, 103) * M(103, 117)
      temp = temp + M(123, 104) * M(104, 117)
      temp = temp + M(123, 105) * M(105, 117)
      temp = temp + M(123, 106) * M(106, 117)
      temp = temp + M(123, 110) * M(110, 117)
      temp = temp + M(123, 111) * M(111, 117)
      temp = temp + M(123, 112) * M(112, 117)
      temp = temp + M(123, 113) * M(113, 117)
      temp = temp + M(123, 114) * M(114, 117)
      temp = temp + M(123, 115) * M(115, 117)
      M(123, 117) = M(123, 117) - temp
C     Upper part.
      temp = M(117, 20) * M(20, 118)
      temp = temp + M(117, 21) * M(21, 118)
      temp = temp + M(117, 25) * M(25, 118)
      temp = temp + M(117, 27) * M(27, 118)
      temp = temp + M(117, 28) * M(28, 118)
      temp = temp + M(117, 31) * M(31, 118)
      temp = temp + M(117, 32) * M(32, 118)
      temp = temp + M(117, 36) * M(36, 118)
      temp = temp + M(117, 38) * M(38, 118)
      temp = temp + M(117, 41) * M(41, 118)
      temp = temp + M(117, 42) * M(42, 118)
      temp = temp + M(117, 43) * M(43, 118)
      temp = temp + M(117, 46) * M(46, 118)
      temp = temp + M(117, 47) * M(47, 118)
      temp = temp + M(117, 52) * M(52, 118)
      temp = temp + M(117, 53) * M(53, 118)
      temp = temp + M(117, 54) * M(54, 118)
      temp = temp + M(117, 55) * M(55, 118)
      temp = temp + M(117, 57) * M(57, 118)
      temp = temp + M(117, 58) * M(58, 118)
      temp = temp + M(117, 60) * M(60, 118)
      temp = temp + M(117, 61) * M(61, 118)
      temp = temp + M(117, 62) * M(62, 118)
      temp = temp + M(117, 63) * M(63, 118)
      temp = temp + M(117, 64) * M(64, 118)
      temp = temp + M(117, 66) * M(66, 118)
      temp = temp + M(117, 67) * M(67, 118)
      temp = temp + M(117, 71) * M(71, 118)
      temp = temp + M(117, 72) * M(72, 118)
      temp = temp + M(117, 76) * M(76, 118)
      temp = temp + M(117, 77) * M(77, 118)
      temp = temp + M(117, 78) * M(78, 118)
      temp = temp + M(117, 79) * M(79, 118)
      temp = temp + M(117, 80) * M(80, 118)
      temp = temp + M(117, 82) * M(82, 118)
      temp = temp + M(117, 83) * M(83, 118)
      temp = temp + M(117, 84) * M(84, 118)
      temp = temp + M(117, 85) * M(85, 118)
      temp = temp + M(117, 86) * M(86, 118)
      temp = temp + M(117, 87) * M(87, 118)
      temp = temp + M(117, 88) * M(88, 118)
      temp = temp + M(117, 90) * M(90, 118)
      temp = temp + M(117, 91) * M(91, 118)
      temp = temp + M(117, 92) * M(92, 118)
      temp = temp + M(117, 94) * M(94, 118)
      temp = temp + M(117, 95) * M(95, 118)
      temp = temp + M(117, 96) * M(96, 118)
      temp = temp + M(117, 97) * M(97, 118)
      temp = temp + M(117, 98) * M(98, 118)
      temp = temp + M(117, 100) * M(100, 118)
      temp = temp + M(117, 101) * M(101, 118)
      temp = temp + M(117, 102) * M(102, 118)
      temp = temp + M(117, 103) * M(103, 118)
      temp = temp + M(117, 104) * M(104, 118)
      temp = temp + M(117, 105) * M(105, 118)
      temp = temp + M(117, 106) * M(106, 118)
      temp = temp + M(117, 109) * M(109, 118)
      temp = temp + M(117, 110) * M(110, 118)
      temp = temp + M(117, 111) * M(111, 118)
      temp = temp + M(117, 112) * M(112, 118)
      temp = temp + M(117, 113) * M(113, 118)
      temp = temp + M(117, 114) * M(114, 118)
      temp = temp + M(117, 115) * M(115, 118)
      temp = temp + M(117, 116) * M(116, 118)
      M(117, 118) = ( M(117, 118) - temp ) / M(117, 117)
C     Upper part.
      temp = M(117, 43) * M(43, 119)
      temp = temp + M(117, 54) * M(54, 119)
      temp = temp + M(117, 60) * M(60, 119)
      temp = temp + M(117, 61) * M(61, 119)
      temp = temp + M(117, 62) * M(62, 119)
      temp = temp + M(117, 63) * M(63, 119)
      temp = temp + M(117, 64) * M(64, 119)
      temp = temp + M(117, 66) * M(66, 119)
      temp = temp + M(117, 67) * M(67, 119)
      temp = temp + M(117, 71) * M(71, 119)
      temp = temp + M(117, 72) * M(72, 119)
      temp = temp + M(117, 76) * M(76, 119)
      temp = temp + M(117, 77) * M(77, 119)
      temp = temp + M(117, 78) * M(78, 119)
      temp = temp + M(117, 79) * M(79, 119)
      temp = temp + M(117, 80) * M(80, 119)
      temp = temp + M(117, 82) * M(82, 119)
      temp = temp + M(117, 83) * M(83, 119)
      temp = temp + M(117, 84) * M(84, 119)
      temp = temp + M(117, 85) * M(85, 119)
      temp = temp + M(117, 86) * M(86, 119)
      temp = temp + M(117, 87) * M(87, 119)
      temp = temp + M(117, 88) * M(88, 119)
      temp = temp + M(117, 90) * M(90, 119)
      temp = temp + M(117, 91) * M(91, 119)
      temp = temp + M(117, 92) * M(92, 119)
      temp = temp + M(117, 94) * M(94, 119)
      temp = temp + M(117, 95) * M(95, 119)
      temp = temp + M(117, 96) * M(96, 119)
      temp = temp + M(117, 97) * M(97, 119)
      temp = temp + M(117, 98) * M(98, 119)
      temp = temp + M(117, 100) * M(100, 119)
      temp = temp + M(117, 101) * M(101, 119)
      temp = temp + M(117, 102) * M(102, 119)
      temp = temp + M(117, 103) * M(103, 119)
      temp = temp + M(117, 104) * M(104, 119)
      temp = temp + M(117, 105) * M(105, 119)
      temp = temp + M(117, 106) * M(106, 119)
      temp = temp + M(117, 109) * M(109, 119)
      temp = temp + M(117, 110) * M(110, 119)
      temp = temp + M(117, 111) * M(111, 119)
      temp = temp + M(117, 112) * M(112, 119)
      temp = temp + M(117, 113) * M(113, 119)
      temp = temp + M(117, 114) * M(114, 119)
      temp = temp + M(117, 115) * M(115, 119)
      temp = temp + M(117, 116) * M(116, 119)
      M(117, 119) = ( M(117, 119) - temp ) / M(117, 117)
C     Upper part.
      temp = M(117, 42) * M(42, 120)
      temp = temp + M(117, 106) * M(106, 120)
      temp = temp + M(117, 112) * M(112, 120)
      temp = temp + M(117, 113) * M(113, 120)
      temp = temp + M(117, 114) * M(114, 120)
      temp = temp + M(117, 115) * M(115, 120)
      temp = temp + M(117, 116) * M(116, 120)
      M(117, 120) = ( M(117, 120) - temp ) / M(117, 117)
C     Upper part.
      temp = M(117, 18) * M(18, 121)
      temp = temp + M(117, 41) * M(41, 121)
      temp = temp + M(117, 42) * M(42, 121)
      temp = temp + M(117, 43) * M(43, 121)
      temp = temp + M(117, 46) * M(46, 121)
      temp = temp + M(117, 47) * M(47, 121)
      temp = temp + M(117, 62) * M(62, 121)
      temp = temp + M(117, 66) * M(66, 121)
      temp = temp + M(117, 91) * M(91, 121)
      temp = temp + M(117, 92) * M(92, 121)
      temp = temp + M(117, 94) * M(94, 121)
      temp = temp + M(117, 95) * M(95, 121)
      temp = temp + M(117, 96) * M(96, 121)
      temp = temp + M(117, 97) * M(97, 121)
      temp = temp + M(117, 98) * M(98, 121)
      temp = temp + M(117, 100) * M(100, 121)
      temp = temp + M(117, 101) * M(101, 121)
      temp = temp + M(117, 102) * M(102, 121)
      temp = temp + M(117, 104) * M(104, 121)
      temp = temp + M(117, 105) * M(105, 121)
      temp = temp + M(117, 106) * M(106, 121)
      temp = temp + M(117, 109) * M(109, 121)
      temp = temp + M(117, 110) * M(110, 121)
      temp = temp + M(117, 111) * M(111, 121)
      temp = temp + M(117, 112) * M(112, 121)
      temp = temp + M(117, 113) * M(113, 121)
      temp = temp + M(117, 114) * M(114, 121)
      temp = temp + M(117, 115) * M(115, 121)
      temp = temp + M(117, 116) * M(116, 121)
      M(117, 121) = ( M(117, 121) - temp ) / M(117, 117)
C     Upper part.
      temp = M(117, 41) * M(41, 122)
      temp = temp + M(117, 52) * M(52, 122)
      temp = temp + M(117, 53) * M(53, 122)
      temp = temp + M(117, 54) * M(54, 122)
      temp = temp + M(117, 55) * M(55, 122)
      temp = temp + M(117, 57) * M(57, 122)
      temp = temp + M(117, 58) * M(58, 122)
      temp = temp + M(117, 60) * M(60, 122)
      temp = temp + M(117, 61) * M(61, 122)
      temp = temp + M(117, 62) * M(62, 122)
      temp = temp + M(117, 63) * M(63, 122)
      temp = temp + M(117, 64) * M(64, 122)
      temp = temp + M(117, 66) * M(66, 122)
      temp = temp + M(117, 67) * M(67, 122)
      temp = temp + M(117, 71) * M(71, 122)
      temp = temp + M(117, 72) * M(72, 122)
      temp = temp + M(117, 76) * M(76, 122)
      temp = temp + M(117, 77) * M(77, 122)
      temp = temp + M(117, 78) * M(78, 122)
      temp = temp + M(117, 79) * M(79, 122)
      temp = temp + M(117, 80) * M(80, 122)
      temp = temp + M(117, 82) * M(82, 122)
      temp = temp + M(117, 83) * M(83, 122)
      temp = temp + M(117, 84) * M(84, 122)
      temp = temp + M(117, 85) * M(85, 122)
      temp = temp + M(117, 86) * M(86, 122)
      temp = temp + M(117, 87) * M(87, 122)
      temp = temp + M(117, 88) * M(88, 122)
      temp = temp + M(117, 90) * M(90, 122)
      temp = temp + M(117, 91) * M(91, 122)
      temp = temp + M(117, 92) * M(92, 122)
      temp = temp + M(117, 94) * M(94, 122)
      temp = temp + M(117, 95) * M(95, 122)
      temp = temp + M(117, 96) * M(96, 122)
      temp = temp + M(117, 97) * M(97, 122)
      temp = temp + M(117, 98) * M(98, 122)
      temp = temp + M(117, 100) * M(100, 122)
      temp = temp + M(117, 101) * M(101, 122)
      temp = temp + M(117, 102) * M(102, 122)
      temp = temp + M(117, 103) * M(103, 122)
      temp = temp + M(117, 104) * M(104, 122)
      temp = temp + M(117, 105) * M(105, 122)
      temp = temp + M(117, 106) * M(106, 122)
      temp = temp + M(117, 109) * M(109, 122)
      temp = temp + M(117, 110) * M(110, 122)
      temp = temp + M(117, 111) * M(111, 122)
      temp = temp + M(117, 112) * M(112, 122)
      temp = temp + M(117, 113) * M(113, 122)
      temp = temp + M(117, 114) * M(114, 122)
      temp = temp + M(117, 115) * M(115, 122)
      temp = temp + M(117, 116) * M(116, 122)
      M(117, 122) = ( M(117, 122) - temp ) / M(117, 117)
C     Upper part.
      temp = M(117, 47) * M(47, 123)
      temp = temp + M(117, 52) * M(52, 123)
      temp = temp + M(117, 53) * M(53, 123)
      temp = temp + M(117, 54) * M(54, 123)
      temp = temp + M(117, 55) * M(55, 123)
      temp = temp + M(117, 57) * M(57, 123)
      temp = temp + M(117, 58) * M(58, 123)
      temp = temp + M(117, 60) * M(60, 123)
      temp = temp + M(117, 61) * M(61, 123)
      temp = temp + M(117, 62) * M(62, 123)
      temp = temp + M(117, 63) * M(63, 123)
      temp = temp + M(117, 64) * M(64, 123)
      temp = temp + M(117, 66) * M(66, 123)
      temp = temp + M(117, 67) * M(67, 123)
      temp = temp + M(117, 71) * M(71, 123)
      temp = temp + M(117, 72) * M(72, 123)
      temp = temp + M(117, 76) * M(76, 123)
      temp = temp + M(117, 77) * M(77, 123)
      temp = temp + M(117, 78) * M(78, 123)
      temp = temp + M(117, 79) * M(79, 123)
      temp = temp + M(117, 80) * M(80, 123)
      temp = temp + M(117, 82) * M(82, 123)
      temp = temp + M(117, 83) * M(83, 123)
      temp = temp + M(117, 84) * M(84, 123)
      temp = temp + M(117, 85) * M(85, 123)
      temp = temp + M(117, 86) * M(86, 123)
      temp = temp + M(117, 87) * M(87, 123)
      temp = temp + M(117, 88) * M(88, 123)
      temp = temp + M(117, 90) * M(90, 123)
      temp = temp + M(117, 91) * M(91, 123)
      temp = temp + M(117, 92) * M(92, 123)
      temp = temp + M(117, 94) * M(94, 123)
      temp = temp + M(117, 95) * M(95, 123)
      temp = temp + M(117, 96) * M(96, 123)
      temp = temp + M(117, 97) * M(97, 123)
      temp = temp + M(117, 98) * M(98, 123)
      temp = temp + M(117, 100) * M(100, 123)
      temp = temp + M(117, 101) * M(101, 123)
      temp = temp + M(117, 102) * M(102, 123)
      temp = temp + M(117, 103) * M(103, 123)
      temp = temp + M(117, 104) * M(104, 123)
      temp = temp + M(117, 105) * M(105, 123)
      temp = temp + M(117, 106) * M(106, 123)
      temp = temp + M(117, 109) * M(109, 123)
      temp = temp + M(117, 110) * M(110, 123)
      temp = temp + M(117, 111) * M(111, 123)
      temp = temp + M(117, 112) * M(112, 123)
      temp = temp + M(117, 113) * M(113, 123)
      temp = temp + M(117, 114) * M(114, 123)
      temp = temp + M(117, 115) * M(115, 123)
      temp = temp + M(117, 116) * M(116, 123)
      M(117, 123) = ( M(117, 123) - temp ) / M(117, 117)

C     Lower part.
      temp = M(118, 4) * M(4, 118)
      temp = temp + M(118, 6) * M(6, 118)
      temp = temp + M(118, 7) * M(7, 118)
      temp = temp + M(118, 8) * M(8, 118)
      temp = temp + M(118, 9) * M(9, 118)
      temp = temp + M(118, 10) * M(10, 118)
      temp = temp + M(118, 11) * M(11, 118)
      temp = temp + M(118, 12) * M(12, 118)
      temp = temp + M(118, 13) * M(13, 118)
      temp = temp + M(118, 14) * M(14, 118)
      temp = temp + M(118, 15) * M(15, 118)
      temp = temp + M(118, 16) * M(16, 118)
      temp = temp + M(118, 19) * M(19, 118)
      temp = temp + M(118, 20) * M(20, 118)
      temp = temp + M(118, 21) * M(21, 118)
      temp = temp + M(118, 24) * M(24, 118)
      temp = temp + M(118, 25) * M(25, 118)
      temp = temp + M(118, 26) * M(26, 118)
      temp = temp + M(118, 27) * M(27, 118)
      temp = temp + M(118, 28) * M(28, 118)
      temp = temp + M(118, 29) * M(29, 118)
      temp = temp + M(118, 31) * M(31, 118)
      temp = temp + M(118, 32) * M(32, 118)
      temp = temp + M(118, 35) * M(35, 118)
      temp = temp + M(118, 36) * M(36, 118)
      temp = temp + M(118, 37) * M(37, 118)
      temp = temp + M(118, 38) * M(38, 118)
      temp = temp + M(118, 39) * M(39, 118)
      temp = temp + M(118, 40) * M(40, 118)
      temp = temp + M(118, 41) * M(41, 118)
      temp = temp + M(118, 42) * M(42, 118)
      temp = temp + M(118, 43) * M(43, 118)
      temp = temp + M(118, 44) * M(44, 118)
      temp = temp + M(118, 45) * M(45, 118)
      temp = temp + M(118, 46) * M(46, 118)
      temp = temp + M(118, 51) * M(51, 118)
      temp = temp + M(118, 54) * M(54, 118)
      temp = temp + M(118, 56) * M(56, 118)
      temp = temp + M(118, 60) * M(60, 118)
      temp = temp + M(118, 61) * M(61, 118)
      temp = temp + M(118, 62) * M(62, 118)
      temp = temp + M(118, 64) * M(64, 118)
      temp = temp + M(118, 65) * M(65, 118)
      temp = temp + M(118, 68) * M(68, 118)
      temp = temp + M(118, 69) * M(69, 118)
      temp = temp + M(118, 70) * M(70, 118)
      temp = temp + M(118, 73) * M(73, 118)
      temp = temp + M(118, 74) * M(74, 118)
      temp = temp + M(118, 75) * M(75, 118)
      temp = temp + M(118, 76) * M(76, 118)
      temp = temp + M(118, 78) * M(78, 118)
      temp = temp + M(118, 80) * M(80, 118)
      temp = temp + M(118, 81) * M(81, 118)
      temp = temp + M(118, 83) * M(83, 118)
      temp = temp + M(118, 85) * M(85, 118)
      temp = temp + M(118, 86) * M(86, 118)
      temp = temp + M(118, 89) * M(89, 118)
      temp = temp + M(118, 90) * M(90, 118)
      temp = temp + M(118, 91) * M(91, 118)
      temp = temp + M(118, 92) * M(92, 118)
      temp = temp + M(118, 93) * M(93, 118)
      temp = temp + M(118, 94) * M(94, 118)
      temp = temp + M(118, 96) * M(96, 118)
      temp = temp + M(118, 97) * M(97, 118)
      temp = temp + M(118, 98) * M(98, 118)
      temp = temp + M(118, 99) * M(99, 118)
      temp = temp + M(118, 100) * M(100, 118)
      temp = temp + M(118, 101) * M(101, 118)
      temp = temp + M(118, 102) * M(102, 118)
      temp = temp + M(118, 103) * M(103, 118)
      temp = temp + M(118, 104) * M(104, 118)
      temp = temp + M(118, 105) * M(105, 118)
      temp = temp + M(118, 106) * M(106, 118)
      temp = temp + M(118, 107) * M(107, 118)
      temp = temp + M(118, 108) * M(108, 118)
      temp = temp + M(118, 109) * M(109, 118)
      temp = temp + M(118, 110) * M(110, 118)
      temp = temp + M(118, 111) * M(111, 118)
      temp = temp + M(118, 113) * M(113, 118)
      temp = temp + M(118, 114) * M(114, 118)
      temp = temp + M(118, 115) * M(115, 118)
      temp = temp + M(118, 116) * M(116, 118)
      temp = temp + M(118, 117) * M(117, 118)
      M(118, 118) = M(118, 118) - temp
C     Lower part.
      temp = M(119, 4) * M(4, 118)
      temp = temp + M(119, 6) * M(6, 118)
      temp = temp + M(119, 7) * M(7, 118)
      temp = temp + M(119, 10) * M(10, 118)
      temp = temp + M(119, 11) * M(11, 118)
      temp = temp + M(119, 12) * M(12, 118)
      temp = temp + M(119, 13) * M(13, 118)
      temp = temp + M(119, 14) * M(14, 118)
      temp = temp + M(119, 15) * M(15, 118)
      temp = temp + M(119, 16) * M(16, 118)
      temp = temp + M(119, 20) * M(20, 118)
      temp = temp + M(119, 21) * M(21, 118)
      temp = temp + M(119, 25) * M(25, 118)
      temp = temp + M(119, 26) * M(26, 118)
      temp = temp + M(119, 27) * M(27, 118)
      temp = temp + M(119, 28) * M(28, 118)
      temp = temp + M(119, 29) * M(29, 118)
      temp = temp + M(119, 31) * M(31, 118)
      temp = temp + M(119, 32) * M(32, 118)
      temp = temp + M(119, 38) * M(38, 118)
      temp = temp + M(119, 40) * M(40, 118)
      temp = temp + M(119, 43) * M(43, 118)
      temp = temp + M(119, 51) * M(51, 118)
      temp = temp + M(119, 52) * M(52, 118)
      temp = temp + M(119, 53) * M(53, 118)
      temp = temp + M(119, 54) * M(54, 118)
      temp = temp + M(119, 55) * M(55, 118)
      temp = temp + M(119, 56) * M(56, 118)
      temp = temp + M(119, 57) * M(57, 118)
      temp = temp + M(119, 58) * M(58, 118)
      temp = temp + M(119, 60) * M(60, 118)
      temp = temp + M(119, 61) * M(61, 118)
      temp = temp + M(119, 62) * M(62, 118)
      temp = temp + M(119, 63) * M(63, 118)
      temp = temp + M(119, 64) * M(64, 118)
      temp = temp + M(119, 65) * M(65, 118)
      temp = temp + M(119, 66) * M(66, 118)
      temp = temp + M(119, 67) * M(67, 118)
      temp = temp + M(119, 68) * M(68, 118)
      temp = temp + M(119, 69) * M(69, 118)
      temp = temp + M(119, 71) * M(71, 118)
      temp = temp + M(119, 72) * M(72, 118)
      temp = temp + M(119, 74) * M(74, 118)
      temp = temp + M(119, 75) * M(75, 118)
      temp = temp + M(119, 76) * M(76, 118)
      temp = temp + M(119, 77) * M(77, 118)
      temp = temp + M(119, 78) * M(78, 118)
      temp = temp + M(119, 79) * M(79, 118)
      temp = temp + M(119, 80) * M(80, 118)
      temp = temp + M(119, 81) * M(81, 118)
      temp = temp + M(119, 82) * M(82, 118)
      temp = temp + M(119, 83) * M(83, 118)
      temp = temp + M(119, 84) * M(84, 118)
      temp = temp + M(119, 85) * M(85, 118)
      temp = temp + M(119, 86) * M(86, 118)
      temp = temp + M(119, 87) * M(87, 118)
      temp = temp + M(119, 88) * M(88, 118)
      temp = temp + M(119, 89) * M(89, 118)
      temp = temp + M(119, 90) * M(90, 118)
      temp = temp + M(119, 91) * M(91, 118)
      temp = temp + M(119, 92) * M(92, 118)
      temp = temp + M(119, 93) * M(93, 118)
      temp = temp + M(119, 94) * M(94, 118)
      temp = temp + M(119, 95) * M(95, 118)
      temp = temp + M(119, 96) * M(96, 118)
      temp = temp + M(119, 97) * M(97, 118)
      temp = temp + M(119, 98) * M(98, 118)
      temp = temp + M(119, 99) * M(99, 118)
      temp = temp + M(119, 100) * M(100, 118)
      temp = temp + M(119, 102) * M(102, 118)
      temp = temp + M(119, 103) * M(103, 118)
      temp = temp + M(119, 104) * M(104, 118)
      temp = temp + M(119, 105) * M(105, 118)
      temp = temp + M(119, 106) * M(106, 118)
      temp = temp + M(119, 107) * M(107, 118)
      temp = temp + M(119, 108) * M(108, 118)
      temp = temp + M(119, 109) * M(109, 118)
      temp = temp + M(119, 110) * M(110, 118)
      temp = temp + M(119, 111) * M(111, 118)
      temp = temp + M(119, 112) * M(112, 118)
      temp = temp + M(119, 113) * M(113, 118)
      temp = temp + M(119, 114) * M(114, 118)
      temp = temp + M(119, 115) * M(115, 118)
      temp = temp + M(119, 116) * M(116, 118)
      temp = temp + M(119, 117) * M(117, 118)
      M(119, 118) = M(119, 118) - temp
C     Lower part.
      temp = M(120, 42) * M(42, 118)
      temp = temp + M(120, 109) * M(109, 118)
      temp = temp + M(120, 110) * M(110, 118)
      temp = temp + M(120, 111) * M(111, 118)
      temp = temp + M(120, 113) * M(113, 118)
      temp = temp + M(120, 114) * M(114, 118)
      temp = temp + M(120, 115) * M(115, 118)
      temp = temp + M(120, 117) * M(117, 118)
      M(120, 118) = M(120, 118) - temp
C     Lower part.
      temp = M(121, 19) * M(19, 118)
      temp = temp + M(121, 24) * M(24, 118)
      temp = temp + M(121, 27) * M(27, 118)
      temp = temp + M(121, 41) * M(41, 118)
      temp = temp + M(121, 42) * M(42, 118)
      temp = temp + M(121, 43) * M(43, 118)
      temp = temp + M(121, 45) * M(45, 118)
      temp = temp + M(121, 46) * M(46, 118)
      temp = temp + M(121, 47) * M(47, 118)
      temp = temp + M(121, 52) * M(52, 118)
      temp = temp + M(121, 53) * M(53, 118)
      temp = temp + M(121, 54) * M(54, 118)
      temp = temp + M(121, 55) * M(55, 118)
      temp = temp + M(121, 57) * M(57, 118)
      temp = temp + M(121, 58) * M(58, 118)
      temp = temp + M(121, 59) * M(59, 118)
      temp = temp + M(121, 60) * M(60, 118)
      temp = temp + M(121, 62) * M(62, 118)
      temp = temp + M(121, 63) * M(63, 118)
      temp = temp + M(121, 64) * M(64, 118)
      temp = temp + M(121, 66) * M(66, 118)
      temp = temp + M(121, 67) * M(67, 118)
      temp = temp + M(121, 71) * M(71, 118)
      temp = temp + M(121, 72) * M(72, 118)
      temp = temp + M(121, 76) * M(76, 118)
      temp = temp + M(121, 77) * M(77, 118)
      temp = temp + M(121, 78) * M(78, 118)
      temp = temp + M(121, 79) * M(79, 118)
      temp = temp + M(121, 80) * M(80, 118)
      temp = temp + M(121, 82) * M(82, 118)
      temp = temp + M(121, 84) * M(84, 118)
      temp = temp + M(121, 85) * M(85, 118)
      temp = temp + M(121, 87) * M(87, 118)
      temp = temp + M(121, 88) * M(88, 118)
      temp = temp + M(121, 90) * M(90, 118)
      temp = temp + M(121, 91) * M(91, 118)
      temp = temp + M(121, 92) * M(92, 118)
      temp = temp + M(121, 95) * M(95, 118)
      temp = temp + M(121, 96) * M(96, 118)
      temp = temp + M(121, 97) * M(97, 118)
      temp = temp + M(121, 98) * M(98, 118)
      temp = temp + M(121, 101) * M(101, 118)
      temp = temp + M(121, 102) * M(102, 118)
      temp = temp + M(121, 103) * M(103, 118)
      temp = temp + M(121, 104) * M(104, 118)
      temp = temp + M(121, 105) * M(105, 118)
      temp = temp + M(121, 106) * M(106, 118)
      temp = temp + M(121, 108) * M(108, 118)
      temp = temp + M(121, 109) * M(109, 118)
      temp = temp + M(121, 110) * M(110, 118)
      temp = temp + M(121, 111) * M(111, 118)
      temp = temp + M(121, 112) * M(112, 118)
      temp = temp + M(121, 113) * M(113, 118)
      temp = temp + M(121, 114) * M(114, 118)
      temp = temp + M(121, 115) * M(115, 118)
      temp = temp + M(121, 116) * M(116, 118)
      temp = temp + M(121, 117) * M(117, 118)
      M(121, 118) = M(121, 118) - temp
C     Lower part.
      temp = M(122, 25) * M(25, 118)
      temp = temp + M(122, 31) * M(31, 118)
      temp = temp + M(122, 37) * M(37, 118)
      temp = temp + M(122, 41) * M(41, 118)
      temp = temp + M(122, 52) * M(52, 118)
      temp = temp + M(122, 53) * M(53, 118)
      temp = temp + M(122, 54) * M(54, 118)
      temp = temp + M(122, 55) * M(55, 118)
      temp = temp + M(122, 57) * M(57, 118)
      temp = temp + M(122, 58) * M(58, 118)
      temp = temp + M(122, 60) * M(60, 118)
      temp = temp + M(122, 63) * M(63, 118)
      temp = temp + M(122, 64) * M(64, 118)
      temp = temp + M(122, 65) * M(65, 118)
      temp = temp + M(122, 66) * M(66, 118)
      temp = temp + M(122, 67) * M(67, 118)
      temp = temp + M(122, 68) * M(68, 118)
      temp = temp + M(122, 69) * M(69, 118)
      temp = temp + M(122, 70) * M(70, 118)
      temp = temp + M(122, 71) * M(71, 118)
      temp = temp + M(122, 72) * M(72, 118)
      temp = temp + M(122, 73) * M(73, 118)
      temp = temp + M(122, 75) * M(75, 118)
      temp = temp + M(122, 76) * M(76, 118)
      temp = temp + M(122, 77) * M(77, 118)
      temp = temp + M(122, 78) * M(78, 118)
      temp = temp + M(122, 79) * M(79, 118)
      temp = temp + M(122, 80) * M(80, 118)
      temp = temp + M(122, 81) * M(81, 118)
      temp = temp + M(122, 82) * M(82, 118)
      temp = temp + M(122, 83) * M(83, 118)
      temp = temp + M(122, 84) * M(84, 118)
      temp = temp + M(122, 85) * M(85, 118)
      temp = temp + M(122, 87) * M(87, 118)
      temp = temp + M(122, 88) * M(88, 118)
      temp = temp + M(122, 90) * M(90, 118)
      temp = temp + M(122, 91) * M(91, 118)
      temp = temp + M(122, 92) * M(92, 118)
      temp = temp + M(122, 94) * M(94, 118)
      temp = temp + M(122, 95) * M(95, 118)
      temp = temp + M(122, 96) * M(96, 118)
      temp = temp + M(122, 97) * M(97, 118)
      temp = temp + M(122, 98) * M(98, 118)
      temp = temp + M(122, 100) * M(100, 118)
      temp = temp + M(122, 103) * M(103, 118)
      temp = temp + M(122, 104) * M(104, 118)
      temp = temp + M(122, 105) * M(105, 118)
      temp = temp + M(122, 106) * M(106, 118)
      temp = temp + M(122, 110) * M(110, 118)
      temp = temp + M(122, 111) * M(111, 118)
      temp = temp + M(122, 112) * M(112, 118)
      temp = temp + M(122, 113) * M(113, 118)
      temp = temp + M(122, 114) * M(114, 118)
      temp = temp + M(122, 115) * M(115, 118)
      temp = temp + M(122, 117) * M(117, 118)
      M(122, 118) = M(122, 118) - temp
C     Lower part.
      temp = M(123, 24) * M(24, 118)
      temp = temp + M(123, 47) * M(47, 118)
      temp = temp + M(123, 52) * M(52, 118)
      temp = temp + M(123, 53) * M(53, 118)
      temp = temp + M(123, 54) * M(54, 118)
      temp = temp + M(123, 55) * M(55, 118)
      temp = temp + M(123, 57) * M(57, 118)
      temp = temp + M(123, 58) * M(58, 118)
      temp = temp + M(123, 60) * M(60, 118)
      temp = temp + M(123, 63) * M(63, 118)
      temp = temp + M(123, 64) * M(64, 118)
      temp = temp + M(123, 66) * M(66, 118)
      temp = temp + M(123, 67) * M(67, 118)
      temp = temp + M(123, 71) * M(71, 118)
      temp = temp + M(123, 72) * M(72, 118)
      temp = temp + M(123, 76) * M(76, 118)
      temp = temp + M(123, 77) * M(77, 118)
      temp = temp + M(123, 78) * M(78, 118)
      temp = temp + M(123, 79) * M(79, 118)
      temp = temp + M(123, 80) * M(80, 118)
      temp = temp + M(123, 82) * M(82, 118)
      temp = temp + M(123, 84) * M(84, 118)
      temp = temp + M(123, 85) * M(85, 118)
      temp = temp + M(123, 87) * M(87, 118)
      temp = temp + M(123, 88) * M(88, 118)
      temp = temp + M(123, 90) * M(90, 118)
      temp = temp + M(123, 91) * M(91, 118)
      temp = temp + M(123, 92) * M(92, 118)
      temp = temp + M(123, 95) * M(95, 118)
      temp = temp + M(123, 96) * M(96, 118)
      temp = temp + M(123, 97) * M(97, 118)
      temp = temp + M(123, 98) * M(98, 118)
      temp = temp + M(123, 103) * M(103, 118)
      temp = temp + M(123, 104) * M(104, 118)
      temp = temp + M(123, 105) * M(105, 118)
      temp = temp + M(123, 106) * M(106, 118)
      temp = temp + M(123, 110) * M(110, 118)
      temp = temp + M(123, 111) * M(111, 118)
      temp = temp + M(123, 112) * M(112, 118)
      temp = temp + M(123, 113) * M(113, 118)
      temp = temp + M(123, 114) * M(114, 118)
      temp = temp + M(123, 115) * M(115, 118)
      temp = temp + M(123, 117) * M(117, 118)
      M(123, 118) = M(123, 118) - temp
C     Upper part.
      temp = M(118, 35) * M(35, 119)
      temp = temp + M(118, 40) * M(40, 119)
      temp = temp + M(118, 43) * M(43, 119)
      temp = temp + M(118, 51) * M(51, 119)
      temp = temp + M(118, 54) * M(54, 119)
      temp = temp + M(118, 60) * M(60, 119)
      temp = temp + M(118, 61) * M(61, 119)
      temp = temp + M(118, 62) * M(62, 119)
      temp = temp + M(118, 64) * M(64, 119)
      temp = temp + M(118, 65) * M(65, 119)
      temp = temp + M(118, 68) * M(68, 119)
      temp = temp + M(118, 69) * M(69, 119)
      temp = temp + M(118, 70) * M(70, 119)
      temp = temp + M(118, 73) * M(73, 119)
      temp = temp + M(118, 74) * M(74, 119)
      temp = temp + M(118, 76) * M(76, 119)
      temp = temp + M(118, 78) * M(78, 119)
      temp = temp + M(118, 80) * M(80, 119)
      temp = temp + M(118, 81) * M(81, 119)
      temp = temp + M(118, 83) * M(83, 119)
      temp = temp + M(118, 85) * M(85, 119)
      temp = temp + M(118, 86) * M(86, 119)
      temp = temp + M(118, 89) * M(89, 119)
      temp = temp + M(118, 90) * M(90, 119)
      temp = temp + M(118, 91) * M(91, 119)
      temp = temp + M(118, 92) * M(92, 119)
      temp = temp + M(118, 93) * M(93, 119)
      temp = temp + M(118, 94) * M(94, 119)
      temp = temp + M(118, 96) * M(96, 119)
      temp = temp + M(118, 97) * M(97, 119)
      temp = temp + M(118, 98) * M(98, 119)
      temp = temp + M(118, 99) * M(99, 119)
      temp = temp + M(118, 100) * M(100, 119)
      temp = temp + M(118, 101) * M(101, 119)
      temp = temp + M(118, 102) * M(102, 119)
      temp = temp + M(118, 103) * M(103, 119)
      temp = temp + M(118, 104) * M(104, 119)
      temp = temp + M(118, 105) * M(105, 119)
      temp = temp + M(118, 106) * M(106, 119)
      temp = temp + M(118, 107) * M(107, 119)
      temp = temp + M(118, 108) * M(108, 119)
      temp = temp + M(118, 109) * M(109, 119)
      temp = temp + M(118, 110) * M(110, 119)
      temp = temp + M(118, 111) * M(111, 119)
      temp = temp + M(118, 113) * M(113, 119)
      temp = temp + M(118, 114) * M(114, 119)
      temp = temp + M(118, 115) * M(115, 119)
      temp = temp + M(118, 116) * M(116, 119)
      temp = temp + M(118, 117) * M(117, 119)
      M(118, 119) = ( M(118, 119) - temp ) / M(118, 118)
C     Upper part.
      temp = M(118, 42) * M(42, 120)
      temp = temp + M(118, 70) * M(70, 120)
      temp = temp + M(118, 106) * M(106, 120)
      temp = temp + M(118, 107) * M(107, 120)
      temp = temp + M(118, 113) * M(113, 120)
      temp = temp + M(118, 114) * M(114, 120)
      temp = temp + M(118, 115) * M(115, 120)
      temp = temp + M(118, 116) * M(116, 120)
      temp = temp + M(118, 117) * M(117, 120)
      M(118, 120) = ( M(118, 120) - temp ) / M(118, 118)
C     Upper part.
      temp = M(118, 24) * M(24, 121)
      temp = temp + M(118, 41) * M(41, 121)
      temp = temp + M(118, 42) * M(42, 121)
      temp = temp + M(118, 43) * M(43, 121)
      temp = temp + M(118, 46) * M(46, 121)
      temp = temp + M(118, 62) * M(62, 121)
      temp = temp + M(118, 91) * M(91, 121)
      temp = temp + M(118, 92) * M(92, 121)
      temp = temp + M(118, 93) * M(93, 121)
      temp = temp + M(118, 94) * M(94, 121)
      temp = temp + M(118, 96) * M(96, 121)
      temp = temp + M(118, 97) * M(97, 121)
      temp = temp + M(118, 98) * M(98, 121)
      temp = temp + M(118, 99) * M(99, 121)
      temp = temp + M(118, 100) * M(100, 121)
      temp = temp + M(118, 101) * M(101, 121)
      temp = temp + M(118, 102) * M(102, 121)
      temp = temp + M(118, 104) * M(104, 121)
      temp = temp + M(118, 105) * M(105, 121)
      temp = temp + M(118, 106) * M(106, 121)
      temp = temp + M(118, 107) * M(107, 121)
      temp = temp + M(118, 108) * M(108, 121)
      temp = temp + M(118, 109) * M(109, 121)
      temp = temp + M(118, 110) * M(110, 121)
      temp = temp + M(118, 111) * M(111, 121)
      temp = temp + M(118, 113) * M(113, 121)
      temp = temp + M(118, 114) * M(114, 121)
      temp = temp + M(118, 115) * M(115, 121)
      temp = temp + M(118, 116) * M(116, 121)
      temp = temp + M(118, 117) * M(117, 121)
      M(118, 121) = ( M(118, 121) - temp ) / M(118, 118)
C     Upper part.
      temp = M(118, 41) * M(41, 122)
      temp = temp + M(118, 54) * M(54, 122)
      temp = temp + M(118, 56) * M(56, 122)
      temp = temp + M(118, 60) * M(60, 122)
      temp = temp + M(118, 61) * M(61, 122)
      temp = temp + M(118, 62) * M(62, 122)
      temp = temp + M(118, 64) * M(64, 122)
      temp = temp + M(118, 65) * M(65, 122)
      temp = temp + M(118, 68) * M(68, 122)
      temp = temp + M(118, 69) * M(69, 122)
      temp = temp + M(118, 70) * M(70, 122)
      temp = temp + M(118, 73) * M(73, 122)
      temp = temp + M(118, 74) * M(74, 122)
      temp = temp + M(118, 75) * M(75, 122)
      temp = temp + M(118, 76) * M(76, 122)
      temp = temp + M(118, 78) * M(78, 122)
      temp = temp + M(118, 80) * M(80, 122)
      temp = temp + M(118, 81) * M(81, 122)
      temp = temp + M(118, 83) * M(83, 122)
      temp = temp + M(118, 85) * M(85, 122)
      temp = temp + M(118, 86) * M(86, 122)
      temp = temp + M(118, 89) * M(89, 122)
      temp = temp + M(118, 90) * M(90, 122)
      temp = temp + M(118, 91) * M(91, 122)
      temp = temp + M(118, 92) * M(92, 122)
      temp = temp + M(118, 93) * M(93, 122)
      temp = temp + M(118, 94) * M(94, 122)
      temp = temp + M(118, 96) * M(96, 122)
      temp = temp + M(118, 97) * M(97, 122)
      temp = temp + M(118, 98) * M(98, 122)
      temp = temp + M(118, 99) * M(99, 122)
      temp = temp + M(118, 100) * M(100, 122)
      temp = temp + M(118, 101) * M(101, 122)
      temp = temp + M(118, 102) * M(102, 122)
      temp = temp + M(118, 103) * M(103, 122)
      temp = temp + M(118, 104) * M(104, 122)
      temp = temp + M(118, 105) * M(105, 122)
      temp = temp + M(118, 106) * M(106, 122)
      temp = temp + M(118, 107) * M(107, 122)
      temp = temp + M(118, 108) * M(108, 122)
      temp = temp + M(118, 109) * M(109, 122)
      temp = temp + M(118, 110) * M(110, 122)
      temp = temp + M(118, 111) * M(111, 122)
      temp = temp + M(118, 113) * M(113, 122)
      temp = temp + M(118, 114) * M(114, 122)
      temp = temp + M(118, 115) * M(115, 122)
      temp = temp + M(118, 116) * M(116, 122)
      temp = temp + M(118, 117) * M(117, 122)
      M(118, 122) = ( M(118, 122) - temp ) / M(118, 118)
C     Upper part.
      temp = M(118, 24) * M(24, 123)
      temp = temp + M(118, 37) * M(37, 123)
      temp = temp + M(118, 45) * M(45, 123)
      temp = temp + M(118, 54) * M(54, 123)
      temp = temp + M(118, 56) * M(56, 123)
      temp = temp + M(118, 60) * M(60, 123)
      temp = temp + M(118, 61) * M(61, 123)
      temp = temp + M(118, 62) * M(62, 123)
      temp = temp + M(118, 64) * M(64, 123)
      temp = temp + M(118, 65) * M(65, 123)
      temp = temp + M(118, 68) * M(68, 123)
      temp = temp + M(118, 69) * M(69, 123)
      temp = temp + M(118, 70) * M(70, 123)
      temp = temp + M(118, 73) * M(73, 123)
      temp = temp + M(118, 74) * M(74, 123)
      temp = temp + M(118, 75) * M(75, 123)
      temp = temp + M(118, 76) * M(76, 123)
      temp = temp + M(118, 78) * M(78, 123)
      temp = temp + M(118, 80) * M(80, 123)
      temp = temp + M(118, 81) * M(81, 123)
      temp = temp + M(118, 83) * M(83, 123)
      temp = temp + M(118, 85) * M(85, 123)
      temp = temp + M(118, 86) * M(86, 123)
      temp = temp + M(118, 89) * M(89, 123)
      temp = temp + M(118, 90) * M(90, 123)
      temp = temp + M(118, 91) * M(91, 123)
      temp = temp + M(118, 92) * M(92, 123)
      temp = temp + M(118, 93) * M(93, 123)
      temp = temp + M(118, 94) * M(94, 123)
      temp = temp + M(118, 96) * M(96, 123)
      temp = temp + M(118, 97) * M(97, 123)
      temp = temp + M(118, 98) * M(98, 123)
      temp = temp + M(118, 99) * M(99, 123)
      temp = temp + M(118, 100) * M(100, 123)
      temp = temp + M(118, 101) * M(101, 123)
      temp = temp + M(118, 102) * M(102, 123)
      temp = temp + M(118, 103) * M(103, 123)
      temp = temp + M(118, 104) * M(104, 123)
      temp = temp + M(118, 105) * M(105, 123)
      temp = temp + M(118, 106) * M(106, 123)
      temp = temp + M(118, 107) * M(107, 123)
      temp = temp + M(118, 108) * M(108, 123)
      temp = temp + M(118, 109) * M(109, 123)
      temp = temp + M(118, 110) * M(110, 123)
      temp = temp + M(118, 111) * M(111, 123)
      temp = temp + M(118, 113) * M(113, 123)
      temp = temp + M(118, 114) * M(114, 123)
      temp = temp + M(118, 115) * M(115, 123)
      temp = temp + M(118, 116) * M(116, 123)
      temp = temp + M(118, 117) * M(117, 123)
      M(118, 123) = ( M(118, 123) - temp ) / M(118, 118)

C     Lower part.
      temp = M(119, 40) * M(40, 119)
      temp = temp + M(119, 43) * M(43, 119)
      temp = temp + M(119, 51) * M(51, 119)
      temp = temp + M(119, 54) * M(54, 119)
      temp = temp + M(119, 60) * M(60, 119)
      temp = temp + M(119, 61) * M(61, 119)
      temp = temp + M(119, 62) * M(62, 119)
      temp = temp + M(119, 63) * M(63, 119)
      temp = temp + M(119, 64) * M(64, 119)
      temp = temp + M(119, 65) * M(65, 119)
      temp = temp + M(119, 66) * M(66, 119)
      temp = temp + M(119, 67) * M(67, 119)
      temp = temp + M(119, 68) * M(68, 119)
      temp = temp + M(119, 69) * M(69, 119)
      temp = temp + M(119, 71) * M(71, 119)
      temp = temp + M(119, 72) * M(72, 119)
      temp = temp + M(119, 74) * M(74, 119)
      temp = temp + M(119, 76) * M(76, 119)
      temp = temp + M(119, 77) * M(77, 119)
      temp = temp + M(119, 78) * M(78, 119)
      temp = temp + M(119, 79) * M(79, 119)
      temp = temp + M(119, 80) * M(80, 119)
      temp = temp + M(119, 81) * M(81, 119)
      temp = temp + M(119, 82) * M(82, 119)
      temp = temp + M(119, 83) * M(83, 119)
      temp = temp + M(119, 84) * M(84, 119)
      temp = temp + M(119, 85) * M(85, 119)
      temp = temp + M(119, 86) * M(86, 119)
      temp = temp + M(119, 87) * M(87, 119)
      temp = temp + M(119, 88) * M(88, 119)
      temp = temp + M(119, 89) * M(89, 119)
      temp = temp + M(119, 90) * M(90, 119)
      temp = temp + M(119, 91) * M(91, 119)
      temp = temp + M(119, 92) * M(92, 119)
      temp = temp + M(119, 93) * M(93, 119)
      temp = temp + M(119, 94) * M(94, 119)
      temp = temp + M(119, 95) * M(95, 119)
      temp = temp + M(119, 96) * M(96, 119)
      temp = temp + M(119, 97) * M(97, 119)
      temp = temp + M(119, 98) * M(98, 119)
      temp = temp + M(119, 99) * M(99, 119)
      temp = temp + M(119, 100) * M(100, 119)
      temp = temp + M(119, 102) * M(102, 119)
      temp = temp + M(119, 103) * M(103, 119)
      temp = temp + M(119, 104) * M(104, 119)
      temp = temp + M(119, 105) * M(105, 119)
      temp = temp + M(119, 106) * M(106, 119)
      temp = temp + M(119, 107) * M(107, 119)
      temp = temp + M(119, 108) * M(108, 119)
      temp = temp + M(119, 109) * M(109, 119)
      temp = temp + M(119, 110) * M(110, 119)
      temp = temp + M(119, 111) * M(111, 119)
      temp = temp + M(119, 112) * M(112, 119)
      temp = temp + M(119, 113) * M(113, 119)
      temp = temp + M(119, 114) * M(114, 119)
      temp = temp + M(119, 115) * M(115, 119)
      temp = temp + M(119, 116) * M(116, 119)
      temp = temp + M(119, 117) * M(117, 119)
      temp = temp + M(119, 118) * M(118, 119)
      M(119, 119) = M(119, 119) - temp
C     Lower part.
      temp = M(120, 109) * M(109, 119)
      temp = temp + M(120, 110) * M(110, 119)
      temp = temp + M(120, 111) * M(111, 119)
      temp = temp + M(120, 113) * M(113, 119)
      temp = temp + M(120, 114) * M(114, 119)
      temp = temp + M(120, 115) * M(115, 119)
      temp = temp + M(120, 117) * M(117, 119)
      temp = temp + M(120, 118) * M(118, 119)
      M(120, 119) = M(120, 119) - temp
C     Lower part.
      temp = M(121, 43) * M(43, 119)
      temp = temp + M(121, 54) * M(54, 119)
      temp = temp + M(121, 60) * M(60, 119)
      temp = temp + M(121, 62) * M(62, 119)
      temp = temp + M(121, 63) * M(63, 119)
      temp = temp + M(121, 64) * M(64, 119)
      temp = temp + M(121, 66) * M(66, 119)
      temp = temp + M(121, 67) * M(67, 119)
      temp = temp + M(121, 71) * M(71, 119)
      temp = temp + M(121, 72) * M(72, 119)
      temp = temp + M(121, 76) * M(76, 119)
      temp = temp + M(121, 77) * M(77, 119)
      temp = temp + M(121, 78) * M(78, 119)
      temp = temp + M(121, 79) * M(79, 119)
      temp = temp + M(121, 80) * M(80, 119)
      temp = temp + M(121, 82) * M(82, 119)
      temp = temp + M(121, 84) * M(84, 119)
      temp = temp + M(121, 85) * M(85, 119)
      temp = temp + M(121, 87) * M(87, 119)
      temp = temp + M(121, 88) * M(88, 119)
      temp = temp + M(121, 90) * M(90, 119)
      temp = temp + M(121, 91) * M(91, 119)
      temp = temp + M(121, 92) * M(92, 119)
      temp = temp + M(121, 95) * M(95, 119)
      temp = temp + M(121, 96) * M(96, 119)
      temp = temp + M(121, 97) * M(97, 119)
      temp = temp + M(121, 98) * M(98, 119)
      temp = temp + M(121, 101) * M(101, 119)
      temp = temp + M(121, 102) * M(102, 119)
      temp = temp + M(121, 103) * M(103, 119)
      temp = temp + M(121, 104) * M(104, 119)
      temp = temp + M(121, 105) * M(105, 119)
      temp = temp + M(121, 106) * M(106, 119)
      temp = temp + M(121, 108) * M(108, 119)
      temp = temp + M(121, 109) * M(109, 119)
      temp = temp + M(121, 110) * M(110, 119)
      temp = temp + M(121, 111) * M(111, 119)
      temp = temp + M(121, 112) * M(112, 119)
      temp = temp + M(121, 113) * M(113, 119)
      temp = temp + M(121, 114) * M(114, 119)
      temp = temp + M(121, 115) * M(115, 119)
      temp = temp + M(121, 116) * M(116, 119)
      temp = temp + M(121, 117) * M(117, 119)
      temp = temp + M(121, 118) * M(118, 119)
      M(121, 119) = M(121, 119) - temp
C     Lower part.
      temp = M(122, 54) * M(54, 119)
      temp = temp + M(122, 60) * M(60, 119)
      temp = temp + M(122, 63) * M(63, 119)
      temp = temp + M(122, 64) * M(64, 119)
      temp = temp + M(122, 65) * M(65, 119)
      temp = temp + M(122, 66) * M(66, 119)
      temp = temp + M(122, 67) * M(67, 119)
      temp = temp + M(122, 68) * M(68, 119)
      temp = temp + M(122, 69) * M(69, 119)
      temp = temp + M(122, 70) * M(70, 119)
      temp = temp + M(122, 71) * M(71, 119)
      temp = temp + M(122, 72) * M(72, 119)
      temp = temp + M(122, 73) * M(73, 119)
      temp = temp + M(122, 76) * M(76, 119)
      temp = temp + M(122, 77) * M(77, 119)
      temp = temp + M(122, 78) * M(78, 119)
      temp = temp + M(122, 79) * M(79, 119)
      temp = temp + M(122, 80) * M(80, 119)
      temp = temp + M(122, 81) * M(81, 119)
      temp = temp + M(122, 82) * M(82, 119)
      temp = temp + M(122, 83) * M(83, 119)
      temp = temp + M(122, 84) * M(84, 119)
      temp = temp + M(122, 85) * M(85, 119)
      temp = temp + M(122, 87) * M(87, 119)
      temp = temp + M(122, 88) * M(88, 119)
      temp = temp + M(122, 90) * M(90, 119)
      temp = temp + M(122, 91) * M(91, 119)
      temp = temp + M(122, 92) * M(92, 119)
      temp = temp + M(122, 94) * M(94, 119)
      temp = temp + M(122, 95) * M(95, 119)
      temp = temp + M(122, 96) * M(96, 119)
      temp = temp + M(122, 97) * M(97, 119)
      temp = temp + M(122, 98) * M(98, 119)
      temp = temp + M(122, 100) * M(100, 119)
      temp = temp + M(122, 103) * M(103, 119)
      temp = temp + M(122, 104) * M(104, 119)
      temp = temp + M(122, 105) * M(105, 119)
      temp = temp + M(122, 106) * M(106, 119)
      temp = temp + M(122, 110) * M(110, 119)
      temp = temp + M(122, 111) * M(111, 119)
      temp = temp + M(122, 112) * M(112, 119)
      temp = temp + M(122, 113) * M(113, 119)
      temp = temp + M(122, 114) * M(114, 119)
      temp = temp + M(122, 115) * M(115, 119)
      temp = temp + M(122, 117) * M(117, 119)
      temp = temp + M(122, 118) * M(118, 119)
      M(122, 119) = M(122, 119) - temp
C     Lower part.
      temp = M(123, 54) * M(54, 119)
      temp = temp + M(123, 60) * M(60, 119)
      temp = temp + M(123, 63) * M(63, 119)
      temp = temp + M(123, 64) * M(64, 119)
      temp = temp + M(123, 66) * M(66, 119)
      temp = temp + M(123, 67) * M(67, 119)
      temp = temp + M(123, 71) * M(71, 119)
      temp = temp + M(123, 72) * M(72, 119)
      temp = temp + M(123, 76) * M(76, 119)
      temp = temp + M(123, 77) * M(77, 119)
      temp = temp + M(123, 78) * M(78, 119)
      temp = temp + M(123, 79) * M(79, 119)
      temp = temp + M(123, 80) * M(80, 119)
      temp = temp + M(123, 82) * M(82, 119)
      temp = temp + M(123, 84) * M(84, 119)
      temp = temp + M(123, 85) * M(85, 119)
      temp = temp + M(123, 87) * M(87, 119)
      temp = temp + M(123, 88) * M(88, 119)
      temp = temp + M(123, 90) * M(90, 119)
      temp = temp + M(123, 91) * M(91, 119)
      temp = temp + M(123, 92) * M(92, 119)
      temp = temp + M(123, 95) * M(95, 119)
      temp = temp + M(123, 96) * M(96, 119)
      temp = temp + M(123, 97) * M(97, 119)
      temp = temp + M(123, 98) * M(98, 119)
      temp = temp + M(123, 103) * M(103, 119)
      temp = temp + M(123, 104) * M(104, 119)
      temp = temp + M(123, 105) * M(105, 119)
      temp = temp + M(123, 106) * M(106, 119)
      temp = temp + M(123, 110) * M(110, 119)
      temp = temp + M(123, 111) * M(111, 119)
      temp = temp + M(123, 112) * M(112, 119)
      temp = temp + M(123, 113) * M(113, 119)
      temp = temp + M(123, 114) * M(114, 119)
      temp = temp + M(123, 115) * M(115, 119)
      temp = temp + M(123, 117) * M(117, 119)
      temp = temp + M(123, 118) * M(118, 119)
      M(123, 119) = M(123, 119) - temp
C     Upper part.
      temp = M(119, 106) * M(106, 120)
      temp = temp + M(119, 107) * M(107, 120)
      temp = temp + M(119, 112) * M(112, 120)
      temp = temp + M(119, 113) * M(113, 120)
      temp = temp + M(119, 114) * M(114, 120)
      temp = temp + M(119, 115) * M(115, 120)
      temp = temp + M(119, 116) * M(116, 120)
      temp = temp + M(119, 117) * M(117, 120)
      temp = temp + M(119, 118) * M(118, 120)
      M(119, 120) = ( M(119, 120) - temp ) / M(119, 119)
C     Upper part.
      temp = M(119, 43) * M(43, 121)
      temp = temp + M(119, 62) * M(62, 121)
      temp = temp + M(119, 66) * M(66, 121)
      temp = temp + M(119, 91) * M(91, 121)
      temp = temp + M(119, 92) * M(92, 121)
      temp = temp + M(119, 93) * M(93, 121)
      temp = temp + M(119, 94) * M(94, 121)
      temp = temp + M(119, 95) * M(95, 121)
      temp = temp + M(119, 96) * M(96, 121)
      temp = temp + M(119, 97) * M(97, 121)
      temp = temp + M(119, 98) * M(98, 121)
      temp = temp + M(119, 99) * M(99, 121)
      temp = temp + M(119, 100) * M(100, 121)
      temp = temp + M(119, 102) * M(102, 121)
      temp = temp + M(119, 104) * M(104, 121)
      temp = temp + M(119, 105) * M(105, 121)
      temp = temp + M(119, 106) * M(106, 121)
      temp = temp + M(119, 107) * M(107, 121)
      temp = temp + M(119, 108) * M(108, 121)
      temp = temp + M(119, 109) * M(109, 121)
      temp = temp + M(119, 110) * M(110, 121)
      temp = temp + M(119, 111) * M(111, 121)
      temp = temp + M(119, 112) * M(112, 121)
      temp = temp + M(119, 113) * M(113, 121)
      temp = temp + M(119, 114) * M(114, 121)
      temp = temp + M(119, 115) * M(115, 121)
      temp = temp + M(119, 116) * M(116, 121)
      temp = temp + M(119, 117) * M(117, 121)
      temp = temp + M(119, 118) * M(118, 121)
      M(119, 121) = ( M(119, 121) - temp ) / M(119, 119)
C     Upper part.
      temp = M(119, 52) * M(52, 122)
      temp = temp + M(119, 53) * M(53, 122)
      temp = temp + M(119, 54) * M(54, 122)
      temp = temp + M(119, 55) * M(55, 122)
      temp = temp + M(119, 56) * M(56, 122)
      temp = temp + M(119, 57) * M(57, 122)
      temp = temp + M(119, 58) * M(58, 122)
      temp = temp + M(119, 60) * M(60, 122)
      temp = temp + M(119, 61) * M(61, 122)
      temp = temp + M(119, 62) * M(62, 122)
      temp = temp + M(119, 63) * M(63, 122)
      temp = temp + M(119, 64) * M(64, 122)
      temp = temp + M(119, 65) * M(65, 122)
      temp = temp + M(119, 66) * M(66, 122)
      temp = temp + M(119, 67) * M(67, 122)
      temp = temp + M(119, 68) * M(68, 122)
      temp = temp + M(119, 69) * M(69, 122)
      temp = temp + M(119, 71) * M(71, 122)
      temp = temp + M(119, 72) * M(72, 122)
      temp = temp + M(119, 74) * M(74, 122)
      temp = temp + M(119, 75) * M(75, 122)
      temp = temp + M(119, 76) * M(76, 122)
      temp = temp + M(119, 77) * M(77, 122)
      temp = temp + M(119, 78) * M(78, 122)
      temp = temp + M(119, 79) * M(79, 122)
      temp = temp + M(119, 80) * M(80, 122)
      temp = temp + M(119, 81) * M(81, 122)
      temp = temp + M(119, 82) * M(82, 122)
      temp = temp + M(119, 83) * M(83, 122)
      temp = temp + M(119, 84) * M(84, 122)
      temp = temp + M(119, 85) * M(85, 122)
      temp = temp + M(119, 86) * M(86, 122)
      temp = temp + M(119, 87) * M(87, 122)
      temp = temp + M(119, 88) * M(88, 122)
      temp = temp + M(119, 89) * M(89, 122)
      temp = temp + M(119, 90) * M(90, 122)
      temp = temp + M(119, 91) * M(91, 122)
      temp = temp + M(119, 92) * M(92, 122)
      temp = temp + M(119, 93) * M(93, 122)
      temp = temp + M(119, 94) * M(94, 122)
      temp = temp + M(119, 95) * M(95, 122)
      temp = temp + M(119, 96) * M(96, 122)
      temp = temp + M(119, 97) * M(97, 122)
      temp = temp + M(119, 98) * M(98, 122)
      temp = temp + M(119, 99) * M(99, 122)
      temp = temp + M(119, 100) * M(100, 122)
      temp = temp + M(119, 102) * M(102, 122)
      temp = temp + M(119, 103) * M(103, 122)
      temp = temp + M(119, 104) * M(104, 122)
      temp = temp + M(119, 105) * M(105, 122)
      temp = temp + M(119, 106) * M(106, 122)
      temp = temp + M(119, 107) * M(107, 122)
      temp = temp + M(119, 108) * M(108, 122)
      temp = temp + M(119, 109) * M(109, 122)
      temp = temp + M(119, 110) * M(110, 122)
      temp = temp + M(119, 111) * M(111, 122)
      temp = temp + M(119, 112) * M(112, 122)
      temp = temp + M(119, 113) * M(113, 122)
      temp = temp + M(119, 114) * M(114, 122)
      temp = temp + M(119, 115) * M(115, 122)
      temp = temp + M(119, 116) * M(116, 122)
      temp = temp + M(119, 117) * M(117, 122)
      temp = temp + M(119, 118) * M(118, 122)
      M(119, 122) = ( M(119, 122) - temp ) / M(119, 119)
C     Upper part.
      temp = M(119, 52) * M(52, 123)
      temp = temp + M(119, 53) * M(53, 123)
      temp = temp + M(119, 54) * M(54, 123)
      temp = temp + M(119, 55) * M(55, 123)
      temp = temp + M(119, 56) * M(56, 123)
      temp = temp + M(119, 57) * M(57, 123)
      temp = temp + M(119, 58) * M(58, 123)
      temp = temp + M(119, 60) * M(60, 123)
      temp = temp + M(119, 61) * M(61, 123)
      temp = temp + M(119, 62) * M(62, 123)
      temp = temp + M(119, 63) * M(63, 123)
      temp = temp + M(119, 64) * M(64, 123)
      temp = temp + M(119, 65) * M(65, 123)
      temp = temp + M(119, 66) * M(66, 123)
      temp = temp + M(119, 67) * M(67, 123)
      temp = temp + M(119, 68) * M(68, 123)
      temp = temp + M(119, 69) * M(69, 123)
      temp = temp + M(119, 71) * M(71, 123)
      temp = temp + M(119, 72) * M(72, 123)
      temp = temp + M(119, 74) * M(74, 123)
      temp = temp + M(119, 75) * M(75, 123)
      temp = temp + M(119, 76) * M(76, 123)
      temp = temp + M(119, 77) * M(77, 123)
      temp = temp + M(119, 78) * M(78, 123)
      temp = temp + M(119, 79) * M(79, 123)
      temp = temp + M(119, 80) * M(80, 123)
      temp = temp + M(119, 81) * M(81, 123)
      temp = temp + M(119, 82) * M(82, 123)
      temp = temp + M(119, 83) * M(83, 123)
      temp = temp + M(119, 84) * M(84, 123)
      temp = temp + M(119, 85) * M(85, 123)
      temp = temp + M(119, 86) * M(86, 123)
      temp = temp + M(119, 87) * M(87, 123)
      temp = temp + M(119, 88) * M(88, 123)
      temp = temp + M(119, 89) * M(89, 123)
      temp = temp + M(119, 90) * M(90, 123)
      temp = temp + M(119, 91) * M(91, 123)
      temp = temp + M(119, 92) * M(92, 123)
      temp = temp + M(119, 93) * M(93, 123)
      temp = temp + M(119, 94) * M(94, 123)
      temp = temp + M(119, 95) * M(95, 123)
      temp = temp + M(119, 96) * M(96, 123)
      temp = temp + M(119, 97) * M(97, 123)
      temp = temp + M(119, 98) * M(98, 123)
      temp = temp + M(119, 99) * M(99, 123)
      temp = temp + M(119, 100) * M(100, 123)
      temp = temp + M(119, 102) * M(102, 123)
      temp = temp + M(119, 103) * M(103, 123)
      temp = temp + M(119, 104) * M(104, 123)
      temp = temp + M(119, 105) * M(105, 123)
      temp = temp + M(119, 106) * M(106, 123)
      temp = temp + M(119, 107) * M(107, 123)
      temp = temp + M(119, 108) * M(108, 123)
      temp = temp + M(119, 109) * M(109, 123)
      temp = temp + M(119, 110) * M(110, 123)
      temp = temp + M(119, 111) * M(111, 123)
      temp = temp + M(119, 112) * M(112, 123)
      temp = temp + M(119, 113) * M(113, 123)
      temp = temp + M(119, 114) * M(114, 123)
      temp = temp + M(119, 115) * M(115, 123)
      temp = temp + M(119, 116) * M(116, 123)
      temp = temp + M(119, 117) * M(117, 123)
      temp = temp + M(119, 118) * M(118, 123)
      M(119, 123) = ( M(119, 123) - temp ) / M(119, 119)

C     Lower part.
      temp = M(120, 42) * M(42, 120)
      temp = temp + M(120, 113) * M(113, 120)
      temp = temp + M(120, 114) * M(114, 120)
      temp = temp + M(120, 115) * M(115, 120)
      temp = temp + M(120, 117) * M(117, 120)
      temp = temp + M(120, 118) * M(118, 120)
      temp = temp + M(120, 119) * M(119, 120)
      M(120, 120) = M(120, 120) - temp
C     Lower part.
      temp = M(121, 42) * M(42, 120)
      temp = temp + M(121, 106) * M(106, 120)
      temp = temp + M(121, 112) * M(112, 120)
      temp = temp + M(121, 113) * M(113, 120)
      temp = temp + M(121, 114) * M(114, 120)
      temp = temp + M(121, 115) * M(115, 120)
      temp = temp + M(121, 116) * M(116, 120)
      temp = temp + M(121, 117) * M(117, 120)
      temp = temp + M(121, 118) * M(118, 120)
      temp = temp + M(121, 119) * M(119, 120)
      M(121, 120) = M(121, 120) - temp
C     Lower part.
      temp = M(122, 70) * M(70, 120)
      temp = temp + M(122, 106) * M(106, 120)
      temp = temp + M(122, 112) * M(112, 120)
      temp = temp + M(122, 113) * M(113, 120)
      temp = temp + M(122, 114) * M(114, 120)
      temp = temp + M(122, 115) * M(115, 120)
      temp = temp + M(122, 117) * M(117, 120)
      temp = temp + M(122, 118) * M(118, 120)
      temp = temp + M(122, 119) * M(119, 120)
      M(122, 120) = M(122, 120) - temp
C     Lower part.
      temp = M(123, 106) * M(106, 120)
      temp = temp + M(123, 112) * M(112, 120)
      temp = temp + M(123, 113) * M(113, 120)
      temp = temp + M(123, 114) * M(114, 120)
      temp = temp + M(123, 115) * M(115, 120)
      temp = temp + M(123, 117) * M(117, 120)
      temp = temp + M(123, 118) * M(118, 120)
      temp = temp + M(123, 119) * M(119, 120)
      M(123, 120) = M(123, 120) - temp
C     Upper part.
      temp = M(120, 42) * M(42, 121)
      temp = temp + M(120, 109) * M(109, 121)
      temp = temp + M(120, 110) * M(110, 121)
      temp = temp + M(120, 111) * M(111, 121)
      temp = temp + M(120, 113) * M(113, 121)
      temp = temp + M(120, 114) * M(114, 121)
      temp = temp + M(120, 115) * M(115, 121)
      temp = temp + M(120, 117) * M(117, 121)
      temp = temp + M(120, 118) * M(118, 121)
      temp = temp + M(120, 119) * M(119, 121)
      M(120, 121) = ( M(120, 121) - temp ) / M(120, 120)
C     Upper part.
      temp = M(120, 109) * M(109, 122)
      temp = temp + M(120, 110) * M(110, 122)
      temp = temp + M(120, 111) * M(111, 122)
      temp = temp + M(120, 113) * M(113, 122)
      temp = temp + M(120, 114) * M(114, 122)
      temp = temp + M(120, 115) * M(115, 122)
      temp = temp + M(120, 117) * M(117, 122)
      temp = temp + M(120, 118) * M(118, 122)
      temp = temp + M(120, 119) * M(119, 122)
      M(120, 122) = ( M(120, 122) - temp ) / M(120, 120)
C     Upper part.
      temp = M(120, 109) * M(109, 123)
      temp = temp + M(120, 110) * M(110, 123)
      temp = temp + M(120, 111) * M(111, 123)
      temp = temp + M(120, 113) * M(113, 123)
      temp = temp + M(120, 114) * M(114, 123)
      temp = temp + M(120, 115) * M(115, 123)
      temp = temp + M(120, 117) * M(117, 123)
      temp = temp + M(120, 118) * M(118, 123)
      temp = temp + M(120, 119) * M(119, 123)
      M(120, 123) = ( M(120, 123) - temp ) / M(120, 120)

C     Lower part.
      temp = M(121, 18) * M(18, 121)
      temp = temp + M(121, 24) * M(24, 121)
      temp = temp + M(121, 41) * M(41, 121)
      temp = temp + M(121, 42) * M(42, 121)
      temp = temp + M(121, 43) * M(43, 121)
      temp = temp + M(121, 46) * M(46, 121)
      temp = temp + M(121, 47) * M(47, 121)
      temp = temp + M(121, 59) * M(59, 121)
      temp = temp + M(121, 62) * M(62, 121)
      temp = temp + M(121, 66) * M(66, 121)
      temp = temp + M(121, 91) * M(91, 121)
      temp = temp + M(121, 92) * M(92, 121)
      temp = temp + M(121, 95) * M(95, 121)
      temp = temp + M(121, 96) * M(96, 121)
      temp = temp + M(121, 97) * M(97, 121)
      temp = temp + M(121, 98) * M(98, 121)
      temp = temp + M(121, 101) * M(101, 121)
      temp = temp + M(121, 102) * M(102, 121)
      temp = temp + M(121, 104) * M(104, 121)
      temp = temp + M(121, 105) * M(105, 121)
      temp = temp + M(121, 106) * M(106, 121)
      temp = temp + M(121, 108) * M(108, 121)
      temp = temp + M(121, 109) * M(109, 121)
      temp = temp + M(121, 110) * M(110, 121)
      temp = temp + M(121, 111) * M(111, 121)
      temp = temp + M(121, 112) * M(112, 121)
      temp = temp + M(121, 113) * M(113, 121)
      temp = temp + M(121, 114) * M(114, 121)
      temp = temp + M(121, 115) * M(115, 121)
      temp = temp + M(121, 116) * M(116, 121)
      temp = temp + M(121, 117) * M(117, 121)
      temp = temp + M(121, 118) * M(118, 121)
      temp = temp + M(121, 119) * M(119, 121)
      temp = temp + M(121, 120) * M(120, 121)
      M(121, 121) = M(121, 121) - temp
C     Lower part.
      temp = M(122, 41) * M(41, 121)
      temp = temp + M(122, 66) * M(66, 121)
      temp = temp + M(122, 91) * M(91, 121)
      temp = temp + M(122, 92) * M(92, 121)
      temp = temp + M(122, 94) * M(94, 121)
      temp = temp + M(122, 95) * M(95, 121)
      temp = temp + M(122, 96) * M(96, 121)
      temp = temp + M(122, 97) * M(97, 121)
      temp = temp + M(122, 98) * M(98, 121)
      temp = temp + M(122, 100) * M(100, 121)
      temp = temp + M(122, 104) * M(104, 121)
      temp = temp + M(122, 105) * M(105, 121)
      temp = temp + M(122, 106) * M(106, 121)
      temp = temp + M(122, 110) * M(110, 121)
      temp = temp + M(122, 111) * M(111, 121)
      temp = temp + M(122, 112) * M(112, 121)
      temp = temp + M(122, 113) * M(113, 121)
      temp = temp + M(122, 114) * M(114, 121)
      temp = temp + M(122, 115) * M(115, 121)
      temp = temp + M(122, 117) * M(117, 121)
      temp = temp + M(122, 118) * M(118, 121)
      temp = temp + M(122, 119) * M(119, 121)
      temp = temp + M(122, 120) * M(120, 121)
      M(122, 121) = M(122, 121) - temp
C     Lower part.
      temp = M(123, 24) * M(24, 121)
      temp = temp + M(123, 47) * M(47, 121)
      temp = temp + M(123, 66) * M(66, 121)
      temp = temp + M(123, 91) * M(91, 121)
      temp = temp + M(123, 92) * M(92, 121)
      temp = temp + M(123, 95) * M(95, 121)
      temp = temp + M(123, 96) * M(96, 121)
      temp = temp + M(123, 97) * M(97, 121)
      temp = temp + M(123, 98) * M(98, 121)
      temp = temp + M(123, 104) * M(104, 121)
      temp = temp + M(123, 105) * M(105, 121)
      temp = temp + M(123, 106) * M(106, 121)
      temp = temp + M(123, 110) * M(110, 121)
      temp = temp + M(123, 111) * M(111, 121)
      temp = temp + M(123, 112) * M(112, 121)
      temp = temp + M(123, 113) * M(113, 121)
      temp = temp + M(123, 114) * M(114, 121)
      temp = temp + M(123, 115) * M(115, 121)
      temp = temp + M(123, 117) * M(117, 121)
      temp = temp + M(123, 118) * M(118, 121)
      temp = temp + M(123, 119) * M(119, 121)
      temp = temp + M(123, 120) * M(120, 121)
      M(123, 121) = M(123, 121) - temp
C     Upper part.
      temp = M(121, 41) * M(41, 122)
      temp = temp + M(121, 52) * M(52, 122)
      temp = temp + M(121, 53) * M(53, 122)
      temp = temp + M(121, 54) * M(54, 122)
      temp = temp + M(121, 55) * M(55, 122)
      temp = temp + M(121, 57) * M(57, 122)
      temp = temp + M(121, 58) * M(58, 122)
      temp = temp + M(121, 59) * M(59, 122)
      temp = temp + M(121, 60) * M(60, 122)
      temp = temp + M(121, 62) * M(62, 122)
      temp = temp + M(121, 63) * M(63, 122)
      temp = temp + M(121, 64) * M(64, 122)
      temp = temp + M(121, 66) * M(66, 122)
      temp = temp + M(121, 67) * M(67, 122)
      temp = temp + M(121, 71) * M(71, 122)
      temp = temp + M(121, 72) * M(72, 122)
      temp = temp + M(121, 76) * M(76, 122)
      temp = temp + M(121, 77) * M(77, 122)
      temp = temp + M(121, 78) * M(78, 122)
      temp = temp + M(121, 79) * M(79, 122)
      temp = temp + M(121, 80) * M(80, 122)
      temp = temp + M(121, 82) * M(82, 122)
      temp = temp + M(121, 84) * M(84, 122)
      temp = temp + M(121, 85) * M(85, 122)
      temp = temp + M(121, 87) * M(87, 122)
      temp = temp + M(121, 88) * M(88, 122)
      temp = temp + M(121, 90) * M(90, 122)
      temp = temp + M(121, 91) * M(91, 122)
      temp = temp + M(121, 92) * M(92, 122)
      temp = temp + M(121, 95) * M(95, 122)
      temp = temp + M(121, 96) * M(96, 122)
      temp = temp + M(121, 97) * M(97, 122)
      temp = temp + M(121, 98) * M(98, 122)
      temp = temp + M(121, 101) * M(101, 122)
      temp = temp + M(121, 102) * M(102, 122)
      temp = temp + M(121, 103) * M(103, 122)
      temp = temp + M(121, 104) * M(104, 122)
      temp = temp + M(121, 105) * M(105, 122)
      temp = temp + M(121, 106) * M(106, 122)
      temp = temp + M(121, 108) * M(108, 122)
      temp = temp + M(121, 109) * M(109, 122)
      temp = temp + M(121, 110) * M(110, 122)
      temp = temp + M(121, 111) * M(111, 122)
      temp = temp + M(121, 112) * M(112, 122)
      temp = temp + M(121, 113) * M(113, 122)
      temp = temp + M(121, 114) * M(114, 122)
      temp = temp + M(121, 115) * M(115, 122)
      temp = temp + M(121, 116) * M(116, 122)
      temp = temp + M(121, 117) * M(117, 122)
      temp = temp + M(121, 118) * M(118, 122)
      temp = temp + M(121, 119) * M(119, 122)
      temp = temp + M(121, 120) * M(120, 122)
      M(121, 122) = ( M(121, 122) - temp ) / M(121, 121)
C     Upper part.
      temp = M(121, 24) * M(24, 123)
      temp = temp + M(121, 45) * M(45, 123)
      temp = temp + M(121, 47) * M(47, 123)
      temp = temp + M(121, 52) * M(52, 123)
      temp = temp + M(121, 53) * M(53, 123)
      temp = temp + M(121, 54) * M(54, 123)
      temp = temp + M(121, 55) * M(55, 123)
      temp = temp + M(121, 57) * M(57, 123)
      temp = temp + M(121, 58) * M(58, 123)
      temp = temp + M(121, 59) * M(59, 123)
      temp = temp + M(121, 60) * M(60, 123)
      temp = temp + M(121, 62) * M(62, 123)
      temp = temp + M(121, 63) * M(63, 123)
      temp = temp + M(121, 64) * M(64, 123)
      temp = temp + M(121, 66) * M(66, 123)
      temp = temp + M(121, 67) * M(67, 123)
      temp = temp + M(121, 71) * M(71, 123)
      temp = temp + M(121, 72) * M(72, 123)
      temp = temp + M(121, 76) * M(76, 123)
      temp = temp + M(121, 77) * M(77, 123)
      temp = temp + M(121, 78) * M(78, 123)
      temp = temp + M(121, 79) * M(79, 123)
      temp = temp + M(121, 80) * M(80, 123)
      temp = temp + M(121, 82) * M(82, 123)
      temp = temp + M(121, 84) * M(84, 123)
      temp = temp + M(121, 85) * M(85, 123)
      temp = temp + M(121, 87) * M(87, 123)
      temp = temp + M(121, 88) * M(88, 123)
      temp = temp + M(121, 90) * M(90, 123)
      temp = temp + M(121, 91) * M(91, 123)
      temp = temp + M(121, 92) * M(92, 123)
      temp = temp + M(121, 95) * M(95, 123)
      temp = temp + M(121, 96) * M(96, 123)
      temp = temp + M(121, 97) * M(97, 123)
      temp = temp + M(121, 98) * M(98, 123)
      temp = temp + M(121, 101) * M(101, 123)
      temp = temp + M(121, 102) * M(102, 123)
      temp = temp + M(121, 103) * M(103, 123)
      temp = temp + M(121, 104) * M(104, 123)
      temp = temp + M(121, 105) * M(105, 123)
      temp = temp + M(121, 106) * M(106, 123)
      temp = temp + M(121, 108) * M(108, 123)
      temp = temp + M(121, 109) * M(109, 123)
      temp = temp + M(121, 110) * M(110, 123)
      temp = temp + M(121, 111) * M(111, 123)
      temp = temp + M(121, 112) * M(112, 123)
      temp = temp + M(121, 113) * M(113, 123)
      temp = temp + M(121, 114) * M(114, 123)
      temp = temp + M(121, 115) * M(115, 123)
      temp = temp + M(121, 116) * M(116, 123)
      temp = temp + M(121, 117) * M(117, 123)
      temp = temp + M(121, 118) * M(118, 123)
      temp = temp + M(121, 119) * M(119, 123)
      temp = temp + M(121, 120) * M(120, 123)
      M(121, 123) = ( M(121, 123) - temp ) / M(121, 121)

C     Lower part.
      temp = M(122, 41) * M(41, 122)
      temp = temp + M(122, 52) * M(52, 122)
      temp = temp + M(122, 53) * M(53, 122)
      temp = temp + M(122, 54) * M(54, 122)
      temp = temp + M(122, 55) * M(55, 122)
      temp = temp + M(122, 57) * M(57, 122)
      temp = temp + M(122, 58) * M(58, 122)
      temp = temp + M(122, 60) * M(60, 122)
      temp = temp + M(122, 63) * M(63, 122)
      temp = temp + M(122, 64) * M(64, 122)
      temp = temp + M(122, 65) * M(65, 122)
      temp = temp + M(122, 66) * M(66, 122)
      temp = temp + M(122, 67) * M(67, 122)
      temp = temp + M(122, 68) * M(68, 122)
      temp = temp + M(122, 69) * M(69, 122)
      temp = temp + M(122, 70) * M(70, 122)
      temp = temp + M(122, 71) * M(71, 122)
      temp = temp + M(122, 72) * M(72, 122)
      temp = temp + M(122, 73) * M(73, 122)
      temp = temp + M(122, 75) * M(75, 122)
      temp = temp + M(122, 76) * M(76, 122)
      temp = temp + M(122, 77) * M(77, 122)
      temp = temp + M(122, 78) * M(78, 122)
      temp = temp + M(122, 79) * M(79, 122)
      temp = temp + M(122, 80) * M(80, 122)
      temp = temp + M(122, 81) * M(81, 122)
      temp = temp + M(122, 82) * M(82, 122)
      temp = temp + M(122, 83) * M(83, 122)
      temp = temp + M(122, 84) * M(84, 122)
      temp = temp + M(122, 85) * M(85, 122)
      temp = temp + M(122, 87) * M(87, 122)
      temp = temp + M(122, 88) * M(88, 122)
      temp = temp + M(122, 90) * M(90, 122)
      temp = temp + M(122, 91) * M(91, 122)
      temp = temp + M(122, 92) * M(92, 122)
      temp = temp + M(122, 94) * M(94, 122)
      temp = temp + M(122, 95) * M(95, 122)
      temp = temp + M(122, 96) * M(96, 122)
      temp = temp + M(122, 97) * M(97, 122)
      temp = temp + M(122, 98) * M(98, 122)
      temp = temp + M(122, 100) * M(100, 122)
      temp = temp + M(122, 103) * M(103, 122)
      temp = temp + M(122, 104) * M(104, 122)
      temp = temp + M(122, 105) * M(105, 122)
      temp = temp + M(122, 106) * M(106, 122)
      temp = temp + M(122, 110) * M(110, 122)
      temp = temp + M(122, 111) * M(111, 122)
      temp = temp + M(122, 112) * M(112, 122)
      temp = temp + M(122, 113) * M(113, 122)
      temp = temp + M(122, 114) * M(114, 122)
      temp = temp + M(122, 115) * M(115, 122)
      temp = temp + M(122, 117) * M(117, 122)
      temp = temp + M(122, 118) * M(118, 122)
      temp = temp + M(122, 119) * M(119, 122)
      temp = temp + M(122, 120) * M(120, 122)
      temp = temp + M(122, 121) * M(121, 122)
      M(122, 122) = M(122, 122) - temp
C     Lower part.
      temp = M(123, 52) * M(52, 122)
      temp = temp + M(123, 53) * M(53, 122)
      temp = temp + M(123, 54) * M(54, 122)
      temp = temp + M(123, 55) * M(55, 122)
      temp = temp + M(123, 57) * M(57, 122)
      temp = temp + M(123, 58) * M(58, 122)
      temp = temp + M(123, 60) * M(60, 122)
      temp = temp + M(123, 63) * M(63, 122)
      temp = temp + M(123, 64) * M(64, 122)
      temp = temp + M(123, 66) * M(66, 122)
      temp = temp + M(123, 67) * M(67, 122)
      temp = temp + M(123, 71) * M(71, 122)
      temp = temp + M(123, 72) * M(72, 122)
      temp = temp + M(123, 76) * M(76, 122)
      temp = temp + M(123, 77) * M(77, 122)
      temp = temp + M(123, 78) * M(78, 122)
      temp = temp + M(123, 79) * M(79, 122)
      temp = temp + M(123, 80) * M(80, 122)
      temp = temp + M(123, 82) * M(82, 122)
      temp = temp + M(123, 84) * M(84, 122)
      temp = temp + M(123, 85) * M(85, 122)
      temp = temp + M(123, 87) * M(87, 122)
      temp = temp + M(123, 88) * M(88, 122)
      temp = temp + M(123, 90) * M(90, 122)
      temp = temp + M(123, 91) * M(91, 122)
      temp = temp + M(123, 92) * M(92, 122)
      temp = temp + M(123, 95) * M(95, 122)
      temp = temp + M(123, 96) * M(96, 122)
      temp = temp + M(123, 97) * M(97, 122)
      temp = temp + M(123, 98) * M(98, 122)
      temp = temp + M(123, 103) * M(103, 122)
      temp = temp + M(123, 104) * M(104, 122)
      temp = temp + M(123, 105) * M(105, 122)
      temp = temp + M(123, 106) * M(106, 122)
      temp = temp + M(123, 110) * M(110, 122)
      temp = temp + M(123, 111) * M(111, 122)
      temp = temp + M(123, 112) * M(112, 122)
      temp = temp + M(123, 113) * M(113, 122)
      temp = temp + M(123, 114) * M(114, 122)
      temp = temp + M(123, 115) * M(115, 122)
      temp = temp + M(123, 117) * M(117, 122)
      temp = temp + M(123, 118) * M(118, 122)
      temp = temp + M(123, 119) * M(119, 122)
      temp = temp + M(123, 120) * M(120, 122)
      temp = temp + M(123, 121) * M(121, 122)
      M(123, 122) = M(123, 122) - temp
C     Upper part.
      temp = M(122, 37) * M(37, 123)
      temp = temp + M(122, 52) * M(52, 123)
      temp = temp + M(122, 53) * M(53, 123)
      temp = temp + M(122, 54) * M(54, 123)
      temp = temp + M(122, 55) * M(55, 123)
      temp = temp + M(122, 57) * M(57, 123)
      temp = temp + M(122, 58) * M(58, 123)
      temp = temp + M(122, 60) * M(60, 123)
      temp = temp + M(122, 63) * M(63, 123)
      temp = temp + M(122, 64) * M(64, 123)
      temp = temp + M(122, 65) * M(65, 123)
      temp = temp + M(122, 66) * M(66, 123)
      temp = temp + M(122, 67) * M(67, 123)
      temp = temp + M(122, 68) * M(68, 123)
      temp = temp + M(122, 69) * M(69, 123)
      temp = temp + M(122, 70) * M(70, 123)
      temp = temp + M(122, 71) * M(71, 123)
      temp = temp + M(122, 72) * M(72, 123)
      temp = temp + M(122, 73) * M(73, 123)
      temp = temp + M(122, 75) * M(75, 123)
      temp = temp + M(122, 76) * M(76, 123)
      temp = temp + M(122, 77) * M(77, 123)
      temp = temp + M(122, 78) * M(78, 123)
      temp = temp + M(122, 79) * M(79, 123)
      temp = temp + M(122, 80) * M(80, 123)
      temp = temp + M(122, 81) * M(81, 123)
      temp = temp + M(122, 82) * M(82, 123)
      temp = temp + M(122, 83) * M(83, 123)
      temp = temp + M(122, 84) * M(84, 123)
      temp = temp + M(122, 85) * M(85, 123)
      temp = temp + M(122, 87) * M(87, 123)
      temp = temp + M(122, 88) * M(88, 123)
      temp = temp + M(122, 90) * M(90, 123)
      temp = temp + M(122, 91) * M(91, 123)
      temp = temp + M(122, 92) * M(92, 123)
      temp = temp + M(122, 94) * M(94, 123)
      temp = temp + M(122, 95) * M(95, 123)
      temp = temp + M(122, 96) * M(96, 123)
      temp = temp + M(122, 97) * M(97, 123)
      temp = temp + M(122, 98) * M(98, 123)
      temp = temp + M(122, 100) * M(100, 123)
      temp = temp + M(122, 103) * M(103, 123)
      temp = temp + M(122, 104) * M(104, 123)
      temp = temp + M(122, 105) * M(105, 123)
      temp = temp + M(122, 106) * M(106, 123)
      temp = temp + M(122, 110) * M(110, 123)
      temp = temp + M(122, 111) * M(111, 123)
      temp = temp + M(122, 112) * M(112, 123)
      temp = temp + M(122, 113) * M(113, 123)
      temp = temp + M(122, 114) * M(114, 123)
      temp = temp + M(122, 115) * M(115, 123)
      temp = temp + M(122, 117) * M(117, 123)
      temp = temp + M(122, 118) * M(118, 123)
      temp = temp + M(122, 119) * M(119, 123)
      temp = temp + M(122, 120) * M(120, 123)
      temp = temp + M(122, 121) * M(121, 123)
      M(122, 123) = ( M(122, 123) - temp ) / M(122, 122)

C     Lower part.
      temp = M(123, 24) * M(24, 123)
      temp = temp + M(123, 47) * M(47, 123)
      temp = temp + M(123, 52) * M(52, 123)
      temp = temp + M(123, 53) * M(53, 123)
      temp = temp + M(123, 54) * M(54, 123)
      temp = temp + M(123, 55) * M(55, 123)
      temp = temp + M(123, 57) * M(57, 123)
      temp = temp + M(123, 58) * M(58, 123)
      temp = temp + M(123, 60) * M(60, 123)
      temp = temp + M(123, 63) * M(63, 123)
      temp = temp + M(123, 64) * M(64, 123)
      temp = temp + M(123, 66) * M(66, 123)
      temp = temp + M(123, 67) * M(67, 123)
      temp = temp + M(123, 71) * M(71, 123)
      temp = temp + M(123, 72) * M(72, 123)
      temp = temp + M(123, 76) * M(76, 123)
      temp = temp + M(123, 77) * M(77, 123)
      temp = temp + M(123, 78) * M(78, 123)
      temp = temp + M(123, 79) * M(79, 123)
      temp = temp + M(123, 80) * M(80, 123)
      temp = temp + M(123, 82) * M(82, 123)
      temp = temp + M(123, 84) * M(84, 123)
      temp = temp + M(123, 85) * M(85, 123)
      temp = temp + M(123, 87) * M(87, 123)
      temp = temp + M(123, 88) * M(88, 123)
      temp = temp + M(123, 90) * M(90, 123)
      temp = temp + M(123, 91) * M(91, 123)
      temp = temp + M(123, 92) * M(92, 123)
      temp = temp + M(123, 95) * M(95, 123)
      temp = temp + M(123, 96) * M(96, 123)
      temp = temp + M(123, 97) * M(97, 123)
      temp = temp + M(123, 98) * M(98, 123)
      temp = temp + M(123, 103) * M(103, 123)
      temp = temp + M(123, 104) * M(104, 123)
      temp = temp + M(123, 105) * M(105, 123)
      temp = temp + M(123, 106) * M(106, 123)
      temp = temp + M(123, 110) * M(110, 123)
      temp = temp + M(123, 111) * M(111, 123)
      temp = temp + M(123, 112) * M(112, 123)
      temp = temp + M(123, 113) * M(113, 123)
      temp = temp + M(123, 114) * M(114, 123)
      temp = temp + M(123, 115) * M(115, 123)
      temp = temp + M(123, 117) * M(117, 123)
      temp = temp + M(123, 118) * M(118, 123)
      temp = temp + M(123, 119) * M(119, 123)
      temp = temp + M(123, 120) * M(120, 123)
      temp = temp + M(123, 121) * M(121, 123)
      temp = temp + M(123, 122) * M(122, 123)
      M(123, 123) = M(123, 123) - temp


      END
