C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc_racm2(ns,nr,y,convers_factor,
     $     convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: RACM2               
C     Species: _ciRACM2            
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j).
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
 
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc_racm2(ns,nr,rk,conc,dw)
 
      JacC( 44,110) = JacC( 44,110) + dw(  1,110)
      JacC(102,110) = JacC(102,110) + dw(  1,110)
      JacC(110,110) = JacC(110,110) - dw(  1,110)
      JacC(  1, 81) = JacC(  1, 81) + dw(  2, 81)
      JacC( 81, 81) = JacC( 81, 81) - dw(  2, 81)
      JacC( 44, 81) = JacC( 44, 81) + dw(  3, 81)
      JacC( 81, 81) = JacC( 81, 81) - dw(  3, 81)
      JacC( 15, 15) = JacC( 15, 15) - dw(  4, 15)
      JacC(102, 15) = JacC(102, 15) + dw(  4, 15)
      JacC(112, 15) = JacC(112, 15) + dw(  4, 15)
      JacC( 94, 94) = JacC( 94, 94) - dw(  5, 94)
      JacC(110, 94) = JacC(110, 94) + dw(  5, 94)
      JacC(112, 94) = JacC(112, 94) + dw(  5, 94)
      JacC( 36, 36) = JacC( 36, 36) - dw(  6, 36)
      JacC(109, 36) = JacC(109, 36)+ 0.2000000000000000D+00*dw(  6, 36)
      JacC(110, 36) = JacC(110, 36)+ 0.8000000000000000D+00*dw(  6, 36)
      JacC(111, 36) = JacC(111, 36)+ 0.8000000000000000D+00*dw(  6, 36)
      JacC(112, 36) = JacC(112, 36)+ 0.2000000000000000D+00*dw(  6, 36)
      JacC(102,109) = JacC(102,109) + dw(  7,109)
      JacC(109,109) = JacC(109,109) - dw(  7,109)
      JacC( 44,109) = JacC( 44,109) + dw(  8,109)
      JacC(109,109) = JacC(109,109) - dw(  8,109)
      JacC(110,109) = JacC(110,109) + dw(  8,109)
      JacC( 38, 38) = JacC( 38, 38) - dw(  9, 38)
      JacC(112, 38) = JacC(112, 38)+ 0.2000000000000000D+01*dw(  9, 38)
      JacC( 96,108) = JacC( 96,108) + dw( 10,108)
      JacC(108,108) = JacC(108,108) - dw( 10,108)
      JacC( 96,108) = JacC( 96,108) + dw( 11,108)
      JacC(108,108) = JacC(108,108) - dw( 11,108)
      JacC(111,108) = JacC(111,108)+ 0.2000000000000000D+01*dw( 11,108)
      JacC( 87, 87) = JacC( 87, 87) - dw( 12, 87)
      JacC( 96, 87) = JacC( 96, 87) + dw( 12, 87)
      JacC(100, 87) = JacC(100, 87) + dw( 12, 87)
      JacC(111, 87) = JacC(111, 87) + dw( 12, 87)
      JacC( 96,107) = JacC( 96,107) + dw( 13,107)
      JacC(104,107) = JacC(104,107) + dw( 13,107)
      JacC(107,107) = JacC(107,107) - dw( 13,107)
      JacC(111,107) = JacC(111,107) + dw( 13,107)
      JacC( 58, 58) = JacC( 58, 58) - dw( 14, 58)
      JacC(100, 58) = JacC(100, 58) + dw( 14, 58)
      JacC(105, 58) = JacC(105, 58) + dw( 14, 58)
      JacC( 30, 30) = JacC( 30, 30) - dw( 15, 30)
      JacC(100, 30) = JacC(100, 30)+ 0.5000000000000000D+00*dw( 15, 30)
      JacC(104, 30) = JacC(104, 30)+ 0.5000000000000000D+00*dw( 15, 30)
      JacC(105, 30) = JacC(105, 30) + dw( 15, 30)
      JacC(103,103) = JacC(103,103) - dw( 16,103)
      JacC(104,103) = JacC(104,103) + dw( 16,103)
      JacC(105,103) = JacC(105,103) + dw( 16,103)
      JacC( 76, 76) = JacC( 76, 76) - dw( 17, 76)
      JacC(105, 76) = JacC(105, 76) + dw( 17, 76)
      JacC(108, 76) = JacC(108, 76) + dw( 17, 76)
      JacC(111, 76) = JacC(111, 76) + dw( 17, 76)
      JacC( 61, 61) = JacC( 61, 61) - dw( 18, 61)
      JacC( 95, 61) = JacC( 95, 61)+ 0.3300000000000000D+00*dw( 18, 61)
      JacC( 96, 61) = JacC( 96, 61)+ 0.6700000000000000D+00*dw( 18, 61)
      JacC(101, 61) = JacC(101, 61)+ 0.3400000000000000D+00*dw( 18, 61)
      JacC(105, 61) = JacC(105, 61)+ 0.6700000000000000D+00*dw( 18, 61)
      JacC(108, 61) = JacC(108, 61)+ 0.6700000000000000D+00*dw( 18, 61)
      JacC(111, 61) = JacC(111, 61)+ 0.6600000000000000D+00*dw( 18, 61)
      JacC(112, 61) = JacC(112, 61)+ 0.3400000000000000D+00*dw( 18, 61)
      JacC( 66, 66) = JacC( 66, 66) - dw( 19, 66)
      JacC( 80, 66) = JacC( 80, 66)+ 0.7000000000000000D+00*dw( 19, 66)
      JacC( 95, 66) = JacC( 95, 66)+ 0.3000000000000000D+00*dw( 19, 66)
      JacC( 96, 66) = JacC( 96, 66)+ 0.7000000000000000D+00*dw( 19, 66)
      JacC(100, 66) = JacC(100, 66)+ 0.3000000000000000D+00*dw( 19, 66)
      JacC( 80, 80) = JacC( 80, 80) - dw( 20, 80)
      JacC( 96, 80) = JacC( 96, 80)+ 0.1220000000000000D+01*dw( 20, 80)
      JacC(103, 80) = JacC(103, 80)+ 0.2160000000000000D+00*dw( 20, 80)
      JacC(105, 80) = JacC(105, 80)+ 0.7840000000000000D+00*dw( 20, 80)
      JacC(107, 80) = JacC(107, 80)+ 0.4340000000000000D+00*dw( 20, 80)
      JacC(108, 80) = JacC(108, 80)+ 0.3500000000000000D+00*dw( 20, 80)
      JacC(111, 80) = JacC(111, 80)+ 0.1220000000000000D+01*dw( 20, 80)
      JacC( 91, 91) = JacC( 91, 91) - dw( 21, 91)
      JacC( 96, 91) = JacC( 96, 91)+ 0.2000000000000000D+01*dw( 21, 91)
      JacC(111, 91) = JacC(111, 91)+ 0.2000000000000000D+01*dw( 21, 91)
      JacC( 91, 91) = JacC( 91, 91) - dw( 22, 91)
      JacC( 96, 91) = JacC( 96, 91)+ 0.2000000000000000D+01*dw( 22, 91)
      JacC( 91, 91) = JacC( 91, 91) - dw( 23, 91)
      JacC( 96, 91) = JacC( 96, 91)+ 0.2000000000000000D+01*dw( 23, 91)
      JacC(108, 91) = JacC(108, 91) + dw( 23, 91)
      JacC( 93, 93) = JacC( 93, 93) - dw( 24, 93)
      JacC( 96, 93) = JacC( 96, 93) + dw( 24, 93)
      JacC(105, 93) = JacC(105, 93) + dw( 24, 93)
      JacC(111, 93) = JacC(111, 93) + dw( 24, 93)
      JacC( 77, 77) = JacC( 77, 77) - dw( 25, 77)
      JacC( 91, 77) = JacC( 91, 77)+ 0.5000000000000000D+00*dw( 25, 77)
      JacC( 93, 77) = JacC( 93, 77)+ 0.5000000000000000D+00*dw( 25, 77)
      JacC( 96, 77) = JacC( 96, 77) + dw( 25, 77)
      JacC(101, 77) = JacC(101, 77)+ 0.2000000000000000D+01*dw( 25, 77)
      JacC(105, 77) = JacC(105, 77)+ 0.5000000000000000D+00*dw( 25, 77)
      JacC(111, 77) = JacC(111, 77)+ 0.1500000000000000D+01*dw( 25, 77)
      JacC( 56, 56) = JacC( 56, 56) - dw( 26, 56)
      JacC( 91, 56) = JacC( 91, 56)+ 0.5000000000000000D+00*dw( 26, 56)
      JacC( 93, 56) = JacC( 93, 56)+ 0.5000000000000000D+00*dw( 26, 56)
      JacC( 96, 56) = JacC( 96, 56) + dw( 26, 56)
      JacC(101, 56) = JacC(101, 56)+ 0.2000000000000000D+01*dw( 26, 56)
      JacC(105, 56) = JacC(105, 56)+ 0.5000000000000000D+00*dw( 26, 56)
      JacC(111, 56) = JacC(111, 56)+ 0.1500000000000000D+01*dw( 26, 56)
      JacC( 78, 78) = JacC( 78, 78) - dw( 27, 78)
      JacC( 79, 78) = JacC( 79, 78) + dw( 27, 78)
      JacC( 96, 78) = JacC( 96, 78) + dw( 27, 78)
      JacC(105, 78) = JacC(105, 78) + dw( 27, 78)
      JacC(111, 78) = JacC(111, 78) + dw( 27, 78)
      JacC( 48, 53) = JacC( 48, 53) + dw( 28, 53)
      JacC( 53, 53) = JacC( 53, 53) - dw( 28, 53)
      JacC( 96, 53) = JacC( 96, 53) + dw( 28, 53)
      JacC(111, 53) = JacC(111, 53) + dw( 28, 53)
      JacC( 34, 34) = JacC( 34, 34) - dw( 29, 34)
      JacC(108, 34) = JacC(108, 34) + dw( 29, 34)
      JacC(111, 34) = JacC(111, 34) + dw( 29, 34)
      JacC(112, 34) = JacC(112, 34) + dw( 29, 34)
      JacC(106,106) = JacC(106,106) - dw( 30,106)
      JacC(107,106) = JacC(107,106) + dw( 30,106)
      JacC(111,106) = JacC(111,106) + dw( 30,106)
      JacC(112,106) = JacC(112,106) + dw( 30,106)
      JacC( 74, 74) = JacC( 74, 74) - dw( 31, 74)
      JacC(100, 74) = JacC(100, 74) + dw( 31, 74)
      JacC(112, 74) = JacC(112, 74) + dw( 31, 74)
      JacC(103,113) = JacC(103,113)+ 0.8000000000000000D+00*dw( 32,113)
      JacC(107,113) = JacC(107,113)+ 0.2000000000000000D+00*dw( 32,113)
      JacC(110,113) = JacC(110,113) + dw( 32,113)
      JacC(111,113) = JacC(111,113) + dw( 32,113)
      JacC(113,113) = JacC(113,113) - dw( 32,113)
      JacC( 35, 35) = JacC( 35, 35) - dw( 33, 35)
      JacC(105, 35) = JacC(105, 35) + dw( 33, 35)
      JacC(110, 35) = JacC(110, 35) + dw( 33, 35)
      JacC( 35, 35) = JacC( 35, 35) - dw( 34, 35)
      JacC(100, 35) = JacC(100, 35) + dw( 34, 35)
      JacC(109, 35) = JacC(109, 35) + dw( 34, 35)
      JacC( 44, 44) = JacC( 44, 44) - dw( 35, 44)
      JacC( 81, 44) = JacC( 81, 44) + dw( 35, 44)
      JacC( 44, 44) = JacC( 44, 44) - dw( 36, 44)
      JacC( 44, 81) = JacC( 44, 81) - dw( 36, 81)
      JacC( 81, 44) = JacC( 81, 44) - dw( 36, 44)
      JacC( 81, 81) = JacC( 81, 81) - dw( 36, 81)
      JacC(  1,  1) = JacC(  1,  1) - dw( 37,  1)
      JacC( 44,  1) = JacC( 44,  1) + dw( 37,  1)
      JacC(  1,  1) = JacC(  1,  1) - dw( 38,  1)
      JacC( 44,  1) = JacC( 44,  1) + dw( 38,  1)
      JacC(  1,  1) = JacC(  1,  1) - dw( 39,  1)
      JacC(112,  1) = JacC(112,  1)+ 0.2000000000000000D+01*dw( 39,  1)
      JacC( 81, 81) = JacC( 81, 81) - dw( 40, 81)
      JacC( 81,112) = JacC( 81,112) - dw( 40,112)
      JacC(111, 81) = JacC(111, 81) + dw( 40, 81)
      JacC(111,112) = JacC(111,112) + dw( 40,112)
      JacC(112, 81) = JacC(112, 81) - dw( 40, 81)
      JacC(112,112) = JacC(112,112) - dw( 40,112)
      JacC( 81, 81) = JacC( 81, 81) - dw( 41, 81)
      JacC( 81,111) = JacC( 81,111) - dw( 41,111)
      JacC(111, 81) = JacC(111, 81) - dw( 41, 81)
      JacC(111,111) = JacC(111,111) - dw( 41,111)
      JacC(112, 81) = JacC(112, 81) + dw( 41, 81)
      JacC(112,111) = JacC(112,111) + dw( 41,111)
      JacC(111,112) = JacC(111,112) - dw( 42,112)
      JacC(111,111) = JacC(111,111) - dw( 42,111)
      JacC(112,112) = JacC(112,112) - dw( 42,112)
      JacC(112,111) = JacC(112,111) - dw( 42,111)
      JacC( 38, 38) = JacC( 38, 38) - dw( 43, 38)
      JacC( 38,112) = JacC( 38,112) - dw( 43,112)
      JacC(111, 38) = JacC(111, 38) + dw( 43, 38)
      JacC(111,112) = JacC(111,112) + dw( 43,112)
      JacC(112, 38) = JacC(112, 38) - dw( 43, 38)
      JacC(112,112) = JacC(112,112) - dw( 43,112)
      JacC( 38,111) = JacC( 38,111) + dw( 44,111)
      JacC( 38,111) = JacC( 38,111) + dw( 44,111)
      JacC(111,111) = JacC(111,111)- 0.2000000000000000D+01*dw( 44,111)
      JacC(111,111) = JacC(111,111)- 0.2000000000000000D+01*dw( 44,111)
      JacC( 38,111) = JacC( 38,111) + dw( 45,111)
      JacC( 38,111) = JacC( 38,111) + dw( 45,111)
      JacC(111,111) = JacC(111,111)- 0.2000000000000000D+01*dw( 45,111)
      JacC(111,111) = JacC(111,111)- 0.2000000000000000D+01*dw( 45,111)
      JacC( 44, 44) = JacC( 44, 44) - dw( 46, 44)
      JacC( 44,102) = JacC( 44,102) - dw( 46,102)
      JacC(102, 44) = JacC(102, 44) - dw( 46, 44)
      JacC(102,102) = JacC(102,102) - dw( 46,102)
      JacC(110, 44) = JacC(110, 44) + dw( 46, 44)
      JacC(110,102) = JacC(110,102) + dw( 46,102)
      JacC( 44, 44) = JacC( 44, 44) - dw( 47, 44)
      JacC( 44,110) = JacC( 44,110) - dw( 47,110)
      JacC(102, 44) = JacC(102, 44) + dw( 47, 44)
      JacC(102,110) = JacC(102,110) + dw( 47,110)
      JacC(110, 44) = JacC(110, 44) - dw( 47, 44)
      JacC(110,110) = JacC(110,110) - dw( 47,110)
      JacC( 44, 44) = JacC( 44, 44) - dw( 48, 44)
      JacC( 44,110) = JacC( 44,110) - dw( 48,110)
      JacC(109, 44) = JacC(109, 44) + dw( 48, 44)
      JacC(109,110) = JacC(109,110) + dw( 48,110)
      JacC(110, 44) = JacC(110, 44) - dw( 48, 44)
      JacC(110,110) = JacC(110,110) - dw( 48,110)
      JacC( 15,112) = JacC( 15,112) + dw( 49,112)
      JacC( 15,102) = JacC( 15,102) + dw( 49,102)
      JacC(102,112) = JacC(102,112) - dw( 49,112)
      JacC(102,102) = JacC(102,102) - dw( 49,102)
      JacC(112,112) = JacC(112,112) - dw( 49,112)
      JacC(112,102) = JacC(112,102) - dw( 49,102)
      JacC( 94,112) = JacC( 94,112) + dw( 50,112)
      JacC( 94,110) = JacC( 94,110) + dw( 50,110)
      JacC(110,112) = JacC(110,112) - dw( 50,112)
      JacC(110,110) = JacC(110,110) - dw( 50,110)
      JacC(112,112) = JacC(112,112) - dw( 50,112)
      JacC(112,110) = JacC(112,110) - dw( 50,110)
      JacC(109,112) = JacC(109,112) - dw( 51,112)
      JacC(109,109) = JacC(109,109) - dw( 51,109)
      JacC(110,112) = JacC(110,112) + dw( 51,112)
      JacC(110,109) = JacC(110,109) + dw( 51,109)
      JacC(111,112) = JacC(111,112) + dw( 51,112)
      JacC(111,109) = JacC(111,109) + dw( 51,109)
      JacC(112,112) = JacC(112,112) - dw( 51,112)
      JacC(112,109) = JacC(112,109) - dw( 51,109)
      JacC(102,111) = JacC(102,111) - dw( 52,111)
      JacC(102,102) = JacC(102,102) - dw( 52,102)
      JacC(110,111) = JacC(110,111) + dw( 52,111)
      JacC(110,102) = JacC(110,102) + dw( 52,102)
      JacC(111,111) = JacC(111,111) - dw( 52,111)
      JacC(111,102) = JacC(111,102) - dw( 52,102)
      JacC(112,111) = JacC(112,111) + dw( 52,111)
      JacC(112,102) = JacC(112,102) + dw( 52,102)
      JacC( 36,111) = JacC( 36,111) + dw( 53,111)
      JacC( 36,110) = JacC( 36,110) + dw( 53,110)
      JacC(110,111) = JacC(110,111) - dw( 53,111)
      JacC(110,110) = JacC(110,110) - dw( 53,110)
      JacC(111,111) = JacC(111,111) - dw( 53,111)
      JacC(111,110) = JacC(111,110) - dw( 53,110)
      JacC( 36, 36) = JacC( 36, 36) - dw( 54, 36)
      JacC(110, 36) = JacC(110, 36) + dw( 54, 36)
      JacC(111, 36) = JacC(111, 36) + dw( 54, 36)
      JacC( 94,111) = JacC( 94,111)+ 0.3000000000000000D+00*dw( 55,111)
      JacC( 94,109) = JacC( 94,109)+ 0.3000000000000000D+00*dw( 55,109)
      JacC(109,111) = JacC(109,111) - dw( 55,111)
      JacC(109,109) = JacC(109,109) - dw( 55,109)
      JacC(110,111) = JacC(110,111)+ 0.7000000000000000D+00*dw( 55,111)
      JacC(110,109) = JacC(110,109)+ 0.7000000000000000D+00*dw( 55,109)
      JacC(111,111) = JacC(111,111) - dw( 55,111)
      JacC(111,109) = JacC(111,109) - dw( 55,109)
      JacC(112,111) = JacC(112,111)+ 0.7000000000000000D+00*dw( 55,111)
      JacC(112,109) = JacC(112,109)+ 0.7000000000000000D+00*dw( 55,109)
      JacC( 15,112) = JacC( 15,112) - dw( 56,112)
      JacC( 15, 15) = JacC( 15, 15) - dw( 56, 15)
      JacC(110,112) = JacC(110,112) + dw( 56,112)
      JacC(110, 15) = JacC(110, 15) + dw( 56, 15)
      JacC(112,112) = JacC(112,112) - dw( 56,112)
      JacC(112, 15) = JacC(112, 15) - dw( 56, 15)
      JacC( 94,112) = JacC( 94,112) - dw( 57,112)
      JacC( 94, 94) = JacC( 94, 94) - dw( 57, 94)
      JacC(109,112) = JacC(109,112) + dw( 57,112)
      JacC(109, 94) = JacC(109, 94) + dw( 57, 94)
      JacC(112,112) = JacC(112,112) - dw( 57,112)
      JacC(112, 94) = JacC(112, 94) - dw( 57, 94)
      JacC( 36,112) = JacC( 36,112) - dw( 58,112)
      JacC( 36, 36) = JacC( 36, 36) - dw( 58, 36)
      JacC(110,112) = JacC(110,112) + dw( 58,112)
      JacC(110, 36) = JacC(110, 36) + dw( 58, 36)
      JacC(112,112) = JacC(112,112) - dw( 58,112)
      JacC(112, 36) = JacC(112, 36) - dw( 58, 36)
      JacC( 81, 81) = JacC( 81, 81) - dw( 59, 81)
      JacC( 81,102) = JacC( 81,102) - dw( 59,102)
      JacC(102, 81) = JacC(102, 81) - dw( 59, 81)
      JacC(102,102) = JacC(102,102) - dw( 59,102)
      JacC(110, 81) = JacC(110, 81) + dw( 59, 81)
      JacC(110,102) = JacC(110,102) + dw( 59,102)
      JacC( 81, 81) = JacC( 81, 81) - dw( 60, 81)
      JacC( 81,110) = JacC( 81,110) - dw( 60,110)
      JacC(109, 81) = JacC(109, 81) + dw( 60, 81)
      JacC(109,110) = JacC(109,110) + dw( 60,110)
      JacC(110, 81) = JacC(110, 81) - dw( 60, 81)
      JacC(110,110) = JacC(110,110) - dw( 60,110)
      JacC(102,102) = JacC(102,102)- 0.2000000000000000D+01*dw( 61,102)
      JacC(102,102) = JacC(102,102)- 0.2000000000000000D+01*dw( 61,102)
      JacC(110,102) = JacC(110,102)+ 0.2000000000000000D+01*dw( 61,102)
      JacC(110,102) = JacC(110,102)+ 0.2000000000000000D+01*dw( 61,102)
      JacC(102,109) = JacC(102,109) - dw( 62,109)
      JacC(102,102) = JacC(102,102) - dw( 62,102)
      JacC(109,109) = JacC(109,109) - dw( 62,109)
      JacC(109,102) = JacC(109,102) - dw( 62,102)
      JacC(110,109) = JacC(110,109)+ 0.2000000000000000D+01*dw( 62,109)
      JacC(110,102) = JacC(110,102)+ 0.2000000000000000D+01*dw( 62,102)
      JacC(102,109) = JacC(102,109) + dw( 63,109)
      JacC(102,110) = JacC(102,110) + dw( 63,110)
      JacC(109,109) = JacC(109,109) - dw( 63,109)
      JacC(109,110) = JacC(109,110) - dw( 63,110)
      JacC( 16,109) = JacC( 16,109) + dw( 64,109)
      JacC( 16,110) = JacC( 16,110) + dw( 64,110)
      JacC(109,109) = JacC(109,109) - dw( 64,109)
      JacC(109,110) = JacC(109,110) - dw( 64,110)
      JacC(110,109) = JacC(110,109) - dw( 64,109)
      JacC(110,110) = JacC(110,110) - dw( 64,110)
      JacC( 16, 16) = JacC( 16, 16) - dw( 65, 16)
      JacC(109, 16) = JacC(109, 16) + dw( 65, 16)
      JacC(110, 16) = JacC(110, 16) + dw( 65, 16)
      JacC( 16, 16) = JacC( 16, 16) - dw( 66, 16)
      JacC( 94, 16) = JacC( 94, 16)+ 0.2000000000000000D+01*dw( 66, 16)
      JacC(109,109) = JacC(109,109)- 0.2000000000000000D+01*dw( 67,109)
      JacC(109,109) = JacC(109,109)- 0.2000000000000000D+01*dw( 67,109)
      JacC(110,109) = JacC(110,109)+ 0.2000000000000000D+01*dw( 67,109)
      JacC(110,109) = JacC(110,109)+ 0.2000000000000000D+01*dw( 67,109)
      JacC(111,112) = JacC(111,112) + dw( 68,112)
      JacC(112,112) = JacC(112,112) - dw( 68,112)
      JacC(  2,112) = JacC(  2,112) - dw( 69,112)
      JacC(  2,  2) = JacC(  2,  2) - dw( 69,  2)
      JacC(  3,112) = JacC(  3,112) + dw( 69,112)
      JacC(  3,  2) = JacC(  3,  2) + dw( 69,  2)
      JacC(111,112) = JacC(111,112) + dw( 69,112)
      JacC(111,  2) = JacC(111,  2) + dw( 69,  2)
      JacC(112,112) = JacC(112,112) - dw( 69,112)
      JacC(112,  2) = JacC(112,  2) - dw( 69,  2)
      JacC( 96, 96) = JacC( 96, 96) - dw( 70, 96)
      JacC( 96,112) = JacC( 96,112) - dw( 70,112)
      JacC(111, 96) = JacC(111, 96) + dw( 70, 96)
      JacC(111,112) = JacC(111,112) + dw( 70,112)
      JacC(112, 96) = JacC(112, 96) - dw( 70, 96)
      JacC(112,112) = JacC(112,112) - dw( 70,112)
      JacC( 32, 32) = JacC( 32, 32) - dw( 71, 32)
      JacC( 32,112) = JacC( 32,112) - dw( 71,112)
      JacC(100, 32) = JacC(100, 32) + dw( 71, 32)
      JacC(100,112) = JacC(100,112) + dw( 71,112)
      JacC(112, 32) = JacC(112, 32) - dw( 71, 32)
      JacC(112,112) = JacC(112,112) - dw( 71,112)
      JacC( 33, 33) = JacC( 33, 33) - dw( 72, 33)
      JacC( 33,112) = JacC( 33,112) - dw( 72,112)
      JacC(104, 33) = JacC(104, 33) + dw( 72, 33)
      JacC(104,112) = JacC(104,112) + dw( 72,112)
      JacC(112, 33) = JacC(112, 33) - dw( 72, 33)
      JacC(112,112) = JacC(112,112) - dw( 72,112)
      JacC( 89, 89) = JacC( 89, 89) - dw( 73, 89)
      JacC( 89,112) = JacC( 89,112) - dw( 73,112)
      JacC(108, 89) = JacC(108, 89) + dw( 73, 89)
      JacC(108,112) = JacC(108,112) + dw( 73,112)
      JacC(111, 89) = JacC(111, 89) + dw( 73, 89)
      JacC(111,112) = JacC(111,112) + dw( 73,112)
      JacC(112, 89) = JacC(112, 89) - dw( 73, 89)
      JacC(112,112) = JacC(112,112) - dw( 73,112)
      JacC( 21, 21) = JacC( 21, 21) - dw( 74, 21)
      JacC( 21,112) = JacC( 21,112) - dw( 74,112)
      JacC( 87, 21) = JacC( 87, 21) + dw( 74, 21)
      JacC( 87,112) = JacC( 87,112) + dw( 74,112)
      JacC(111, 21) = JacC(111, 21) + dw( 74, 21)
      JacC(111,112) = JacC(111,112) + dw( 74,112)
      JacC(112, 21) = JacC(112, 21) - dw( 74, 21)
      JacC(112,112) = JacC(112,112) - dw( 74,112)
      JacC( 85, 85) = JacC( 85, 85) - dw( 75, 85)
      JacC( 85,112) = JacC( 85,112) - dw( 75,112)
      JacC( 87, 85) = JacC( 87, 85)+ 0.1840000000000000D+00*dw( 75, 85)
      JacC( 87,112) = JacC( 87,112)+ 0.1840000000000000D+00*dw( 75,112)
      JacC(107, 85) = JacC(107, 85)+ 0.7190000000000000D+00*dw( 75, 85)
      JacC(107,112) = JacC(107,112)+ 0.7190000000000000D+00*dw( 75,112)
      JacC(111, 85) = JacC(111, 85) + dw( 75, 85)
      JacC(111,112) = JacC(111,112) + dw( 75,112)
      JacC(112, 85) = JacC(112, 85) - dw( 75, 85)
      JacC(112,112) = JacC(112,112) - dw( 75,112)
      JacC(  4,  4) = JacC(  4,  4) - dw( 76,  4)
      JacC(  4,112) = JacC(  4,112) - dw( 76,112)
      JacC( 67,  4) = JacC( 67,  4)+ 0.3500000000000000D+00*dw( 76,  4)
      JacC( 67,112) = JacC( 67,112)+ 0.3500000000000000D+00*dw( 76,112)
      JacC( 91,  4) = JacC( 91,  4)+ 0.6500000000000000D+00*dw( 76,  4)
      JacC( 91,112) = JacC( 91,112)+ 0.6500000000000000D+00*dw( 76,112)
      JacC( 96,  4) = JacC( 96,  4)+ 0.3500000000000000D+00*dw( 76,  4)
      JacC( 96,112) = JacC( 96,112)+ 0.3500000000000000D+00*dw( 76,112)
      JacC(111,  4) = JacC(111,  4)+ 0.3500000000000000D+00*dw( 76,  4)
      JacC(111,112) = JacC(111,112)+ 0.3500000000000000D+00*dw( 76,112)
      JacC(112,  4) = JacC(112,  4)- 0.3500000000000000D+00*dw( 76,  4)
      JacC(112,112) = JacC(112,112)- 0.3500000000000000D+00*dw( 76,112)
      JacC(  6,  6) = JacC(  6,  6) - dw( 77,  6)
      JacC(  6,112) = JacC(  6,112) - dw( 77,112)
      JacC( 99,  6) = JacC( 99,  6) + dw( 77,  6)
      JacC( 99,112) = JacC( 99,112) + dw( 77,112)
      JacC(112,  6) = JacC(112,  6) - dw( 77,  6)
      JacC(112,112) = JacC(112,112) - dw( 77,112)
      JacC(  7,  7) = JacC(  7,  7) - dw( 78,  7)
      JacC(  7,112) = JacC(  7,112) - dw( 78,112)
      JacC( 86,  7) = JacC( 86,  7) + dw( 78,  7)
      JacC( 86,112) = JacC( 86,112) + dw( 78,112)
      JacC(112,  7) = JacC(112,  7) - dw( 78,  7)
      JacC(112,112) = JacC(112,112) - dw( 78,112)
      JacC(  8,  8) = JacC(  8,  8) - dw( 79,  8)
      JacC(  8,112) = JacC(  8,112) - dw( 79,112)
      JacC( 62,  8) = JacC( 62,  8)+ 0.9510000000000000D+00*dw( 79,  8)
      JacC( 62,112) = JacC( 62,112)+ 0.9510000000000000D+00*dw( 79,112)
      JacC( 76,  8) = JacC( 76,  8)+ 0.2400000000000000D-01*dw( 79,  8)
      JacC( 76,112) = JacC( 76,112)+ 0.2400000000000000D-01*dw( 79,112)
      JacC(107,  8) = JacC(107,  8)+ 0.2500000000000000D-01*dw( 79,  8)
      JacC(107,112) = JacC(107,112)+ 0.2500000000000000D-01*dw( 79,112)
      JacC(111,  8) = JacC(111,  8)+ 0.4900000000000000D-01*dw( 79,  8)
      JacC(111,112) = JacC(111,112)+ 0.4900000000000000D-01*dw( 79,112)
      JacC(112,  8) = JacC(112,  8) - dw( 79,  8)
      JacC(112,112) = JacC(112,112) - dw( 79,112)
      JacC( 23, 23) = JacC( 23, 23) - dw( 80, 23)
      JacC( 23,112) = JacC( 23,112) - dw( 80,112)
      JacC( 88, 23) = JacC( 88, 23) + dw( 80, 23)
      JacC( 88,112) = JacC( 88,112) + dw( 80,112)
      JacC(112, 23) = JacC(112, 23) - dw( 80, 23)
      JacC(112,112) = JacC(112,112) - dw( 80,112)
      JacC( 31, 31) = JacC( 31, 31) - dw( 81, 31)
      JacC( 31,112) = JacC( 31,112) - dw( 81,112)
      JacC( 72, 31) = JacC( 72, 31) + dw( 81, 31)
      JacC( 72,112) = JacC( 72,112) + dw( 81,112)
      JacC(112, 31) = JacC(112, 31) - dw( 81, 31)
      JacC(112,112) = JacC(112,112) - dw( 81,112)
      JacC( 69, 69) = JacC( 69, 69) - dw( 82, 69)
      JacC( 69,112) = JacC( 69,112) - dw( 82,112)
      JacC( 79, 69) = JacC( 79, 69) + dw( 82, 69)
      JacC( 79,112) = JacC( 79,112) + dw( 82,112)
      JacC(112, 69) = JacC(112, 69) - dw( 82, 69)
      JacC(112,112) = JacC(112,112) - dw( 82,112)
      JacC( 20, 20) = JacC( 20, 20) - dw( 83, 20)
      JacC( 20,112) = JacC( 20,112) - dw( 83,112)
      JacC( 79, 20) = JacC( 79, 20) + dw( 83, 20)
      JacC( 79,112) = JacC( 79,112) + dw( 83,112)
      JacC(112, 20) = JacC(112, 20) - dw( 83, 20)
      JacC(112,112) = JacC(112,112) - dw( 83,112)
      JacC( 26, 26) = JacC( 26, 26) - dw( 84, 26)
      JacC( 26,112) = JacC( 26,112) - dw( 84,112)
      JacC( 59, 26) = JacC( 59, 26) + dw( 84, 26)
      JacC( 59,112) = JacC( 59,112) + dw( 84,112)
      JacC(112, 26) = JacC(112, 26) - dw( 84, 26)
      JacC(112,112) = JacC(112,112) - dw( 84,112)
      JacC( 19, 19) = JacC( 19, 19) - dw( 85, 19)
      JacC( 19,112) = JacC( 19,112) - dw( 85,112)
      JacC( 57, 19) = JacC( 57, 19) + dw( 85, 19)
      JacC( 57,112) = JacC( 57,112) + dw( 85,112)
      JacC(112, 19) = JacC(112, 19) - dw( 85, 19)
      JacC(112,112) = JacC(112,112) - dw( 85,112)
      JacC( 27, 27) = JacC( 27, 27) - dw( 86, 27)
      JacC( 27,112) = JacC( 27,112) - dw( 86,112)
      JacC( 60, 27) = JacC( 60, 27) + dw( 86, 27)
      JacC( 60,112) = JacC( 60,112) + dw( 86,112)
      JacC(112, 27) = JacC(112, 27) - dw( 86, 27)
      JacC(112,112) = JacC(112,112) - dw( 86,112)
      JacC( 25, 25) = JacC( 25, 25) - dw( 87, 25)
      JacC( 25,112) = JacC( 25,112) - dw( 87,112)
      JacC( 61, 25) = JacC( 61, 25) + dw( 87, 25)
      JacC( 61,112) = JacC( 61,112) + dw( 87,112)
      JacC( 17, 39) = JacC( 17, 39) + dw( 88, 39)
      JacC( 17,112) = JacC( 17,112) + dw( 88,112)
      JacC( 39, 39) = JacC( 39, 39) - dw( 88, 39)
      JacC( 39,112) = JacC( 39,112) - dw( 88,112)
      JacC( 73, 39) = JacC( 73, 39) + dw( 88, 39)
      JacC( 73,112) = JacC( 73,112) + dw( 88,112)
      JacC(112, 39) = JacC(112, 39) - dw( 88, 39)
      JacC(112,112) = JacC(112,112) - dw( 88,112)
      JacC( 28, 28) = JacC( 28, 28) - dw( 89, 28)
      JacC( 28,112) = JacC( 28,112) - dw( 89,112)
      JacC( 95, 28) = JacC( 95, 28) + dw( 89, 28)
      JacC( 95,112) = JacC( 95,112) + dw( 89,112)
      JacC(112, 28) = JacC(112, 28) - dw( 89, 28)
      JacC(112,112) = JacC(112,112) - dw( 89,112)
      JacC( 73, 73) = JacC( 73, 73) - dw( 90, 73)
      JacC( 73,112) = JacC( 73,112) - dw( 90,112)
      JacC( 93, 73) = JacC( 93, 73) + dw( 90, 73)
      JacC( 93,112) = JacC( 93,112) + dw( 90,112)
      JacC(111, 73) = JacC(111, 73) + dw( 90, 73)
      JacC(111,112) = JacC(111,112) + dw( 90,112)
      JacC(112, 73) = JacC(112, 73) - dw( 90, 73)
      JacC(112,112) = JacC(112,112) - dw( 90,112)
      JacC( 17, 17) = JacC( 17, 17) - dw( 91, 17)
      JacC( 17,112) = JacC( 17,112) - dw( 91,112)
      JacC( 96, 17) = JacC( 96, 17) + dw( 91, 17)
      JacC( 96,112) = JacC( 96,112) + dw( 91,112)
      JacC(108, 17) = JacC(108, 17) + dw( 91, 17)
      JacC(108,112) = JacC(108,112) + dw( 91,112)
      JacC(110, 17) = JacC(110, 17) + dw( 91, 17)
      JacC(110,112) = JacC(110,112) + dw( 91,112)
      JacC(112, 17) = JacC(112, 17) - dw( 91, 17)
      JacC(112,112) = JacC(112,112) - dw( 91,112)
      JacC( 24, 24) = JacC( 24, 24) - dw( 92, 24)
      JacC( 24,112) = JacC( 24,112) - dw( 92,112)
      JacC(107, 24) = JacC(107, 24) + dw( 92, 24)
      JacC(107,112) = JacC(107,112) + dw( 92,112)
      JacC(111, 24) = JacC(111, 24) + dw( 92, 24)
      JacC(111,112) = JacC(111,112) + dw( 92,112)
      JacC(112, 24) = JacC(112, 24) - dw( 92, 24)
      JacC(112,112) = JacC(112,112) - dw( 92,112)
      JacC(  5,  5) = JacC(  5,  5) - dw( 93,  5)
      JacC(  5,112) = JacC(  5,112) - dw( 93,112)
      JacC( 18,  5) = JacC( 18,  5)+ 0.5300000000000000D+00*dw( 93,  5)
      JacC( 18,112) = JacC( 18,112)+ 0.5300000000000000D+00*dw( 93,112)
      JacC( 63,  5) = JacC( 63,  5)+ 0.3520000000000000D+00*dw( 93,  5)
      JacC( 63,112) = JacC( 63,112)+ 0.3520000000000000D+00*dw( 93,112)
      JacC( 80,  5) = JacC( 80,  5)+ 0.1180000000000000D+00*dw( 93,  5)
      JacC( 80,112) = JacC( 80,112)+ 0.1180000000000000D+00*dw( 93,112)
      JacC(111,  5) = JacC(111,  5)+ 0.6480000000000000D+00*dw( 93,  5)
      JacC(111,112) = JacC(111,112)+ 0.6480000000000000D+00*dw( 93,112)
      JacC(112,  5) = JacC(112,  5) - dw( 93,  5)
      JacC(112,112) = JacC(112,112) - dw( 93,112)
      JacC(  9,  9) = JacC(  9,  9) - dw( 94,  9)
      JacC(  9,112) = JacC(  9,112) - dw( 94,112)
      JacC( 10,  9) = JacC( 10,  9)+ 0.8900000000000000D+00*dw( 94,  9)
      JacC( 10,112) = JacC( 10,112)+ 0.8900000000000000D+00*dw( 94,112)
      JacC( 47,  9) = JacC( 47,  9)+ 0.5000000000000000D-01*dw( 94,  9)
      JacC( 47,112) = JacC( 47,112)+ 0.5000000000000000D-01*dw( 94,112)
      JacC( 50,  9) = JacC( 50,  9)+ 0.6000000000000000D-01*dw( 94,  9)
      JacC( 50,112) = JacC( 50,112)+ 0.6000000000000000D-01*dw( 94,112)
      JacC(111,  9) = JacC(111,  9)+ 0.5000000000000000D-01*dw( 94,  9)
      JacC(111,112) = JacC(111,112)+ 0.5000000000000000D-01*dw( 94,112)
      JacC(112,  9) = JacC(112,  9) - dw( 94,  9)
      JacC(112,112) = JacC(112,112) - dw( 94,112)
      JacC( 50, 50) = JacC( 50, 50) - dw( 95, 50)
      JacC( 50,102) = JacC( 50,102) - dw( 95,102)
      JacC( 53, 50) = JacC( 53, 50) + dw( 95, 50)
      JacC( 53,102) = JacC( 53,102) + dw( 95,102)
      JacC(102, 50) = JacC(102, 50) - dw( 95, 50)
      JacC(102,102) = JacC(102,102) - dw( 95,102)
      JacC(110, 50) = JacC(110, 50) + dw( 95, 50)
      JacC(110,102) = JacC(110,102) + dw( 95,102)
      JacC( 10, 10) = JacC( 10, 10) - dw( 96, 10)
      JacC( 22, 10) = JacC( 22, 10)+ 0.2800000000000000D+00*dw( 96, 10)
      JacC( 41, 10) = JacC( 41, 10)+ 0.2800000000000000D+00*dw( 96, 10)
      JacC( 42, 10) = JacC( 42, 10)+ 0.1500000000000000D+00*dw( 96, 10)
      JacC( 47, 10) = JacC( 47, 10)+ 0.1000000000000000D-01*dw( 96, 10)
      JacC( 56, 10) = JacC( 56, 10)+ 0.2800000000000000D+00*dw( 96, 10)
      JacC(111, 10) = JacC(111, 10)+ 0.2900000000000000D+00*dw( 96, 10)
      JacC(112, 10) = JacC(112, 10)+ 0.2800000000000000D+00*dw( 96, 10)
      JacC( 41, 41) = JacC( 41, 41) - dw( 97, 41)
      JacC( 42, 41) = JacC( 42, 41)+ 0.5000000000000000D+00*dw( 97, 41)
      JacC( 47, 41) = JacC( 47, 41)+ 0.1000000000000000D-01*dw( 97, 41)
      JacC( 56, 41) = JacC( 56, 41)+ 0.4900000000000000D+00*dw( 97, 41)
      JacC(111, 41) = JacC(111, 41)+ 0.1000000000000000D-01*dw( 97, 41)
      JacC(112, 41) = JacC(112, 41)+ 0.4900000000000000D+00*dw( 97, 41)
      JacC( 41, 41) = JacC( 41, 41) - dw( 98, 41)
      JacC( 41,102) = JacC( 41,102) - dw( 98,102)
      JacC( 56, 41) = JacC( 56, 41)+ 0.9500000000000000D+00*dw( 98, 41)
      JacC( 56,102) = JacC( 56,102)+ 0.9500000000000000D+00*dw( 98,102)
      JacC(102, 41) = JacC(102, 41) - dw( 98, 41)
      JacC(102,102) = JacC(102,102) - dw( 98,102)
      JacC(110, 41) = JacC(110, 41)+ 0.9500000000000000D+00*dw( 98, 41)
      JacC(110,102) = JacC(110,102)+ 0.9500000000000000D+00*dw( 98,102)
      JacC(111, 41) = JacC(111, 41)+ 0.9500000000000000D+00*dw( 98, 41)
      JacC(111,102) = JacC(111,102)+ 0.9500000000000000D+00*dw( 98,102)
      JacC(113, 41) = JacC(113, 41)+ 0.5000000000000000D-01*dw( 98, 41)
      JacC(113,102) = JacC(113,102)+ 0.5000000000000000D-01*dw( 98,102)
      JacC( 42, 42) = JacC( 42, 42) - dw( 99, 42)
      JacC( 42,102) = JacC( 42,102) - dw( 99,102)
      JacC( 77, 42) = JacC( 77, 42)+ 0.9500000000000000D+00*dw( 99, 42)
      JacC( 77,102) = JacC( 77,102)+ 0.9500000000000000D+00*dw( 99,102)
      JacC( 93, 42) = JacC( 93, 42)+ 0.9500000000000000D+00*dw( 99, 42)
      JacC( 93,102) = JacC( 93,102)+ 0.9500000000000000D+00*dw( 99,102)
      JacC(102, 42) = JacC(102, 42) - dw( 99, 42)
      JacC(102,102) = JacC(102,102) - dw( 99,102)
      JacC(110, 42) = JacC(110, 42)+ 0.9500000000000000D+00*dw( 99, 42)
      JacC(110,102) = JacC(110,102)+ 0.9500000000000000D+00*dw( 99,102)
      JacC(111, 42) = JacC(111, 42)+ 0.9500000000000000D+00*dw( 99, 42)
      JacC(111,102) = JacC(111,102)+ 0.9500000000000000D+00*dw( 99,102)
      JacC(113, 42) = JacC(113, 42)+ 0.5000000000000000D-01*dw( 99, 42)
      JacC(113,102) = JacC(113,102)+ 0.5000000000000000D-01*dw( 99,102)
      JacC( 13, 13) = JacC( 13, 13) - dw(100, 13)
      JacC( 13,112) = JacC( 13,112) - dw(100,112)
      JacC( 14, 13) = JacC( 14, 13)+ 0.8900000000000000D+00*dw(100, 13)
      JacC( 14,112) = JacC( 14,112)+ 0.8900000000000000D+00*dw(100,112)
      JacC( 47, 13) = JacC( 47, 13)+ 0.5000000000000000D-01*dw(100, 13)
      JacC( 47,112) = JacC( 47,112)+ 0.5000000000000000D-01*dw(100,112)
      JacC( 52, 13) = JacC( 52, 13)+ 0.6000000000000000D-01*dw(100, 13)
      JacC( 52,112) = JacC( 52,112)+ 0.6000000000000000D-01*dw(100,112)
      JacC(111, 13) = JacC(111, 13)+ 0.5000000000000000D-01*dw(100, 13)
      JacC(111,112) = JacC(111,112)+ 0.5000000000000000D-01*dw(100,112)
      JacC(112, 13) = JacC(112, 13) - dw(100, 13)
      JacC(112,112) = JacC(112,112) - dw(100,112)
      JacC( 11, 11) = JacC( 11, 11) - dw(101, 11)
      JacC( 11,112) = JacC( 11,112) - dw(101,112)
      JacC( 12, 11) = JacC( 12, 11)+ 0.8900000000000000D+00*dw(101, 11)
      JacC( 12,112) = JacC( 12,112)+ 0.8900000000000000D+00*dw(101,112)
      JacC( 47, 11) = JacC( 47, 11)+ 0.5000000000000000D-01*dw(101, 11)
      JacC( 47,112) = JacC( 47,112)+ 0.5000000000000000D-01*dw(101,112)
      JacC( 52, 11) = JacC( 52, 11)+ 0.6000000000000000D-01*dw(101, 11)
      JacC( 52,112) = JacC( 52,112)+ 0.6000000000000000D-01*dw(101,112)
      JacC(111, 11) = JacC(111, 11)+ 0.5000000000000000D-01*dw(101, 11)
      JacC(111,112) = JacC(111,112)+ 0.5000000000000000D-01*dw(101,112)
      JacC(112, 11) = JacC(112, 11) - dw(101, 11)
      JacC(112,112) = JacC(112,112) - dw(101,112)
      JacC( 52, 52) = JacC( 52, 52) - dw(102, 52)
      JacC( 52,102) = JacC( 52,102) - dw(102,102)
      JacC( 53, 52) = JacC( 53, 52) + dw(102, 52)
      JacC( 53,102) = JacC( 53,102) + dw(102,102)
      JacC(102, 52) = JacC(102, 52) - dw(102, 52)
      JacC(102,102) = JacC(102,102) - dw(102,102)
      JacC(110, 52) = JacC(110, 52) + dw(102, 52)
      JacC(110,102) = JacC(110,102) + dw(102,102)
      JacC( 12, 12) = JacC( 12, 12) - dw(103, 12)
      JacC( 22, 12) = JacC( 22, 12)+ 0.8400000000000000D+00*dw(103, 12)
      JacC( 43, 12) = JacC( 43, 12)+ 0.3080000000000000D+00*dw(103, 12)
      JacC( 47, 12) = JacC( 47, 12)+ 0.1000000000000000D-01*dw(103, 12)
      JacC( 49, 12) = JacC( 49, 12)+ 0.1500000000000000D+00*dw(103, 12)
      JacC( 56, 12) = JacC( 56, 12)+ 0.2240000000000000D+00*dw(103, 12)
      JacC(111, 12) = JacC(111, 12)+ 0.3080000000000000D+00*dw(103, 12)
      JacC(112, 12) = JacC(112, 12)+ 0.3080000000000000D+00*dw(103, 12)
      JacC( 14, 14) = JacC( 14, 14) - dw(104, 14)
      JacC( 22, 14) = JacC( 22, 14)+ 0.8400000000000000D+00*dw(104, 14)
      JacC( 47, 14) = JacC( 47, 14)+ 0.1000000000000000D-01*dw(104, 14)
      JacC( 49, 14) = JacC( 49, 14)+ 0.1500000000000000D+00*dw(104, 14)
      JacC( 55, 14) = JacC( 55, 14)+ 0.3080000000000000D+00*dw(104, 14)
      JacC( 56, 14) = JacC( 56, 14)+ 0.2240000000000000D+00*dw(104, 14)
      JacC(111, 14) = JacC(111, 14)+ 0.3080000000000000D+00*dw(104, 14)
      JacC(112, 14) = JacC(112, 14)+ 0.3080000000000000D+00*dw(104, 14)
      JacC( 43, 43) = JacC( 43, 43) - dw(105, 43)
      JacC( 47, 43) = JacC( 47, 43)+ 0.1000000000000000D-01*dw(105, 43)
      JacC( 49, 43) = JacC( 49, 43)+ 0.5000000000000000D+00*dw(105, 43)
      JacC( 56, 43) = JacC( 56, 43)+ 0.4900000000000000D+00*dw(105, 43)
      JacC(111, 43) = JacC(111, 43)+ 0.1000000000000000D-01*dw(105, 43)
      JacC(112, 43) = JacC(112, 43)+ 0.4900000000000000D+00*dw(105, 43)
      JacC( 47, 55) = JacC( 47, 55)+ 0.1000000000000000D-01*dw(106, 55)
      JacC( 49, 55) = JacC( 49, 55)+ 0.5000000000000000D+00*dw(106, 55)
      JacC( 55, 55) = JacC( 55, 55) - dw(106, 55)
      JacC( 56, 55) = JacC( 56, 55)+ 0.4900000000000000D+00*dw(106, 55)
      JacC(111, 55) = JacC(111, 55)+ 0.1000000000000000D-01*dw(106, 55)
      JacC(112, 55) = JacC(112, 55)+ 0.4900000000000000D+00*dw(106, 55)
      JacC( 43, 43) = JacC( 43, 43) - dw(107, 43)
      JacC( 43,102) = JacC( 43,102) - dw(107,102)
      JacC( 56, 43) = JacC( 56, 43)+ 0.9500000000000000D+00*dw(107, 43)
      JacC( 56,102) = JacC( 56,102)+ 0.9500000000000000D+00*dw(107,102)
      JacC(102, 43) = JacC(102, 43) - dw(107, 43)
      JacC(102,102) = JacC(102,102) - dw(107,102)
      JacC(110, 43) = JacC(110, 43)+ 0.9500000000000000D+00*dw(107, 43)
      JacC(110,102) = JacC(110,102)+ 0.9500000000000000D+00*dw(107,102)
      JacC(111, 43) = JacC(111, 43)+ 0.9500000000000000D+00*dw(107, 43)
      JacC(111,102) = JacC(111,102)+ 0.9500000000000000D+00*dw(107,102)
      JacC(113, 43) = JacC(113, 43)+ 0.5000000000000000D-01*dw(107, 43)
      JacC(113,102) = JacC(113,102)+ 0.5000000000000000D-01*dw(107,102)
      JacC( 49, 49) = JacC( 49, 49) - dw(108, 49)
      JacC( 49,102) = JacC( 49,102) - dw(108,102)
      JacC( 77, 49) = JacC( 77, 49)+ 0.9500000000000000D+00*dw(108, 49)
      JacC( 77,102) = JacC( 77,102)+ 0.9500000000000000D+00*dw(108,102)
      JacC( 78, 49) = JacC( 78, 49)+ 0.1950000000000000D+01*dw(108, 49)
      JacC( 78,102) = JacC( 78,102)+ 0.1950000000000000D+01*dw(108,102)
      JacC( 93, 49) = JacC( 93, 49)+ 0.9500000000000000D+00*dw(108, 49)
      JacC( 93,102) = JacC( 93,102)+ 0.9500000000000000D+00*dw(108,102)
      JacC(102, 49) = JacC(102, 49) - dw(108, 49)
      JacC(102,102) = JacC(102,102) - dw(108,102)
      JacC(110, 49) = JacC(110, 49)+ 0.9500000000000000D+00*dw(108, 49)
      JacC(110,102) = JacC(110,102)+ 0.9500000000000000D+00*dw(108,102)
      JacC(111, 49) = JacC(111, 49)+ 0.9500000000000000D+00*dw(108, 49)
      JacC(111,102) = JacC(111,102)+ 0.9500000000000000D+00*dw(108,102)
      JacC(113, 49) = JacC(113, 49)+ 0.5000000000000000D-01*dw(108, 49)
      JacC(113,102) = JacC(113,102)+ 0.5000000000000000D-01*dw(108,102)
      JacC( 53, 53) = JacC( 53, 53) - dw(109, 53)
      JacC( 53,112) = JacC( 53,112) - dw(109,112)
      JacC( 54, 53) = JacC( 54, 53) + dw(109, 53)
      JacC( 54,112) = JacC( 54,112) + dw(109,112)
      JacC(112, 53) = JacC(112, 53) - dw(109, 53)
      JacC(112,112) = JacC(112,112) - dw(109,112)
      JacC( 45, 54) = JacC( 45, 54) + dw(110, 54)
      JacC( 45,102) = JacC( 45,102) + dw(110,102)
      JacC( 54, 54) = JacC( 54, 54) - dw(110, 54)
      JacC( 54,102) = JacC( 54,102) - dw(110,102)
      JacC(102, 54) = JacC(102, 54) - dw(110, 54)
      JacC(102,102) = JacC(102,102) - dw(110,102)
      JacC(110, 54) = JacC(110, 54) + dw(110, 54)
      JacC(110,102) = JacC(110,102) + dw(110,102)
      JacC( 45, 45) = JacC( 45, 45) - dw(111, 45)
      JacC( 45,102) = JacC( 45,102) - dw(111,102)
      JacC( 46, 45) = JacC( 46, 45) + dw(111, 45)
      JacC( 46,102) = JacC( 46,102) + dw(111,102)
      JacC(102, 45) = JacC(102, 45) - dw(111, 45)
      JacC(102,102) = JacC(102,102) - dw(111,102)
      JacC(110, 45) = JacC(110, 45) + dw(111, 45)
      JacC(110,102) = JacC(110,102) + dw(111,102)
      JacC( 46, 46) = JacC( 46, 46) - dw(112, 46)
      JacC( 46,110) = JacC( 46,110) - dw(112,110)
      JacC(110, 46) = JacC(110, 46) - dw(112, 46)
      JacC(110,110) = JacC(110,110) - dw(112,110)
      JacC(113, 46) = JacC(113, 46) + dw(112, 46)
      JacC(113,110) = JacC(113,110) + dw(112,110)
      JacC( 18, 18) = JacC( 18, 18) - dw(113, 18)
      JacC( 18,112) = JacC( 18,112) - dw(113,112)
      JacC( 29, 18) = JacC( 29, 18)+ 0.7300000000000000D+00*dw(113, 18)
      JacC( 29,112) = JacC( 29,112)+ 0.7300000000000000D+00*dw(113,112)
      JacC( 48, 18) = JacC( 48, 18)+ 0.7000000000000001D-01*dw(113, 18)
      JacC( 48,112) = JacC( 48,112)+ 0.7000000000000001D-01*dw(113,112)
      JacC( 75, 18) = JacC( 75, 18)+ 0.2000000000000000D+00*dw(113, 18)
      JacC( 75,112) = JacC( 75,112)+ 0.2000000000000000D+00*dw(113,112)
      JacC(111, 18) = JacC(111, 18)+ 0.7300000000000000D+00*dw(113, 18)
      JacC(111,112) = JacC(111,112)+ 0.7300000000000000D+00*dw(113,112)
      JacC(112, 18) = JacC(112, 18) - dw(113, 18)
      JacC(112,112) = JacC(112,112) - dw(113,112)
      JacC( 29, 47) = JacC( 29, 47)+ 0.7300000000000000D+00*dw(114, 47)
      JacC( 29,112) = JacC( 29,112)+ 0.7300000000000000D+00*dw(114,112)
      JacC( 47, 47) = JacC( 47, 47) - dw(114, 47)
      JacC( 47,112) = JacC( 47,112) - dw(114,112)
      JacC( 48, 47) = JacC( 48, 47)+ 0.7000000000000001D-01*dw(114, 47)
      JacC( 48,112) = JacC( 48,112)+ 0.7000000000000001D-01*dw(114,112)
      JacC( 75, 47) = JacC( 75, 47)+ 0.2000000000000000D+00*dw(114, 47)
      JacC( 75,112) = JacC( 75,112)+ 0.2000000000000000D+00*dw(114,112)
      JacC(111, 47) = JacC(111, 47)+ 0.7300000000000000D+00*dw(114, 47)
      JacC(111,112) = JacC(111,112)+ 0.7300000000000000D+00*dw(114,112)
      JacC(112, 47) = JacC(112, 47) - dw(114, 47)
      JacC(112,112) = JacC(112,112) - dw(114,112)
      JacC( 29, 29) = JacC( 29, 29) - dw(115, 29)
      JacC( 29,112) = JacC( 29,112) - dw(115,112)
      JacC( 83, 29) = JacC( 83, 29) + dw(115, 29)
      JacC( 83,112) = JacC( 83,112) + dw(115,112)
      JacC(112, 29) = JacC(112, 29) - dw(115, 29)
      JacC(112,112) = JacC(112,112) - dw(115,112)
      JacC( 29, 29) = JacC( 29, 29) - dw(116, 29)
      JacC( 29,109) = JacC( 29,109) - dw(116,109)
      JacC( 83, 29) = JacC( 83, 29) + dw(116, 29)
      JacC( 83,109) = JacC( 83,109) + dw(116,109)
      JacC( 94, 29) = JacC( 94, 29) + dw(116, 29)
      JacC( 94,109) = JacC( 94,109) + dw(116,109)
      JacC(109, 29) = JacC(109, 29) - dw(116, 29)
      JacC(109,109) = JacC(109,109) - dw(116,109)
      JacC( 81, 83) = JacC( 81, 83) - dw(117, 83)
      JacC( 81, 81) = JacC( 81, 81) - dw(117, 81)
      JacC( 82, 83) = JacC( 82, 83) + dw(117, 83)
      JacC( 82, 81) = JacC( 82, 81) + dw(117, 81)
      JacC( 83, 83) = JacC( 83, 83) - dw(117, 83)
      JacC( 83, 81) = JacC( 83, 81) - dw(117, 81)
      JacC( 83, 83) = JacC( 83, 83) - dw(118, 83)
      JacC( 83,110) = JacC( 83,110) - dw(118,110)
      JacC(110, 83) = JacC(110, 83) - dw(118, 83)
      JacC(110,110) = JacC(110,110) - dw(118,110)
      JacC(113, 83) = JacC(113, 83) + dw(118, 83)
      JacC(113,110) = JacC(113,110) + dw(118,110)
      JacC( 82, 82) = JacC( 82, 82) - dw(119, 82)
      JacC( 82,102) = JacC( 82,102) - dw(119,102)
      JacC( 83, 82) = JacC( 83, 82) + dw(119, 82)
      JacC( 83,102) = JacC( 83,102) + dw(119,102)
      JacC(102, 82) = JacC(102, 82) - dw(119, 82)
      JacC(102,102) = JacC(102,102) - dw(119,102)
      JacC(110, 82) = JacC(110, 82) + dw(119, 82)
      JacC(110,102) = JacC(110,102) + dw(119,102)
      JacC( 82, 82) = JacC( 82, 82) - dw(120, 82)
      JacC( 82,100) = JacC( 82,100) - dw(120,100)
      JacC( 83, 82) = JacC( 83, 82) + dw(120, 82)
      JacC( 83,100) = JacC( 83,100) + dw(120,100)
      JacC(100, 82) = JacC(100, 82) - dw(120, 82)
      JacC(100,100) = JacC(100,100) - dw(120,100)
      JacC(108, 82) = JacC(108, 82) + dw(120, 82)
      JacC(108,100) = JacC(108,100) + dw(120,100)
      JacC(111, 82) = JacC(111, 82) + dw(120, 82)
      JacC(111,100) = JacC(111,100) + dw(120,100)
      JacC( 82, 82) = JacC( 82, 82) - dw(121, 82)
      JacC( 82,105) = JacC( 82,105) - dw(121,105)
      JacC( 83, 82) = JacC( 83, 82) + dw(121, 82)
      JacC( 83,105) = JacC( 83,105) + dw(121,105)
      JacC(100, 82) = JacC(100, 82) + dw(121, 82)
      JacC(100,105) = JacC(100,105) + dw(121,105)
      JacC(105, 82) = JacC(105, 82) - dw(121, 82)
      JacC(105,105) = JacC(105,105) - dw(121,105)
      JacC(111, 82) = JacC(111, 82) + dw(121, 82)
      JacC(111,105) = JacC(111,105) + dw(121,105)
      JacC( 82, 82) = JacC( 82, 82) - dw(122, 82)
      JacC( 82,111) = JacC( 82,111) - dw(122,111)
      JacC(106, 82) = JacC(106, 82) + dw(122, 82)
      JacC(106,111) = JacC(106,111) + dw(122,111)
      JacC(111, 82) = JacC(111, 82) - dw(122, 82)
      JacC(111,111) = JacC(111,111) - dw(122,111)
      JacC( 82, 82) = JacC( 82, 82) - dw(123, 82)
      JacC( 82,109) = JacC( 82,109) - dw(123,109)
      JacC( 83, 82) = JacC( 83, 82) + dw(123, 82)
      JacC( 83,109) = JacC( 83,109) + dw(123,109)
      JacC(109, 82) = JacC(109, 82) - dw(123, 82)
      JacC(109,109) = JacC(109,109) - dw(123,109)
      JacC(110, 82) = JacC(110, 82) + dw(123, 82)
      JacC(110,109) = JacC(110,109) + dw(123,109)
      JacC( 96,108) = JacC( 96,108) + dw(124,108)
      JacC( 96,112) = JacC( 96,112) + dw(124,112)
      JacC(108,108) = JacC(108,108) - dw(124,108)
      JacC(108,112) = JacC(108,112) - dw(124,112)
      JacC(111,108) = JacC(111,108) + dw(124,108)
      JacC(111,112) = JacC(111,112) + dw(124,112)
      JacC(112,108) = JacC(112,108) - dw(124,108)
      JacC(112,112) = JacC(112,112) - dw(124,112)
      JacC( 87, 87) = JacC( 87, 87) - dw(125, 87)
      JacC( 87,112) = JacC( 87,112) - dw(125,112)
      JacC(105, 87) = JacC(105, 87) + dw(125, 87)
      JacC(105,112) = JacC(105,112) + dw(125,112)
      JacC(112, 87) = JacC(112, 87) - dw(125, 87)
      JacC(112,112) = JacC(112,112) - dw(125,112)
      JacC( 98,107) = JacC( 98,107) + dw(126,107)
      JacC( 98,112) = JacC( 98,112) + dw(126,112)
      JacC(107,107) = JacC(107,107) - dw(126,107)
      JacC(107,112) = JacC(107,112) - dw(126,112)
      JacC(112,107) = JacC(112,107) - dw(126,107)
      JacC(112,112) = JacC(112,112) - dw(126,112)
      JacC( 58, 58) = JacC( 58, 58) - dw(127, 58)
      JacC( 58,112) = JacC( 58,112) - dw(127,112)
      JacC( 65, 58) = JacC( 65, 58) + dw(127, 58)
      JacC( 65,112) = JacC( 65,112) + dw(127,112)
      JacC(112, 58) = JacC(112, 58) - dw(127, 58)
      JacC(112,112) = JacC(112,112) - dw(127,112)
      JacC( 30, 30) = JacC( 30, 30) - dw(128, 30)
      JacC( 30,112) = JacC( 30,112) - dw(128,112)
      JacC( 64, 30) = JacC( 64, 30) + dw(128, 30)
      JacC( 64,112) = JacC( 64,112) + dw(128,112)
      JacC(112, 30) = JacC(112, 30) - dw(128, 30)
      JacC(112,112) = JacC(112,112) - dw(128,112)
      JacC( 92,103) = JacC( 92,103) + dw(129,103)
      JacC( 92,112) = JacC( 92,112) + dw(129,112)
      JacC(103,103) = JacC(103,103) - dw(129,103)
      JacC(103,112) = JacC(103,112) - dw(129,112)
      JacC(112,103) = JacC(112,103) - dw(129,103)
      JacC(112,112) = JacC(112,112) - dw(129,112)
      JacC( 76, 76) = JacC( 76, 76) - dw(130, 76)
      JacC( 76,112) = JacC( 76,112) - dw(130,112)
      JacC( 93, 76) = JacC( 93, 76) + dw(130, 76)
      JacC( 93,112) = JacC( 93,112) + dw(130,112)
      JacC(111, 76) = JacC(111, 76) + dw(130, 76)
      JacC(111,112) = JacC(111,112) + dw(130,112)
      JacC(112, 76) = JacC(112, 76) - dw(130, 76)
      JacC(112,112) = JacC(112,112) - dw(130,112)
      JacC( 91, 91) = JacC( 91, 91) - dw(131, 91)
      JacC( 91,112) = JacC( 91,112) - dw(131,112)
      JacC( 96, 91) = JacC( 96, 91)+ 0.2000000000000000D+01*dw(131, 91)
      JacC( 96,112) = JacC( 96,112)+ 0.2000000000000000D+01*dw(131,112)
      JacC(111, 91) = JacC(111, 91) + dw(131, 91)
      JacC(111,112) = JacC(111,112) + dw(131,112)
      JacC(112, 91) = JacC(112, 91) - dw(131, 91)
      JacC(112,112) = JacC(112,112) - dw(131,112)
      JacC( 93, 93) = JacC( 93, 93) - dw(132, 93)
      JacC( 93,112) = JacC( 93,112) - dw(132,112)
      JacC( 96, 93) = JacC( 96, 93) + dw(132, 93)
      JacC( 96,112) = JacC( 96,112) + dw(132,112)
      JacC(105, 93) = JacC(105, 93) + dw(132, 93)
      JacC(105,112) = JacC(105,112) + dw(132,112)
      JacC(112, 93) = JacC(112, 93) - dw(132, 93)
      JacC(112,112) = JacC(112,112) - dw(132,112)
      JacC( 61, 61) = JacC( 61, 61) - dw(133, 61)
      JacC( 61,112) = JacC( 61,112) - dw(133,112)
      JacC( 95, 61) = JacC( 95, 61) + dw(133, 61)
      JacC( 95,112) = JacC( 95,112) + dw(133,112)
      JacC(112, 61) = JacC(112, 61) - dw(133, 61)
      JacC(112,112) = JacC(112,112) - dw(133,112)
      JacC( 66, 66) = JacC( 66, 66) - dw(134, 66)
      JacC( 66,112) = JacC( 66,112) - dw(134,112)
      JacC( 68, 66) = JacC( 68, 66) + dw(134, 66)
      JacC( 68,112) = JacC( 68,112) + dw(134,112)
      JacC(112, 66) = JacC(112, 66) - dw(134, 66)
      JacC(112,112) = JacC(112,112) - dw(134,112)
      JacC( 80, 80) = JacC( 80, 80) - dw(135, 80)
      JacC( 80,112) = JacC( 80,112) - dw(135,112)
      JacC( 84, 80) = JacC( 84, 80)+ 0.6870000000000001D+00*dw(135, 80)
      JacC( 84,112) = JacC( 84,112)+ 0.6870000000000001D+00*dw(135,112)
      JacC(105, 80) = JacC(105, 80)+ 0.3130000000000000D+00*dw(135, 80)
      JacC(105,112) = JacC(105,112)+ 0.3130000000000000D+00*dw(135,112)
      JacC(112, 80) = JacC(112, 80) - dw(135, 80)
      JacC(112,112) = JacC(112,112) - dw(135,112)
      JacC( 22, 22) = JacC( 22, 22) - dw(136, 22)
      JacC( 22,112) = JacC( 22,112) - dw(136,112)
      JacC( 96, 22) = JacC( 96, 22) + dw(136, 22)
      JacC( 96,112) = JacC( 96,112) + dw(136,112)
      JacC(101, 22) = JacC(101, 22) + dw(136, 22)
      JacC(101,112) = JacC(101,112) + dw(136,112)
      JacC(107, 22) = JacC(107, 22) + dw(136, 22)
      JacC(107,112) = JacC(107,112) + dw(136,112)
      JacC(111, 22) = JacC(111, 22) + dw(136, 22)
      JacC(111,112) = JacC(111,112) + dw(136,112)
      JacC(112, 22) = JacC(112, 22) - dw(136, 22)
      JacC(112,112) = JacC(112,112) - dw(136,112)
      JacC( 56, 56) = JacC( 56, 56) - dw(137, 56)
      JacC( 56,112) = JacC( 56,112) - dw(137,112)
      JacC(101, 56) = JacC(101, 56) + dw(137, 56)
      JacC(101,112) = JacC(101,112) + dw(137,112)
      JacC(105, 56) = JacC(105, 56) + dw(137, 56)
      JacC(105,112) = JacC(105,112) + dw(137,112)
      JacC(107, 56) = JacC(107, 56) + dw(137, 56)
      JacC(107,112) = JacC(107,112) + dw(137,112)
      JacC(112, 56) = JacC(112, 56) - dw(137, 56)
      JacC(112,112) = JacC(112,112) - dw(137,112)
      JacC( 77, 77) = JacC( 77, 77) - dw(138, 77)
      JacC( 77,112) = JacC( 77,112) - dw(138,112)
      JacC(101, 77) = JacC(101, 77) + dw(138, 77)
      JacC(101,112) = JacC(101,112) + dw(138,112)
      JacC(105, 77) = JacC(105, 77) + dw(138, 77)
      JacC(105,112) = JacC(105,112) + dw(138,112)
      JacC(107, 77) = JacC(107, 77) + dw(138, 77)
      JacC(107,112) = JacC(107,112) + dw(138,112)
      JacC(112, 77) = JacC(112, 77) - dw(138, 77)
      JacC(112,112) = JacC(112,112) - dw(138,112)
      JacC( 78, 78) = JacC( 78, 78) - dw(139, 78)
      JacC( 78,112) = JacC( 78,112) - dw(139,112)
      JacC( 96, 78) = JacC( 96, 78) + dw(139, 78)
      JacC( 96,112) = JacC( 96,112) + dw(139,112)
      JacC(105, 78) = JacC(105, 78) + dw(139, 78)
      JacC(105,112) = JacC(105,112) + dw(139,112)
      JacC(112, 78) = JacC(112, 78) - dw(139, 78)
      JacC(112,112) = JacC(112,112) - dw(139,112)
      JacC( 34, 34) = JacC( 34, 34) - dw(140, 34)
      JacC( 34,112) = JacC( 34,112) - dw(140,112)
      JacC(100, 34) = JacC(100, 34)+ 0.6500000000000000D+00*dw(140, 34)
      JacC(100,112) = JacC(100,112)+ 0.6500000000000000D+00*dw(140,112)
      JacC(108, 34) = JacC(108, 34)+ 0.3500000000000000D+00*dw(140, 34)
      JacC(108,112) = JacC(108,112)+ 0.3500000000000000D+00*dw(140,112)
      JacC(112, 34) = JacC(112, 34)- 0.6500000000000000D+00*dw(140, 34)
      JacC(112,112) = JacC(112,112)- 0.6500000000000000D+00*dw(140,112)
      JacC( 99,106) = JacC( 99,106)+ 0.4400000000000000D+00*dw(141,106)
      JacC( 99,112) = JacC( 99,112)+ 0.4400000000000000D+00*dw(141,112)
      JacC(101,106) = JacC(101,106)+ 0.7000000000000001D-01*dw(141,106)
      JacC(101,112) = JacC(101,112)+ 0.7000000000000001D-01*dw(141,112)
      JacC(103,106) = JacC(103,106)+ 0.4100000000000000D+00*dw(141,106)
      JacC(103,112) = JacC(103,112)+ 0.4100000000000000D+00*dw(141,112)
      JacC(106,106) = JacC(106,106) - dw(141,106)
      JacC(106,112) = JacC(106,112) - dw(141,112)
      JacC(107,106) = JacC(107,106)+ 0.8000000000000000D-01*dw(141,106)
      JacC(107,112) = JacC(107,112)+ 0.8000000000000000D-01*dw(141,112)
      JacC(112,106) = JacC(112,106)- 0.5100000000000000D+00*dw(141,106)
      JacC(112,112) = JacC(112,112)- 0.5100000000000000D+00*dw(141,112)
      JacC( 74, 74) = JacC( 74, 74) - dw(142, 74)
      JacC( 74,112) = JacC( 74,112) - dw(142,112)
      JacC(101, 74) = JacC(101, 74)+ 0.3500000000000000D+00*dw(142, 74)
      JacC(101,112) = JacC(101,112)+ 0.3500000000000000D+00*dw(142,112)
      JacC(105, 74) = JacC(105, 74)+ 0.6500000000000000D+00*dw(142, 74)
      JacC(105,112) = JacC(105,112)+ 0.6500000000000000D+00*dw(142,112)
      JacC(108, 74) = JacC(108, 74)+ 0.3500000000000000D+00*dw(142, 74)
      JacC(108,112) = JacC(108,112)+ 0.3500000000000000D+00*dw(142,112)
      JacC(112, 74) = JacC(112, 74)- 0.6500000000000000D+00*dw(142, 74)
      JacC(112,112) = JacC(112,112)- 0.6500000000000000D+00*dw(142,112)
      JacC( 35, 35) = JacC( 35, 35) - dw(143, 35)
      JacC( 35,112) = JacC( 35,112) - dw(143,112)
      JacC(101, 35) = JacC(101, 35) + dw(143, 35)
      JacC(101,112) = JacC(101,112) + dw(143,112)
      JacC(108, 35) = JacC(108, 35) + dw(143, 35)
      JacC(108,112) = JacC(108,112) + dw(143,112)
      JacC(109, 35) = JacC(109, 35) + dw(143, 35)
      JacC(109,112) = JacC(109,112) + dw(143,112)
      JacC(112, 35) = JacC(112, 35) - dw(143, 35)
      JacC(112,112) = JacC(112,112) - dw(143,112)
      JacC( 37, 37) = JacC( 37, 37) - dw(144, 37)
      JacC( 37,112) = JacC( 37,112) - dw(144,112)
      JacC(101, 37) = JacC(101, 37) + dw(144, 37)
      JacC(101,112) = JacC(101,112) + dw(144,112)
      JacC(108, 37) = JacC(108, 37) + dw(144, 37)
      JacC(108,112) = JacC(108,112) + dw(144,112)
      JacC(109, 37) = JacC(109, 37) + dw(144, 37)
      JacC(109,112) = JacC(109,112) + dw(144,112)
      JacC(112, 37) = JacC(112, 37) - dw(144, 37)
      JacC(112,112) = JacC(112,112) - dw(144,112)
      JacC( 40, 40) = JacC( 40, 40) - dw(145, 40)
      JacC( 40,112) = JacC( 40,112) - dw(145,112)
      JacC( 73, 40) = JacC( 73, 40) + dw(145, 40)
      JacC( 73,112) = JacC( 73,112) + dw(145,112)
      JacC(110, 40) = JacC(110, 40) + dw(145, 40)
      JacC(110,112) = JacC(110,112) + dw(145,112)
      JacC(112, 40) = JacC(112, 40) - dw(145, 40)
      JacC(112,112) = JacC(112,112) - dw(145,112)
      JacC( 99,113) = JacC( 99,113) + dw(146,113)
      JacC( 99,112) = JacC( 99,112) + dw(146,112)
      JacC(110,113) = JacC(110,113) + dw(146,113)
      JacC(110,112) = JacC(110,112) + dw(146,112)
      JacC(112,113) = JacC(112,113) - dw(146,113)
      JacC(112,112) = JacC(112,112) - dw(146,112)
      JacC(113,113) = JacC(113,113) - dw(146,113)
      JacC(113,112) = JacC(113,112) - dw(146,112)
      JacC( 67, 67) = JacC( 67, 67) - dw(147, 67)
      JacC( 67,112) = JacC( 67,112) - dw(147,112)
      JacC(111, 67) = JacC(111, 67) + dw(147, 67)
      JacC(111,112) = JacC(111,112) + dw(147,112)
      JacC(112, 67) = JacC(112, 67) - dw(147, 67)
      JacC(112,112) = JacC(112,112) - dw(147,112)
      JacC( 90, 97) = JacC( 90, 97)+ 0.3600000000000000D+00*dw(148, 97)
      JacC( 90,112) = JacC( 90,112)+ 0.3600000000000000D+00*dw(148,112)
      JacC( 97, 97) = JacC( 97, 97) - dw(148, 97)
      JacC( 97,112) = JacC( 97,112) - dw(148,112)
      JacC(100, 97) = JacC(100, 97)+ 0.6400000000000000D+00*dw(148, 97)
      JacC(100,112) = JacC(100,112)+ 0.6400000000000000D+00*dw(148,112)
      JacC(112, 97) = JacC(112, 97) - dw(148, 97)
      JacC(112,112) = JacC(112,112) - dw(148,112)
      JacC( 94,108) = JacC( 94,108) + dw(149,108)
      JacC( 94,109) = JacC( 94,109) + dw(149,109)
      JacC( 96,108) = JacC( 96,108) + dw(149,108)
      JacC( 96,109) = JacC( 96,109) + dw(149,109)
      JacC(108,108) = JacC(108,108) - dw(149,108)
      JacC(108,109) = JacC(108,109) - dw(149,109)
      JacC(109,108) = JacC(109,108) - dw(149,108)
      JacC(109,109) = JacC(109,109) - dw(149,109)
      JacC(111,108) = JacC(111,108) + dw(149,108)
      JacC(111,109) = JacC(111,109) + dw(149,109)
      JacC( 87, 87) = JacC( 87, 87) - dw(150, 87)
      JacC( 87,109) = JacC( 87,109) - dw(150,109)
      JacC( 94, 87) = JacC( 94, 87) + dw(150, 87)
      JacC( 94,109) = JacC( 94,109) + dw(150,109)
      JacC(105, 87) = JacC(105, 87) + dw(150, 87)
      JacC(105,109) = JacC(105,109) + dw(150,109)
      JacC(109, 87) = JacC(109, 87) - dw(150, 87)
      JacC(109,109) = JacC(109,109) - dw(150,109)
      JacC( 94,107) = JacC( 94,107) + dw(151,107)
      JacC( 94,109) = JacC( 94,109) + dw(151,109)
      JacC( 98,107) = JacC( 98,107) + dw(151,107)
      JacC( 98,109) = JacC( 98,109) + dw(151,109)
      JacC(107,107) = JacC(107,107) - dw(151,107)
      JacC(107,109) = JacC(107,109) - dw(151,109)
      JacC(109,107) = JacC(109,107) - dw(151,107)
      JacC(109,109) = JacC(109,109) - dw(151,109)
      JacC( 91, 91) = JacC( 91, 91) - dw(152, 91)
      JacC( 91,109) = JacC( 91,109) - dw(152,109)
      JacC( 94, 91) = JacC( 94, 91) + dw(152, 91)
      JacC( 94,109) = JacC( 94,109) + dw(152,109)
      JacC( 96, 91) = JacC( 96, 91)+ 0.2000000000000000D+01*dw(152, 91)
      JacC( 96,109) = JacC( 96,109)+ 0.2000000000000000D+01*dw(152,109)
      JacC(109, 91) = JacC(109, 91) - dw(152, 91)
      JacC(109,109) = JacC(109,109) - dw(152,109)
      JacC(111, 91) = JacC(111, 91) + dw(152, 91)
      JacC(111,109) = JacC(111,109) + dw(152,109)
      JacC( 93, 93) = JacC( 93, 93) - dw(153, 93)
      JacC( 93,109) = JacC( 93,109) - dw(153,109)
      JacC( 94, 93) = JacC( 94, 93) + dw(153, 93)
      JacC( 94,109) = JacC( 94,109) + dw(153,109)
      JacC( 96, 93) = JacC( 96, 93) + dw(153, 93)
      JacC( 96,109) = JacC( 96,109) + dw(153,109)
      JacC(105, 93) = JacC(105, 93) + dw(153, 93)
      JacC(105,109) = JacC(105,109) + dw(153,109)
      JacC(109, 93) = JacC(109, 93) - dw(153, 93)
      JacC(109,109) = JacC(109,109) - dw(153,109)
      JacC( 22, 22) = JacC( 22, 22) - dw(154, 22)
      JacC( 22,109) = JacC( 22,109) - dw(154,109)
      JacC( 91, 22) = JacC( 91, 22) + dw(154, 22)
      JacC( 91,109) = JacC( 91,109) + dw(154,109)
      JacC( 94, 22) = JacC( 94, 22)+ 0.5000000000000000D+00*dw(154, 22)
      JacC( 94,109) = JacC( 94,109)+ 0.5000000000000000D+00*dw(154,109)
      JacC( 96, 22) = JacC( 96, 22)+ 0.1500000000000000D+01*dw(154, 22)
      JacC( 96,109) = JacC( 96,109)+ 0.1500000000000000D+01*dw(154,109)
      JacC(109, 22) = JacC(109, 22) - dw(154, 22)
      JacC(109,109) = JacC(109,109) - dw(154,109)
      JacC(110, 22) = JacC(110, 22)+ 0.5000000000000000D+00*dw(154, 22)
      JacC(110,109) = JacC(110,109)+ 0.5000000000000000D+00*dw(154,109)
      JacC(111, 22) = JacC(111, 22)+ 0.1500000000000000D+01*dw(154, 22)
      JacC(111,109) = JacC(111,109)+ 0.1500000000000000D+01*dw(154,109)
      JacC(112, 22) = JacC(112, 22)+ 0.5000000000000000D+00*dw(154, 22)
      JacC(112,109) = JacC(112,109)+ 0.5000000000000000D+00*dw(154,109)
      JacC( 18, 18) = JacC( 18, 18) - dw(155, 18)
      JacC( 18,109) = JacC( 18,109) - dw(155,109)
      JacC( 48, 18) = JacC( 48, 18)+ 0.4000000000000000D+00*dw(155, 18)
      JacC( 48,109) = JacC( 48,109)+ 0.4000000000000000D+00*dw(155,109)
      JacC( 51, 18) = JacC( 51, 18)+ 0.5000000000000000D+00*dw(155, 18)
      JacC( 51,109) = JacC( 51,109)+ 0.5000000000000000D+00*dw(155,109)
      JacC( 75, 18) = JacC( 75, 18)+ 0.1000000000000000D+00*dw(155, 18)
      JacC( 75,109) = JacC( 75,109)+ 0.1000000000000000D+00*dw(155,109)
      JacC( 94, 18) = JacC( 94, 18)+ 0.5000000000000000D+00*dw(155, 18)
      JacC( 94,109) = JacC( 94,109)+ 0.5000000000000000D+00*dw(155,109)
      JacC(109, 18) = JacC(109, 18) - dw(155, 18)
      JacC(109,109) = JacC(109,109) - dw(155,109)
      JacC( 47, 47) = JacC( 47, 47) - dw(156, 47)
      JacC( 47,109) = JacC( 47,109) - dw(156,109)
      JacC( 48, 47) = JacC( 48, 47)+ 0.4000000000000000D+00*dw(156, 47)
      JacC( 48,109) = JacC( 48,109)+ 0.4000000000000000D+00*dw(156,109)
      JacC( 51, 47) = JacC( 51, 47)+ 0.5000000000000000D+00*dw(156, 47)
      JacC( 51,109) = JacC( 51,109)+ 0.5000000000000000D+00*dw(156,109)
      JacC( 75, 47) = JacC( 75, 47)+ 0.1000000000000000D+00*dw(156, 47)
      JacC( 75,109) = JacC( 75,109)+ 0.1000000000000000D+00*dw(156,109)
      JacC( 94, 47) = JacC( 94, 47)+ 0.5000000000000000D+00*dw(156, 47)
      JacC( 94,109) = JacC( 94,109)+ 0.5000000000000000D+00*dw(156,109)
      JacC(109, 47) = JacC(109, 47) - dw(156, 47)
      JacC(109,109) = JacC(109,109) - dw(156,109)
      JacC( 51, 51) = JacC( 51, 51) - dw(157, 51)
      JacC( 51,102) = JacC( 51,102) - dw(157,102)
      JacC( 91, 51) = JacC( 91, 51) + dw(157, 51)
      JacC( 91,102) = JacC( 91,102) + dw(157,102)
      JacC(102, 51) = JacC(102, 51) - dw(157, 51)
      JacC(102,102) = JacC(102,102) - dw(157,102)
      JacC(106, 51) = JacC(106, 51) + dw(157, 51)
      JacC(106,102) = JacC(106,102) + dw(157,102)
      JacC(110, 51) = JacC(110, 51)+ 0.2000000000000000D+01*dw(157, 51)
      JacC(110,102) = JacC(110,102)+ 0.2000000000000000D+01*dw(157,102)
      JacC( 51, 51) = JacC( 51, 51) - dw(158, 51)
      JacC( 51,109) = JacC( 51,109) - dw(158,109)
      JacC( 91, 51) = JacC( 91, 51) + dw(158, 51)
      JacC( 91,109) = JacC( 91,109) + dw(158,109)
      JacC(106, 51) = JacC(106, 51) + dw(158, 51)
      JacC(106,109) = JacC(106,109) + dw(158,109)
      JacC(109, 51) = JacC(109, 51) - dw(158, 51)
      JacC(109,109) = JacC(109,109) - dw(158,109)
      JacC(110, 51) = JacC(110, 51)+ 0.2000000000000000D+01*dw(158, 51)
      JacC(110,109) = JacC(110,109)+ 0.2000000000000000D+01*dw(158,109)
      JacC( 51, 51) = JacC( 51, 51) - dw(159, 51)
      JacC( 51,100) = JacC( 51,100) - dw(159,100)
      JacC( 91, 51) = JacC( 91, 51)+ 0.7000000000000000D+00*dw(159, 51)
      JacC( 91,100) = JacC( 91,100)+ 0.7000000000000000D+00*dw(159,100)
      JacC(100, 51) = JacC(100, 51) - dw(159, 51)
      JacC(100,100) = JacC(100,100) - dw(159,100)
      JacC(106, 51) = JacC(106, 51)+ 0.7000000000000000D+00*dw(159, 51)
      JacC(106,100) = JacC(106,100)+ 0.7000000000000000D+00*dw(159,100)
      JacC(108, 51) = JacC(108, 51) + dw(159, 51)
      JacC(108,100) = JacC(108,100) + dw(159,100)
      JacC(110, 51) = JacC(110, 51)+ 0.7000000000000000D+00*dw(159, 51)
      JacC(110,100) = JacC(110,100)+ 0.7000000000000000D+00*dw(159,100)
      JacC(111, 51) = JacC(111, 51) + dw(159, 51)
      JacC(111,100) = JacC(111,100) + dw(159,100)
      JacC(113, 51) = JacC(113, 51)+ 0.3000000000000000D+00*dw(159, 51)
      JacC(113,100) = JacC(113,100)+ 0.3000000000000000D+00*dw(159,100)
      JacC( 51, 51) = JacC( 51, 51) - dw(160, 51)
      JacC( 51,105) = JacC( 51,105) - dw(160,105)
      JacC( 91, 51) = JacC( 91, 51)+ 0.7000000000000000D+00*dw(160, 51)
      JacC( 91,105) = JacC( 91,105)+ 0.7000000000000000D+00*dw(160,105)
      JacC(100, 51) = JacC(100, 51) + dw(160, 51)
      JacC(100,105) = JacC(100,105) + dw(160,105)
      JacC(105, 51) = JacC(105, 51) - dw(160, 51)
      JacC(105,105) = JacC(105,105) - dw(160,105)
      JacC(106, 51) = JacC(106, 51)+ 0.7000000000000000D+00*dw(160, 51)
      JacC(106,105) = JacC(106,105)+ 0.7000000000000000D+00*dw(160,105)
      JacC(110, 51) = JacC(110, 51)+ 0.7000000000000000D+00*dw(160, 51)
      JacC(110,105) = JacC(110,105)+ 0.7000000000000000D+00*dw(160,105)
      JacC(111, 51) = JacC(111, 51) + dw(160, 51)
      JacC(111,105) = JacC(111,105) + dw(160,105)
      JacC(113, 51) = JacC(113, 51)+ 0.3000000000000000D+00*dw(160, 51)
      JacC(113,105) = JacC(113,105)+ 0.3000000000000000D+00*dw(160,105)
      JacC( 51, 51) = JacC( 51, 51) - dw(161, 51)
      JacC( 51,111) = JacC( 51,111) - dw(161,111)
      JacC(106, 51) = JacC(106, 51) + dw(161, 51)
      JacC(106,111) = JacC(106,111) + dw(161,111)
      JacC(111, 51) = JacC(111, 51) - dw(161, 51)
      JacC(111,111) = JacC(111,111) - dw(161,111)
      JacC( 23, 23) = JacC( 23, 23) - dw(162, 23)
      JacC( 23,109) = JacC( 23,109) - dw(162,109)
      JacC( 70, 23) = JacC( 70, 23)+ 0.2000000000000000D+00*dw(162, 23)
      JacC( 70,109) = JacC( 70,109)+ 0.2000000000000000D+00*dw(162,109)
      JacC( 71, 23) = JacC( 71, 23)+ 0.8000000000000000D+00*dw(162, 23)
      JacC( 71,109) = JacC( 71,109)+ 0.8000000000000000D+00*dw(162,109)
      JacC(109, 23) = JacC(109, 23) - dw(162, 23)
      JacC(109,109) = JacC(109,109) - dw(162,109)
      JacC( 31, 31) = JacC( 31, 31) - dw(163, 31)
      JacC( 31,109) = JacC( 31,109) - dw(163,109)
      JacC( 70, 31) = JacC( 70, 31)+ 0.5700000000000000D+00*dw(163, 31)
      JacC( 70,109) = JacC( 70,109)+ 0.5700000000000000D+00*dw(163,109)
      JacC( 71, 31) = JacC( 71, 31)+ 0.4300000000000000D+00*dw(163, 31)
      JacC( 71,109) = JacC( 71,109)+ 0.4300000000000000D+00*dw(163,109)
      JacC(109, 31) = JacC(109, 31) - dw(163, 31)
      JacC(109,109) = JacC(109,109) - dw(163,109)
      JacC( 69, 69) = JacC( 69, 69) - dw(164, 69)
      JacC( 69,109) = JacC( 69,109) - dw(164,109)
      JacC( 70, 69) = JacC( 70, 69)+ 0.8900000000000000D+00*dw(164, 69)
      JacC( 70,109) = JacC( 70,109)+ 0.8900000000000000D+00*dw(164,109)
      JacC( 71, 69) = JacC( 71, 69)+ 0.1100000000000000D+00*dw(164, 69)
      JacC( 71,109) = JacC( 71,109)+ 0.1100000000000000D+00*dw(164,109)
      JacC(109, 69) = JacC(109, 69) - dw(164, 69)
      JacC(109,109) = JacC(109,109) - dw(164,109)
      JacC( 20, 20) = JacC( 20, 20) - dw(165, 20)
      JacC( 20,109) = JacC( 20,109) - dw(165,109)
      JacC( 61, 20) = JacC( 61, 20)+ 0.9000000000000000D+00*dw(165, 20)
      JacC( 61,109) = JacC( 61,109)+ 0.9000000000000000D+00*dw(165,109)
      JacC( 70, 20) = JacC( 70, 20)+ 0.1000000000000000D+00*dw(165, 20)
      JacC( 70,109) = JacC( 70,109)+ 0.1000000000000000D+00*dw(165,109)
      JacC( 71, 20) = JacC( 71, 20)+ 0.9000000000000000D+00*dw(165, 20)
      JacC( 71,109) = JacC( 71,109)+ 0.9000000000000000D+00*dw(165,109)
      JacC(109, 20) = JacC(109, 20) - dw(165, 20)
      JacC(109,109) = JacC(109,109) - dw(165,109)
      JacC( 26, 26) = JacC( 26, 26) - dw(166, 26)
      JacC( 26,109) = JacC( 26,109) - dw(166,109)
      JacC( 39, 26) = JacC( 39, 26) + dw(166, 26)
      JacC( 39,109) = JacC( 39,109) + dw(166,109)
      JacC(109, 26) = JacC(109, 26) - dw(166, 26)
      JacC(109,109) = JacC(109,109) - dw(166,109)
      JacC( 61, 61) = JacC( 61, 61) - dw(167, 61)
      JacC( 61,109) = JacC( 61,109) - dw(167,109)
      JacC( 94, 61) = JacC( 94, 61)+ 0.5000000000000000D+00*dw(167, 61)
      JacC( 94,109) = JacC( 94,109)+ 0.5000000000000000D+00*dw(167,109)
      JacC( 95, 61) = JacC( 95, 61)+ 0.5000000000000000D+00*dw(167, 61)
      JacC( 95,109) = JacC( 95,109)+ 0.5000000000000000D+00*dw(167,109)
      JacC( 96, 61) = JacC( 96, 61)+ 0.5000000000000000D+00*dw(167, 61)
      JacC( 96,109) = JacC( 96,109)+ 0.5000000000000000D+00*dw(167,109)
      JacC(101, 61) = JacC(101, 61)+ 0.5000000000000000D+00*dw(167, 61)
      JacC(101,109) = JacC(101,109)+ 0.5000000000000000D+00*dw(167,109)
      JacC(109, 61) = JacC(109, 61) - dw(167, 61)
      JacC(109,109) = JacC(109,109) - dw(167,109)
      JacC(111, 61) = JacC(111, 61)+ 0.5000000000000000D+00*dw(167, 61)
      JacC(111,109) = JacC(111,109)+ 0.5000000000000000D+00*dw(167,109)
      JacC(113, 61) = JacC(113, 61)+ 0.5000000000000000D+00*dw(167, 61)
      JacC(113,109) = JacC(113,109)+ 0.5000000000000000D+00*dw(167,109)
      JacC( 80, 80) = JacC( 80, 80) - dw(168, 80)
      JacC( 80,109) = JacC( 80,109) - dw(168,109)
      JacC( 96, 80) = JacC( 96, 80)+ 0.6680000000000000D+00*dw(168, 80)
      JacC( 96,109) = JacC( 96,109)+ 0.6680000000000000D+00*dw(168,109)
      JacC(101, 80) = JacC(101, 80) + dw(168, 80)
      JacC(101,109) = JacC(101,109) + dw(168,109)
      JacC(107, 80) = JacC(107, 80)+ 0.3320000000000000D+00*dw(168, 80)
      JacC(107,109) = JacC(107,109)+ 0.3320000000000000D+00*dw(168,109)
      JacC(108, 80) = JacC(108, 80)+ 0.3320000000000000D+00*dw(168, 80)
      JacC(108,109) = JacC(108,109)+ 0.3320000000000000D+00*dw(168,109)
      JacC(109, 80) = JacC(109, 80) - dw(168, 80)
      JacC(109,109) = JacC(109,109) - dw(168,109)
      JacC(111, 80) = JacC(111, 80) + dw(168, 80)
      JacC(111,109) = JacC(111,109) + dw(168,109)
      JacC(113, 80) = JacC(113, 80) + dw(168, 80)
      JacC(113,109) = JacC(113,109) + dw(168,109)
      JacC( 19, 19) = JacC( 19, 19) - dw(169, 19)
      JacC( 19,109) = JacC( 19,109) - dw(169,109)
      JacC( 70, 19) = JacC( 70, 19)+ 0.9000000000000000D+00*dw(169, 19)
      JacC( 70,109) = JacC( 70,109)+ 0.9000000000000000D+00*dw(169,109)
      JacC( 71, 19) = JacC( 71, 19)+ 0.1000000000000000D+00*dw(169, 19)
      JacC( 71,109) = JacC( 71,109)+ 0.1000000000000000D+00*dw(169,109)
      JacC(109, 19) = JacC(109, 19) - dw(169, 19)
      JacC(109,109) = JacC(109,109) - dw(169,109)
      JacC( 27, 27) = JacC( 27, 27) - dw(170, 27)
      JacC( 27,109) = JacC( 27,109) - dw(170,109)
      JacC( 70, 27) = JacC( 70, 27)+ 0.8700000000000000D+00*dw(170, 27)
      JacC( 70,109) = JacC( 70,109)+ 0.8700000000000000D+00*dw(170,109)
      JacC( 71, 27) = JacC( 71, 27)+ 0.1300000000000000D+00*dw(170, 27)
      JacC( 71,109) = JacC( 71,109)+ 0.1300000000000000D+00*dw(170,109)
      JacC(109, 27) = JacC(109, 27) - dw(170, 27)
      JacC(109,109) = JacC(109,109) - dw(170,109)
      JacC( 40, 40) = JacC( 40, 40) - dw(171, 40)
      JacC( 40,109) = JacC( 40,109) - dw(171,109)
      JacC( 95, 40) = JacC( 95, 40) + dw(171, 40)
      JacC( 95,109) = JacC( 95,109) + dw(171,109)
      JacC(109, 40) = JacC(109, 40) - dw(171, 40)
      JacC(109,109) = JacC(109,109) - dw(171,109)
      JacC(110, 40) = JacC(110, 40) + dw(171, 40)
      JacC(110,109) = JacC(110,109) + dw(171,109)
      JacC( 23, 23) = JacC( 23, 23) - dw(172, 23)
      JacC( 23, 81) = JacC( 23, 81) - dw(172, 81)
      JacC( 67, 23) = JacC( 67, 23)+ 0.3700000000000000D+00*dw(172, 23)
      JacC( 67, 81) = JacC( 67, 81)+ 0.3700000000000000D+00*dw(172, 81)
      JacC( 81, 23) = JacC( 81, 23) - dw(172, 23)
      JacC( 81, 81) = JacC( 81, 81) - dw(172, 81)
      JacC( 96, 23) = JacC( 96, 23)+ 0.4300000000000000D+00*dw(172, 23)
      JacC( 96, 81) = JacC( 96, 81)+ 0.4300000000000000D+00*dw(172, 81)
      JacC(108, 23) = JacC(108, 23) + dw(172, 23)
      JacC(108, 81) = JacC(108, 81) + dw(172, 81)
      JacC(111, 23) = JacC(111, 23)+ 0.2600000000000000D+00*dw(172, 23)
      JacC(111, 81) = JacC(111, 81)+ 0.2600000000000000D+00*dw(172, 81)
      JacC(112, 23) = JacC(112, 23)+ 0.1200000000000000D+00*dw(172, 23)
      JacC(112, 81) = JacC(112, 81)+ 0.1200000000000000D+00*dw(172, 81)
      JacC( 31, 31) = JacC( 31, 31) - dw(173, 31)
      JacC( 31, 81) = JacC( 31, 81) - dw(173, 81)
      JacC( 32, 31) = JacC( 32, 31)+ 0.6000000000000000D-01*dw(173, 31)
      JacC( 32, 81) = JacC( 32, 81)+ 0.6000000000000000D-01*dw(173, 81)
      JacC( 33, 31) = JacC( 33, 31)+ 0.3000000000000000D-01*dw(173, 31)
      JacC( 33, 81) = JacC( 33, 81)+ 0.3000000000000000D-01*dw(173, 81)
      JacC( 38, 31) = JacC( 38, 31)+ 0.6000000000000000D-02*dw(173, 31)
      JacC( 38, 81) = JacC( 38, 81)+ 0.6000000000000000D-02*dw(173, 81)
      JacC( 67, 31) = JacC( 67, 31)+ 0.1400000000000000D+00*dw(173, 31)
      JacC( 67, 81) = JacC( 67, 81)+ 0.1400000000000000D+00*dw(173, 81)
      JacC( 81, 31) = JacC( 81, 31) - dw(173, 31)
      JacC( 81, 81) = JacC( 81, 81) - dw(173, 81)
      JacC( 92, 31) = JacC( 92, 31)+ 0.3000000000000000D-01*dw(173, 31)
      JacC( 92, 81) = JacC( 92, 81)+ 0.3000000000000000D-01*dw(173, 81)
      JacC( 96, 31) = JacC( 96, 31)+ 0.3700000000000000D+00*dw(173, 31)
      JacC( 96, 81) = JacC( 96, 81)+ 0.3700000000000000D+00*dw(173, 81)
      JacC( 97, 31) = JacC( 97, 31)+ 0.1000000000000000D+00*dw(173, 31)
      JacC( 97, 81) = JacC( 97, 81)+ 0.1000000000000000D+00*dw(173, 81)
      JacC(100, 31) = JacC(100, 31)+ 0.1900000000000000D+00*dw(173, 31)
      JacC(100, 81) = JacC(100, 81)+ 0.1900000000000000D+00*dw(173, 81)
      JacC(103, 31) = JacC(103, 31)+ 0.3000000000000000D-01*dw(173, 31)
      JacC(103, 81) = JacC(103, 81)+ 0.3000000000000000D-01*dw(173, 81)
      JacC(104, 31) = JacC(104, 31)+ 0.1000000000000000D+00*dw(173, 31)
      JacC(104, 81) = JacC(104, 81)+ 0.1000000000000000D+00*dw(173, 81)
      JacC(107, 31) = JacC(107, 31)+ 0.4400000000000000D+00*dw(173, 31)
      JacC(107, 81) = JacC(107, 81)+ 0.4400000000000000D+00*dw(173, 81)
      JacC(108, 31) = JacC(108, 31)+ 0.6400000000000000D+00*dw(173, 31)
      JacC(108, 81) = JacC(108, 81)+ 0.6400000000000000D+00*dw(173, 81)
      JacC(111, 31) = JacC(111, 31)+ 0.2500000000000000D+00*dw(173, 31)
      JacC(111, 81) = JacC(111, 81)+ 0.2500000000000000D+00*dw(173, 81)
      JacC(112, 31) = JacC(112, 31)+ 0.4000000000000000D+00*dw(173, 31)
      JacC(112, 81) = JacC(112, 81)+ 0.4000000000000000D+00*dw(173, 81)
      JacC( 32, 69) = JacC( 32, 69)+ 0.7000000000000001D-01*dw(174, 69)
      JacC( 32, 81) = JacC( 32, 81)+ 0.7000000000000001D-01*dw(174, 81)
      JacC( 33, 69) = JacC( 33, 69)+ 0.6000000000000000D-01*dw(174, 69)
      JacC( 33, 81) = JacC( 33, 81)+ 0.6000000000000000D-01*dw(174, 81)
      JacC( 38, 69) = JacC( 38, 69)+ 0.1100000000000000D-01*dw(174, 69)
      JacC( 38, 81) = JacC( 38, 81)+ 0.1100000000000000D-01*dw(174, 81)
      JacC( 69, 69) = JacC( 69, 69) - dw(174, 69)
      JacC( 69, 81) = JacC( 69, 81) - dw(174, 81)
      JacC( 81, 69) = JacC( 81, 69) - dw(174, 69)
      JacC( 81, 81) = JacC( 81, 81) - dw(174, 81)
      JacC( 92, 69) = JacC( 92, 69)+ 0.1200000000000000D+00*dw(174, 69)
      JacC( 92, 81) = JacC( 92, 81)+ 0.1200000000000000D+00*dw(174, 81)
      JacC( 96, 69) = JacC( 96, 69)+ 0.3000000000000000D+00*dw(174, 69)
      JacC( 96, 81) = JacC( 96, 81)+ 0.3000000000000000D+00*dw(174, 81)
      JacC( 97, 69) = JacC( 97, 69)+ 0.1400000000000000D+00*dw(174, 69)
      JacC( 97, 81) = JacC( 97, 81)+ 0.1400000000000000D+00*dw(174, 81)
      JacC(100, 69) = JacC(100, 69)+ 0.2300000000000000D+00*dw(174, 69)
      JacC(100, 81) = JacC(100, 81)+ 0.2300000000000000D+00*dw(174, 81)
      JacC(103, 69) = JacC(103, 69)+ 0.1600000000000000D+00*dw(174, 69)
      JacC(103, 81) = JacC(103, 81)+ 0.1600000000000000D+00*dw(174, 81)
      JacC(104, 69) = JacC(104, 69)+ 0.1800000000000000D+00*dw(174, 69)
      JacC(104, 81) = JacC(104, 81)+ 0.1800000000000000D+00*dw(174, 81)
      JacC(107, 69) = JacC(107, 69)+ 0.9900000000000000D+00*dw(174, 69)
      JacC(107, 81) = JacC(107, 81)+ 0.9900000000000000D+00*dw(174, 81)
      JacC(108, 69) = JacC(108, 69)+ 0.2000000000000000D-01*dw(174, 69)
      JacC(108, 81) = JacC(108, 81)+ 0.2000000000000000D-01*dw(174, 81)
      JacC(111, 69) = JacC(111, 69)+ 0.2200000000000000D+00*dw(174, 69)
      JacC(111, 81) = JacC(111, 81)+ 0.2200000000000000D+00*dw(174, 81)
      JacC(112, 69) = JacC(112, 69)+ 0.6300000000000000D+00*dw(174, 69)
      JacC(112, 81) = JacC(112, 81)+ 0.6300000000000000D+00*dw(174, 81)
      JacC( 20, 20) = JacC( 20, 20) - dw(175, 20)
      JacC( 20, 81) = JacC( 20, 81) - dw(175, 81)
      JacC( 31, 20) = JacC( 31, 20)+ 0.3500000000000000D+00*dw(175, 20)
      JacC( 31, 81) = JacC( 31, 81)+ 0.3500000000000000D+00*dw(175, 81)
      JacC( 38, 20) = JacC( 38, 20)+ 0.1000000000000000D-02*dw(175, 20)
      JacC( 38, 81) = JacC( 38, 81)+ 0.1000000000000000D-02*dw(175, 81)
      JacC( 44, 20) = JacC( 44, 20)+ 0.9000000000000000D-01*dw(175, 20)
      JacC( 44, 81) = JacC( 44, 81)+ 0.9000000000000000D-01*dw(175, 81)
      JacC( 61, 20) = JacC( 61, 20)+ 0.3900000000000000D+00*dw(175, 20)
      JacC( 61, 81) = JacC( 61, 81)+ 0.3900000000000000D+00*dw(175, 81)
      JacC( 67, 20) = JacC( 67, 20)+ 0.1500000000000000D+00*dw(175, 20)
      JacC( 67, 81) = JacC( 67, 81)+ 0.1500000000000000D+00*dw(175, 81)
      JacC( 81, 20) = JacC( 81, 20) - dw(175, 20)
      JacC( 81, 81) = JacC( 81, 81) - dw(175, 81)
      JacC( 92, 20) = JacC( 92, 20)+ 0.2000000000000000D-01*dw(175, 20)
      JacC( 92, 81) = JacC( 92, 81)+ 0.2000000000000000D-01*dw(175, 81)
      JacC( 96, 20) = JacC( 96, 20)+ 0.3600000000000000D+00*dw(175, 20)
      JacC( 96, 81) = JacC( 96, 81)+ 0.3600000000000000D+00*dw(175, 81)
      JacC(100, 20) = JacC(100, 20)+ 0.3000000000000000D-01*dw(175, 20)
      JacC(100, 81) = JacC(100, 81)+ 0.3000000000000000D-01*dw(175, 81)
      JacC(101, 20) = JacC(101, 20)+ 0.1300000000000000D+00*dw(175, 20)
      JacC(101, 81) = JacC(101, 81)+ 0.1300000000000000D+00*dw(175, 81)
      JacC(105, 20) = JacC(105, 20)+ 0.1500000000000000D+00*dw(175, 20)
      JacC(105, 81) = JacC(105, 81)+ 0.1500000000000000D+00*dw(175, 81)
      JacC(108, 20) = JacC(108, 20)+ 0.9000000000000000D+00*dw(175, 20)
      JacC(108, 81) = JacC(108, 81)+ 0.9000000000000000D+00*dw(175, 81)
      JacC(111, 20) = JacC(111, 20)+ 0.3000000000000000D+00*dw(175, 20)
      JacC(111, 81) = JacC(111, 81)+ 0.3000000000000000D+00*dw(175, 81)
      JacC(112, 20) = JacC(112, 20)+ 0.2800000000000000D+00*dw(175, 20)
      JacC(112, 81) = JacC(112, 81)+ 0.2800000000000000D+00*dw(175, 81)
      JacC( 26, 26) = JacC( 26, 26) - dw(176, 26)
      JacC( 26, 81) = JacC( 26, 81) - dw(176, 81)
      JacC( 38, 26) = JacC( 38, 26)+ 0.9000000000000000D-01*dw(176, 26)
      JacC( 38, 81) = JacC( 38, 81)+ 0.9000000000000000D-01*dw(176, 81)
      JacC( 61, 26) = JacC( 61, 26)+ 0.4610000000000000D+00*dw(176, 26)
      JacC( 61, 81) = JacC( 61, 81)+ 0.4610000000000000D+00*dw(176, 81)
      JacC( 66, 26) = JacC( 66, 26)+ 0.1890000000000000D+00*dw(176, 26)
      JacC( 66, 81) = JacC( 66, 81)+ 0.1890000000000000D+00*dw(176, 81)
      JacC( 67, 26) = JacC( 67, 26)+ 0.2800000000000000D+00*dw(176, 26)
      JacC( 67, 81) = JacC( 67, 81)+ 0.2800000000000000D+00*dw(176, 81)
      JacC( 81, 26) = JacC( 81, 26) - dw(176, 26)
      JacC( 81, 81) = JacC( 81, 81) - dw(176, 81)
      JacC( 95, 26) = JacC( 95, 26)+ 0.1000000000000000D+00*dw(176, 26)
      JacC( 95, 81) = JacC( 95, 81)+ 0.1000000000000000D+00*dw(176, 81)
      JacC( 96, 26) = JacC( 96, 26)+ 0.1400000000000000D+00*dw(176, 26)
      JacC( 96, 81) = JacC( 96, 81)+ 0.1400000000000000D+00*dw(176, 81)
      JacC(100, 26) = JacC(100, 26)+ 0.8000000000000000D-01*dw(176, 26)
      JacC(100, 81) = JacC(100, 81)+ 0.8000000000000000D-01*dw(176, 81)
      JacC(105, 26) = JacC(105, 26)+ 0.1000000000000000D+00*dw(176, 26)
      JacC(105, 81) = JacC(105, 81)+ 0.1000000000000000D+00*dw(176, 81)
      JacC(108, 26) = JacC(108, 26)+ 0.5800000000000000D+00*dw(176, 26)
      JacC(108, 81) = JacC(108, 81)+ 0.5800000000000000D+00*dw(176, 81)
      JacC(111, 26) = JacC(111, 26)+ 0.2500000000000000D+00*dw(176, 26)
      JacC(111, 81) = JacC(111, 81)+ 0.2500000000000000D+00*dw(176, 81)
      JacC(112, 26) = JacC(112, 26)+ 0.2500000000000000D+00*dw(176, 26)
      JacC(112, 81) = JacC(112, 81)+ 0.2500000000000000D+00*dw(176, 81)
      JacC( 61, 61) = JacC( 61, 61) - dw(177, 61)
      JacC( 61, 81) = JacC( 61, 81) - dw(177, 81)
      JacC( 67, 61) = JacC( 67, 61)+ 0.4500000000000000D+00*dw(177, 61)
      JacC( 67, 81) = JacC( 67, 81)+ 0.4500000000000000D+00*dw(177, 81)
      JacC( 81, 61) = JacC( 81, 61) - dw(177, 61)
      JacC( 81, 81) = JacC( 81, 81) - dw(177, 81)
      JacC( 93, 61) = JacC( 93, 61)+ 0.9000000000000000D+00*dw(177, 61)
      JacC( 93, 81) = JacC( 93, 81)+ 0.9000000000000000D+00*dw(177, 81)
      JacC( 96, 61) = JacC( 96, 61)+ 0.2200000000000000D+00*dw(177, 61)
      JacC( 96, 81) = JacC( 96, 81)+ 0.2200000000000000D+00*dw(177, 81)
      JacC(105, 61) = JacC(105, 61)+ 0.1000000000000000D+00*dw(177, 61)
      JacC(105, 81) = JacC(105, 81)+ 0.1000000000000000D+00*dw(177, 81)
      JacC(111, 61) = JacC(111, 61)+ 0.3200000000000000D+00*dw(177, 61)
      JacC(111, 81) = JacC(111, 81)+ 0.3200000000000000D+00*dw(177, 81)
      JacC(112, 61) = JacC(112, 61)+ 0.1900000000000000D+00*dw(177, 61)
      JacC(112, 81) = JacC(112, 81)+ 0.1900000000000000D+00*dw(177, 81)
      JacC( 66, 66) = JacC( 66, 66) - dw(178, 66)
      JacC( 66, 81) = JacC( 66, 81) - dw(178, 81)
      JacC( 67, 66) = JacC( 67, 66)+ 0.6700000000000000D+00*dw(178, 66)
      JacC( 67, 81) = JacC( 67, 81)+ 0.6700000000000000D+00*dw(178, 81)
      JacC( 81, 66) = JacC( 81, 66) - dw(178, 66)
      JacC( 81, 81) = JacC( 81, 81) - dw(178, 81)
      JacC( 93, 66) = JacC( 93, 66)+ 0.9500000000000000D+00*dw(178, 66)
      JacC( 93, 81) = JacC( 93, 81)+ 0.9500000000000000D+00*dw(178, 81)
      JacC( 96, 66) = JacC( 96, 66)+ 0.1100000000000000D+00*dw(178, 66)
      JacC( 96, 81) = JacC( 96, 81)+ 0.1100000000000000D+00*dw(178, 81)
      JacC(101, 66) = JacC(101, 66)+ 0.5000000000000000D-01*dw(178, 66)
      JacC(101, 81) = JacC(101, 81)+ 0.5000000000000000D-01*dw(178, 81)
      JacC(105, 66) = JacC(105, 66)+ 0.5000000000000000D-01*dw(178, 66)
      JacC(105, 81) = JacC(105, 81)+ 0.5000000000000000D-01*dw(178, 81)
      JacC(108, 66) = JacC(108, 66)+ 0.1000000000000000D+00*dw(178, 66)
      JacC(108, 81) = JacC(108, 81)+ 0.1000000000000000D+00*dw(178, 81)
      JacC(111, 66) = JacC(111, 66)+ 0.1100000000000000D+00*dw(178, 66)
      JacC(111, 81) = JacC(111, 81)+ 0.1100000000000000D+00*dw(178, 81)
      JacC(112, 66) = JacC(112, 66)+ 0.1600000000000000D+00*dw(178, 66)
      JacC(112, 81) = JacC(112, 81)+ 0.1600000000000000D+00*dw(178, 81)
      JacC( 67, 80) = JacC( 67, 80)+ 0.4400000000000000D-01*dw(179, 80)
      JacC( 67, 81) = JacC( 67, 81)+ 0.4400000000000000D-01*dw(179, 81)
      JacC( 80, 80) = JacC( 80, 80) - dw(179, 80)
      JacC( 80, 81) = JacC( 80, 81) - dw(179, 81)
      JacC( 81, 80) = JacC( 81, 80) - dw(179, 80)
      JacC( 81, 81) = JacC( 81, 81) - dw(179, 81)
      JacC( 91, 80) = JacC( 91, 80)+ 0.3100000000000000D-01*dw(179, 80)
      JacC( 91, 81) = JacC( 91, 81)+ 0.3100000000000000D-01*dw(179, 81)
      JacC( 93, 80) = JacC( 93, 80)+ 0.6530000000000000D+00*dw(179, 80)
      JacC( 93, 81) = JacC( 93, 81)+ 0.6530000000000000D+00*dw(179, 81)
      JacC( 96, 80) = JacC( 96, 80)+ 0.2430000000000000D+00*dw(179, 80)
      JacC( 96, 81) = JacC( 96, 81)+ 0.2430000000000000D+00*dw(179, 81)
      JacC(100, 80) = JacC(100, 80)+ 0.1680000000000000D+00*dw(179, 80)
      JacC(100, 81) = JacC(100, 81)+ 0.1680000000000000D+00*dw(179, 81)
      JacC(101, 80) = JacC(101, 80)+ 0.1000000000000000D+00*dw(179, 80)
      JacC(101, 81) = JacC(101, 81)+ 0.1000000000000000D+00*dw(179, 81)
      JacC(103, 80) = JacC(103, 80)+ 0.2780000000000000D+00*dw(179, 80)
      JacC(103, 81) = JacC(103, 81)+ 0.2780000000000000D+00*dw(179, 81)
      JacC(105, 80) = JacC(105, 80)+ 0.2370000000000000D+00*dw(179, 80)
      JacC(105, 81) = JacC(105, 81)+ 0.2370000000000000D+00*dw(179, 81)
      JacC(107, 80) = JacC(107, 80)+ 0.6200000000000000D-01*dw(179, 80)
      JacC(107, 81) = JacC(107, 81)+ 0.6200000000000000D-01*dw(179, 81)
      JacC(108, 80) = JacC(108, 80)+ 0.2180000000000000D+00*dw(179, 80)
      JacC(108, 81) = JacC(108, 81)+ 0.2180000000000000D+00*dw(179, 81)
      JacC(111, 80) = JacC(111, 80)+ 0.7199999999999999D-01*dw(179, 80)
      JacC(111, 81) = JacC(111, 81)+ 0.7199999999999999D-01*dw(179, 81)
      JacC(112, 80) = JacC(112, 80)+ 0.4760000000000000D+00*dw(179, 80)
      JacC(112, 81) = JacC(112, 81)+ 0.4760000000000000D+00*dw(179, 81)
      JacC( 19, 19) = JacC( 19, 19) - dw(180, 19)
      JacC( 19, 81) = JacC( 19, 81) - dw(180, 81)
      JacC( 38, 19) = JacC( 38, 19)+ 0.2000000000000000D-01*dw(180, 19)
      JacC( 38, 81) = JacC( 38, 81)+ 0.2000000000000000D-01*dw(180, 81)
      JacC( 81, 19) = JacC( 81, 19) - dw(180, 19)
      JacC( 81, 81) = JacC( 81, 81) - dw(180, 81)
      JacC( 92, 19) = JacC( 92, 19)+ 0.4200000000000000D+00*dw(180, 19)
      JacC( 92, 81) = JacC( 92, 81)+ 0.4200000000000000D+00*dw(180, 81)
      JacC( 96, 19) = JacC( 96, 19)+ 0.1400000000000000D+00*dw(180, 19)
      JacC( 96, 81) = JacC( 96, 81)+ 0.1400000000000000D+00*dw(180, 81)
      JacC(103, 19) = JacC(103, 19)+ 0.5300000000000000D+00*dw(180, 19)
      JacC(103, 81) = JacC(103, 81)+ 0.5300000000000000D+00*dw(180, 81)
      JacC(104, 19) = JacC(104, 19)+ 0.2000000000000000D+00*dw(180, 19)
      JacC(104, 81) = JacC(104, 81)+ 0.2000000000000000D+00*dw(180, 81)
      JacC(107, 19) = JacC(107, 19)+ 0.6500000000000000D+00*dw(180, 19)
      JacC(107, 81) = JacC(107, 81)+ 0.6500000000000000D+00*dw(180, 81)
      JacC(111, 19) = JacC(111, 19)+ 0.1000000000000000D+00*dw(180, 19)
      JacC(111, 81) = JacC(111, 81)+ 0.1000000000000000D+00*dw(180, 81)
      JacC(112, 19) = JacC(112, 19)+ 0.8500000000000000D+00*dw(180, 19)
      JacC(112, 81) = JacC(112, 81)+ 0.8500000000000000D+00*dw(180, 81)
      JacC( 27, 27) = JacC( 27, 27) - dw(181, 27)
      JacC( 27, 81) = JacC( 27, 81) - dw(181, 81)
      JacC( 31, 27) = JacC( 31, 27)+ 0.4600000000000000D+00*dw(181, 27)
      JacC( 31, 81) = JacC( 31, 81)+ 0.4600000000000000D+00*dw(181, 81)
      JacC( 38, 27) = JacC( 38, 27)+ 0.2000000000000000D-01*dw(181, 27)
      JacC( 38, 81) = JacC( 38, 81)+ 0.2000000000000000D-01*dw(181, 81)
      JacC( 61, 27) = JacC( 61, 27)+ 0.7900000000000000D+00*dw(181, 27)
      JacC( 61, 81) = JacC( 61, 81)+ 0.7900000000000000D+00*dw(181, 81)
      JacC( 67, 27) = JacC( 67, 27)+ 0.1000000000000000D-01*dw(181, 27)
      JacC( 67, 81) = JacC( 67, 81)+ 0.1000000000000000D-01*dw(181, 81)
      JacC( 81, 27) = JacC( 81, 27) - dw(181, 27)
      JacC( 81, 81) = JacC( 81, 81) - dw(181, 81)
      JacC( 92, 27) = JacC( 92, 27)+ 0.4200000000000000D+00*dw(181, 27)
      JacC( 92, 81) = JacC( 92, 81)+ 0.4200000000000000D+00*dw(181, 81)
      JacC( 96, 27) = JacC( 96, 27)+ 0.1400000000000000D+00*dw(181, 27)
      JacC( 96, 81) = JacC( 96, 81)+ 0.1400000000000000D+00*dw(181, 81)
      JacC( 97, 27) = JacC( 97, 27)+ 0.7000000000000001D-01*dw(181, 27)
      JacC( 97, 81) = JacC( 97, 81)+ 0.7000000000000001D-01*dw(181, 81)
      JacC(104, 27) = JacC(104, 27)+ 0.1600000000000000D+00*dw(181, 27)
      JacC(104, 81) = JacC(104, 81)+ 0.1600000000000000D+00*dw(181, 81)
      JacC(108, 27) = JacC(108, 27)+ 0.4000000000000000D-01*dw(181, 27)
      JacC(108, 81) = JacC(108, 81)+ 0.4000000000000000D-01*dw(181, 81)
      JacC(111, 27) = JacC(111, 27)+ 0.1000000000000000D+00*dw(181, 27)
      JacC(111, 81) = JacC(111, 81)+ 0.1000000000000000D+00*dw(181, 81)
      JacC(112, 27) = JacC(112, 27)+ 0.8500000000000000D+00*dw(181, 27)
      JacC(112, 81) = JacC(112, 81)+ 0.8500000000000000D+00*dw(181, 81)
      JacC( 22, 22) = JacC( 22, 22) - dw(182, 22)
      JacC( 22, 81) = JacC( 22, 81) - dw(182, 81)
      JacC( 81, 22) = JacC( 81, 22) - dw(182, 22)
      JacC( 81, 81) = JacC( 81, 81) - dw(182, 81)
      JacC( 91, 22) = JacC( 91, 22) + dw(182, 22)
      JacC( 91, 81) = JacC( 91, 81) + dw(182, 81)
      JacC( 96, 22) = JacC( 96, 22)+ 0.1500000000000000D+01*dw(182, 22)
      JacC( 96, 81) = JacC( 96, 81)+ 0.1500000000000000D+01*dw(182, 81)
      JacC(111, 22) = JacC(111, 22)+ 0.1500000000000000D+01*dw(182, 22)
      JacC(111, 81) = JacC(111, 81)+ 0.1500000000000000D+01*dw(182, 81)
      JacC(112, 22) = JacC(112, 22)+ 0.5000000000000000D+00*dw(182, 22)
      JacC(112, 81) = JacC(112, 81)+ 0.5000000000000000D+00*dw(182, 81)
      JacC( 67, 78) = JacC( 67, 78)+ 0.2500000000000000D+00*dw(183, 78)
      JacC( 67, 81) = JacC( 67, 81)+ 0.2500000000000000D+00*dw(183, 81)
      JacC( 74, 78) = JacC( 74, 78)+ 0.1100000000000000D+00*dw(183, 78)
      JacC( 74, 81) = JacC( 74, 81)+ 0.1100000000000000D+00*dw(183, 81)
      JacC( 78, 78) = JacC( 78, 78) - dw(183, 78)
      JacC( 78, 81) = JacC( 78, 81) - dw(183, 81)
      JacC( 81, 78) = JacC( 81, 78) - dw(183, 78)
      JacC( 81, 81) = JacC( 81, 81) - dw(183, 81)
      JacC( 93, 78) = JacC( 93, 78)+ 0.2480000000000000D+01*dw(183, 78)
      JacC( 93, 81) = JacC( 93, 81)+ 0.2480000000000000D+01*dw(183, 81)
      JacC( 96, 78) = JacC( 96, 78)+ 0.1500000000000000D+01*dw(183, 78)
      JacC( 96, 81) = JacC( 96, 81)+ 0.1500000000000000D+01*dw(183, 81)
      JacC( 97, 78) = JacC( 97, 78)+ 0.2500000000000000D+00*dw(183, 78)
      JacC( 97, 81) = JacC( 97, 81)+ 0.2500000000000000D+00*dw(183, 81)
      JacC(111, 78) = JacC(111, 78) + dw(183, 78)
      JacC(111, 81) = JacC(111, 81) + dw(183, 81)
      JacC(112, 78) = JacC(112, 78)+ 0.5000000000000000D+00*dw(183, 78)
      JacC(112, 81) = JacC(112, 81)+ 0.5000000000000000D+00*dw(183, 81)
      JacC( 48, 48) = JacC( 48, 48) - dw(184, 48)
      JacC( 48,110) = JacC( 48,110) - dw(184,110)
      JacC(110, 48) = JacC(110, 48) - dw(184, 48)
      JacC(110,110) = JacC(110,110) - dw(184,110)
      JacC(113, 48) = JacC(113, 48) + dw(184, 48)
      JacC(113,110) = JacC(113,110) + dw(184,110)
      JacC( 35,105) = JacC( 35,105) + dw(185,105)
      JacC( 35,110) = JacC( 35,110) + dw(185,110)
      JacC(105,105) = JacC(105,105) - dw(185,105)
      JacC(105,110) = JacC(105,110) - dw(185,110)
      JacC(110,105) = JacC(110,105) - dw(185,105)
      JacC(110,110) = JacC(110,110) - dw(185,110)
      JacC( 37, 98) = JacC( 37, 98) + dw(186, 98)
      JacC( 37,110) = JacC( 37,110) + dw(186,110)
      JacC( 98, 98) = JacC( 98, 98) - dw(186, 98)
      JacC( 98,110) = JacC( 98,110) - dw(186,110)
      JacC(110, 98) = JacC(110, 98) - dw(186, 98)
      JacC(110,110) = JacC(110,110) - dw(186,110)
      JacC( 35, 35) = JacC( 35, 35) - dw(187, 35)
      JacC(105, 35) = JacC(105, 35) + dw(187, 35)
      JacC(110, 35) = JacC(110, 35) + dw(187, 35)
      JacC( 37, 37) = JacC( 37, 37) - dw(188, 37)
      JacC( 98, 37) = JacC( 98, 37) + dw(188, 37)
      JacC(110, 37) = JacC(110, 37) + dw(188, 37)
      JacC( 40, 95) = JacC( 40, 95) + dw(189, 95)
      JacC( 40,110) = JacC( 40,110) + dw(189,110)
      JacC( 95, 95) = JacC( 95, 95) - dw(189, 95)
      JacC( 95,110) = JacC( 95,110) - dw(189,110)
      JacC(110, 95) = JacC(110, 95) - dw(189, 95)
      JacC(110,110) = JacC(110,110) - dw(189,110)
      JacC( 40, 40) = JacC( 40, 40) - dw(190, 40)
      JacC( 95, 40) = JacC( 95, 40) + dw(190, 40)
      JacC(110, 40) = JacC(110, 40) + dw(190, 40)
      JacC(100,100) = JacC(100,100) - dw(191,100)
      JacC(100,102) = JacC(100,102) - dw(191,102)
      JacC(102,100) = JacC(102,100) - dw(191,100)
      JacC(102,102) = JacC(102,102) - dw(191,102)
      JacC(108,100) = JacC(108,100) + dw(191,100)
      JacC(108,102) = JacC(108,102) + dw(191,102)
      JacC(110,100) = JacC(110,100) + dw(191,100)
      JacC(110,102) = JacC(110,102) + dw(191,102)
      JacC(111,100) = JacC(111,100) + dw(191,100)
      JacC(111,102) = JacC(111,102) + dw(191,102)
      JacC( 87,104) = JacC( 87,104) + dw(192,104)
      JacC( 87,102) = JacC( 87,102) + dw(192,102)
      JacC(102,104) = JacC(102,104) - dw(192,104)
      JacC(102,102) = JacC(102,102) - dw(192,102)
      JacC(104,104) = JacC(104,104) - dw(192,104)
      JacC(104,102) = JacC(104,102) - dw(192,102)
      JacC(110,104) = JacC(110,104) + dw(192,104)
      JacC(110,102) = JacC(110,102) + dw(192,102)
      JacC(111,104) = JacC(111,104) + dw(192,104)
      JacC(111,102) = JacC(111,102) + dw(192,102)
      JacC( 58, 99) = JacC( 58, 99)+ 0.6230000000000000D+00*dw(193, 99)
      JacC( 58,102) = JacC( 58,102)+ 0.6230000000000000D+00*dw(193,102)
      JacC( 91, 99) = JacC( 91, 99)+ 0.6300000000000000D-01*dw(193, 99)
      JacC( 91,102) = JacC( 91,102)+ 0.6300000000000000D-01*dw(193,102)
      JacC( 99, 99) = JacC( 99, 99) - dw(193, 99)
      JacC( 99,102) = JacC( 99,102) - dw(193,102)
      JacC(100, 99) = JacC(100, 99)+ 0.1500000000000000D+00*dw(193, 99)
      JacC(100,102) = JacC(100,102)+ 0.1500000000000000D+00*dw(193,102)
      JacC(101, 99) = JacC(101, 99)+ 0.4800000000000000D-01*dw(193, 99)
      JacC(101,102) = JacC(101,102)+ 0.4800000000000000D-01*dw(193,102)
      JacC(102, 99) = JacC(102, 99) - dw(193, 99)
      JacC(102,102) = JacC(102,102) - dw(193,102)
      JacC(104, 99) = JacC(104, 99)+ 0.4800000000000000D-01*dw(193, 99)
      JacC(104,102) = JacC(104,102)+ 0.4800000000000000D-01*dw(193,102)
      JacC(107, 99) = JacC(107, 99)+ 0.2330000000000000D+00*dw(193, 99)
      JacC(107,102) = JacC(107,102)+ 0.2330000000000000D+00*dw(193,102)
      JacC(108, 99) = JacC(108, 99)+ 0.4700000000000000D-01*dw(193, 99)
      JacC(108,102) = JacC(108,102)+ 0.4700000000000000D-01*dw(193,102)
      JacC(110, 99) = JacC(110, 99)+ 0.9409999999999999D+00*dw(193, 99)
      JacC(110,102) = JacC(110,102)+ 0.9409999999999999D+00*dw(193,102)
      JacC(111, 99) = JacC(111, 99)+ 0.7420000000000000D+00*dw(193, 99)
      JacC(111,102) = JacC(111,102)+ 0.7420000000000000D+00*dw(193,102)
      JacC(113, 99) = JacC(113, 99)+ 0.5900000000000000D-01*dw(193, 99)
      JacC(113,102) = JacC(113,102)+ 0.5900000000000000D-01*dw(193,102)
      JacC( 30, 86) = JacC( 30, 86)+ 0.1220000000000000D+00*dw(194, 86)
      JacC( 30,102) = JacC( 30,102)+ 0.1220000000000000D+00*dw(194,102)
      JacC( 58, 86) = JacC( 58, 86)+ 0.1000000000000000D+00*dw(194, 86)
      JacC( 58,102) = JacC( 58,102)+ 0.1000000000000000D+00*dw(194,102)
      JacC( 86, 86) = JacC( 86, 86) - dw(194, 86)
      JacC( 86,102) = JacC( 86,102) - dw(194,102)
      JacC(100, 86) = JacC(100, 86)+ 0.3100000000000000D-01*dw(194, 86)
      JacC(100,102) = JacC(100,102)+ 0.3100000000000000D-01*dw(194,102)
      JacC(101, 86) = JacC(101, 86)+ 0.3340000000000000D+00*dw(194, 86)
      JacC(101,102) = JacC(101,102)+ 0.3340000000000000D+00*dw(194,102)
      JacC(102, 86) = JacC(102, 86) - dw(194, 86)
      JacC(102,102) = JacC(102,102) - dw(194,102)
      JacC(103, 86) = JacC(103, 86)+ 0.5000000000000000D+00*dw(194, 86)
      JacC(103,102) = JacC(103,102)+ 0.5000000000000000D+00*dw(194,102)
      JacC(104, 86) = JacC(104, 86)+ 0.2450000000000000D+00*dw(194, 86)
      JacC(104,102) = JacC(104,102)+ 0.2450000000000000D+00*dw(194,102)
      JacC(107, 86) = JacC(107, 86)+ 0.2110000000000000D+00*dw(194, 86)
      JacC(107,102) = JacC(107,102)+ 0.2110000000000000D+00*dw(194,102)
      JacC(108, 86) = JacC(108, 86)+ 0.2100000000000000D-01*dw(194, 86)
      JacC(108,102) = JacC(108,102)+ 0.2100000000000000D-01*dw(194,102)
      JacC(110, 86) = JacC(110, 86)+ 0.8760000000000000D+00*dw(194, 86)
      JacC(110,102) = JacC(110,102)+ 0.8760000000000000D+00*dw(194,102)
      JacC(111, 86) = JacC(111, 86)+ 0.5990000000000000D+00*dw(194, 86)
      JacC(111,102) = JacC(111,102)+ 0.5990000000000000D+00*dw(194,102)
      JacC(113, 86) = JacC(113, 86)+ 0.1240000000000000D+00*dw(194, 86)
      JacC(113,102) = JacC(113,102)+ 0.1240000000000000D+00*dw(194,102)
      JacC( 62, 62) = JacC( 62, 62) - dw(195, 62)
      JacC( 62,102) = JacC( 62,102) - dw(195,102)
      JacC(101, 62) = JacC(101, 62)+ 0.4160000000000000D+00*dw(195, 62)
      JacC(101,102) = JacC(101,102)+ 0.4160000000000000D+00*dw(195,102)
      JacC(102, 62) = JacC(102, 62) - dw(195, 62)
      JacC(102,102) = JacC(102,102) - dw(195,102)
      JacC(103, 62) = JacC(103, 62)+ 0.6420000000000000D+00*dw(195, 62)
      JacC(103,102) = JacC(103,102)+ 0.6420000000000000D+00*dw(195,102)
      JacC(104, 62) = JacC(104, 62)+ 0.1330000000000000D+00*dw(195, 62)
      JacC(104,102) = JacC(104,102)+ 0.1330000000000000D+00*dw(195,102)
      JacC(107, 62) = JacC(107, 62)+ 0.1500000000000000D+00*dw(195, 62)
      JacC(107,102) = JacC(107,102)+ 0.1500000000000000D+00*dw(195,102)
      JacC(110, 62) = JacC(110, 62)+ 0.7390000000000000D+00*dw(195, 62)
      JacC(110,102) = JacC(110,102)+ 0.7390000000000000D+00*dw(195,102)
      JacC(111, 62) = JacC(111, 62)+ 0.6060000000000000D+00*dw(195, 62)
      JacC(111,102) = JacC(111,102)+ 0.6060000000000000D+00*dw(195,102)
      JacC(113, 62) = JacC(113, 62)+ 0.2610000000000000D+00*dw(195, 62)
      JacC(113,102) = JacC(113,102)+ 0.2610000000000000D+00*dw(195,102)
      JacC( 88, 88) = JacC( 88, 88) - dw(196, 88)
      JacC( 88,102) = JacC( 88,102) - dw(196,102)
      JacC(102, 88) = JacC(102, 88) - dw(196, 88)
      JacC(102,102) = JacC(102,102) - dw(196,102)
      JacC(107, 88) = JacC(107, 88)+ 0.2000000000000000D+00*dw(196, 88)
      JacC(107,102) = JacC(107,102)+ 0.2000000000000000D+00*dw(196,102)
      JacC(108, 88) = JacC(108, 88)+ 0.1600000000000000D+01*dw(196, 88)
      JacC(108,102) = JacC(108,102)+ 0.1600000000000000D+01*dw(196,102)
      JacC(110, 88) = JacC(110, 88) + dw(196, 88)
      JacC(110,102) = JacC(110,102) + dw(196,102)
      JacC(111, 88) = JacC(111, 88) + dw(196, 88)
      JacC(111,102) = JacC(111,102) + dw(196,102)
      JacC( 72, 72) = JacC( 72, 72) - dw(197, 72)
      JacC( 72,102) = JacC( 72,102) - dw(197,102)
      JacC(102, 72) = JacC(102, 72) - dw(197, 72)
      JacC(102,102) = JacC(102,102) - dw(197,102)
      JacC(103, 72) = JacC(103, 72)+ 0.6000000000000000D-01*dw(197, 72)
      JacC(103,102) = JacC(103,102)+ 0.6000000000000000D-01*dw(197,102)
      JacC(107, 72) = JacC(107, 72)+ 0.9399999999999999D+00*dw(197, 72)
      JacC(107,102) = JacC(107,102)+ 0.9399999999999999D+00*dw(197,102)
      JacC(108, 72) = JacC(108, 72) + dw(197, 72)
      JacC(108,102) = JacC(108,102) + dw(197,102)
      JacC(110, 72) = JacC(110, 72) + dw(197, 72)
      JacC(110,102) = JacC(110,102) + dw(197,102)
      JacC(111, 72) = JacC(111, 72) + dw(197, 72)
      JacC(111,102) = JacC(111,102) + dw(197,102)
      JacC( 79, 79) = JacC( 79, 79) - dw(198, 79)
      JacC( 79,102) = JacC( 79,102) - dw(198,102)
      JacC(102, 79) = JacC(102, 79) - dw(198, 79)
      JacC(102,102) = JacC(102,102) - dw(198,102)
      JacC(103, 79) = JacC(103, 79)+ 0.2900000000000000D+00*dw(198, 79)
      JacC(103,102) = JacC(103,102)+ 0.2900000000000000D+00*dw(198,102)
      JacC(107, 79) = JacC(107, 79)+ 0.1710000000000000D+01*dw(198, 79)
      JacC(107,102) = JacC(107,102)+ 0.1710000000000000D+01*dw(198,102)
      JacC(110, 79) = JacC(110, 79) + dw(198, 79)
      JacC(110,102) = JacC(110,102) + dw(198,102)
      JacC(111, 79) = JacC(111, 79) + dw(198, 79)
      JacC(111,102) = JacC(111,102) + dw(198,102)
      JacC( 39, 59) = JacC( 39, 59)+ 0.4600000000000000D-01*dw(199, 59)
      JacC( 39,102) = JacC( 39,102)+ 0.4600000000000000D-01*dw(199,102)
      JacC( 59, 59) = JacC( 59, 59) - dw(199, 59)
      JacC( 59,102) = JacC( 59,102) - dw(199,102)
      JacC( 61, 59) = JacC( 61, 59)+ 0.4180000000000000D+00*dw(199, 59)
      JacC( 61,102) = JacC( 61,102)+ 0.4180000000000000D+00*dw(199,102)
      JacC( 66, 59) = JacC( 66, 59)+ 0.5820000000000000D+00*dw(199, 59)
      JacC( 66,102) = JacC( 66,102)+ 0.5820000000000000D+00*dw(199,102)
      JacC(102, 59) = JacC(102, 59) - dw(199, 59)
      JacC(102,102) = JacC(102,102) - dw(199,102)
      JacC(108, 59) = JacC(108, 59) + dw(199, 59)
      JacC(108,102) = JacC(108,102) + dw(199,102)
      JacC(110, 59) = JacC(110, 59)+ 0.9540000000000000D+00*dw(199, 59)
      JacC(110,102) = JacC(110,102)+ 0.9540000000000000D+00*dw(199,102)
      JacC(111, 59) = JacC(111, 59)+ 0.9540000000000000D+00*dw(199, 59)
      JacC(111,102) = JacC(111,102)+ 0.9540000000000000D+00*dw(199,102)
      JacC( 73, 95) = JacC( 73, 95)+ 0.2500000000000000D+00*dw(200, 95)
      JacC( 73,102) = JacC( 73,102)+ 0.2500000000000000D+00*dw(200,102)
      JacC( 93, 95) = JacC( 93, 95)+ 0.5000000000000000D+00*dw(200, 95)
      JacC( 93,102) = JacC( 93,102)+ 0.5000000000000000D+00*dw(200,102)
      JacC( 95, 95) = JacC( 95, 95) - dw(200, 95)
      JacC( 95,102) = JacC( 95,102) - dw(200,102)
      JacC( 96, 95) = JacC( 96, 95)+ 0.2500000000000000D+00*dw(200, 95)
      JacC( 96,102) = JacC( 96,102)+ 0.2500000000000000D+00*dw(200,102)
      JacC(102, 95) = JacC(102, 95) - dw(200, 95)
      JacC(102,102) = JacC(102,102) - dw(200,102)
      JacC(105, 95) = JacC(105, 95)+ 0.2500000000000000D+00*dw(200, 95)
      JacC(105,102) = JacC(105,102)+ 0.2500000000000000D+00*dw(200,102)
      JacC(108, 95) = JacC(108, 95)+ 0.7500000000000000D+00*dw(200, 95)
      JacC(108,102) = JacC(108,102)+ 0.7500000000000000D+00*dw(200,102)
      JacC(110, 95) = JacC(110, 95) + dw(200, 95)
      JacC(110,102) = JacC(110,102) + dw(200,102)
      JacC(111, 95) = JacC(111, 95)+ 0.7500000000000000D+00*dw(200, 95)
      JacC(111,102) = JacC(111,102)+ 0.7500000000000000D+00*dw(200,102)
      JacC( 68, 68) = JacC( 68, 68) - dw(201, 68)
      JacC( 68,102) = JacC( 68,102) - dw(201,102)
      JacC( 93, 68) = JacC( 93, 68)+ 0.3000000000000000D+00*dw(201, 68)
      JacC( 93,102) = JacC( 93,102)+ 0.3000000000000000D+00*dw(201,102)
      JacC(101, 68) = JacC(101, 68)+ 0.7000000000000000D+00*dw(201, 68)
      JacC(101,102) = JacC(101,102)+ 0.7000000000000000D+00*dw(201,102)
      JacC(102, 68) = JacC(102, 68) - dw(201, 68)
      JacC(102,102) = JacC(102,102) - dw(201,102)
      JacC(105, 68) = JacC(105, 68)+ 0.7000000000000000D+00*dw(201, 68)
      JacC(105,102) = JacC(105,102)+ 0.7000000000000000D+00*dw(201,102)
      JacC(107, 68) = JacC(107, 68)+ 0.7000000000000000D+00*dw(201, 68)
      JacC(107,102) = JacC(107,102)+ 0.7000000000000000D+00*dw(201,102)
      JacC(108, 68) = JacC(108, 68)+ 0.3000000000000000D+00*dw(201, 68)
      JacC(108,102) = JacC(108,102)+ 0.3000000000000000D+00*dw(201,102)
      JacC(110, 68) = JacC(110, 68) + dw(201, 68)
      JacC(110,102) = JacC(110,102) + dw(201,102)
      JacC(111, 68) = JacC(111, 68)+ 0.3000000000000000D+00*dw(201, 68)
      JacC(111,102) = JacC(111,102)+ 0.3000000000000000D+00*dw(201,102)
      JacC( 64, 64) = JacC( 64, 64) - dw(202, 64)
      JacC( 64,102) = JacC( 64,102) - dw(202,102)
      JacC( 77, 64) = JacC( 77, 64)+ 0.6700000000000000D+00*dw(202, 64)
      JacC( 77,102) = JacC( 77,102)+ 0.6700000000000000D+00*dw(202,102)
      JacC(102, 64) = JacC(102, 64) - dw(202, 64)
      JacC(102,102) = JacC(102,102) - dw(202,102)
      JacC(108, 64) = JacC(108, 64)+ 0.3300000000000000D+00*dw(202, 64)
      JacC(108,102) = JacC(108,102)+ 0.3300000000000000D+00*dw(202,102)
      JacC(110, 64) = JacC(110, 64) + dw(202, 64)
      JacC(110,102) = JacC(110,102) + dw(202,102)
      JacC(111, 64) = JacC(111, 64)+ 0.6700000000000000D+00*dw(202, 64)
      JacC(111,102) = JacC(111,102)+ 0.6700000000000000D+00*dw(202,102)
      JacC( 84, 84) = JacC( 84, 84) - dw(203, 84)
      JacC( 84,102) = JacC( 84,102) - dw(203,102)
      JacC( 91, 84) = JacC( 91, 84)+ 0.1800000000000000D+00*dw(203, 84)
      JacC( 91,102) = JacC( 91,102)+ 0.1800000000000000D+00*dw(203,102)
      JacC( 93, 84) = JacC( 93, 84)+ 0.2100000000000000D+00*dw(203, 84)
      JacC( 93,102) = JacC( 93,102)+ 0.2100000000000000D+00*dw(203,102)
      JacC( 96, 84) = JacC( 96, 84)+ 0.6100000000000000D+00*dw(203, 84)
      JacC( 96,102) = JacC( 96,102)+ 0.6100000000000000D+00*dw(203,102)
      JacC(102, 84) = JacC(102, 84) - dw(203, 84)
      JacC(102,102) = JacC(102,102) - dw(203,102)
      JacC(103, 84) = JacC(103, 84)+ 0.7000000000000000D+00*dw(203, 84)
      JacC(103,102) = JacC(103,102)+ 0.7000000000000000D+00*dw(203,102)
      JacC(107, 84) = JacC(107, 84)+ 0.2700000000000000D+00*dw(203, 84)
      JacC(107,102) = JacC(107,102)+ 0.2700000000000000D+00*dw(203,102)
      JacC(108, 84) = JacC(108, 84)+ 0.3000000000000000D-01*dw(203, 84)
      JacC(108,102) = JacC(108,102)+ 0.3000000000000000D-01*dw(203,102)
      JacC(110, 84) = JacC(110, 84) + dw(203, 84)
      JacC(110,102) = JacC(110,102) + dw(203,102)
      JacC(111, 84) = JacC(111, 84) + dw(203, 84)
      JacC(111,102) = JacC(111,102) + dw(203,102)
      JacC( 57, 57) = JacC( 57, 57) - dw(204, 57)
      JacC( 57,102) = JacC( 57,102) - dw(204,102)
      JacC( 58, 57) = JacC( 58, 57)+ 0.1100000000000000D+00*dw(204, 57)
      JacC( 58,102) = JacC( 58,102)+ 0.1100000000000000D+00*dw(204,102)
      JacC( 67, 57) = JacC( 67, 57)+ 0.7000000000000001D-01*dw(204, 57)
      JacC( 67,102) = JacC( 67,102)+ 0.7000000000000001D-01*dw(204,102)
      JacC(102, 57) = JacC(102, 57) - dw(204, 57)
      JacC(102,102) = JacC(102,102) - dw(204,102)
      JacC(103, 57) = JacC(103, 57)+ 0.4400000000000000D+00*dw(204, 57)
      JacC(103,102) = JacC(103,102)+ 0.4400000000000000D+00*dw(204,102)
      JacC(107, 57) = JacC(107, 57)+ 0.4300000000000000D+00*dw(204, 57)
      JacC(107,102) = JacC(107,102)+ 0.4300000000000000D+00*dw(204,102)
      JacC(108, 57) = JacC(108, 57)+ 0.2300000000000000D+00*dw(204, 57)
      JacC(108,102) = JacC(108,102)+ 0.2300000000000000D+00*dw(204,102)
      JacC(110, 57) = JacC(110, 57)+ 0.8200000000000000D+00*dw(204, 57)
      JacC(110,102) = JacC(110,102)+ 0.8200000000000000D+00*dw(204,102)
      JacC(111, 57) = JacC(111, 57)+ 0.8200000000000000D+00*dw(204, 57)
      JacC(111,102) = JacC(111,102)+ 0.8200000000000000D+00*dw(204,102)
      JacC(113, 57) = JacC(113, 57)+ 0.1800000000000000D+00*dw(204, 57)
      JacC(113,102) = JacC(113,102)+ 0.1800000000000000D+00*dw(204,102)
      JacC( 58, 60) = JacC( 58, 60)+ 0.3000000000000000D-01*dw(205, 60)
      JacC( 58,102) = JacC( 58,102)+ 0.3000000000000000D-01*dw(205,102)
      JacC( 60, 60) = JacC( 60, 60) - dw(205, 60)
      JacC( 60,102) = JacC( 60,102) - dw(205,102)
      JacC( 61, 60) = JacC( 61, 60)+ 0.2500000000000000D+00*dw(205, 60)
      JacC( 61,102) = JacC( 61,102)+ 0.2500000000000000D+00*dw(205,102)
      JacC(102, 60) = JacC(102, 60) - dw(205, 60)
      JacC(102,102) = JacC(102,102) - dw(205,102)
      JacC(103, 60) = JacC(103, 60)+ 0.2500000000000000D+00*dw(205, 60)
      JacC(103,102) = JacC(103,102)+ 0.2500000000000000D+00*dw(205,102)
      JacC(110, 60) = JacC(110, 60)+ 0.9000000000000000D+00*dw(205, 60)
      JacC(110,102) = JacC(110,102)+ 0.9000000000000000D+00*dw(205,102)
      JacC(111, 60) = JacC(111, 60)+ 0.9000000000000000D+00*dw(205, 60)
      JacC(111,102) = JacC(111,102)+ 0.9000000000000000D+00*dw(205,102)
      JacC(113, 60) = JacC(113, 60)+ 0.1000000000000000D+00*dw(205, 60)
      JacC(113,102) = JacC(113,102)+ 0.1000000000000000D+00*dw(205,102)
      JacC( 63, 63) = JacC( 63, 63) - dw(206, 63)
      JacC( 63,102) = JacC( 63,102) - dw(206,102)
      JacC( 69, 63) = JacC( 69, 63)+ 0.4590000000000000D+00*dw(206, 63)
      JacC( 69,102) = JacC( 69,102)+ 0.4590000000000000D+00*dw(206,102)
      JacC( 80, 63) = JacC( 80, 63)+ 0.4590000000000000D+00*dw(206, 63)
      JacC( 80,102) = JacC( 80,102)+ 0.4590000000000000D+00*dw(206,102)
      JacC( 91, 63) = JacC( 91, 63)+ 0.9180000000000000D+00*dw(206, 63)
      JacC( 91,102) = JacC( 91,102)+ 0.9180000000000000D+00*dw(206,102)
      JacC(102, 63) = JacC(102, 63) - dw(206, 63)
      JacC(102,102) = JacC(102,102) - dw(206,102)
      JacC(110, 63) = JacC(110, 63)+ 0.9180000000000000D+00*dw(206, 63)
      JacC(110,102) = JacC(110,102)+ 0.9180000000000000D+00*dw(206,102)
      JacC(111, 63) = JacC(111, 63)+ 0.9180000000000000D+00*dw(206, 63)
      JacC(111,102) = JacC(111,102)+ 0.9180000000000000D+00*dw(206,102)
      JacC(113, 63) = JacC(113, 63)+ 0.8200000000000000D-01*dw(206, 63)
      JacC(113,102) = JacC(113,102)+ 0.8200000000000000D-01*dw(206,102)
      JacC( 55, 55) = JacC( 55, 55) - dw(207, 55)
      JacC( 55,102) = JacC( 55,102) - dw(207,102)
      JacC( 56, 55) = JacC( 56, 55)+ 0.7300000000000000D-01*dw(207, 55)
      JacC( 56,102) = JacC( 56,102)+ 0.7300000000000000D-01*dw(207,102)
      JacC( 77, 55) = JacC( 77, 55)+ 0.7000000000000000D+00*dw(207, 55)
      JacC( 77,102) = JacC( 77,102)+ 0.7000000000000000D+00*dw(207,102)
      JacC( 78, 55) = JacC( 78, 55)+ 0.1770000000000000D+00*dw(207, 55)
      JacC( 78,102) = JacC( 78,102)+ 0.1770000000000000D+00*dw(207,102)
      JacC( 91, 55) = JacC( 91, 55)+ 0.3500000000000000D+00*dw(207, 55)
      JacC( 91,102) = JacC( 91,102)+ 0.3500000000000000D+00*dw(207,102)
      JacC( 93, 55) = JacC( 93, 55)+ 0.6000000000000000D+00*dw(207, 55)
      JacC( 93,102) = JacC( 93,102)+ 0.6000000000000000D+00*dw(207,102)
      JacC(102, 55) = JacC(102, 55) - dw(207, 55)
      JacC(102,102) = JacC(102,102) - dw(207,102)
      JacC(110, 55) = JacC(110, 55)+ 0.9500000000000000D+00*dw(207, 55)
      JacC(110,102) = JacC(110,102)+ 0.9500000000000000D+00*dw(207,102)
      JacC(111, 55) = JacC(111, 55)+ 0.9500000000000000D+00*dw(207, 55)
      JacC(111,102) = JacC(111,102)+ 0.9500000000000000D+00*dw(207,102)
      JacC(113, 55) = JacC(113, 55)+ 0.5000000000000000D-01*dw(207, 55)
      JacC(113,102) = JacC(113,102)+ 0.5000000000000000D-01*dw(207,102)
      JacC( 75, 75) = JacC( 75, 75) - dw(208, 75)
      JacC( 75,102) = JacC( 75,102) - dw(208,102)
      JacC( 76, 75) = JacC( 76, 75)+ 0.3200000000000000D+00*dw(208, 75)
      JacC( 76,102) = JacC( 76,102)+ 0.3200000000000000D+00*dw(208,102)
      JacC( 91, 75) = JacC( 91, 75)+ 0.6800000000000000D+00*dw(208, 75)
      JacC( 91,102) = JacC( 91,102)+ 0.6800000000000000D+00*dw(208,102)
      JacC(102, 75) = JacC(102, 75) - dw(208, 75)
      JacC(102,102) = JacC(102,102) - dw(208,102)
      JacC(106, 75) = JacC(106, 75)+ 0.6800000000000000D+00*dw(208, 75)
      JacC(106,102) = JacC(106,102)+ 0.6800000000000000D+00*dw(208,102)
      JacC(110, 75) = JacC(110, 75) + dw(208, 75)
      JacC(110,102) = JacC(110,102) + dw(208,102)
      JacC(111, 75) = JacC(111, 75) + dw(208, 75)
      JacC(111,102) = JacC(111,102) + dw(208,102)
      JacC(100,105) = JacC(100,105) + dw(209,105)
      JacC(100,102) = JacC(100,102) + dw(209,102)
      JacC(102,105) = JacC(102,105) - dw(209,105)
      JacC(102,102) = JacC(102,102) - dw(209,102)
      JacC(105,105) = JacC(105,105) - dw(209,105)
      JacC(105,102) = JacC(105,102) - dw(209,102)
      JacC(110,105) = JacC(110,105) + dw(209,105)
      JacC(110,102) = JacC(110,102) + dw(209,102)
      JacC( 98, 98) = JacC( 98, 98) - dw(210, 98)
      JacC( 98,102) = JacC( 98,102) - dw(210,102)
      JacC(102, 98) = JacC(102, 98) - dw(210, 98)
      JacC(102,102) = JacC(102,102) - dw(210,102)
      JacC(104, 98) = JacC(104, 98) + dw(210, 98)
      JacC(104,102) = JacC(104,102) + dw(210,102)
      JacC(110, 98) = JacC(110, 98) + dw(210, 98)
      JacC(110,102) = JacC(110,102) + dw(210,102)
      JacC( 92, 92) = JacC( 92, 92) - dw(211, 92)
      JacC( 92,102) = JacC( 92,102) - dw(211,102)
      JacC( 93, 92) = JacC( 93, 92)+ 0.5400000000000000D+00*dw(211, 92)
      JacC( 93,102) = JacC( 93,102)+ 0.5400000000000000D+00*dw(211,102)
      JacC(101, 92) = JacC(101, 92)+ 0.1600000000000000D+00*dw(211, 92)
      JacC(101,102) = JacC(101,102)+ 0.1600000000000000D+00*dw(211,102)
      JacC(102, 92) = JacC(102, 92) - dw(211, 92)
      JacC(102,102) = JacC(102,102) - dw(211,102)
      JacC(105, 92) = JacC(105, 92)+ 0.2300000000000000D+00*dw(211, 92)
      JacC(105,102) = JacC(105,102)+ 0.2300000000000000D+00*dw(211,102)
      JacC(107, 92) = JacC(107, 92)+ 0.4600000000000000D+00*dw(211, 92)
      JacC(107,102) = JacC(107,102)+ 0.4600000000000000D+00*dw(211,102)
      JacC(110, 92) = JacC(110, 92) + dw(211, 92)
      JacC(110,102) = JacC(110,102) + dw(211,102)
      JacC(111, 92) = JacC(111, 92)+ 0.7700000000000000D+00*dw(211, 92)
      JacC(111,102) = JacC(111,102)+ 0.7700000000000000D+00*dw(211,102)
      JacC( 65, 65) = JacC( 65, 65) - dw(212, 65)
      JacC( 65,102) = JacC( 65,102) - dw(212,102)
      JacC(102, 65) = JacC(102, 65) - dw(212, 65)
      JacC(102,102) = JacC(102,102) - dw(212,102)
      JacC(105, 65) = JacC(105, 65) + dw(212, 65)
      JacC(105,102) = JacC(105,102) + dw(212,102)
      JacC(108, 65) = JacC(108, 65) + dw(212, 65)
      JacC(108,102) = JacC(108,102) + dw(212,102)
      JacC(110, 65) = JacC(110, 65) + dw(212, 65)
      JacC(110,102) = JacC(110,102) + dw(212,102)
      JacC( 71, 71) = JacC( 71, 71) - dw(213, 71)
      JacC( 71,102) = JacC( 71,102) - dw(213,102)
      JacC(102, 71) = JacC(102, 71) - dw(213, 71)
      JacC(102,102) = JacC(102,102) - dw(213,102)
      JacC(110, 71) = JacC(110, 71) + dw(213, 71)
      JacC(110,102) = JacC(110,102) + dw(213,102)
      JacC(111, 71) = JacC(111, 71) + dw(213, 71)
      JacC(111,102) = JacC(111,102) + dw(213,102)
      JacC(113, 71) = JacC(113, 71) + dw(213, 71)
      JacC(113,102) = JacC(113,102) + dw(213,102)
      JacC( 70, 70) = JacC( 70, 70) - dw(214, 70)
      JacC( 70,102) = JacC( 70,102) - dw(214,102)
      JacC(102, 70) = JacC(102, 70) - dw(214, 70)
      JacC(102,102) = JacC(102,102) - dw(214,102)
      JacC(103, 70) = JacC(103, 70)+ 0.4640000000000000D+00*dw(214, 70)
      JacC(103,102) = JacC(103,102)+ 0.4640000000000000D+00*dw(214,102)
      JacC(107, 70) = JacC(107, 70)+ 0.1240000000000000D+01*dw(214, 70)
      JacC(107,102) = JacC(107,102)+ 0.1240000000000000D+01*dw(214,102)
      JacC(108, 70) = JacC(108, 70)+ 0.2870000000000000D+00*dw(214, 70)
      JacC(108,102) = JacC(108,102)+ 0.2870000000000000D+00*dw(214,102)
      JacC(110, 70) = JacC(110, 70)+ 0.2000000000000000D+01*dw(214, 70)
      JacC(110,102) = JacC(110,102)+ 0.2000000000000000D+01*dw(214,102)
      JacC( 34,100) = JacC( 34,100) + dw(215,100)
      JacC( 34,111) = JacC( 34,111) + dw(215,111)
      JacC(100,100) = JacC(100,100) - dw(215,100)
      JacC(100,111) = JacC(100,111) - dw(215,111)
      JacC(111,100) = JacC(111,100) - dw(215,100)
      JacC(111,111) = JacC(111,111) - dw(215,111)
      JacC(104,104) = JacC(104,104) - dw(216,104)
      JacC(104,111) = JacC(104,111) - dw(216,111)
      JacC(106,104) = JacC(106,104) + dw(216,104)
      JacC(106,111) = JacC(106,111) + dw(216,111)
      JacC(111,104) = JacC(111,104) - dw(216,104)
      JacC(111,111) = JacC(111,111) - dw(216,111)
      JacC( 99, 99) = JacC( 99, 99) - dw(217, 99)
      JacC( 99,111) = JacC( 99,111) - dw(217,111)
      JacC(106, 99) = JacC(106, 99) + dw(217, 99)
      JacC(106,111) = JacC(106,111) + dw(217,111)
      JacC(111, 99) = JacC(111, 99) - dw(217, 99)
      JacC(111,111) = JacC(111,111) - dw(217,111)
      JacC( 86, 86) = JacC( 86, 86) - dw(218, 86)
      JacC( 86,111) = JacC( 86,111) - dw(218,111)
      JacC(106, 86) = JacC(106, 86) + dw(218, 86)
      JacC(106,111) = JacC(106,111) + dw(218,111)
      JacC(111, 86) = JacC(111, 86) - dw(218, 86)
      JacC(111,111) = JacC(111,111) - dw(218,111)
      JacC( 62, 62) = JacC( 62, 62) - dw(219, 62)
      JacC( 62,111) = JacC( 62,111) - dw(219,111)
      JacC(106, 62) = JacC(106, 62) + dw(219, 62)
      JacC(106,111) = JacC(106,111) + dw(219,111)
      JacC(111, 62) = JacC(111, 62) - dw(219, 62)
      JacC(111,111) = JacC(111,111) - dw(219,111)
      JacC( 88, 88) = JacC( 88, 88) - dw(220, 88)
      JacC( 88,111) = JacC( 88,111) - dw(220,111)
      JacC(106, 88) = JacC(106, 88) + dw(220, 88)
      JacC(106,111) = JacC(106,111) + dw(220,111)
      JacC(111, 88) = JacC(111, 88) - dw(220, 88)
      JacC(111,111) = JacC(111,111) - dw(220,111)
      JacC( 72, 72) = JacC( 72, 72) - dw(221, 72)
      JacC( 72,111) = JacC( 72,111) - dw(221,111)
      JacC(106, 72) = JacC(106, 72) + dw(221, 72)
      JacC(106,111) = JacC(106,111) + dw(221,111)
      JacC(111, 72) = JacC(111, 72) - dw(221, 72)
      JacC(111,111) = JacC(111,111) - dw(221,111)
      JacC( 79, 79) = JacC( 79, 79) - dw(222, 79)
      JacC( 79,111) = JacC( 79,111) - dw(222,111)
      JacC(106, 79) = JacC(106, 79) + dw(222, 79)
      JacC(106,111) = JacC(106,111) + dw(222,111)
      JacC(111, 79) = JacC(111, 79) - dw(222, 79)
      JacC(111,111) = JacC(111,111) - dw(222,111)
      JacC( 25, 59) = JacC( 25, 59) + dw(223, 59)
      JacC( 25,111) = JacC( 25,111) + dw(223,111)
      JacC( 59, 59) = JacC( 59, 59) - dw(223, 59)
      JacC( 59,111) = JacC( 59,111) - dw(223,111)
      JacC(111, 59) = JacC(111, 59) - dw(223, 59)
      JacC(111,111) = JacC(111,111) - dw(223,111)
      JacC( 28, 95) = JacC( 28, 95) + dw(224, 95)
      JacC( 28,111) = JacC( 28,111) + dw(224,111)
      JacC( 95, 95) = JacC( 95, 95) - dw(224, 95)
      JacC( 95,111) = JacC( 95,111) - dw(224,111)
      JacC(111, 95) = JacC(111, 95) - dw(224, 95)
      JacC(111,111) = JacC(111,111) - dw(224,111)
      JacC( 68, 68) = JacC( 68, 68) - dw(225, 68)
      JacC( 68,111) = JacC( 68,111) - dw(225,111)
      JacC(106, 68) = JacC(106, 68) + dw(225, 68)
      JacC(106,111) = JacC(106,111) + dw(225,111)
      JacC(111, 68) = JacC(111, 68) - dw(225, 68)
      JacC(111,111) = JacC(111,111) - dw(225,111)
      JacC( 84, 84) = JacC( 84, 84) - dw(226, 84)
      JacC( 84,111) = JacC( 84,111) - dw(226,111)
      JacC(106, 84) = JacC(106, 84) + dw(226, 84)
      JacC(106,111) = JacC(106,111) + dw(226,111)
      JacC(111, 84) = JacC(111, 84) - dw(226, 84)
      JacC(111,111) = JacC(111,111) - dw(226,111)
      JacC( 57, 57) = JacC( 57, 57) - dw(227, 57)
      JacC( 57,111) = JacC( 57,111) - dw(227,111)
      JacC(106, 57) = JacC(106, 57) + dw(227, 57)
      JacC(106,111) = JacC(106,111) + dw(227,111)
      JacC(111, 57) = JacC(111, 57) - dw(227, 57)
      JacC(111,111) = JacC(111,111) - dw(227,111)
      JacC( 60, 60) = JacC( 60, 60) - dw(228, 60)
      JacC( 60,111) = JacC( 60,111) - dw(228,111)
      JacC(106, 60) = JacC(106, 60) + dw(228, 60)
      JacC(106,111) = JacC(106,111) + dw(228,111)
      JacC(111, 60) = JacC(111, 60) - dw(228, 60)
      JacC(111,111) = JacC(111,111) - dw(228,111)
      JacC( 63, 63) = JacC( 63, 63) - dw(229, 63)
      JacC( 63,111) = JacC( 63,111) - dw(229,111)
      JacC(106, 63) = JacC(106, 63) + dw(229, 63)
      JacC(106,111) = JacC(106,111) + dw(229,111)
      JacC(111, 63) = JacC(111, 63) - dw(229, 63)
      JacC(111,111) = JacC(111,111) - dw(229,111)
      JacC( 55, 55) = JacC( 55, 55) - dw(230, 55)
      JacC( 55,111) = JacC( 55,111) - dw(230,111)
      JacC(106, 55) = JacC(106, 55) + dw(230, 55)
      JacC(106,111) = JacC(106,111) + dw(230,111)
      JacC(111, 55) = JacC(111, 55) - dw(230, 55)
      JacC(111,111) = JacC(111,111) - dw(230,111)
      JacC( 75, 75) = JacC( 75, 75) - dw(231, 75)
      JacC( 75,111) = JacC( 75,111) - dw(231,111)
      JacC(106, 75) = JacC(106, 75) + dw(231, 75)
      JacC(106,111) = JacC(106,111) + dw(231,111)
      JacC(111, 75) = JacC(111, 75) - dw(231, 75)
      JacC(111,111) = JacC(111,111) - dw(231,111)
      JacC( 47, 48) = JacC( 47, 48) + dw(232, 48)
      JacC( 47,111) = JacC( 47,111) + dw(232,111)
      JacC( 48, 48) = JacC( 48, 48) - dw(232, 48)
      JacC( 48,111) = JacC( 48,111) - dw(232,111)
      JacC(111, 48) = JacC(111, 48) - dw(232, 48)
      JacC(111,111) = JacC(111,111) - dw(232,111)
      JacC( 74,105) = JacC( 74,105)+ 0.4000000000000000D+00*dw(233,105)
      JacC( 74,111) = JacC( 74,111)+ 0.4000000000000000D+00*dw(233,111)
      JacC( 97,105) = JacC( 97,105)+ 0.2000000000000000D+00*dw(233,105)
      JacC( 97,111) = JacC( 97,111)+ 0.2000000000000000D+00*dw(233,111)
      JacC(100,105) = JacC(100,105)+ 0.4000000000000000D+00*dw(233,105)
      JacC(100,111) = JacC(100,111)+ 0.4000000000000000D+00*dw(233,111)
      JacC(105,105) = JacC(105,105) - dw(233,105)
      JacC(105,111) = JacC(105,111) - dw(233,111)
      JacC(111,105) = JacC(111,105) - dw(233,105)
      JacC(111,111) = JacC(111,111) - dw(233,111)
      JacC(112,105) = JacC(112,105)+ 0.4000000000000000D+00*dw(233,105)
      JacC(112,111) = JacC(112,111)+ 0.4000000000000000D+00*dw(233,111)
      JacC( 74, 98) = JacC( 74, 98)+ 0.4000000000000000D+00*dw(234, 98)
      JacC( 74,111) = JacC( 74,111)+ 0.4000000000000000D+00*dw(234,111)
      JacC( 97, 98) = JacC( 97, 98)+ 0.2000000000000000D+00*dw(234, 98)
      JacC( 97,111) = JacC( 97,111)+ 0.2000000000000000D+00*dw(234,111)
      JacC( 98, 98) = JacC( 98, 98) - dw(234, 98)
      JacC( 98,111) = JacC( 98,111) - dw(234,111)
      JacC(104, 98) = JacC(104, 98)+ 0.4000000000000000D+00*dw(234, 98)
      JacC(104,111) = JacC(104,111)+ 0.4000000000000000D+00*dw(234,111)
      JacC(111, 98) = JacC(111, 98) - dw(234, 98)
      JacC(111,111) = JacC(111,111) - dw(234,111)
      JacC(112, 98) = JacC(112, 98)+ 0.4000000000000000D+00*dw(234, 98)
      JacC(112,111) = JacC(112,111)+ 0.4000000000000000D+00*dw(234,111)
      JacC( 65, 65) = JacC( 65, 65) - dw(235, 65)
      JacC( 65,111) = JacC( 65,111) - dw(235,111)
      JacC(105, 65) = JacC(105, 65)+ 0.6700000000000000D+00*dw(235, 65)
      JacC(105,111) = JacC(105,111)+ 0.6700000000000000D+00*dw(235,111)
      JacC(106, 65) = JacC(106, 65)+ 0.3300000000000000D+00*dw(235, 65)
      JacC(106,111) = JacC(106,111)+ 0.3300000000000000D+00*dw(235,111)
      JacC(108, 65) = JacC(108, 65)+ 0.6700000000000000D+00*dw(235, 65)
      JacC(108,111) = JacC(108,111)+ 0.6700000000000000D+00*dw(235,111)
      JacC(111, 65) = JacC(111, 65) - dw(235, 65)
      JacC(111,111) = JacC(111,111) - dw(235,111)
      JacC(112, 65) = JacC(112, 65)+ 0.6700000000000000D+00*dw(235, 65)
      JacC(112,111) = JacC(112,111)+ 0.6700000000000000D+00*dw(235,111)
      JacC( 64, 64) = JacC( 64, 64) - dw(236, 64)
      JacC( 64,111) = JacC( 64,111) - dw(236,111)
      JacC(106, 64) = JacC(106, 64) + dw(236, 64)
      JacC(106,111) = JacC(106,111) + dw(236,111)
      JacC(111, 64) = JacC(111, 64) - dw(236, 64)
      JacC(111,111) = JacC(111,111) - dw(236,111)
      JacC( 92, 92) = JacC( 92, 92) - dw(237, 92)
      JacC( 92,111) = JacC( 92,111) - dw(237,111)
      JacC(106, 92) = JacC(106, 92) + dw(237, 92)
      JacC(106,111) = JacC(106,111) + dw(237,111)
      JacC(111, 92) = JacC(111, 92) - dw(237, 92)
      JacC(111,111) = JacC(111,111) - dw(237,111)
      JacC( 71, 71) = JacC( 71, 71) - dw(238, 71)
      JacC( 71,111) = JacC( 71,111) - dw(238,111)
      JacC(111, 71) = JacC(111, 71) - dw(238, 71)
      JacC(111,111) = JacC(111,111) - dw(238,111)
      JacC(113, 71) = JacC(113, 71) + dw(238, 71)
      JacC(113,111) = JacC(113,111) + dw(238,111)
      JacC( 70, 70) = JacC( 70, 70) - dw(239, 70)
      JacC( 70,111) = JacC( 70,111) - dw(239,111)
      JacC(111, 70) = JacC(111, 70) - dw(239, 70)
      JacC(111,111) = JacC(111,111) - dw(239,111)
      JacC(113, 70) = JacC(113, 70) + dw(239, 70)
      JacC(113,111) = JacC(113,111) + dw(239,111)
      JacC( 89,100) = JacC( 89,100)+ 0.6300000000000000D+00*dw(240,100)
      JacC( 89,100) = JacC( 89,100)+ 0.6300000000000000D+00*dw(240,100)
      JacC(100,100) = JacC(100,100)- 0.2000000000000000D+01*dw(240,100)
      JacC(100,100) = JacC(100,100)- 0.2000000000000000D+01*dw(240,100)
      JacC(108,100) = JacC(108,100)+ 0.1370000000000000D+01*dw(240,100)
      JacC(108,100) = JacC(108,100)+ 0.1370000000000000D+01*dw(240,100)
      JacC(111,100) = JacC(111,100)+ 0.7400000000000000D+00*dw(240,100)
      JacC(111,100) = JacC(111,100)+ 0.7400000000000000D+00*dw(240,100)
      JacC( 21,104) = JacC( 21,104)+ 0.2500000000000000D+00*dw(241,104)
      JacC( 21,100) = JacC( 21,100)+ 0.2500000000000000D+00*dw(241,100)
      JacC( 87,104) = JacC( 87,104)+ 0.7500000000000000D+00*dw(241,104)
      JacC( 87,100) = JacC( 87,100)+ 0.7500000000000000D+00*dw(241,100)
      JacC( 89,104) = JacC( 89,104)+ 0.2500000000000000D+00*dw(241,104)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(241,100)
      JacC(100,104) = JacC(100,104) - dw(241,104)
      JacC(100,100) = JacC(100,100) - dw(241,100)
      JacC(104,104) = JacC(104,104) - dw(241,104)
      JacC(104,100) = JacC(104,100) - dw(241,100)
      JacC(108,104) = JacC(108,104)+ 0.7500000000000000D+00*dw(241,104)
      JacC(108,100) = JacC(108,100)+ 0.7500000000000000D+00*dw(241,100)
      JacC(111,104) = JacC(111,104) + dw(241,104)
      JacC(111,100) = JacC(111,100) + dw(241,100)
      JacC( 85, 99) = JacC( 85, 99)+ 0.2500000000000000D+00*dw(242, 99)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(242,100)
      JacC( 89, 99) = JacC( 89, 99)+ 0.2500000000000000D+00*dw(242, 99)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(242,100)
      JacC( 91, 99) = JacC( 91, 99)+ 0.5000000000000000D-01*dw(242, 99)
      JacC( 91,100) = JacC( 91,100)+ 0.5000000000000000D-01*dw(242,100)
      JacC( 99, 99) = JacC( 99, 99) - dw(242, 99)
      JacC( 99,100) = JacC( 99,100) - dw(242,100)
      JacC(100, 99) = JacC(100, 99)- 0.9200000000000000D+00*dw(242, 99)
      JacC(100,100) = JacC(100,100)- 0.9200000000000000D+00*dw(242,100)
      JacC(101, 99) = JacC(101, 99)+ 0.2600000000000000D-01*dw(242, 99)
      JacC(101,100) = JacC(101,100)+ 0.2600000000000000D-01*dw(242,100)
      JacC(103, 99) = JacC(103, 99)+ 0.4970000000000000D+00*dw(242, 99)
      JacC(103,100) = JacC(103,100)+ 0.4970000000000000D+00*dw(242,100)
      JacC(104, 99) = JacC(104, 99)+ 0.2600000000000000D-01*dw(242, 99)
      JacC(104,100) = JacC(104,100)+ 0.2600000000000000D-01*dw(242,100)
      JacC(107, 99) = JacC(107, 99)+ 0.1980000000000000D+00*dw(242, 99)
      JacC(107,100) = JacC(107,100)+ 0.1980000000000000D+00*dw(242,100)
      JacC(108, 99) = JacC(108, 99)+ 0.8270000000000000D+00*dw(242, 99)
      JacC(108,100) = JacC(108,100)+ 0.8270000000000000D+00*dw(242,100)
      JacC(111, 99) = JacC(111, 99)+ 0.8940000000000000D+00*dw(242, 99)
      JacC(111,100) = JacC(111,100)+ 0.8940000000000000D+00*dw(242,100)
      JacC( 85, 86) = JacC( 85, 86)+ 0.2500000000000000D+00*dw(243, 86)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(243,100)
      JacC( 86, 86) = JacC( 86, 86) - dw(243, 86)
      JacC( 86,100) = JacC( 86,100) - dw(243,100)
      JacC( 89, 86) = JacC( 89, 86)+ 0.2500000000000000D+00*dw(243, 86)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(243,100)
      JacC(100, 86) = JacC(100, 86)- 0.9820000000000000D+00*dw(243, 86)
      JacC(100,100) = JacC(100,100)- 0.9820000000000000D+00*dw(243,100)
      JacC(101, 86) = JacC(101, 86)+ 0.1910000000000000D+00*dw(243, 86)
      JacC(101,100) = JacC(101,100)+ 0.1910000000000000D+00*dw(243,100)
      JacC(103, 86) = JacC(103, 86)+ 0.6180000000000000D+00*dw(243, 86)
      JacC(103,100) = JacC(103,100)+ 0.6180000000000000D+00*dw(243,100)
      JacC(104, 86) = JacC(104, 86)+ 0.1400000000000000D+00*dw(243, 86)
      JacC(104,100) = JacC(104,100)+ 0.1400000000000000D+00*dw(243,100)
      JacC(107, 86) = JacC(107, 86)+ 0.2510000000000000D+00*dw(243, 86)
      JacC(107,100) = JacC(107,100)+ 0.2510000000000000D+00*dw(243,100)
      JacC(108, 86) = JacC(108, 86)+ 0.7770000000000000D+00*dw(243, 86)
      JacC(108,100) = JacC(108,100)+ 0.7770000000000000D+00*dw(243,100)
      JacC(111, 86) = JacC(111, 86)+ 0.8420000000000000D+00*dw(243, 86)
      JacC(111,100) = JacC(111,100)+ 0.8420000000000000D+00*dw(243,100)
      JacC( 62, 62) = JacC( 62, 62) - dw(244, 62)
      JacC( 62,100) = JacC( 62,100) - dw(244,100)
      JacC( 85, 62) = JacC( 85, 62)+ 0.2500000000000000D+00*dw(244, 62)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(244,100)
      JacC( 89, 62) = JacC( 89, 62)+ 0.2500000000000000D+00*dw(244, 62)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(244,100)
      JacC(100, 62) = JacC(100, 62) - dw(244, 62)
      JacC(100,100) = JacC(100,100) - dw(244,100)
      JacC(101, 62) = JacC(101, 62)+ 0.2810000000000000D+00*dw(244, 62)
      JacC(101,100) = JacC(101,100)+ 0.2810000000000000D+00*dw(244,100)
      JacC(103, 62) = JacC(103, 62)+ 0.6520000000000000D+00*dw(244, 62)
      JacC(103,100) = JacC(103,100)+ 0.6520000000000000D+00*dw(244,100)
      JacC(104, 62) = JacC(104, 62)+ 0.9000000000000000D-01*dw(244, 62)
      JacC(104,100) = JacC(104,100)+ 0.9000000000000000D-01*dw(244,100)
      JacC(107, 62) = JacC(107, 62)+ 0.1970000000000000D+00*dw(244, 62)
      JacC(107,100) = JacC(107,100)+ 0.1970000000000000D+00*dw(244,100)
      JacC(108, 62) = JacC(108, 62)+ 0.7500000000000000D+00*dw(244, 62)
      JacC(108,100) = JacC(108,100)+ 0.7500000000000000D+00*dw(244,100)
      JacC(111, 62) = JacC(111, 62)+ 0.9100000000000000D+00*dw(244, 62)
      JacC(111,100) = JacC(111,100)+ 0.9100000000000000D+00*dw(244,100)
      JacC( 24, 88) = JacC( 24, 88)+ 0.2500000000000000D+00*dw(245, 88)
      JacC( 24,100) = JacC( 24,100)+ 0.2500000000000000D+00*dw(245,100)
      JacC( 88, 88) = JacC( 88, 88) - dw(245, 88)
      JacC( 88,100) = JacC( 88,100) - dw(245,100)
      JacC( 89, 88) = JacC( 89, 88)+ 0.2500000000000000D+00*dw(245, 88)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(245,100)
      JacC(100, 88) = JacC(100, 88) - dw(245, 88)
      JacC(100,100) = JacC(100,100) - dw(245,100)
      JacC(107, 88) = JacC(107, 88)+ 0.1500000000000000D+00*dw(245, 88)
      JacC(107,100) = JacC(107,100)+ 0.1500000000000000D+00*dw(245,100)
      JacC(108, 88) = JacC(108, 88)+ 0.1950000000000000D+01*dw(245, 88)
      JacC(108,100) = JacC(108,100)+ 0.1950000000000000D+01*dw(245,100)
      JacC(111, 88) = JacC(111, 88) + dw(245, 88)
      JacC(111,100) = JacC(111,100) + dw(245,100)
      JacC( 72, 72) = JacC( 72, 72) - dw(246, 72)
      JacC( 72,100) = JacC( 72,100) - dw(246,100)
      JacC( 85, 72) = JacC( 85, 72)+ 0.2500000000000000D+00*dw(246, 72)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(246,100)
      JacC( 89, 72) = JacC( 89, 72)+ 0.2500000000000000D+00*dw(246, 72)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(246,100)
      JacC(100, 72) = JacC(100, 72) - dw(246, 72)
      JacC(100,100) = JacC(100,100) - dw(246,100)
      JacC(103, 72) = JacC(103, 72)+ 0.4500000000000000D-01*dw(246, 72)
      JacC(103,100) = JacC(103,100)+ 0.4500000000000000D-01*dw(246,100)
      JacC(107, 72) = JacC(107, 72)+ 0.7050000000000000D+00*dw(246, 72)
      JacC(107,100) = JacC(107,100)+ 0.7050000000000000D+00*dw(246,100)
      JacC(108, 72) = JacC(108, 72)+ 0.1500000000000000D+01*dw(246, 72)
      JacC(108,100) = JacC(108,100)+ 0.1500000000000000D+01*dw(246,100)
      JacC(111, 72) = JacC(111, 72) + dw(246, 72)
      JacC(111,100) = JacC(111,100) + dw(246,100)
      JacC( 79, 79) = JacC( 79, 79) - dw(247, 79)
      JacC( 79,100) = JacC( 79,100) - dw(247,100)
      JacC( 85, 79) = JacC( 85, 79)+ 0.2500000000000000D+00*dw(247, 79)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(247,100)
      JacC( 89, 79) = JacC( 89, 79)+ 0.2500000000000000D+00*dw(247, 79)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(247,100)
      JacC(100, 79) = JacC(100, 79) - dw(247, 79)
      JacC(100,100) = JacC(100,100) - dw(247,100)
      JacC(103, 79) = JacC(103, 79)+ 0.2180000000000000D+00*dw(247, 79)
      JacC(103,100) = JacC(103,100)+ 0.2180000000000000D+00*dw(247,100)
      JacC(107, 79) = JacC(107, 79)+ 0.1280000000000000D+01*dw(247, 79)
      JacC(107,100) = JacC(107,100)+ 0.1280000000000000D+01*dw(247,100)
      JacC(108, 79) = JacC(108, 79)+ 0.7500000000000000D+00*dw(247, 79)
      JacC(108,100) = JacC(108,100)+ 0.7500000000000000D+00*dw(247,100)
      JacC(111, 79) = JacC(111, 79) + dw(247, 79)
      JacC(111,100) = JacC(111,100) + dw(247,100)
      JacC( 59, 59) = JacC( 59, 59) - dw(248, 59)
      JacC( 59,100) = JacC( 59,100) - dw(248,100)
      JacC( 61, 59) = JacC( 61, 59)+ 0.2190000000000000D+00*dw(248, 59)
      JacC( 61,100) = JacC( 61,100)+ 0.2190000000000000D+00*dw(248,100)
      JacC( 66, 59) = JacC( 66, 59)+ 0.3050000000000000D+00*dw(248, 59)
      JacC( 66,100) = JacC( 66,100)+ 0.3050000000000000D+00*dw(248,100)
      JacC( 85, 59) = JacC( 85, 59)+ 0.2500000000000000D+00*dw(248, 59)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(248,100)
      JacC( 89, 59) = JacC( 89, 59)+ 0.2500000000000000D+00*dw(248, 59)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(248,100)
      JacC(100, 59) = JacC(100, 59) - dw(248, 59)
      JacC(100,100) = JacC(100,100) - dw(248,100)
      JacC(108, 59) = JacC(108, 59)+ 0.1540000000000000D+01*dw(248, 59)
      JacC(108,100) = JacC(108,100)+ 0.1540000000000000D+01*dw(248,100)
      JacC(111, 59) = JacC(111, 59) + dw(248, 59)
      JacC(111,100) = JacC(111,100) + dw(248,100)
      JacC( 73, 95) = JacC( 73, 95)+ 0.1670000000000000D+00*dw(249, 95)
      JacC( 73,100) = JacC( 73,100)+ 0.1670000000000000D+00*dw(249,100)
      JacC( 85, 95) = JacC( 85, 95)+ 0.2500000000000000D+00*dw(249, 95)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(249,100)
      JacC( 89, 95) = JacC( 89, 95)+ 0.2500000000000000D+00*dw(249, 95)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(249,100)
      JacC( 93, 95) = JacC( 93, 95)+ 0.3330000000000000D+00*dw(249, 95)
      JacC( 93,100) = JacC( 93,100)+ 0.3330000000000000D+00*dw(249,100)
      JacC( 95, 95) = JacC( 95, 95) - dw(249, 95)
      JacC( 95,100) = JacC( 95,100) - dw(249,100)
      JacC( 96, 95) = JacC( 96, 95)+ 0.1670000000000000D+00*dw(249, 95)
      JacC( 96,100) = JacC( 96,100)+ 0.1670000000000000D+00*dw(249,100)
      JacC( 97, 95) = JacC( 97, 95)+ 0.4200000000000000D-01*dw(249, 95)
      JacC( 97,100) = JacC( 97,100)+ 0.4200000000000000D-01*dw(249,100)
      JacC(100, 95) = JacC(100, 95) - dw(249, 95)
      JacC(100,100) = JacC(100,100) - dw(249,100)
      JacC(105, 95) = JacC(105, 95)+ 0.1670000000000000D+00*dw(249, 95)
      JacC(105,100) = JacC(105,100)+ 0.1670000000000000D+00*dw(249,100)
      JacC(108, 95) = JacC(108, 95)+ 0.1500000000000000D+01*dw(249, 95)
      JacC(108,100) = JacC(108,100)+ 0.1500000000000000D+01*dw(249,100)
      JacC(111, 95) = JacC(111, 95) + dw(249, 95)
      JacC(111,100) = JacC(111,100) + dw(249,100)
      JacC( 68, 68) = JacC( 68, 68) - dw(250, 68)
      JacC( 68,100) = JacC( 68,100) - dw(250,100)
      JacC( 85, 68) = JacC( 85, 68)+ 0.2500000000000000D+00*dw(250, 68)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(250,100)
      JacC( 89, 68) = JacC( 89, 68)+ 0.2500000000000000D+00*dw(250, 68)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(250,100)
      JacC( 93, 68) = JacC( 93, 68)+ 0.5000000000000000D+00*dw(250, 68)
      JacC( 93,100) = JacC( 93,100)+ 0.5000000000000000D+00*dw(250,100)
      JacC( 97, 68) = JacC( 97, 68)+ 0.2920000000000000D+00*dw(250, 68)
      JacC( 97,100) = JacC( 97,100)+ 0.2920000000000000D+00*dw(250,100)
      JacC(100, 68) = JacC(100, 68) - dw(250, 68)
      JacC(100,100) = JacC(100,100) - dw(250,100)
      JacC(101, 68) = JacC(101, 68)+ 0.1160000000000000D+01*dw(250, 68)
      JacC(101,100) = JacC(101,100)+ 0.1160000000000000D+01*dw(250,100)
      JacC(105, 68) = JacC(105, 68)+ 0.1160000000000000D+01*dw(250, 68)
      JacC(105,100) = JacC(105,100)+ 0.1160000000000000D+01*dw(250,100)
      JacC(107, 68) = JacC(107, 68)+ 0.1750000000000000D+01*dw(250, 68)
      JacC(107,100) = JacC(107,100)+ 0.1750000000000000D+01*dw(250,100)
      JacC(108, 68) = JacC(108, 68)+ 0.1500000000000000D+01*dw(250, 68)
      JacC(108,100) = JacC(108,100)+ 0.1500000000000000D+01*dw(250,100)
      JacC(111, 68) = JacC(111, 68) + dw(250, 68)
      JacC(111,100) = JacC(111,100) + dw(250,100)
      JacC( 84, 84) = JacC( 84, 84) - dw(251, 84)
      JacC( 84,100) = JacC( 84,100) - dw(251,100)
      JacC( 85, 84) = JacC( 85, 84)+ 0.2500000000000000D+00*dw(251, 84)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(251,100)
      JacC( 89, 84) = JacC( 89, 84)+ 0.2500000000000000D+00*dw(251, 84)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(251,100)
      JacC( 91, 84) = JacC( 91, 84)+ 0.1350000000000000D+00*dw(251, 84)
      JacC( 91,100) = JacC( 91,100)+ 0.1350000000000000D+00*dw(251,100)
      JacC( 93, 84) = JacC( 93, 84)+ 0.1050000000000000D+00*dw(251, 84)
      JacC( 93,100) = JacC( 93,100)+ 0.1050000000000000D+00*dw(251,100)
      JacC( 96, 84) = JacC( 96, 84)+ 0.3050000000000000D+00*dw(251, 84)
      JacC( 96,100) = JacC( 96,100)+ 0.3050000000000000D+00*dw(251,100)
      JacC(100, 84) = JacC(100, 84) - dw(251, 84)
      JacC(100,100) = JacC(100,100) - dw(251,100)
      JacC(103, 84) = JacC(103, 84)+ 0.5250000000000000D+00*dw(251, 84)
      JacC(103,100) = JacC(103,100)+ 0.5250000000000000D+00*dw(251,100)
      JacC(107, 84) = JacC(107, 84)+ 0.2030000000000000D+00*dw(251, 84)
      JacC(107,100) = JacC(107,100)+ 0.2030000000000000D+00*dw(251,100)
      JacC(108, 84) = JacC(108, 84)+ 0.7730000000000000D+00*dw(251, 84)
      JacC(108,100) = JacC(108,100)+ 0.7730000000000000D+00*dw(251,100)
      JacC(111, 84) = JacC(111, 84) + dw(251, 84)
      JacC(111,100) = JacC(111,100) + dw(251,100)
      JacC( 57, 57) = JacC( 57, 57) - dw(252, 57)
      JacC( 57,100) = JacC( 57,100) - dw(252,100)
      JacC( 85, 57) = JacC( 85, 57)+ 0.2500000000000000D+00*dw(252, 57)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(252,100)
      JacC( 89, 57) = JacC( 89, 57)+ 0.2500000000000000D+00*dw(252, 57)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(252,100)
      JacC(100, 57) = JacC(100, 57) - dw(252, 57)
      JacC(100,100) = JacC(100,100) - dw(252,100)
      JacC(103, 57) = JacC(103, 57)+ 0.7500000000000000D+00*dw(252, 57)
      JacC(103,100) = JacC(103,100)+ 0.7500000000000000D+00*dw(252,100)
      JacC(107, 57) = JacC(107, 57)+ 0.7500000000000000D+00*dw(252, 57)
      JacC(107,100) = JacC(107,100)+ 0.7500000000000000D+00*dw(252,100)
      JacC(108, 57) = JacC(108, 57)+ 0.7500000000000000D+00*dw(252, 57)
      JacC(108,100) = JacC(108,100)+ 0.7500000000000000D+00*dw(252,100)
      JacC(111, 57) = JacC(111, 57) + dw(252, 57)
      JacC(111,100) = JacC(111,100) + dw(252,100)
      JacC( 60, 60) = JacC( 60, 60) - dw(253, 60)
      JacC( 60,100) = JacC( 60,100) - dw(253,100)
      JacC( 61, 60) = JacC( 61, 60)+ 0.3080000000000000D+00*dw(253, 60)
      JacC( 61,100) = JacC( 61,100)+ 0.3080000000000000D+00*dw(253,100)
      JacC( 69, 60) = JacC( 69, 60)+ 0.1920000000000000D+00*dw(253, 60)
      JacC( 69,100) = JacC( 69,100)+ 0.1920000000000000D+00*dw(253,100)
      JacC( 85, 60) = JacC( 85, 60)+ 0.2500000000000000D+00*dw(253, 60)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(253,100)
      JacC( 89, 60) = JacC( 89, 60)+ 0.2500000000000000D+00*dw(253, 60)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(253,100)
      JacC(100, 60) = JacC(100, 60) - dw(253, 60)
      JacC(100,100) = JacC(100,100) - dw(253,100)
      JacC(108, 60) = JacC(108, 60)+ 0.1040000000000000D+01*dw(253, 60)
      JacC(108,100) = JacC(108,100)+ 0.1040000000000000D+01*dw(253,100)
      JacC(111, 60) = JacC(111, 60) + dw(253, 60)
      JacC(111,100) = JacC(111,100) + dw(253,100)
      JacC( 63, 63) = JacC( 63, 63) - dw(254, 63)
      JacC( 63,100) = JacC( 63,100) - dw(254,100)
      JacC( 69, 63) = JacC( 69, 63)+ 0.3000000000000000D+00*dw(254, 63)
      JacC( 69,100) = JacC( 69,100)+ 0.3000000000000000D+00*dw(254,100)
      JacC( 80, 63) = JacC( 80, 63)+ 0.7000000000000000D+00*dw(254, 63)
      JacC( 80,100) = JacC( 80,100)+ 0.7000000000000000D+00*dw(254,100)
      JacC( 91, 63) = JacC( 91, 63)+ 0.6000000000000000D+00*dw(254, 63)
      JacC( 91,100) = JacC( 91,100)+ 0.6000000000000000D+00*dw(254,100)
      JacC(100, 63) = JacC(100, 63) - dw(254, 63)
      JacC(100,100) = JacC(100,100) - dw(254,100)
      JacC(108, 63) = JacC(108, 63) + dw(254, 63)
      JacC(108,100) = JacC(108,100) + dw(254,100)
      JacC(111, 63) = JacC(111, 63)+ 0.2600000000000000D+01*dw(254, 63)
      JacC(111,100) = JacC(111,100)+ 0.2600000000000000D+01*dw(254,100)
      JacC( 41, 41) = JacC( 41, 41) - dw(255, 41)
      JacC( 41,100) = JacC( 41,100) - dw(255,100)
      JacC( 56, 41) = JacC( 56, 41) + dw(255, 41)
      JacC( 56,100) = JacC( 56,100) + dw(255,100)
      JacC( 91, 41) = JacC( 91, 41)+ 0.2710000000000000D+00*dw(255, 41)
      JacC( 91,100) = JacC( 91,100)+ 0.2710000000000000D+00*dw(255,100)
      JacC(100, 41) = JacC(100, 41) - dw(255, 41)
      JacC(100,100) = JacC(100,100) - dw(255,100)
      JacC(108, 41) = JacC(108, 41) + dw(255, 41)
      JacC(108,100) = JacC(108,100) + dw(255,100)
      JacC(111, 41) = JacC(111, 41)+ 0.2000000000000000D+01*dw(255, 41)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(255,100)
      JacC( 50, 50) = JacC( 50, 50) - dw(256, 50)
      JacC( 50,100) = JacC( 50,100) - dw(256,100)
      JacC( 53, 50) = JacC( 53, 50) + dw(256, 50)
      JacC( 53,100) = JacC( 53,100) + dw(256,100)
      JacC(100, 50) = JacC(100, 50) - dw(256, 50)
      JacC(100,100) = JacC(100,100) - dw(256,100)
      JacC(108, 50) = JacC(108, 50) + dw(256, 50)
      JacC(108,100) = JacC(108,100) + dw(256,100)
      JacC(111, 50) = JacC(111, 50) + dw(256, 50)
      JacC(111,100) = JacC(111,100) + dw(256,100)
      JacC( 42, 42) = JacC( 42, 42) - dw(257, 42)
      JacC( 42,100) = JacC( 42,100) - dw(257,100)
      JacC( 77, 42) = JacC( 77, 42) + dw(257, 42)
      JacC( 77,100) = JacC( 77,100) + dw(257,100)
      JacC( 93, 42) = JacC( 93, 42) + dw(257, 42)
      JacC( 93,100) = JacC( 93,100) + dw(257,100)
      JacC(100, 42) = JacC(100, 42) - dw(257, 42)
      JacC(100,100) = JacC(100,100) - dw(257,100)
      JacC(108, 42) = JacC(108, 42) + dw(257, 42)
      JacC(108,100) = JacC(108,100) + dw(257,100)
      JacC(111, 42) = JacC(111, 42)+ 0.2000000000000000D+01*dw(257, 42)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(257,100)
      JacC( 55, 55) = JacC( 55, 55) - dw(258, 55)
      JacC( 55,100) = JacC( 55,100) - dw(258,100)
      JacC( 56, 55) = JacC( 56, 55)+ 0.7700000000000000D-01*dw(258, 55)
      JacC( 56,100) = JacC( 56,100)+ 0.7700000000000000D-01*dw(258,100)
      JacC( 77, 55) = JacC( 77, 55)+ 0.7370000000000000D+00*dw(258, 55)
      JacC( 77,100) = JacC( 77,100)+ 0.7370000000000000D+00*dw(258,100)
      JacC( 78, 55) = JacC( 78, 55)+ 0.1860000000000000D+00*dw(258, 55)
      JacC( 78,100) = JacC( 78,100)+ 0.1860000000000000D+00*dw(258,100)
      JacC( 91, 55) = JacC( 91, 55)+ 0.3680000000000000D+00*dw(258, 55)
      JacC( 91,100) = JacC( 91,100)+ 0.3680000000000000D+00*dw(258,100)
      JacC( 93, 55) = JacC( 93, 55)+ 0.6320000000000000D+00*dw(258, 55)
      JacC( 93,100) = JacC( 93,100)+ 0.6320000000000000D+00*dw(258,100)
      JacC(100, 55) = JacC(100, 55) - dw(258, 55)
      JacC(100,100) = JacC(100,100) - dw(258,100)
      JacC(108, 55) = JacC(108, 55) + dw(258, 55)
      JacC(108,100) = JacC(108,100) + dw(258,100)
      JacC(111, 55) = JacC(111, 55)+ 0.2000000000000000D+01*dw(258, 55)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(258,100)
      JacC( 52, 52) = JacC( 52, 52) - dw(259, 52)
      JacC( 52,100) = JacC( 52,100) - dw(259,100)
      JacC( 53, 52) = JacC( 53, 52) + dw(259, 52)
      JacC( 53,100) = JacC( 53,100) + dw(259,100)
      JacC(100, 52) = JacC(100, 52) - dw(259, 52)
      JacC(100,100) = JacC(100,100) - dw(259,100)
      JacC(108, 52) = JacC(108, 52) + dw(259, 52)
      JacC(108,100) = JacC(108,100) + dw(259,100)
      JacC(111, 52) = JacC(111, 52) + dw(259, 52)
      JacC(111,100) = JacC(111,100) + dw(259,100)
      JacC( 43, 43) = JacC( 43, 43) - dw(260, 43)
      JacC( 43,100) = JacC( 43,100) - dw(260,100)
      JacC( 56, 43) = JacC( 56, 43) + dw(260, 43)
      JacC( 56,100) = JacC( 56,100) + dw(260,100)
      JacC(100, 43) = JacC(100, 43) - dw(260, 43)
      JacC(100,100) = JacC(100,100) - dw(260,100)
      JacC(108, 43) = JacC(108, 43) + dw(260, 43)
      JacC(108,100) = JacC(108,100) + dw(260,100)
      JacC(111, 43) = JacC(111, 43)+ 0.2000000000000000D+01*dw(260, 43)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(260,100)
      JacC( 49, 49) = JacC( 49, 49) - dw(261, 49)
      JacC( 49,100) = JacC( 49,100) - dw(261,100)
      JacC( 77, 49) = JacC( 77, 49) + dw(261, 49)
      JacC( 77,100) = JacC( 77,100) + dw(261,100)
      JacC( 78, 49) = JacC( 78, 49)+ 0.2050000000000000D+01*dw(261, 49)
      JacC( 78,100) = JacC( 78,100)+ 0.2050000000000000D+01*dw(261,100)
      JacC( 93, 49) = JacC( 93, 49) + dw(261, 49)
      JacC( 93,100) = JacC( 93,100) + dw(261,100)
      JacC(100, 49) = JacC(100, 49) - dw(261, 49)
      JacC(100,100) = JacC(100,100) - dw(261,100)
      JacC(108, 49) = JacC(108, 49) + dw(261, 49)
      JacC(108,100) = JacC(108,100) + dw(261,100)
      JacC(111, 49) = JacC(111, 49)+ 0.2000000000000000D+01*dw(261, 49)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(261,100)
      JacC( 45, 54) = JacC( 45, 54) + dw(262, 54)
      JacC( 45,100) = JacC( 45,100) + dw(262,100)
      JacC( 54, 54) = JacC( 54, 54) - dw(262, 54)
      JacC( 54,100) = JacC( 54,100) - dw(262,100)
      JacC(100, 54) = JacC(100, 54) - dw(262, 54)
      JacC(100,100) = JacC(100,100) - dw(262,100)
      JacC(108, 54) = JacC(108, 54) + dw(262, 54)
      JacC(108,100) = JacC(108,100) + dw(262,100)
      JacC(111, 54) = JacC(111, 54) + dw(262, 54)
      JacC(111,100) = JacC(111,100) + dw(262,100)
      JacC( 45, 45) = JacC( 45, 45) - dw(263, 45)
      JacC( 45,100) = JacC( 45,100) - dw(263,100)
      JacC( 46, 45) = JacC( 46, 45) + dw(263, 45)
      JacC( 46,100) = JacC( 46,100) + dw(263,100)
      JacC(100, 45) = JacC(100, 45) - dw(263, 45)
      JacC(100,100) = JacC(100,100) - dw(263,100)
      JacC(108, 45) = JacC(108, 45) + dw(263, 45)
      JacC(108,100) = JacC(108,100) + dw(263,100)
      JacC(111, 45) = JacC(111, 45) + dw(263, 45)
      JacC(111,100) = JacC(111,100) + dw(263,100)
      JacC( 75, 75) = JacC( 75, 75) - dw(264, 75)
      JacC( 75,100) = JacC( 75,100) - dw(264,100)
      JacC( 76, 75) = JacC( 76, 75)+ 0.3200000000000000D+00*dw(264, 75)
      JacC( 76,100) = JacC( 76,100)+ 0.3200000000000000D+00*dw(264,100)
      JacC( 91, 75) = JacC( 91, 75)+ 0.6800000000000000D+00*dw(264, 75)
      JacC( 91,100) = JacC( 91,100)+ 0.6800000000000000D+00*dw(264,100)
      JacC(100, 75) = JacC(100, 75) - dw(264, 75)
      JacC(100,100) = JacC(100,100) - dw(264,100)
      JacC(106, 75) = JacC(106, 75)+ 0.6800000000000000D+00*dw(264, 75)
      JacC(106,100) = JacC(106,100)+ 0.6800000000000000D+00*dw(264,100)
      JacC(108, 75) = JacC(108, 75) + dw(264, 75)
      JacC(108,100) = JacC(108,100) + dw(264,100)
      JacC(111, 75) = JacC(111, 75)+ 0.2000000000000000D+01*dw(264, 75)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(264,100)
      JacC( 97,105) = JacC( 97,105)+ 0.1000000000000000D+00*dw(265,105)
      JacC( 97,100) = JacC( 97,100)+ 0.1000000000000000D+00*dw(265,100)
      JacC(100,105) = JacC(100,105)- 0.9999999999999998D-01*dw(265,105)
      JacC(100,100) = JacC(100,100)- 0.9999999999999998D-01*dw(265,100)
      JacC(105,105) = JacC(105,105) - dw(265,105)
      JacC(105,100) = JacC(105,100) - dw(265,100)
      JacC(108,105) = JacC(108,105) + dw(265,105)
      JacC(108,100) = JacC(108,100) + dw(265,100)
      JacC(111,105) = JacC(111,105)+ 0.9000000000000000D+00*dw(265,105)
      JacC(111,100) = JacC(111,100)+ 0.9000000000000000D+00*dw(265,100)
      JacC( 97, 98) = JacC( 97, 98)+ 0.1000000000000000D+00*dw(266, 98)
      JacC( 97,100) = JacC( 97,100)+ 0.1000000000000000D+00*dw(266,100)
      JacC( 98, 98) = JacC( 98, 98) - dw(266, 98)
      JacC( 98,100) = JacC( 98,100) - dw(266,100)
      JacC(100, 98) = JacC(100, 98)- 0.9999999999999998D-01*dw(266, 98)
      JacC(100,100) = JacC(100,100)- 0.9999999999999998D-01*dw(266,100)
      JacC(108, 98) = JacC(108, 98) + dw(266, 98)
      JacC(108,100) = JacC(108,100) + dw(266,100)
      JacC(111, 98) = JacC(111, 98)+ 0.9000000000000000D+00*dw(266, 98)
      JacC(111,100) = JacC(111,100)+ 0.9000000000000000D+00*dw(266,100)
      JacC( 65, 65) = JacC( 65, 65) - dw(267, 65)
      JacC( 65,100) = JacC( 65,100) - dw(267,100)
      JacC( 85, 65) = JacC( 85, 65)+ 0.2500000000000000D+00*dw(267, 65)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(267,100)
      JacC( 89, 65) = JacC( 89, 65)+ 0.2500000000000000D+00*dw(267, 65)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(267,100)
      JacC( 97, 65) = JacC( 97, 65)+ 0.1250000000000000D+00*dw(267, 65)
      JacC( 97,100) = JacC( 97,100)+ 0.1250000000000000D+00*dw(267,100)
      JacC(100, 65) = JacC(100, 65) - dw(267, 65)
      JacC(100,100) = JacC(100,100) - dw(267,100)
      JacC(105, 65) = JacC(105, 65)+ 0.5000000000000000D+00*dw(267, 65)
      JacC(105,100) = JacC(105,100)+ 0.5000000000000000D+00*dw(267,100)
      JacC(108, 65) = JacC(108, 65)+ 0.1500000000000000D+01*dw(267, 65)
      JacC(108,100) = JacC(108,100)+ 0.1500000000000000D+01*dw(267,100)
      JacC(111, 65) = JacC(111, 65)+ 0.5000000000000000D+00*dw(267, 65)
      JacC(111,100) = JacC(111,100)+ 0.5000000000000000D+00*dw(267,100)
      JacC( 64, 64) = JacC( 64, 64) - dw(268, 64)
      JacC( 64,100) = JacC( 64,100) - dw(268,100)
      JacC( 77, 64) = JacC( 77, 64)+ 0.3340000000000000D+00*dw(268, 64)
      JacC( 77,100) = JacC( 77,100)+ 0.3340000000000000D+00*dw(268,100)
      JacC( 85, 64) = JacC( 85, 64)+ 0.2500000000000000D+00*dw(268, 64)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(268,100)
      JacC( 89, 64) = JacC( 89, 64)+ 0.2500000000000000D+00*dw(268, 64)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(268,100)
      JacC(100, 64) = JacC(100, 64) - dw(268, 64)
      JacC(100,100) = JacC(100,100) - dw(268,100)
      JacC(108, 64) = JacC(108, 64) + dw(268, 64)
      JacC(108,100) = JacC(108,100) + dw(268,100)
      JacC(111, 64) = JacC(111, 64)+ 0.8340000000000000D+00*dw(268, 64)
      JacC(111,100) = JacC(111,100)+ 0.8340000000000000D+00*dw(268,100)
      JacC( 77, 92) = JacC( 77, 92)+ 0.5000000000000000D+00*dw(269, 92)
      JacC( 77,100) = JacC( 77,100)+ 0.5000000000000000D+00*dw(269,100)
      JacC( 85, 92) = JacC( 85, 92)+ 0.2500000000000000D+00*dw(269, 92)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(269,100)
      JacC( 89, 92) = JacC( 89, 92)+ 0.2500000000000000D+00*dw(269, 92)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(269,100)
      JacC( 92, 92) = JacC( 92, 92) - dw(269, 92)
      JacC( 92,100) = JacC( 92,100) - dw(269,100)
      JacC(100, 92) = JacC(100, 92) - dw(269, 92)
      JacC(100,100) = JacC(100,100) - dw(269,100)
      JacC(108, 92) = JacC(108, 92)+ 0.7500000000000000D+00*dw(269, 92)
      JacC(108,100) = JacC(108,100)+ 0.7500000000000000D+00*dw(269,100)
      JacC(111, 92) = JacC(111, 92) + dw(269, 92)
      JacC(111,100) = JacC(111,100) + dw(269,100)
      JacC( 71, 71) = JacC( 71, 71) - dw(270, 71)
      JacC( 71,100) = JacC( 71,100) - dw(270,100)
      JacC(100, 71) = JacC(100, 71) - dw(270, 71)
      JacC(100,100) = JacC(100,100) - dw(270,100)
      JacC(108, 71) = JacC(108, 71) + dw(270, 71)
      JacC(108,100) = JacC(108,100) + dw(270,100)
      JacC(111, 71) = JacC(111, 71)+ 0.2000000000000000D+01*dw(270, 71)
      JacC(111,100) = JacC(111,100)+ 0.2000000000000000D+01*dw(270,100)
      JacC(113, 71) = JacC(113, 71) + dw(270, 71)
      JacC(113,100) = JacC(113,100) + dw(270,100)
      JacC( 70, 70) = JacC( 70, 70) - dw(271, 70)
      JacC( 70,100) = JacC( 70,100) - dw(271,100)
      JacC( 85, 70) = JacC( 85, 70)+ 0.2500000000000000D+00*dw(271, 70)
      JacC( 85,100) = JacC( 85,100)+ 0.2500000000000000D+00*dw(271,100)
      JacC( 89, 70) = JacC( 89, 70)+ 0.2500000000000000D+00*dw(271, 70)
      JacC( 89,100) = JacC( 89,100)+ 0.2500000000000000D+00*dw(271,100)
      JacC(100, 70) = JacC(100, 70) - dw(271, 70)
      JacC(100,100) = JacC(100,100) - dw(271,100)
      JacC(103, 70) = JacC(103, 70)+ 0.3480000000000000D+00*dw(271, 70)
      JacC(103,100) = JacC(103,100)+ 0.3480000000000000D+00*dw(271,100)
      JacC(107, 70) = JacC(107, 70)+ 0.9300000000000000D+00*dw(271, 70)
      JacC(107,100) = JacC(107,100)+ 0.9300000000000000D+00*dw(271,100)
      JacC(108, 70) = JacC(108, 70)+ 0.9650000000000000D+00*dw(271, 70)
      JacC(108,100) = JacC(108,100)+ 0.9650000000000000D+00*dw(271,100)
      JacC(110, 70) = JacC(110, 70)+ 0.5000000000000000D+00*dw(271, 70)
      JacC(110,100) = JacC(110,100)+ 0.5000000000000000D+00*dw(271,100)
      JacC(111, 70) = JacC(111, 70)+ 0.5000000000000000D+00*dw(271, 70)
      JacC(111,100) = JacC(111,100)+ 0.5000000000000000D+00*dw(271,100)
      JacC(113, 70) = JacC(113, 70)+ 0.5000000000000000D+00*dw(271, 70)
      JacC(113,100) = JacC(113,100)+ 0.5000000000000000D+00*dw(271,100)
      JacC( 87,104) = JacC( 87,104) + dw(272,104)
      JacC( 87,105) = JacC( 87,105) + dw(272,105)
      JacC( 97,104) = JacC( 97,104)+ 0.5000000000000000D+00*dw(272,104)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(272,105)
      JacC(100,104) = JacC(100,104)+ 0.5000000000000000D+00*dw(272,104)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(272,105)
      JacC(104,104) = JacC(104,104) - dw(272,104)
      JacC(104,105) = JacC(104,105) - dw(272,105)
      JacC(105,104) = JacC(105,104) - dw(272,104)
      JacC(105,105) = JacC(105,105) - dw(272,105)
      JacC(111,104) = JacC(111,104)+ 0.5000000000000000D+00*dw(272,104)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(272,105)
      JacC( 91, 99) = JacC( 91, 99)+ 0.6700000000000000D-01*dw(273, 99)
      JacC( 91,105) = JacC( 91,105)+ 0.6700000000000000D-01*dw(273,105)
      JacC( 97, 99) = JacC( 97, 99)+ 0.5000000000000000D+00*dw(273, 99)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(273,105)
      JacC( 99, 99) = JacC( 99, 99) - dw(273, 99)
      JacC( 99,105) = JacC( 99,105) - dw(273,105)
      JacC(100, 99) = JacC(100, 99)+ 0.5800000000000000D+00*dw(273, 99)
      JacC(100,105) = JacC(100,105)+ 0.5800000000000000D+00*dw(273,105)
      JacC(101, 99) = JacC(101, 99)+ 0.2600000000000000D-01*dw(273, 99)
      JacC(101,105) = JacC(101,105)+ 0.2600000000000000D-01*dw(273,105)
      JacC(103, 99) = JacC(103, 99)+ 0.6620000000000000D+00*dw(273, 99)
      JacC(103,105) = JacC(103,105)+ 0.6620000000000000D+00*dw(273,105)
      JacC(104, 99) = JacC(104, 99)+ 0.2600000000000000D-01*dw(273, 99)
      JacC(104,105) = JacC(104,105)+ 0.2600000000000000D-01*dw(273,105)
      JacC(105, 99) = JacC(105, 99) - dw(273, 99)
      JacC(105,105) = JacC(105,105) - dw(273,105)
      JacC(107, 99) = JacC(107, 99)+ 0.2730000000000000D+00*dw(273, 99)
      JacC(107,105) = JacC(107,105)+ 0.2730000000000000D+00*dw(273,105)
      JacC(108, 99) = JacC(108, 99)+ 0.1300000000000000D+00*dw(273, 99)
      JacC(108,105) = JacC(108,105)+ 0.1300000000000000D+00*dw(273,105)
      JacC(111, 99) = JacC(111, 99)+ 0.3940000000000000D+00*dw(273, 99)
      JacC(111,105) = JacC(111,105)+ 0.3940000000000000D+00*dw(273,105)
      JacC( 86, 86) = JacC( 86, 86) - dw(274, 86)
      JacC( 86,105) = JacC( 86,105) - dw(274,105)
      JacC( 97, 86) = JacC( 97, 86)+ 0.5000000000000000D+00*dw(274, 86)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(274,105)
      JacC(100, 86) = JacC(100, 86)+ 0.5180000000000000D+00*dw(274, 86)
      JacC(100,105) = JacC(100,105)+ 0.5180000000000000D+00*dw(274,105)
      JacC(101, 86) = JacC(101, 86)+ 0.1910000000000000D+00*dw(274, 86)
      JacC(101,105) = JacC(101,105)+ 0.1910000000000000D+00*dw(274,105)
      JacC(103, 86) = JacC(103, 86)+ 0.8240000000000000D+00*dw(274, 86)
      JacC(103,105) = JacC(103,105)+ 0.8240000000000000D+00*dw(274,105)
      JacC(104, 86) = JacC(104, 86)+ 0.1400000000000000D+00*dw(274, 86)
      JacC(104,105) = JacC(104,105)+ 0.1400000000000000D+00*dw(274,105)
      JacC(105, 86) = JacC(105, 86) - dw(274, 86)
      JacC(105,105) = JacC(105,105) - dw(274,105)
      JacC(107, 86) = JacC(107, 86)+ 0.3810000000000000D+00*dw(274, 86)
      JacC(107,105) = JacC(107,105)+ 0.3810000000000000D+00*dw(274,105)
      JacC(108, 86) = JacC(108, 86)+ 0.4200000000000000D-01*dw(274, 86)
      JacC(108,105) = JacC(108,105)+ 0.4200000000000000D-01*dw(274,105)
      JacC(111, 86) = JacC(111, 86)+ 0.3420000000000000D+00*dw(274, 86)
      JacC(111,105) = JacC(111,105)+ 0.3420000000000000D+00*dw(274,105)
      JacC( 62, 62) = JacC( 62, 62) - dw(275, 62)
      JacC( 62,105) = JacC( 62,105) - dw(275,105)
      JacC( 97, 62) = JacC( 97, 62)+ 0.4950000000000000D+00*dw(275, 62)
      JacC( 97,105) = JacC( 97,105)+ 0.4950000000000000D+00*dw(275,105)
      JacC(100, 62) = JacC(100, 62)+ 0.5000000000000000D+00*dw(275, 62)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(275,105)
      JacC(101, 62) = JacC(101, 62)+ 0.2080000000000000D+00*dw(275, 62)
      JacC(101,105) = JacC(101,105)+ 0.2080000000000000D+00*dw(275,105)
      JacC(103, 62) = JacC(103, 62)+ 0.6420000000000000D+00*dw(275, 62)
      JacC(103,105) = JacC(103,105)+ 0.6420000000000000D+00*dw(275,105)
      JacC(104, 62) = JacC(104, 62)+ 0.6700000000000000D-01*dw(275, 62)
      JacC(104,105) = JacC(104,105)+ 0.6700000000000000D-01*dw(275,105)
      JacC(105, 62) = JacC(105, 62) - dw(275, 62)
      JacC(105,105) = JacC(105,105) - dw(275,105)
      JacC(107, 62) = JacC(107, 62)+ 0.2170000000000000D+00*dw(275, 62)
      JacC(107,105) = JacC(107,105)+ 0.2170000000000000D+00*dw(275,105)
      JacC(111, 62) = JacC(111, 62)+ 0.3030000000000000D+00*dw(275, 62)
      JacC(111,105) = JacC(111,105)+ 0.3030000000000000D+00*dw(275,105)
      JacC( 88, 88) = JacC( 88, 88) - dw(276, 88)
      JacC( 88,105) = JacC( 88,105) - dw(276,105)
      JacC( 97, 88) = JacC( 97, 88)+ 0.5000000000000000D+00*dw(276, 88)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(276,105)
      JacC(100, 88) = JacC(100, 88)+ 0.5000000000000000D+00*dw(276, 88)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(276,105)
      JacC(105, 88) = JacC(105, 88) - dw(276, 88)
      JacC(105,105) = JacC(105,105) - dw(276,105)
      JacC(107, 88) = JacC(107, 88)+ 0.2000000000000000D+00*dw(276, 88)
      JacC(107,105) = JacC(107,105)+ 0.2000000000000000D+00*dw(276,105)
      JacC(108, 88) = JacC(108, 88)+ 0.1600000000000000D+01*dw(276, 88)
      JacC(108,105) = JacC(108,105)+ 0.1600000000000000D+01*dw(276,105)
      JacC(111, 88) = JacC(111, 88)+ 0.5000000000000000D+00*dw(276, 88)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(276,105)
      JacC( 72, 72) = JacC( 72, 72) - dw(277, 72)
      JacC( 72,105) = JacC( 72,105) - dw(277,105)
      JacC( 97, 72) = JacC( 97, 72)+ 0.5000000000000000D+00*dw(277, 72)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(277,105)
      JacC(100, 72) = JacC(100, 72)+ 0.5000000000000000D+00*dw(277, 72)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(277,105)
      JacC(103, 72) = JacC(103, 72)+ 0.6000000000000000D-01*dw(277, 72)
      JacC(103,105) = JacC(103,105)+ 0.6000000000000000D-01*dw(277,105)
      JacC(105, 72) = JacC(105, 72) - dw(277, 72)
      JacC(105,105) = JacC(105,105) - dw(277,105)
      JacC(107, 72) = JacC(107, 72)+ 0.9399999999999999D+00*dw(277, 72)
      JacC(107,105) = JacC(107,105)+ 0.9399999999999999D+00*dw(277,105)
      JacC(108, 72) = JacC(108, 72) + dw(277, 72)
      JacC(108,105) = JacC(108,105) + dw(277,105)
      JacC(111, 72) = JacC(111, 72)+ 0.5000000000000000D+00*dw(277, 72)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(277,105)
      JacC( 79, 79) = JacC( 79, 79) - dw(278, 79)
      JacC( 79,105) = JacC( 79,105) - dw(278,105)
      JacC( 97, 79) = JacC( 97, 79)+ 0.5000000000000000D+00*dw(278, 79)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(278,105)
      JacC(100, 79) = JacC(100, 79)+ 0.5000000000000000D+00*dw(278, 79)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(278,105)
      JacC(103, 79) = JacC(103, 79)+ 0.2900000000000000D+00*dw(278, 79)
      JacC(103,105) = JacC(103,105)+ 0.2900000000000000D+00*dw(278,105)
      JacC(105, 79) = JacC(105, 79) - dw(278, 79)
      JacC(105,105) = JacC(105,105) - dw(278,105)
      JacC(107, 79) = JacC(107, 79)+ 0.1710000000000000D+01*dw(278, 79)
      JacC(107,105) = JacC(107,105)+ 0.1710000000000000D+01*dw(278,105)
      JacC(111, 79) = JacC(111, 79)+ 0.5000000000000000D+00*dw(278, 79)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(278,105)
      JacC( 59, 59) = JacC( 59, 59) - dw(279, 59)
      JacC( 59,105) = JacC( 59,105) - dw(279,105)
      JacC( 61, 59) = JacC( 61, 59)+ 0.2190000000000000D+00*dw(279, 59)
      JacC( 61,105) = JacC( 61,105)+ 0.2190000000000000D+00*dw(279,105)
      JacC( 66, 59) = JacC( 66, 59)+ 0.3050000000000000D+00*dw(279, 59)
      JacC( 66,105) = JacC( 66,105)+ 0.3050000000000000D+00*dw(279,105)
      JacC( 97, 59) = JacC( 97, 59)+ 0.5000000000000000D+00*dw(279, 59)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(279,105)
      JacC(100, 59) = JacC(100, 59)+ 0.5000000000000000D+00*dw(279, 59)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(279,105)
      JacC(105, 59) = JacC(105, 59) - dw(279, 59)
      JacC(105,105) = JacC(105,105) - dw(279,105)
      JacC(108, 59) = JacC(108, 59)+ 0.1048000000000000D+01*dw(279, 59)
      JacC(108,105) = JacC(108,105)+ 0.1048000000000000D+01*dw(279,105)
      JacC(111, 59) = JacC(111, 59)+ 0.5000000000000000D+00*dw(279, 59)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(279,105)
      JacC( 73, 95) = JacC( 73, 95)+ 0.1670000000000000D+00*dw(280, 95)
      JacC( 73,105) = JacC( 73,105)+ 0.1670000000000000D+00*dw(280,105)
      JacC( 93, 95) = JacC( 93, 95)+ 0.3300000000000000D+00*dw(280, 95)
      JacC( 93,105) = JacC( 93,105)+ 0.3300000000000000D+00*dw(280,105)
      JacC( 95, 95) = JacC( 95, 95) - dw(280, 95)
      JacC( 95,105) = JacC( 95,105) - dw(280,105)
      JacC( 96, 95) = JacC( 96, 95)+ 0.1670000000000000D+00*dw(280, 95)
      JacC( 96,105) = JacC( 96,105)+ 0.1670000000000000D+00*dw(280,105)
      JacC( 97, 95) = JacC( 97, 95)+ 0.5830000000000000D+00*dw(280, 95)
      JacC( 97,105) = JacC( 97,105)+ 0.5830000000000000D+00*dw(280,105)
      JacC(100, 95) = JacC(100, 95)+ 0.5000000000000000D+00*dw(280, 95)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(280,105)
      JacC(105, 95) = JacC(105, 95)- 0.8330000000000000D+00*dw(280, 95)
      JacC(105,105) = JacC(105,105)- 0.8330000000000000D+00*dw(280,105)
      JacC(108, 95) = JacC(108, 95) + dw(280, 95)
      JacC(108,105) = JacC(108,105) + dw(280,105)
      JacC(111, 95) = JacC(111, 95)+ 0.5000000000000000D+00*dw(280, 95)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(280,105)
      JacC( 68, 68) = JacC( 68, 68) - dw(281, 68)
      JacC( 68,105) = JacC( 68,105) - dw(281,105)
      JacC( 93, 68) = JacC( 93, 68)+ 0.5000000000000000D+00*dw(281, 68)
      JacC( 93,105) = JacC( 93,105)+ 0.5000000000000000D+00*dw(281,105)
      JacC( 97, 68) = JacC( 97, 68)+ 0.1083000000000000D+01*dw(281, 68)
      JacC( 97,105) = JacC( 97,105)+ 0.1083000000000000D+01*dw(281,105)
      JacC(100, 68) = JacC(100, 68)+ 0.5000000000000000D+00*dw(281, 68)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(281,105)
      JacC(101, 68) = JacC(101, 68)+ 0.1160000000000000D+01*dw(281, 68)
      JacC(101,105) = JacC(101,105)+ 0.1160000000000000D+01*dw(281,105)
      JacC(105, 68) = JacC(105, 68)+ 0.1599999999999999D+00*dw(281, 68)
      JacC(105,105) = JacC(105,105)+ 0.1599999999999999D+00*dw(281,105)
      JacC(107, 68) = JacC(107, 68)+ 0.2300000000000000D+01*dw(281, 68)
      JacC(107,105) = JacC(107,105)+ 0.2300000000000000D+01*dw(281,105)
      JacC(108, 68) = JacC(108, 68) + dw(281, 68)
      JacC(108,105) = JacC(108,105) + dw(281,105)
      JacC(111, 68) = JacC(111, 68)+ 0.5000000000000000D+00*dw(281, 68)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(281,105)
      JacC( 84, 84) = JacC( 84, 84) - dw(282, 84)
      JacC( 84,105) = JacC( 84,105) - dw(282,105)
      JacC( 91, 84) = JacC( 91, 84)+ 0.1800000000000000D+00*dw(282, 84)
      JacC( 91,105) = JacC( 91,105)+ 0.1800000000000000D+00*dw(282,105)
      JacC( 93, 84) = JacC( 93, 84)+ 0.1050000000000000D+00*dw(282, 84)
      JacC( 93,105) = JacC( 93,105)+ 0.1050000000000000D+00*dw(282,105)
      JacC( 96, 84) = JacC( 96, 84)+ 0.5000000000000000D+00*dw(282, 84)
      JacC( 96,105) = JacC( 96,105)+ 0.5000000000000000D+00*dw(282,105)
      JacC( 97, 84) = JacC( 97, 84)+ 0.5000000000000000D+00*dw(282, 84)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(282,105)
      JacC(100, 84) = JacC(100, 84)+ 0.5000000000000000D+00*dw(282, 84)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(282,105)
      JacC(103, 84) = JacC(103, 84)+ 0.7000000000000000D+00*dw(282, 84)
      JacC(103,105) = JacC(103,105)+ 0.7000000000000000D+00*dw(282,105)
      JacC(105, 84) = JacC(105, 84) - dw(282, 84)
      JacC(105,105) = JacC(105,105) - dw(282,105)
      JacC(107, 84) = JacC(107, 84)+ 0.2700000000000000D+00*dw(282, 84)
      JacC(107,105) = JacC(107,105)+ 0.2700000000000000D+00*dw(282,105)
      JacC(108, 84) = JacC(108, 84)+ 0.3000000000000000D-01*dw(282, 84)
      JacC(108,105) = JacC(108,105)+ 0.3000000000000000D-01*dw(282,105)
      JacC(111, 84) = JacC(111, 84)+ 0.5000000000000000D+00*dw(282, 84)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(282,105)
      JacC( 57, 57) = JacC( 57, 57) - dw(283, 57)
      JacC( 57,105) = JacC( 57,105) - dw(283,105)
      JacC( 97, 57) = JacC( 97, 57) + dw(283, 57)
      JacC( 97,105) = JacC( 97,105) + dw(283,105)
      JacC(100, 57) = JacC(100, 57)+ 0.5000000000000000D+00*dw(283, 57)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(283,105)
      JacC(103, 57) = JacC(103, 57) + dw(283, 57)
      JacC(103,105) = JacC(103,105) + dw(283,105)
      JacC(105, 57) = JacC(105, 57) - dw(283, 57)
      JacC(105,105) = JacC(105,105) - dw(283,105)
      JacC(107, 57) = JacC(107, 57) + dw(283, 57)
      JacC(107,105) = JacC(107,105) + dw(283,105)
      JacC(111, 57) = JacC(111, 57)+ 0.5000000000000000D+00*dw(283, 57)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(283,105)
      JacC( 60, 60) = JacC( 60, 60) - dw(284, 60)
      JacC( 60,105) = JacC( 60,105) - dw(284,105)
      JacC( 61, 60) = JacC( 61, 60)+ 0.3080000000000000D+00*dw(284, 60)
      JacC( 61,105) = JacC( 61,105)+ 0.3080000000000000D+00*dw(284,105)
      JacC( 69, 60) = JacC( 69, 60)+ 0.1920000000000000D+00*dw(284, 60)
      JacC( 69,105) = JacC( 69,105)+ 0.1920000000000000D+00*dw(284,105)
      JacC( 97, 60) = JacC( 97, 60)+ 0.5000000000000000D+00*dw(284, 60)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(284,105)
      JacC(100, 60) = JacC(100, 60)+ 0.5000000000000000D+00*dw(284, 60)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(284,105)
      JacC(105, 60) = JacC(105, 60) - dw(284, 60)
      JacC(105,105) = JacC(105,105) - dw(284,105)
      JacC(108, 60) = JacC(108, 60)+ 0.3850000000000000D+00*dw(284, 60)
      JacC(108,105) = JacC(108,105)+ 0.3850000000000000D+00*dw(284,105)
      JacC(111, 60) = JacC(111, 60)+ 0.5000000000000000D+00*dw(284, 60)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(284,105)
      JacC( 63, 63) = JacC( 63, 63) - dw(285, 63)
      JacC( 63,105) = JacC( 63,105) - dw(285,105)
      JacC( 69, 63) = JacC( 69, 63)+ 0.3000000000000000D+00*dw(285, 63)
      JacC( 69,105) = JacC( 69,105)+ 0.3000000000000000D+00*dw(285,105)
      JacC( 80, 63) = JacC( 80, 63)+ 0.7000000000000000D+00*dw(285, 63)
      JacC( 80,105) = JacC( 80,105)+ 0.7000000000000000D+00*dw(285,105)
      JacC( 91, 63) = JacC( 91, 63)+ 0.6000000000000000D+00*dw(285, 63)
      JacC( 91,105) = JacC( 91,105)+ 0.6000000000000000D+00*dw(285,105)
      JacC(100, 63) = JacC(100, 63) + dw(285, 63)
      JacC(100,105) = JacC(100,105) + dw(285,105)
      JacC(105, 63) = JacC(105, 63) - dw(285, 63)
      JacC(105,105) = JacC(105,105) - dw(285,105)
      JacC(111, 63) = JacC(111, 63)+ 0.6000000000000000D+00*dw(285, 63)
      JacC(111,105) = JacC(111,105)+ 0.6000000000000000D+00*dw(285,105)
      JacC( 41, 41) = JacC( 41, 41) - dw(286, 41)
      JacC( 41,105) = JacC( 41,105) - dw(286,105)
      JacC( 56, 41) = JacC( 56, 41) + dw(286, 41)
      JacC( 56,105) = JacC( 56,105) + dw(286,105)
      JacC(100, 41) = JacC(100, 41) + dw(286, 41)
      JacC(100,105) = JacC(100,105) + dw(286,105)
      JacC(105, 41) = JacC(105, 41) - dw(286, 41)
      JacC(105,105) = JacC(105,105) - dw(286,105)
      JacC(111, 41) = JacC(111, 41) + dw(286, 41)
      JacC(111,105) = JacC(111,105) + dw(286,105)
      JacC( 50, 50) = JacC( 50, 50) - dw(287, 50)
      JacC( 50,105) = JacC( 50,105) - dw(287,105)
      JacC( 53, 50) = JacC( 53, 50) + dw(287, 50)
      JacC( 53,105) = JacC( 53,105) + dw(287,105)
      JacC(100, 50) = JacC(100, 50) + dw(287, 50)
      JacC(100,105) = JacC(100,105) + dw(287,105)
      JacC(105, 50) = JacC(105, 50) - dw(287, 50)
      JacC(105,105) = JacC(105,105) - dw(287,105)
      JacC( 42, 42) = JacC( 42, 42) - dw(288, 42)
      JacC( 42,105) = JacC( 42,105) - dw(288,105)
      JacC( 77, 42) = JacC( 77, 42) + dw(288, 42)
      JacC( 77,105) = JacC( 77,105) + dw(288,105)
      JacC( 93, 42) = JacC( 93, 42) + dw(288, 42)
      JacC( 93,105) = JacC( 93,105) + dw(288,105)
      JacC(100, 42) = JacC(100, 42) + dw(288, 42)
      JacC(100,105) = JacC(100,105) + dw(288,105)
      JacC(105, 42) = JacC(105, 42) - dw(288, 42)
      JacC(105,105) = JacC(105,105) - dw(288,105)
      JacC(111, 42) = JacC(111, 42) + dw(288, 42)
      JacC(111,105) = JacC(111,105) + dw(288,105)
      JacC( 49, 49) = JacC( 49, 49) - dw(289, 49)
      JacC( 49,105) = JacC( 49,105) - dw(289,105)
      JacC( 77, 49) = JacC( 77, 49) + dw(289, 49)
      JacC( 77,105) = JacC( 77,105) + dw(289,105)
      JacC( 78, 49) = JacC( 78, 49)+ 0.2050000000000000D+01*dw(289, 49)
      JacC( 78,105) = JacC( 78,105)+ 0.2050000000000000D+01*dw(289,105)
      JacC( 93, 49) = JacC( 93, 49) + dw(289, 49)
      JacC( 93,105) = JacC( 93,105) + dw(289,105)
      JacC(100, 49) = JacC(100, 49) + dw(289, 49)
      JacC(100,105) = JacC(100,105) + dw(289,105)
      JacC(105, 49) = JacC(105, 49) - dw(289, 49)
      JacC(105,105) = JacC(105,105) - dw(289,105)
      JacC(111, 49) = JacC(111, 49) + dw(289, 49)
      JacC(111,105) = JacC(111,105) + dw(289,105)
      JacC( 45, 54) = JacC( 45, 54) + dw(290, 54)
      JacC( 45,105) = JacC( 45,105) + dw(290,105)
      JacC( 54, 54) = JacC( 54, 54) - dw(290, 54)
      JacC( 54,105) = JacC( 54,105) - dw(290,105)
      JacC(100, 54) = JacC(100, 54) + dw(290, 54)
      JacC(100,105) = JacC(100,105) + dw(290,105)
      JacC(105, 54) = JacC(105, 54) - dw(290, 54)
      JacC(105,105) = JacC(105,105) - dw(290,105)
      JacC( 45, 45) = JacC( 45, 45) - dw(291, 45)
      JacC( 45,105) = JacC( 45,105) - dw(291,105)
      JacC( 46, 45) = JacC( 46, 45) + dw(291, 45)
      JacC( 46,105) = JacC( 46,105) + dw(291,105)
      JacC(100, 45) = JacC(100, 45) + dw(291, 45)
      JacC(100,105) = JacC(100,105) + dw(291,105)
      JacC(105, 45) = JacC(105, 45) - dw(291, 45)
      JacC(105,105) = JacC(105,105) - dw(291,105)
      JacC( 55, 55) = JacC( 55, 55) - dw(292, 55)
      JacC( 55,105) = JacC( 55,105) - dw(292,105)
      JacC( 56, 55) = JacC( 56, 55)+ 0.7700000000000000D-01*dw(292, 55)
      JacC( 56,105) = JacC( 56,105)+ 0.7700000000000000D-01*dw(292,105)
      JacC( 77, 55) = JacC( 77, 55)+ 0.7370000000000000D+00*dw(292, 55)
      JacC( 77,105) = JacC( 77,105)+ 0.7370000000000000D+00*dw(292,105)
      JacC( 78, 55) = JacC( 78, 55)+ 0.1860000000000000D+00*dw(292, 55)
      JacC( 78,105) = JacC( 78,105)+ 0.1860000000000000D+00*dw(292,105)
      JacC( 91, 55) = JacC( 91, 55)+ 0.3680000000000000D+00*dw(292, 55)
      JacC( 91,105) = JacC( 91,105)+ 0.3680000000000000D+00*dw(292,105)
      JacC( 93, 55) = JacC( 93, 55)+ 0.6320000000000000D+00*dw(292, 55)
      JacC( 93,105) = JacC( 93,105)+ 0.6320000000000000D+00*dw(292,105)
      JacC(100, 55) = JacC(100, 55) + dw(292, 55)
      JacC(100,105) = JacC(100,105) + dw(292,105)
      JacC(105, 55) = JacC(105, 55) - dw(292, 55)
      JacC(105,105) = JacC(105,105) - dw(292,105)
      JacC(111, 55) = JacC(111, 55) + dw(292, 55)
      JacC(111,105) = JacC(111,105) + dw(292,105)
      JacC( 52, 52) = JacC( 52, 52) - dw(293, 52)
      JacC( 52,105) = JacC( 52,105) - dw(293,105)
      JacC( 53, 52) = JacC( 53, 52) + dw(293, 52)
      JacC( 53,105) = JacC( 53,105) + dw(293,105)
      JacC(100, 52) = JacC(100, 52) + dw(293, 52)
      JacC(100,105) = JacC(100,105) + dw(293,105)
      JacC(105, 52) = JacC(105, 52) - dw(293, 52)
      JacC(105,105) = JacC(105,105) - dw(293,105)
      JacC( 43, 43) = JacC( 43, 43) - dw(294, 43)
      JacC( 43,105) = JacC( 43,105) - dw(294,105)
      JacC( 56, 43) = JacC( 56, 43) + dw(294, 43)
      JacC( 56,105) = JacC( 56,105) + dw(294,105)
      JacC(100, 43) = JacC(100, 43) + dw(294, 43)
      JacC(100,105) = JacC(100,105) + dw(294,105)
      JacC(105, 43) = JacC(105, 43) - dw(294, 43)
      JacC(105,105) = JacC(105,105) - dw(294,105)
      JacC(111, 43) = JacC(111, 43) + dw(294, 43)
      JacC(111,105) = JacC(111,105) + dw(294,105)
      JacC( 75, 75) = JacC( 75, 75) - dw(295, 75)
      JacC( 75,105) = JacC( 75,105) - dw(295,105)
      JacC( 76, 75) = JacC( 76, 75)+ 0.3200000000000000D+00*dw(295, 75)
      JacC( 76,105) = JacC( 76,105)+ 0.3200000000000000D+00*dw(295,105)
      JacC( 91, 75) = JacC( 91, 75)+ 0.6800000000000000D+00*dw(295, 75)
      JacC( 91,105) = JacC( 91,105)+ 0.6800000000000000D+00*dw(295,105)
      JacC(100, 75) = JacC(100, 75) + dw(295, 75)
      JacC(100,105) = JacC(100,105) + dw(295,105)
      JacC(105, 75) = JacC(105, 75) - dw(295, 75)
      JacC(105,105) = JacC(105,105) - dw(295,105)
      JacC(106, 75) = JacC(106, 75)+ 0.6800000000000000D+00*dw(295, 75)
      JacC(106,105) = JacC(106,105)+ 0.6800000000000000D+00*dw(295,105)
      JacC(111, 75) = JacC(111, 75)+ 0.2000000000000000D+01*dw(295, 75)
      JacC(111,105) = JacC(111,105)+ 0.2000000000000000D+01*dw(295,105)
      JacC(100,105) = JacC(100,105)+ 0.2000000000000000D+01*dw(296,105)
      JacC(100,105) = JacC(100,105)+ 0.2000000000000000D+01*dw(296,105)
      JacC(105,105) = JacC(105,105)- 0.2000000000000000D+01*dw(296,105)
      JacC(105,105) = JacC(105,105)- 0.2000000000000000D+01*dw(296,105)
      JacC( 98, 98) = JacC( 98, 98)- 0.2000000000000000D+01*dw(297, 98)
      JacC( 98, 98) = JacC( 98, 98)- 0.2000000000000000D+01*dw(297, 98)
      JacC(104, 98) = JacC(104, 98)+ 0.2000000000000000D+01*dw(297, 98)
      JacC(104, 98) = JacC(104, 98)+ 0.2000000000000000D+01*dw(297, 98)
      JacC( 77, 92) = JacC( 77, 92)+ 0.5000000000000000D+00*dw(298, 92)
      JacC( 77,105) = JacC( 77,105)+ 0.5000000000000000D+00*dw(298,105)
      JacC( 92, 92) = JacC( 92, 92) - dw(298, 92)
      JacC( 92,105) = JacC( 92,105) - dw(298,105)
      JacC( 97, 92) = JacC( 97, 92)+ 0.5000000000000000D+00*dw(298, 92)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(298,105)
      JacC(100, 92) = JacC(100, 92)+ 0.5000000000000000D+00*dw(298, 92)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(298,105)
      JacC(105, 92) = JacC(105, 92) - dw(298, 92)
      JacC(105,105) = JacC(105,105) - dw(298,105)
      JacC(111, 92) = JacC(111, 92)+ 0.5000000000000000D+00*dw(298, 92)
      JacC(111,105) = JacC(111,105)+ 0.5000000000000000D+00*dw(298,105)
      JacC( 65, 65) = JacC( 65, 65) - dw(299, 65)
      JacC( 65,105) = JacC( 65,105) - dw(299,105)
      JacC( 97, 65) = JacC( 97, 65)+ 0.7500000000000000D+00*dw(299, 65)
      JacC( 97,105) = JacC( 97,105)+ 0.7500000000000000D+00*dw(299,105)
      JacC(100, 65) = JacC(100, 65)+ 0.5000000000000000D+00*dw(299, 65)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(299,105)
      JacC(105, 65) = JacC(105, 65)- 0.5000000000000000D+00*dw(299, 65)
      JacC(105,105) = JacC(105,105)- 0.5000000000000000D+00*dw(299,105)
      JacC(108, 65) = JacC(108, 65) + dw(299, 65)
      JacC(108,105) = JacC(108,105) + dw(299,105)
      JacC( 64, 64) = JacC( 64, 64) - dw(300, 64)
      JacC( 64,105) = JacC( 64,105) - dw(300,105)
      JacC( 77, 64) = JacC( 77, 64)+ 0.3340000000000000D+00*dw(300, 64)
      JacC( 77,105) = JacC( 77,105)+ 0.3340000000000000D+00*dw(300,105)
      JacC( 97, 64) = JacC( 97, 64)+ 0.5000000000000000D+00*dw(300, 64)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(300,105)
      JacC(100, 64) = JacC(100, 64)+ 0.5000000000000000D+00*dw(300, 64)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(300,105)
      JacC(105, 64) = JacC(105, 64) - dw(300, 64)
      JacC(105,105) = JacC(105,105) - dw(300,105)
      JacC(108, 64) = JacC(108, 64)+ 0.3300000000000000D+00*dw(300, 64)
      JacC(108,105) = JacC(108,105)+ 0.3300000000000000D+00*dw(300,105)
      JacC(111, 64) = JacC(111, 64)+ 0.3300000000000000D+00*dw(300, 64)
      JacC(111,105) = JacC(111,105)+ 0.3300000000000000D+00*dw(300,105)
      JacC( 71, 71) = JacC( 71, 71) - dw(301, 71)
      JacC( 71,105) = JacC( 71,105) - dw(301,105)
      JacC(100, 71) = JacC(100, 71) + dw(301, 71)
      JacC(100,105) = JacC(100,105) + dw(301,105)
      JacC(105, 71) = JacC(105, 71) - dw(301, 71)
      JacC(105,105) = JacC(105,105) - dw(301,105)
      JacC(111, 71) = JacC(111, 71) + dw(301, 71)
      JacC(111,105) = JacC(111,105) + dw(301,105)
      JacC(113, 71) = JacC(113, 71) + dw(301, 71)
      JacC(113,105) = JacC(113,105) + dw(301,105)
      JacC( 70, 70) = JacC( 70, 70) - dw(302, 70)
      JacC( 70,105) = JacC( 70,105) - dw(302,105)
      JacC( 97, 70) = JacC( 97, 70)+ 0.5000000000000000D+00*dw(302, 70)
      JacC( 97,105) = JacC( 97,105)+ 0.5000000000000000D+00*dw(302,105)
      JacC(100, 70) = JacC(100, 70)+ 0.5000000000000000D+00*dw(302, 70)
      JacC(100,105) = JacC(100,105)+ 0.5000000000000000D+00*dw(302,105)
      JacC(103, 70) = JacC(103, 70)+ 0.4640000000000000D+00*dw(302, 70)
      JacC(103,105) = JacC(103,105)+ 0.4640000000000000D+00*dw(302,105)
      JacC(105, 70) = JacC(105, 70) - dw(302, 70)
      JacC(105,105) = JacC(105,105) - dw(302,105)
      JacC(107, 70) = JacC(107, 70)+ 0.1240000000000000D+01*dw(302, 70)
      JacC(107,105) = JacC(107,105)+ 0.1240000000000000D+01*dw(302,105)
      JacC(108, 70) = JacC(108, 70)+ 0.2870000000000000D+00*dw(302, 70)
      JacC(108,105) = JacC(108,105)+ 0.2870000000000000D+00*dw(302,105)
      JacC(110, 70) = JacC(110, 70) + dw(302, 70)
      JacC(110,105) = JacC(110,105) + dw(302,105)
      JacC( 71, 71) = JacC( 71, 71)- 0.2000000000000000D+01*dw(303, 71)
      JacC( 71, 71) = JacC( 71, 71)- 0.2000000000000000D+01*dw(303, 71)
      JacC(111, 71) = JacC(111, 71) + dw(303, 71)
      JacC(111, 71) = JacC(111, 71) + dw(303, 71)
      JacC(113, 71) = JacC(113, 71)+ 0.2000000000000000D+01*dw(303, 71)
      JacC(113, 71) = JacC(113, 71)+ 0.2000000000000000D+01*dw(303, 71)
      JacC( 70, 71) = JacC( 70, 71) - dw(304, 71)
      JacC( 70, 70) = JacC( 70, 70) - dw(304, 70)
      JacC( 71, 71) = JacC( 71, 71) - dw(304, 71)
      JacC( 71, 70) = JacC( 71, 70) - dw(304, 70)
      JacC(103, 71) = JacC(103, 71)+ 0.1490000000000000D+00*dw(304, 71)
      JacC(103, 70) = JacC(103, 70)+ 0.1490000000000000D+00*dw(304, 70)
      JacC(107, 71) = JacC(107, 71)+ 0.6400000000000000D+00*dw(304, 71)
      JacC(107, 70) = JacC(107, 70)+ 0.6400000000000000D+00*dw(304, 70)
      JacC(108, 71) = JacC(108, 71)+ 0.2020000000000000D+00*dw(304, 71)
      JacC(108, 70) = JacC(108, 70)+ 0.2020000000000000D+00*dw(304, 70)
      JacC(110, 71) = JacC(110, 71)+ 0.5000000000000000D+00*dw(304, 71)
      JacC(110, 70) = JacC(110, 70)+ 0.5000000000000000D+00*dw(304, 70)
      JacC(111, 71) = JacC(111, 71)+ 0.5000000000000000D+00*dw(304, 71)
      JacC(111, 70) = JacC(111, 70)+ 0.5000000000000000D+00*dw(304, 70)
      JacC(113, 71) = JacC(113, 71)+ 0.1500000000000000D+01*dw(304, 71)
      JacC(113, 70) = JacC(113, 70)+ 0.1500000000000000D+01*dw(304, 70)
      JacC( 70, 70) = JacC( 70, 70)- 0.2000000000000000D+01*dw(305, 70)
      JacC( 70, 70) = JacC( 70, 70)- 0.2000000000000000D+01*dw(305, 70)
      JacC(103, 70) = JacC(103, 70)+ 0.2850000000000000D+00*dw(305, 70)
      JacC(103, 70) = JacC(103, 70)+ 0.2850000000000000D+00*dw(305, 70)
      JacC(107, 70) = JacC(107, 70)+ 0.1210000000000000D+01*dw(305, 70)
      JacC(107, 70) = JacC(107, 70)+ 0.1210000000000000D+01*dw(305, 70)
      JacC(108, 70) = JacC(108, 70)+ 0.5040000000000000D+00*dw(305, 70)
      JacC(108, 70) = JacC(108, 70)+ 0.5040000000000000D+00*dw(305, 70)
      JacC(110, 70) = JacC(110, 70) + dw(305, 70)
      JacC(110, 70) = JacC(110, 70) + dw(305, 70)
      JacC(113, 70) = JacC(113, 70) + dw(305, 70)
      JacC(113, 70) = JacC(113, 70) + dw(305, 70)
      JacC(100,100) = JacC(100,100) - dw(306,100)
      JacC(100,109) = JacC(100,109) - dw(306,109)
      JacC(108,100) = JacC(108,100) + dw(306,100)
      JacC(108,109) = JacC(108,109) + dw(306,109)
      JacC(109,100) = JacC(109,100) - dw(306,100)
      JacC(109,109) = JacC(109,109) - dw(306,109)
      JacC(110,100) = JacC(110,100) + dw(306,100)
      JacC(110,109) = JacC(110,109) + dw(306,109)
      JacC(111,100) = JacC(111,100) + dw(306,100)
      JacC(111,109) = JacC(111,109) + dw(306,109)
      JacC( 87,104) = JacC( 87,104) + dw(307,104)
      JacC( 87,109) = JacC( 87,109) + dw(307,109)
      JacC(104,104) = JacC(104,104) - dw(307,104)
      JacC(104,109) = JacC(104,109) - dw(307,109)
      JacC(109,104) = JacC(109,104) - dw(307,104)
      JacC(109,109) = JacC(109,109) - dw(307,109)
      JacC(110,104) = JacC(110,104) + dw(307,104)
      JacC(110,109) = JacC(110,109) + dw(307,109)
      JacC(111,104) = JacC(111,104) + dw(307,104)
      JacC(111,109) = JacC(111,109) + dw(307,109)
      JacC( 91, 99) = JacC( 91, 99)+ 0.6700000000000000D-01*dw(308, 99)
      JacC( 91,109) = JacC( 91,109)+ 0.6700000000000000D-01*dw(308,109)
      JacC( 99, 99) = JacC( 99, 99) - dw(308, 99)
      JacC( 99,109) = JacC( 99,109) - dw(308,109)
      JacC(100, 99) = JacC(100, 99)+ 0.1590000000000000D+00*dw(308, 99)
      JacC(100,109) = JacC(100,109)+ 0.1590000000000000D+00*dw(308,109)
      JacC(101, 99) = JacC(101, 99)+ 0.5100000000000000D-01*dw(308, 99)
      JacC(101,109) = JacC(101,109)+ 0.5100000000000000D-01*dw(308,109)
      JacC(103, 99) = JacC(103, 99)+ 0.6620000000000000D+00*dw(308, 99)
      JacC(103,109) = JacC(103,109)+ 0.6620000000000000D+00*dw(308,109)
      JacC(104, 99) = JacC(104, 99)+ 0.5100000000000000D-01*dw(308, 99)
      JacC(104,109) = JacC(104,109)+ 0.5100000000000000D-01*dw(308,109)
      JacC(107, 99) = JacC(107, 99)+ 0.2480000000000000D+00*dw(308, 99)
      JacC(107,109) = JacC(107,109)+ 0.2480000000000000D+00*dw(308,109)
      JacC(108, 99) = JacC(108, 99)+ 0.5000000000000000D-01*dw(308, 99)
      JacC(108,109) = JacC(108,109)+ 0.5000000000000000D-01*dw(308,109)
      JacC(109, 99) = JacC(109, 99) - dw(308, 99)
      JacC(109,109) = JacC(109,109) - dw(308,109)
      JacC(110, 99) = JacC(110, 99) + dw(308, 99)
      JacC(110,109) = JacC(110,109) + dw(308,109)
      JacC(111, 99) = JacC(111, 99)+ 0.7890000000000000D+00*dw(308, 99)
      JacC(111,109) = JacC(111,109)+ 0.7890000000000000D+00*dw(308,109)
      JacC( 86, 86) = JacC( 86, 86) - dw(309, 86)
      JacC( 86,109) = JacC( 86,109) - dw(309,109)
      JacC(100, 86) = JacC(100, 86)+ 0.3500000000000000D-01*dw(309, 86)
      JacC(100,109) = JacC(100,109)+ 0.3500000000000000D-01*dw(309,109)
      JacC(101, 86) = JacC(101, 86)+ 0.3810000000000000D+00*dw(309, 86)
      JacC(101,109) = JacC(101,109)+ 0.3810000000000000D+00*dw(309,109)
      JacC(103, 86) = JacC(103, 86)+ 0.8240000000000000D+00*dw(309, 86)
      JacC(103,109) = JacC(103,109)+ 0.8240000000000000D+00*dw(309,109)
      JacC(104, 86) = JacC(104, 86)+ 0.2800000000000000D+00*dw(309, 86)
      JacC(104,109) = JacC(104,109)+ 0.2800000000000000D+00*dw(309,109)
      JacC(107, 86) = JacC(107, 86)+ 0.2410000000000000D+00*dw(309, 86)
      JacC(107,109) = JacC(107,109)+ 0.2410000000000000D+00*dw(309,109)
      JacC(108, 86) = JacC(108, 86)+ 0.2400000000000000D-01*dw(309, 86)
      JacC(108,109) = JacC(108,109)+ 0.2400000000000000D-01*dw(309,109)
      JacC(109, 86) = JacC(109, 86) - dw(309, 86)
      JacC(109,109) = JacC(109,109) - dw(309,109)
      JacC(110, 86) = JacC(110, 86) + dw(309, 86)
      JacC(110,109) = JacC(110,109) + dw(309,109)
      JacC(111, 86) = JacC(111, 86)+ 0.6840000000000001D+00*dw(309, 86)
      JacC(111,109) = JacC(111,109)+ 0.6840000000000001D+00*dw(309,109)
      JacC( 62, 62) = JacC( 62, 62) - dw(310, 62)
      JacC( 62,109) = JacC( 62,109) - dw(310,109)
      JacC(101, 62) = JacC(101, 62)+ 0.5629999999999999D+00*dw(310, 62)
      JacC(101,109) = JacC(101,109)+ 0.5629999999999999D+00*dw(310,109)
      JacC(103, 62) = JacC(103, 62)+ 0.8690000000000000D+00*dw(310, 62)
      JacC(103,109) = JacC(103,109)+ 0.8690000000000000D+00*dw(310,109)
      JacC(104, 62) = JacC(104, 62)+ 0.1800000000000000D+00*dw(310, 62)
      JacC(104,109) = JacC(104,109)+ 0.1800000000000000D+00*dw(310,109)
      JacC(107, 62) = JacC(107, 62)+ 0.2030000000000000D+00*dw(310, 62)
      JacC(107,109) = JacC(107,109)+ 0.2030000000000000D+00*dw(310,109)
      JacC(109, 62) = JacC(109, 62) - dw(310, 62)
      JacC(109,109) = JacC(109,109) - dw(310,109)
      JacC(110, 62) = JacC(110, 62) + dw(310, 62)
      JacC(110,109) = JacC(110,109) + dw(310,109)
      JacC(111, 62) = JacC(111, 62)+ 0.8200000000000000D+00*dw(310, 62)
      JacC(111,109) = JacC(111,109)+ 0.8200000000000000D+00*dw(310,109)
      JacC( 88, 88) = JacC( 88, 88) - dw(311, 88)
      JacC( 88,109) = JacC( 88,109) - dw(311,109)
      JacC(107, 88) = JacC(107, 88)+ 0.2000000000000000D+00*dw(311, 88)
      JacC(107,109) = JacC(107,109)+ 0.2000000000000000D+00*dw(311,109)
      JacC(108, 88) = JacC(108, 88)+ 0.1600000000000000D+01*dw(311, 88)
      JacC(108,109) = JacC(108,109)+ 0.1600000000000000D+01*dw(311,109)
      JacC(109, 88) = JacC(109, 88) - dw(311, 88)
      JacC(109,109) = JacC(109,109) - dw(311,109)
      JacC(110, 88) = JacC(110, 88) + dw(311, 88)
      JacC(110,109) = JacC(110,109) + dw(311,109)
      JacC(111, 88) = JacC(111, 88) + dw(311, 88)
      JacC(111,109) = JacC(111,109) + dw(311,109)
      JacC( 72, 72) = JacC( 72, 72) - dw(312, 72)
      JacC( 72,109) = JacC( 72,109) - dw(312,109)
      JacC(103, 72) = JacC(103, 72)+ 0.6000000000000000D-01*dw(312, 72)
      JacC(103,109) = JacC(103,109)+ 0.6000000000000000D-01*dw(312,109)
      JacC(107, 72) = JacC(107, 72)+ 0.9399999999999999D+00*dw(312, 72)
      JacC(107,109) = JacC(107,109)+ 0.9399999999999999D+00*dw(312,109)
      JacC(108, 72) = JacC(108, 72) + dw(312, 72)
      JacC(108,109) = JacC(108,109) + dw(312,109)
      JacC(109, 72) = JacC(109, 72) - dw(312, 72)
      JacC(109,109) = JacC(109,109) - dw(312,109)
      JacC(110, 72) = JacC(110, 72) + dw(312, 72)
      JacC(110,109) = JacC(110,109) + dw(312,109)
      JacC(111, 72) = JacC(111, 72) + dw(312, 72)
      JacC(111,109) = JacC(111,109) + dw(312,109)
      JacC( 79, 79) = JacC( 79, 79) - dw(313, 79)
      JacC( 79,109) = JacC( 79,109) - dw(313,109)
      JacC(103, 79) = JacC(103, 79)+ 0.2900000000000000D+00*dw(313, 79)
      JacC(103,109) = JacC(103,109)+ 0.2900000000000000D+00*dw(313,109)
      JacC(107, 79) = JacC(107, 79)+ 0.1710000000000000D+01*dw(313, 79)
      JacC(107,109) = JacC(107,109)+ 0.1710000000000000D+01*dw(313,109)
      JacC(109, 79) = JacC(109, 79) - dw(313, 79)
      JacC(109,109) = JacC(109,109) - dw(313,109)
      JacC(110, 79) = JacC(110, 79) + dw(313, 79)
      JacC(110,109) = JacC(110,109) + dw(313,109)
      JacC(111, 79) = JacC(111, 79) + dw(313, 79)
      JacC(111,109) = JacC(111,109) + dw(313,109)
      JacC( 59, 59) = JacC( 59, 59) - dw(314, 59)
      JacC( 59,109) = JacC( 59,109) - dw(314,109)
      JacC( 61, 59) = JacC( 61, 59)+ 0.4380000000000000D+00*dw(314, 59)
      JacC( 61,109) = JacC( 61,109)+ 0.4380000000000000D+00*dw(314,109)
      JacC( 66, 59) = JacC( 66, 59)+ 0.6100000000000000D+00*dw(314, 59)
      JacC( 66,109) = JacC( 66,109)+ 0.6100000000000000D+00*dw(314,109)
      JacC(108, 59) = JacC(108, 59)+ 0.1050000000000000D+01*dw(314, 59)
      JacC(108,109) = JacC(108,109)+ 0.1050000000000000D+01*dw(314,109)
      JacC(109, 59) = JacC(109, 59) - dw(314, 59)
      JacC(109,109) = JacC(109,109) - dw(314,109)
      JacC(110, 59) = JacC(110, 59) + dw(314, 59)
      JacC(110,109) = JacC(110,109) + dw(314,109)
      JacC(111, 59) = JacC(111, 59) + dw(314, 59)
      JacC(111,109) = JacC(111,109) + dw(314,109)
      JacC( 57, 57) = JacC( 57, 57) - dw(315, 57)
      JacC( 57,109) = JacC( 57,109) - dw(315,109)
      JacC(103, 57) = JacC(103, 57) + dw(315, 57)
      JacC(103,109) = JacC(103,109) + dw(315,109)
      JacC(107, 57) = JacC(107, 57) + dw(315, 57)
      JacC(107,109) = JacC(107,109) + dw(315,109)
      JacC(109, 57) = JacC(109, 57) - dw(315, 57)
      JacC(109,109) = JacC(109,109) - dw(315,109)
      JacC(110, 57) = JacC(110, 57) + dw(315, 57)
      JacC(110,109) = JacC(110,109) + dw(315,109)
      JacC(111, 57) = JacC(111, 57) + dw(315, 57)
      JacC(111,109) = JacC(111,109) + dw(315,109)
      JacC( 60, 60) = JacC( 60, 60) - dw(316, 60)
      JacC( 60,109) = JacC( 60,109) - dw(316,109)
      JacC( 61, 60) = JacC( 61, 60)+ 0.6150000000000000D+00*dw(316, 60)
      JacC( 61,109) = JacC( 61,109)+ 0.6150000000000000D+00*dw(316,109)
      JacC( 69, 60) = JacC( 69, 60)+ 0.3850000000000000D+00*dw(316, 60)
      JacC( 69,109) = JacC( 69,109)+ 0.3850000000000000D+00*dw(316,109)
      JacC(108, 60) = JacC(108, 60)+ 0.3850000000000000D+00*dw(316, 60)
      JacC(108,109) = JacC(108,109)+ 0.3850000000000000D+00*dw(316,109)
      JacC(109, 60) = JacC(109, 60) - dw(316, 60)
      JacC(109,109) = JacC(109,109) - dw(316,109)
      JacC(110, 60) = JacC(110, 60) + dw(316, 60)
      JacC(110,109) = JacC(110,109) + dw(316,109)
      JacC(111, 60) = JacC(111, 60) + dw(316, 60)
      JacC(111,109) = JacC(111,109) + dw(316,109)
      JacC( 63, 63) = JacC( 63, 63) - dw(317, 63)
      JacC( 63,109) = JacC( 63,109) - dw(317,109)
      JacC( 69, 63) = JacC( 69, 63)+ 0.5000000000000000D+00*dw(317, 63)
      JacC( 69,109) = JacC( 69,109)+ 0.5000000000000000D+00*dw(317,109)
      JacC( 80, 63) = JacC( 80, 63)+ 0.5000000000000000D+00*dw(317, 63)
      JacC( 80,109) = JacC( 80,109)+ 0.5000000000000000D+00*dw(317,109)
      JacC( 91, 63) = JacC( 91, 63) + dw(317, 63)
      JacC( 91,109) = JacC( 91,109) + dw(317,109)
      JacC(109, 63) = JacC(109, 63) - dw(317, 63)
      JacC(109,109) = JacC(109,109) - dw(317,109)
      JacC(110, 63) = JacC(110, 63) + dw(317, 63)
      JacC(110,109) = JacC(110,109) + dw(317,109)
      JacC(111, 63) = JacC(111, 63) + dw(317, 63)
      JacC(111,109) = JacC(111,109) + dw(317,109)
      JacC( 55, 55) = JacC( 55, 55) - dw(318, 55)
      JacC( 55,109) = JacC( 55,109) - dw(318,109)
      JacC( 56, 55) = JacC( 56, 55)+ 0.7700000000000000D-01*dw(318, 55)
      JacC( 56,109) = JacC( 56,109)+ 0.7700000000000000D-01*dw(318,109)
      JacC( 77, 55) = JacC( 77, 55)+ 0.7370000000000000D+00*dw(318, 55)
      JacC( 77,109) = JacC( 77,109)+ 0.7370000000000000D+00*dw(318,109)
      JacC( 78, 55) = JacC( 78, 55)+ 0.1860000000000000D+00*dw(318, 55)
      JacC( 78,109) = JacC( 78,109)+ 0.1860000000000000D+00*dw(318,109)
      JacC( 91, 55) = JacC( 91, 55)+ 0.3680000000000000D+00*dw(318, 55)
      JacC( 91,109) = JacC( 91,109)+ 0.3680000000000000D+00*dw(318,109)
      JacC( 93, 55) = JacC( 93, 55)+ 0.6320000000000000D+00*dw(318, 55)
      JacC( 93,109) = JacC( 93,109)+ 0.6320000000000000D+00*dw(318,109)
      JacC(109, 55) = JacC(109, 55) - dw(318, 55)
      JacC(109,109) = JacC(109,109) - dw(318,109)
      JacC(110, 55) = JacC(110, 55) + dw(318, 55)
      JacC(110,109) = JacC(110,109) + dw(318,109)
      JacC(111, 55) = JacC(111, 55) + dw(318, 55)
      JacC(111,109) = JacC(111,109) + dw(318,109)
      JacC( 75, 75) = JacC( 75, 75) - dw(319, 75)
      JacC( 75,109) = JacC( 75,109) - dw(319,109)
      JacC( 76, 75) = JacC( 76, 75)+ 0.3200000000000000D+00*dw(319, 75)
      JacC( 76,109) = JacC( 76,109)+ 0.3200000000000000D+00*dw(319,109)
      JacC( 91, 75) = JacC( 91, 75)+ 0.6800000000000000D+00*dw(319, 75)
      JacC( 91,109) = JacC( 91,109)+ 0.6800000000000000D+00*dw(319,109)
      JacC(106, 75) = JacC(106, 75)+ 0.6800000000000000D+00*dw(319, 75)
      JacC(106,109) = JacC(106,109)+ 0.6800000000000000D+00*dw(319,109)
      JacC(109, 75) = JacC(109, 75) - dw(319, 75)
      JacC(109,109) = JacC(109,109) - dw(319,109)
      JacC(110, 75) = JacC(110, 75) + dw(319, 75)
      JacC(110,109) = JacC(110,109) + dw(319,109)
      JacC(111, 75) = JacC(111, 75) + dw(319, 75)
      JacC(111,109) = JacC(111,109) + dw(319,109)
      JacC(100,105) = JacC(100,105) + dw(320,105)
      JacC(100,109) = JacC(100,109) + dw(320,109)
      JacC(105,105) = JacC(105,105) - dw(320,105)
      JacC(105,109) = JacC(105,109) - dw(320,109)
      JacC(109,105) = JacC(109,105) - dw(320,105)
      JacC(109,109) = JacC(109,109) - dw(320,109)
      JacC(110,105) = JacC(110,105) + dw(320,105)
      JacC(110,109) = JacC(110,109) + dw(320,109)
      JacC( 98, 98) = JacC( 98, 98) - dw(321, 98)
      JacC( 98,109) = JacC( 98,109) - dw(321,109)
      JacC(104, 98) = JacC(104, 98) + dw(321, 98)
      JacC(104,109) = JacC(104,109) + dw(321,109)
      JacC(109, 98) = JacC(109, 98) - dw(321, 98)
      JacC(109,109) = JacC(109,109) - dw(321,109)
      JacC(110, 98) = JacC(110, 98) + dw(321, 98)
      JacC(110,109) = JacC(110,109) + dw(321,109)
      JacC( 64, 64) = JacC( 64, 64) - dw(322, 64)
      JacC( 64,109) = JacC( 64,109) - dw(322,109)
      JacC( 77, 64) = JacC( 77, 64)+ 0.6700000000000000D+00*dw(322, 64)
      JacC( 77,109) = JacC( 77,109)+ 0.6700000000000000D+00*dw(322,109)
      JacC(108, 64) = JacC(108, 64)+ 0.3300000000000000D+00*dw(322, 64)
      JacC(108,109) = JacC(108,109)+ 0.3300000000000000D+00*dw(322,109)
      JacC(109, 64) = JacC(109, 64) - dw(322, 64)
      JacC(109,109) = JacC(109,109) - dw(322,109)
      JacC(110, 64) = JacC(110, 64) + dw(322, 64)
      JacC(110,109) = JacC(110,109) + dw(322,109)
      JacC(111, 64) = JacC(111, 64)+ 0.6700000000000000D+00*dw(322, 64)
      JacC(111,109) = JacC(111,109)+ 0.6700000000000000D+00*dw(322,109)
      JacC( 77, 92) = JacC( 77, 92) + dw(323, 92)
      JacC( 77,109) = JacC( 77,109) + dw(323,109)
      JacC( 92, 92) = JacC( 92, 92) - dw(323, 92)
      JacC( 92,109) = JacC( 92,109) - dw(323,109)
      JacC(109, 92) = JacC(109, 92) - dw(323, 92)
      JacC(109,109) = JacC(109,109) - dw(323,109)
      JacC(110, 92) = JacC(110, 92) + dw(323, 92)
      JacC(110,109) = JacC(110,109) + dw(323,109)
      JacC(111, 92) = JacC(111, 92) + dw(323, 92)
      JacC(111,109) = JacC(111,109) + dw(323,109)
      JacC( 65, 65) = JacC( 65, 65) - dw(324, 65)
      JacC( 65,109) = JacC( 65,109) - dw(324,109)
      JacC(105, 65) = JacC(105, 65) + dw(324, 65)
      JacC(105,109) = JacC(105,109) + dw(324,109)
      JacC(108, 65) = JacC(108, 65) + dw(324, 65)
      JacC(108,109) = JacC(108,109) + dw(324,109)
      JacC(109, 65) = JacC(109, 65) - dw(324, 65)
      JacC(109,109) = JacC(109,109) - dw(324,109)
      JacC(110, 65) = JacC(110, 65) + dw(324, 65)
      JacC(110,109) = JacC(110,109) + dw(324,109)
      JacC( 71, 71) = JacC( 71, 71) - dw(325, 71)
      JacC( 71,109) = JacC( 71,109) - dw(325,109)
      JacC(109, 71) = JacC(109, 71) - dw(325, 71)
      JacC(109,109) = JacC(109,109) - dw(325,109)
      JacC(110, 71) = JacC(110, 71) + dw(325, 71)
      JacC(110,109) = JacC(110,109) + dw(325,109)
      JacC(111, 71) = JacC(111, 71) + dw(325, 71)
      JacC(111,109) = JacC(111,109) + dw(325,109)
      JacC(113, 71) = JacC(113, 71) + dw(325, 71)
      JacC(113,109) = JacC(113,109) + dw(325,109)
      JacC( 70, 70) = JacC( 70, 70) - dw(326, 70)
      JacC( 70,109) = JacC( 70,109) - dw(326,109)
      JacC(103, 70) = JacC(103, 70)+ 0.4640000000000000D+00*dw(326, 70)
      JacC(103,109) = JacC(103,109)+ 0.4640000000000000D+00*dw(326,109)
      JacC(107, 70) = JacC(107, 70)+ 0.1240000000000000D+01*dw(326, 70)
      JacC(107,109) = JacC(107,109)+ 0.1240000000000000D+01*dw(326,109)
      JacC(108, 70) = JacC(108, 70)+ 0.2870000000000000D+00*dw(326, 70)
      JacC(108,109) = JacC(108,109)+ 0.2870000000000000D+00*dw(326,109)
      JacC(109, 70) = JacC(109, 70) - dw(326, 70)
      JacC(109,109) = JacC(109,109) - dw(326,109)
      JacC(110, 70) = JacC(110, 70)+ 0.2000000000000000D+01*dw(326, 70)
      JacC(110,109) = JacC(110,109)+ 0.2000000000000000D+01*dw(326,109)
      JacC( 68, 68) = JacC( 68, 68) - dw(327, 68)
      JacC( 68,109) = JacC( 68,109) - dw(327,109)
      JacC( 93, 68) = JacC( 93, 68) + dw(327, 68)
      JacC( 93,109) = JacC( 93,109) + dw(327,109)
      JacC(101, 68) = JacC(101, 68)+ 0.2300000000000000D+01*dw(327, 68)
      JacC(101,109) = JacC(101,109)+ 0.2300000000000000D+01*dw(327,109)
      JacC(105, 68) = JacC(105, 68)+ 0.2300000000000000D+01*dw(327, 68)
      JacC(105,109) = JacC(105,109)+ 0.2300000000000000D+01*dw(327,109)
      JacC(107, 68) = JacC(107, 68)+ 0.7000000000000000D+00*dw(327, 68)
      JacC(107,109) = JacC(107,109)+ 0.7000000000000000D+00*dw(327,109)
      JacC(108, 68) = JacC(108, 68)+ 0.3000000000000000D+00*dw(327, 68)
      JacC(108,109) = JacC(108,109)+ 0.3000000000000000D+00*dw(327,109)
      JacC(109, 68) = JacC(109, 68) - dw(327, 68)
      JacC(109,109) = JacC(109,109) - dw(327,109)
      JacC(110, 68) = JacC(110, 68) + dw(327, 68)
      JacC(110,109) = JacC(110,109) + dw(327,109)
      JacC(111, 68) = JacC(111, 68) + dw(327, 68)
      JacC(111,109) = JacC(111,109) + dw(327,109)
      JacC( 73, 95) = JacC( 73, 95)+ 0.3300000000000000D+00*dw(328, 95)
      JacC( 73,109) = JacC( 73,109)+ 0.3300000000000000D+00*dw(328,109)
      JacC( 93, 95) = JacC( 93, 95)+ 0.6670000000000000D+00*dw(328, 95)
      JacC( 93,109) = JacC( 93,109)+ 0.6670000000000000D+00*dw(328,109)
      JacC( 95, 95) = JacC( 95, 95) - dw(328, 95)
      JacC( 95,109) = JacC( 95,109) - dw(328,109)
      JacC( 96, 95) = JacC( 96, 95)+ 0.3300000000000000D+00*dw(328, 95)
      JacC( 96,109) = JacC( 96,109)+ 0.3300000000000000D+00*dw(328,109)
      JacC(105, 95) = JacC(105, 95)+ 0.3300000000000000D+00*dw(328, 95)
      JacC(105,109) = JacC(105,109)+ 0.3300000000000000D+00*dw(328,109)
      JacC(108, 95) = JacC(108, 95) + dw(328, 95)
      JacC(108,109) = JacC(108,109) + dw(328,109)
      JacC(109, 95) = JacC(109, 95) - dw(328, 95)
      JacC(109,109) = JacC(109,109) - dw(328,109)
      JacC(110, 95) = JacC(110, 95) + dw(328, 95)
      JacC(110,109) = JacC(110,109) + dw(328,109)
      JacC(111, 95) = JacC(111, 95) + dw(328, 95)
      JacC(111,109) = JacC(111,109) + dw(328,109)
      JacC( 50, 50) = JacC( 50, 50) - dw(329, 50)
      JacC( 50,109) = JacC( 50,109) - dw(329,109)
      JacC( 53, 50) = JacC( 53, 50) + dw(329, 50)
      JacC( 53,109) = JacC( 53,109) + dw(329,109)
      JacC(109, 50) = JacC(109, 50) - dw(329, 50)
      JacC(109,109) = JacC(109,109) - dw(329,109)
      JacC(110, 50) = JacC(110, 50) + dw(329, 50)
      JacC(110,109) = JacC(110,109) + dw(329,109)
      JacC( 41, 41) = JacC( 41, 41) - dw(330, 41)
      JacC( 41,109) = JacC( 41,109) - dw(330,109)
      JacC( 56, 41) = JacC( 56, 41) + dw(330, 41)
      JacC( 56,109) = JacC( 56,109) + dw(330,109)
      JacC(109, 41) = JacC(109, 41) - dw(330, 41)
      JacC(109,109) = JacC(109,109) - dw(330,109)
      JacC(110, 41) = JacC(110, 41) + dw(330, 41)
      JacC(110,109) = JacC(110,109) + dw(330,109)
      JacC(111, 41) = JacC(111, 41) + dw(330, 41)
      JacC(111,109) = JacC(111,109) + dw(330,109)
      JacC( 42, 42) = JacC( 42, 42) - dw(331, 42)
      JacC( 42,109) = JacC( 42,109) - dw(331,109)
      JacC( 77, 42) = JacC( 77, 42) + dw(331, 42)
      JacC( 77,109) = JacC( 77,109) + dw(331,109)
      JacC( 93, 42) = JacC( 93, 42) + dw(331, 42)
      JacC( 93,109) = JacC( 93,109) + dw(331,109)
      JacC(109, 42) = JacC(109, 42) - dw(331, 42)
      JacC(109,109) = JacC(109,109) - dw(331,109)
      JacC(110, 42) = JacC(110, 42) + dw(331, 42)
      JacC(110,109) = JacC(110,109) + dw(331,109)
      JacC(111, 42) = JacC(111, 42) + dw(331, 42)
      JacC(111,109) = JacC(111,109) + dw(331,109)
      JacC( 52, 52) = JacC( 52, 52) - dw(332, 52)
      JacC( 52,109) = JacC( 52,109) - dw(332,109)
      JacC( 53, 52) = JacC( 53, 52) + dw(332, 52)
      JacC( 53,109) = JacC( 53,109) + dw(332,109)
      JacC(109, 52) = JacC(109, 52) - dw(332, 52)
      JacC(109,109) = JacC(109,109) - dw(332,109)
      JacC(110, 52) = JacC(110, 52) + dw(332, 52)
      JacC(110,109) = JacC(110,109) + dw(332,109)
      JacC( 43, 43) = JacC( 43, 43) - dw(333, 43)
      JacC( 43,109) = JacC( 43,109) - dw(333,109)
      JacC( 56, 43) = JacC( 56, 43) + dw(333, 43)
      JacC( 56,109) = JacC( 56,109) + dw(333,109)
      JacC(109, 43) = JacC(109, 43) - dw(333, 43)
      JacC(109,109) = JacC(109,109) - dw(333,109)
      JacC(110, 43) = JacC(110, 43) + dw(333, 43)
      JacC(110,109) = JacC(110,109) + dw(333,109)
      JacC(111, 43) = JacC(111, 43) + dw(333, 43)
      JacC(111,109) = JacC(111,109) + dw(333,109)
      JacC( 49, 49) = JacC( 49, 49) - dw(334, 49)
      JacC( 49,109) = JacC( 49,109) - dw(334,109)
      JacC( 77, 49) = JacC( 77, 49) + dw(334, 49)
      JacC( 77,109) = JacC( 77,109) + dw(334,109)
      JacC( 78, 49) = JacC( 78, 49)+ 0.2050000000000000D+01*dw(334, 49)
      JacC( 78,109) = JacC( 78,109)+ 0.2050000000000000D+01*dw(334,109)
      JacC( 93, 49) = JacC( 93, 49) + dw(334, 49)
      JacC( 93,109) = JacC( 93,109) + dw(334,109)
      JacC(109, 49) = JacC(109, 49) - dw(334, 49)
      JacC(109,109) = JacC(109,109) - dw(334,109)
      JacC(110, 49) = JacC(110, 49) + dw(334, 49)
      JacC(110,109) = JacC(110,109) + dw(334,109)
      JacC(111, 49) = JacC(111, 49) + dw(334, 49)
      JacC(111,109) = JacC(111,109) + dw(334,109)
      JacC( 45, 54) = JacC( 45, 54) + dw(335, 54)
      JacC( 45,109) = JacC( 45,109) + dw(335,109)
      JacC( 54, 54) = JacC( 54, 54) - dw(335, 54)
      JacC( 54,109) = JacC( 54,109) - dw(335,109)
      JacC(109, 54) = JacC(109, 54) - dw(335, 54)
      JacC(109,109) = JacC(109,109) - dw(335,109)
      JacC(110, 54) = JacC(110, 54) + dw(335, 54)
      JacC(110,109) = JacC(110,109) + dw(335,109)
      JacC( 45, 45) = JacC( 45, 45) - dw(336, 45)
      JacC( 45,109) = JacC( 45,109) - dw(336,109)
      JacC( 46, 45) = JacC( 46, 45) + dw(336, 45)
      JacC( 46,109) = JacC( 46,109) + dw(336,109)
      JacC(109, 45) = JacC(109, 45) - dw(336, 45)
      JacC(109,109) = JacC(109,109) - dw(336,109)
      JacC(110, 45) = JacC(110, 45) + dw(336, 45)
      JacC(110,109) = JacC(110,109) + dw(336,109)
      JacC( 84, 84) = JacC( 84, 84) - dw(337, 84)
      JacC( 84,109) = JacC( 84,109) - dw(337,109)
      JacC( 91, 84) = JacC( 91, 84)+ 0.1800000000000000D+00*dw(337, 84)
      JacC( 91,109) = JacC( 91,109)+ 0.1800000000000000D+00*dw(337,109)
      JacC( 93, 84) = JacC( 93, 84)+ 0.2100000000000000D+00*dw(337, 84)
      JacC( 93,109) = JacC( 93,109)+ 0.2100000000000000D+00*dw(337,109)
      JacC( 96, 84) = JacC( 96, 84)+ 0.6100000000000000D+00*dw(337, 84)
      JacC( 96,109) = JacC( 96,109)+ 0.6100000000000000D+00*dw(337,109)
      JacC(103, 84) = JacC(103, 84)+ 0.7000000000000000D+00*dw(337, 84)
      JacC(103,109) = JacC(103,109)+ 0.7000000000000000D+00*dw(337,109)
      JacC(107, 84) = JacC(107, 84)+ 0.2700000000000000D+00*dw(337, 84)
      JacC(107,109) = JacC(107,109)+ 0.2700000000000000D+00*dw(337,109)
      JacC(108, 84) = JacC(108, 84)+ 0.3000000000000000D-01*dw(337, 84)
      JacC(108,109) = JacC(108,109)+ 0.3000000000000000D-01*dw(337,109)
      JacC(109, 84) = JacC(109, 84) - dw(337, 84)
      JacC(109,109) = JacC(109,109) - dw(337,109)
      JacC(110, 84) = JacC(110, 84) + dw(337, 84)
      JacC(110,109) = JacC(110,109) + dw(337,109)
      JacC(111, 84) = JacC(111, 84) + dw(337, 84)
      JacC(111,109) = JacC(111,109) + dw(337,109)
      JacC(101,101) = JacC(101,101) - dw(338,101)
      JacC(101,111) = JacC(101,111) - dw(338,111)
      JacC(106,101) = JacC(106,101) + dw(338,101)
      JacC(106,111) = JacC(106,111) + dw(338,111)
      JacC(111,101) = JacC(111,101) - dw(338,101)
      JacC(111,111) = JacC(111,111) - dw(338,111)
      JacC(100,101) = JacC(100,101) - dw(339,101)
      JacC(100,100) = JacC(100,100) - dw(339,100)
      JacC(101,101) = JacC(101,101) - dw(339,101)
      JacC(101,100) = JacC(101,100) - dw(339,100)
      JacC(108,101) = JacC(108,101) + dw(339,101)
      JacC(108,100) = JacC(108,100) + dw(339,100)
      JacC(111,101) = JacC(111,101) + dw(339,101)
      JacC(111,100) = JacC(111,100) + dw(339,100)
      JacC(100,101) = JacC(100,101) + dw(340,101)
      JacC(100,105) = JacC(100,105) + dw(340,105)
      JacC(101,101) = JacC(101,101) - dw(340,101)
      JacC(101,105) = JacC(101,105) - dw(340,105)
      JacC(105,101) = JacC(105,101) - dw(340,101)
      JacC(105,105) = JacC(105,105) - dw(340,105)
      JacC(101,101) = JacC(101,101)- 0.2000000000000000D+01*dw(341,101)
      JacC(101,101) = JacC(101,101)- 0.2000000000000000D+01*dw(341,101)
      JacC(101,101) = JacC(101,101) - dw(342,101)
      JacC(101,102) = JacC(101,102) - dw(342,102)
      JacC(102,101) = JacC(102,101) - dw(342,101)
      JacC(102,102) = JacC(102,102) - dw(342,102)
      JacC(110,101) = JacC(110,101) + dw(342,101)
      JacC(110,102) = JacC(110,102) + dw(342,102)
      JacC(101,101) = JacC(101,101) - dw(343,101)
      JacC(101,109) = JacC(101,109) - dw(343,109)
      JacC(109,101) = JacC(109,101) - dw(343,101)
      JacC(109,109) = JacC(109,109) - dw(343,109)
      JacC(110,101) = JacC(110,101) + dw(343,101)
      JacC(110,109) = JacC(110,109) + dw(343,109)
      JacC( 90, 90) = JacC( 90, 90) - dw(344, 90)
      JacC( 90,102) = JacC( 90,102) - dw(344,102)
      JacC( 91, 90) = JacC( 91, 90) + dw(344, 90)
      JacC( 91,102) = JacC( 91,102) + dw(344,102)
      JacC(102, 90) = JacC(102, 90) - dw(344, 90)
      JacC(102,102) = JacC(102,102) - dw(344,102)
      JacC(110, 90) = JacC(110, 90) + dw(344, 90)
      JacC(110,102) = JacC(110,102) + dw(344,102)
      JacC(111, 90) = JacC(111, 90) + dw(344, 90)
      JacC(111,102) = JacC(111,102) + dw(344,102)
      JacC( 90, 90) = JacC( 90, 90) - dw(345, 90)
      JacC( 90,111) = JacC( 90,111) - dw(345,111)
      JacC(106, 90) = JacC(106, 90) + dw(345, 90)
      JacC(106,111) = JacC(106,111) + dw(345,111)
      JacC(111, 90) = JacC(111, 90) - dw(345, 90)
      JacC(111,111) = JacC(111,111) - dw(345,111)
      JacC( 90, 90) = JacC( 90, 90) - dw(346, 90)
      JacC( 90,100) = JacC( 90,100) - dw(346,100)
      JacC( 91, 90) = JacC( 91, 90) + dw(346, 90)
      JacC( 91,100) = JacC( 91,100) + dw(346,100)
      JacC(100, 90) = JacC(100, 90) - dw(346, 90)
      JacC(100,100) = JacC(100,100) - dw(346,100)
      JacC(108, 90) = JacC(108, 90) + dw(346, 90)
      JacC(108,100) = JacC(108,100) + dw(346,100)
      JacC(111, 90) = JacC(111, 90) + dw(346, 90)
      JacC(111,100) = JacC(111,100) + dw(346,100)
      JacC( 90, 90) = JacC( 90, 90) - dw(347, 90)
      JacC( 90,105) = JacC( 90,105) - dw(347,105)
      JacC( 91, 90) = JacC( 91, 90) + dw(347, 90)
      JacC( 91,105) = JacC( 91,105) + dw(347,105)
      JacC(100, 90) = JacC(100, 90) + dw(347, 90)
      JacC(100,105) = JacC(100,105) + dw(347,105)
      JacC(105, 90) = JacC(105, 90) - dw(347, 90)
      JacC(105,105) = JacC(105,105) - dw(347,105)
      JacC( 90, 90) = JacC( 90, 90) - dw(348, 90)
      JacC( 90,109) = JacC( 90,109) - dw(348,109)
      JacC( 91, 90) = JacC( 91, 90) + dw(348, 90)
      JacC( 91,109) = JacC( 91,109) + dw(348,109)
      JacC(109, 90) = JacC(109, 90) - dw(348, 90)
      JacC(109,109) = JacC(109,109) - dw(348,109)
      JacC(110, 90) = JacC(110, 90) + dw(348, 90)
      JacC(110,109) = JacC(110,109) + dw(348,109)
      JacC(111, 90) = JacC(111, 90) + dw(348, 90)
      JacC(111,109) = JacC(111,109) + dw(348,109)
      JacC( 98, 98) = JacC( 98, 98) - dw(349, 98)
      JacC( 98,105) = JacC( 98,105) - dw(349,105)
      JacC(100, 98) = JacC(100, 98) + dw(349, 98)
      JacC(100,105) = JacC(100,105) + dw(349,105)
      JacC(104, 98) = JacC(104, 98) + dw(349, 98)
      JacC(104,105) = JacC(104,105) + dw(349,105)
      JacC(105, 98) = JacC(105, 98) - dw(349, 98)
      JacC(105,105) = JacC(105,105) - dw(349,105)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
